<?php
/*
Plugin Name: WPDM - Multi-Level Affiliates
Plugin URL: https://www.wpdownloadmanager.com/download/multilevel-affiliates/
Description: Multi-Level Affiliates Plugins for WordPress
Version: 1.4.2
Author: WordPress Download Manager
Author URI: https://www.wpdownloadmanager.com/
*/
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
    die;
}
if(!defined('MLM_TD')) {
    define('MLM_TD', 'multilevel_marketing');
}
if(!class_exists('MultiLevelAffiliates')):
require_once __DIR__.'/libs/functions.php';
class MultiLevelAffiliates {
    private static $instance;
    private static $site_url;
    private static $site_dir;

    public static function getInstance() {
        if(self::$instance === null) {
            self::$instance = new self;
            self::$instance->actions();
            self::$site_dir =  dirname(__FILE__);
            self::$site_url = WP_PLUGIN_URL . '/' . basename(self::$site_dir);

        }
        return self::$instance;
    }

    private function __construct() { /* Do nothing here */ }
    public function __clone() { _doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; huh?', MLM_TD ), '2.1' ); }
    public function __wakeup() { _doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; huh?', MLM_TD ), '2.1' ); }

    private function actions(){
        register_activation_hook(__FILE__, array($this, 'activate'));
        register_deactivation_hook(__FILE__, array($this, 'deactivate'));

        add_action('wp_ajax_save_trackback',array($this,'save_trackback'),10,1);
        add_action('wp_ajax_ml_payout_req',array($this,'payout_calls'),10,1);

        if(is_admin()){
            add_action('admin_menu', array($this, 'add_menus'),100);
            add_action('admin_enqueue_scripts', array($this,'admin_register_scripts'));

            //pagewise css and js
            add_action('admin_print_scripts-subscription_page_wpmp-affiliate-level', array($this,'admin_scripts') );
            add_action('admin_print_styles-subscription_page_wpmp-affiliate-level',array($this,'admin_styles'));

            //register settings
            add_action( 'admin_init', array($this,'registerSettings'), 100 );
        }
        if(!is_admin()) {
            //frontend account page hook
            add_action('init',array($this,'affiliate_track'),1);
            //add_action('wp',array($this,'payout_calls'));

            add_shortcode('ml_affiliate_frontend',array($this,'shortcodeFrontend'));

            add_filter('wpdm_user_dashboard_menu', array($this, 'udbMenu'));

            //successfull checkout hook
            //located in functions.php under function wpmp_ipnChangeMembershipLevel()

            add_action('wpdmpp_payment_completed',array($this,'affiliate_process'),10,1);

            add_action('wpdm_before_placing_order',array($this,'referrerCheck'),10,1);

            add_action('wpdm_frontend',array($this,'add_frontend_tab'),10,1);

        }


    }

    public function udbMenu($menus){
        $c = count($menus);
        $tmenus['affiliates'] = array('name'=> __('Affiliates','wpdmpro'), 'callback' => array($this, 'shortcodeFrontend'));
        $menus = array_merge(array_slice($menus, 0, $c-1), $tmenus, array_slice($menus, $c-1));
        return $menus;
    }


    public function activate(){
        global $wpdb;

        $sqls[] = "CREATE TABLE IF NOT EXISTS `{$wpdb->prefix}affiliate_visitors` (
                  `id` int(11) NOT NULL AUTO_INCREMENT,
                  `affid` varchar(40) COLLATE utf8_unicode_ci NOT NULL,
                  `referer` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
                  `ip` varchar(40) COLLATE utf8_unicode_ci NOT NULL,
                  `landing` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
                  `date` int(11) NOT NULL,
                  PRIMARY KEY (`id`)
                )";


        $sqls[] = 'CREATE TABLE `' . $wpdb->prefix .'affiliate_level` (
                    `id` int(11) NOT NULL AUTO_INCREMENT,
                    `level_name` varchar(100) COLLATE utf8_unicode_ci NOT NULL,
                    `depth` int(11) NOT NULL,
                    `level_cost` varchar(500) COLLATE utf8_unicode_ci NOT NULL,
                    `updated` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
                    PRIMARY KEY (`id`)
                  )';

        $sqls[] = 'CREATE TABLE `' . $wpdb->prefix .'affiliate_referer` (
                `id` int(11) NOT NULL AUTO_INCREMENT,
                `user_id` int(11) NOT NULL,
                `referer_id` int(11) NOT NULL,
                `depth` int(11) NOT NULL,
                `product` varchar(250) COLLATE utf8_unicode_ci NOT NULL,
                `amount` decimal(10,2) NOT NULL,
                `payout` int(1) NOT NULL DEFAULT 0,
                `updated` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                PRIMARY KEY (`id`)
              ) DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci AUTO_INCREMENT=1 ;
              ';
        $sqls[] = 'CREATE TABLE `' . $wpdb->prefix .'affiliate_payout` (
                    `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
                    `user_id` int(10) unsigned NOT NULL,
                    `amount` decimal(10,2) NOT NULL,
                    `status` int(2) NOT NULL,
                    `updated` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                    UNIQUE KEY `id` (`id`)
                  ) DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci AUTO_INCREMENT=1 ;';

        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );


        foreach($sqls as $key => $sql){
            $wpdb->query($sql);
           //dbDelta( $sql );
        }
    }

    public function deactivate() {

    }

    public function add_menus(){
        add_menu_page(__('Multilevel Affiliates',MLM_TD), __('ML Affiliates',MLM_TD), 'manage_options', 'multilevel-affiliates', array($this,'affiliateSettings'), self::$site_url . '/assets/icon.png');

        add_submenu_page('multilevel-affiliates', __('Multilevel Affiliates', MLM_TD), __('Level Settings', MLM_TD),'manage_options', 'multilevel-affiliates', array($this,'affiliateSettings'));
        add_submenu_page('multilevel-affiliates', __('MultiLevel Affiliate Commission', MLM_TD), __('Affiliate Commission', MLM_TD),'manage_options', 'wpmp-affiliate-commission', array($this,'wpmp_affiliate_commission'));
        add_submenu_page('multilevel-affiliates', __('MultiLevel Affiliate Payouts', MLM_TD), __('Affiliate Payouts', MLM_TD),'manage_options', 'wpmp-affiliate-payouts', array($this,'wpmp_affiliate_payouts'));

        //add_submenu_page('multilevel-affiliates', __('MultiLevel Affiliate Settings', MLM_TD), __('Affliate Settings', MLM_TD),'manage_options', 'multilevel-affiliates', array($this,'affiliateSettings'));

    }

    function admin_register_scripts() {
        /** Register datatables script and stylesheet for admin pages */
        //die('came here');
        //wp_deregister_script('datatables');
        wp_register_script('datatables',
                   self::$site_url . '/assets/datatables/js/jquery.dataTables.min.js',
                   array('jquery'),
                   '1.7.4' );

        //wp_deregister_style('datatables');
        wp_register_style('datatables', self::$site_url . '/assets/datatables/css/style.css');

        /** Register autocomplete script and stylesheet for admin pages */
        //wp_deregister_script('autocomplete');
        wp_register_script('autocomplete',
                   self::$site_url . '/assets/autocomplete/jquery.autocomplete.js',
                   array('jquery'),
                   '3.2.2' );

        //wp_deregister_style('autocomplete');
        wp_register_style('autocomplete', self::$site_url . '/assets/autocomplete/jquery.autocomplete.css');
    }
    public function admin_scripts(){
        wp_enqueue_script('jquery');
        wp_enqueue_script('datatables');
    }

    public function admin_styles(){
        wp_enqueue_style('datatables');
    }


    public function registerSettings(){
        register_setting( 'ml_affiliate_settings_group', 'ml_affiliate_settings' );
    }

    public function wpmp_affiliate_commission(){
        if(!class_exists('AffiliateFunctions')){
            require_once __DIR__.'/libs/affiliatefunctions.php';
        }
        $aff = new AffiliateFunctions();
        echo "<div class='wrap'>";
        echo $aff->showAll();
        echo "</div>";
    }

    public function wpmp_affiliate_payouts(){
        if(!class_exists('AffiliateCommission')){
                require_once __DIR__.'/libs/affiliatecommission.php';
        }
        $aff = new affiliateCommission();
        //echo $aff->showAll();
    }

    public function affiliateSettings() {
        if(!class_exists('AffiliateSettings')){
                require_once __DIR__.'/libs/affiliatesettings.php';
        }
        $aff = new AffiliateSettings();
    }

    public function add_frontend_tab($tabs){
        $tabs['affiliate'] = array('label' => 'Manage Affiliates', 'callback' => array($this, 'manage_frontned_affiliates'));
        return $tabs;
    }

    public function manage_frontned_affiliates(){
        global $current_user;
        if(isset($_POST['ml_affiliate_settings']))
            update_user_meta($current_user->ID, 'ml_affiliate_settings', $_POST['ml_affiliate_settings']);
        $data = get_user_meta($current_user->ID, 'ml_affiliate_settings', true);
        if(!$data) $data = array('depth' => 1, 'level_cost' => array(0,0,0,0,0,0));
        require_once \WPDM\__\Template::locate("manage-frontned-affiliates.php", __DIR__.'/tpls'.WPDM()->bsversion.'/');
    }


    //withdraw money from paypal notification
    public function wpmp_withdraw_paypal_notification(){
        if(isset($_REQUEST['action']) && $_REQUEST['action']=="withdraw_paypal_notification"){

            if(isset($_POST["txn_id"]) && isset($_POST["txn_type"])&& $_POST["status"]=="Completed"){
                global $wpdb;
                $wpdb->update(
                    $wpdb->prefix .'affiliate_payout',
                    array(
                        'status' => 1
                    ),
                    array('id'=>$_POST['custom']),
                    array(
                        '%d'
                    ),
                    array( '%d' )
                );
            }
        }
    }

    public function referrerCheck($order_id){
        global $wpdb;
        if(is_user_logged_in()){
            $user_id = get_current_user_id();

            if($user_id && isset($_COOKIE['wpsaff']) && $_COOKIE['wpsaff'] != '') {
                $ref_user_id = $wpdb->get_var( $wpdb->prepare( "SELECT user_id from $wpdb->usermeta WHERE meta_key = '_wp_membership_affiliate_id' and meta_value=%s", $_COOKIE['wpsaff'] ) );
                if(get_user_meta($user_id, '_wp_membership_affiliate_referer', true) == ""){
                    add_user_meta($user_id, '_wp_membership_affiliate_referer', $ref_user_id,true);
                    add_user_meta($user_id, '_wp_membership_new_affiliate', '1', true);
                }

                unset($_COOKIE['wpsaff']);
                setcookie('wpsaff', '', time() - 3600); // empty value and old timestamp
            }
        }
    }

    function affiliate_preprocess($order_id)
    {

    }

    public function affiliate_process($order_id){
        //echo "I'm here...";
        if(!class_exists('AffiliateFunctions')){
            require_once __DIR__.'/libs/affiliatefunctions.php';
        }
        global $wpdb;

        $order = new \WPDMPP\Libs\Order();
        $order_data = $order->GetOrder($order_id);
        $new_user = get_user_meta($order_data->uid, '_wp_membership_new_affiliate', true);
        //wpdmprecho($_COOKIE);
        //wpdmdd($new_user);
        if( (int)$new_user == 1){
            //update_user_meta($order_data->uid, '_wp_membership_new_affiliate', '2');
            $aff = new AffiliateFunctions();
            $aff->calculateAffiliate($order_id, $order_data->uid, $order_data->total);


        }


    }

    public function affiliate_track() {
        //print_r($_COOKIE);
        global $wpdb;
        if ((isset($_GET['wpsaff']) and $_GET['wpsaff'] != '')) {
            $affid = $_GET['wpsaff'];

            //if ($_COOKIE['wpsaff'] == '') {
            setcookie("wpsaff", $affid, strtotime("+60 days"), "/");
            $opname = str_replace(".", "_", $_SERVER['REMOTE_ADDR']);
            update_option($opname, array('wpsaff' => $affid, 'expire' => strtotime("+60 days")));
            //}

            $wpdb->insert(
                $wpdb->prefix.'afl_visitors',
                array(

                    'affid' => $affid,
                    'referer' => $_SERVER['HTTP_REFERER'],
                    'ip' => $_SERVER['REMOTE_ADDR'],
                    'landing' => $_SERVER['REQUEST_URI'],
                    'date' => time()
                ),
                array(
                    '%s',
                    '%s',
                    '%s',
                    '%s',
                    '%d'
                )
            );
            $tmp = explode("?", $_SERVER['REQUEST_URI']);
            header("location: " . array_shift($tmp));
            die();
        }
    }

    function trackbackSignup($cid){
        global $wpdb;
        if(!isset($_COOKIE['wpsaff'])) return;
        $rid = $wpdb->get_var( $wpdb->prepare( "SELECT user_id from $wpdb->usermeta WHERE meta_key = '_wp_membership_affiliate_id' and meta_value=%s", $_COOKIE['wpsaff'] ) );
        if(!$rid) return;
        $user = get_user_by('id', $cid);
        $track = get_user_meta($rid, '__wpdmaff_trackback', true);
        if(!isset($track['signup'])) return;
        $trackbacksale = $track['signup'];
        $order = new \WPDMPP\Libs\Order();
        $trackbacksale = str_replace(array('{name}', '{email}', '{date}'), array( $user->display_name, $user->user_email, time() ), $trackbacksale);
        return wpdm_remote_get($trackbacksale);
    }

    public function payout_calls(){
        if(isset($_POST['affiliate_payout_request']) && $_REQUEST['affiliate_payout_request']==1){

            if(is_user_logged_in()){
                if(!class_exists('AffiliateFunctions')){
                    require_once __DIR__.'/libs/affiliatefunctions.php';
                }
                $aff = new AffiliateFunctions();
                $aff->affiliateRequestForUser();
            }
        }
        if(isset($_POST['affiliate_paypal_email']) && $_POST['affiliate_paypal_email']==1 ){
            $email = $_POST['affiliate_paypal_email_data'];
            global $current_user;
            if(is_email($email) && $current_user->ID){
                update_user_meta($current_user->ID, '_wp_membership_affiliate_paypal', $email);
                wp_send_json(['success' => true, 'message' => 'Email Updated Successfully!']);
            }
            wp_send_json(['success' => false, 'message' => 'Invalid Email Address!']);
        }
    }

    function save_trackback(){
        if(is_user_logged_in() && isset($_POST['track'])){
            update_user_meta(get_current_user_id(), '__wpdmaff_trackback', $_POST['track']);
            die('Saved!');
        }
    }



    public function shortcodeFrontend(){

        $title = __('MultiLevel Affiliate Program',MLM_TD);
        $ret = "";
        //get user affiliate id
        if(is_user_logged_in()){
            global $current_user,$wpdb;
            $aff_id = get_user_meta($current_user->ID,'_wp_membership_affiliate_id',true);
            //echo "<pre>"; print_r($user_query); echo  "</pre>";
            if($aff_id==""){
                //generate aff_id
                while(1){
                    //checking for unique id
                    $aff_id = uniqid_base36(true);
                    $user = $wpdb->get_var( $wpdb->prepare( "SELECT user_id from $wpdb->usermeta WHERE user_id = %d and meta_key = '_wp_membership_affiliate_id' and meta_value=%s", $current_user->ID,$aff_id ) );

                    //$user_query = new WP_User_Query( array( 'meta_key' => '_wp_membership_affiliate_id', 'meta_value' => $aff_id, 'meta_compare' => '=' ));
                    //if($user_query->total_users==0) break;
                    if($user == NULL || $user == "") break;
                }
                update_user_meta($current_user->ID, '_wp_membership_affiliate_id', $aff_id);
            }

             $url = site_url("?wpsaff=$aff_id");
            $length = strlen($url);

            if(!class_exists('AffiliateFunctions')){
                require_once __DIR__.'/libs/affiliatefunctions.php';
            }
            $aff = new AffiliateFunctions();
            $data = $aff->affiliateGraph();

            $visual = $data['js'];
            $messages = $data['btn'];
            $table = $data['table'];
            if($table=="") {
                $table = "No Records Found...";
            }
            if($visual==""){
                $visual="No Records Found...";
            }

            $paypal = get_user_meta($current_user->ID, '_wp_membership_affiliate_paypal', true);

            ob_start();
            include \WPDM\__\Template::locate("affiliate-overview.php", __DIR__.'/tpls'.WPDM()->bsversion.'/');
            $ret =  ob_get_clean();

        }

        else {
            $ret = __('Please Login',MLM_TD);
        }

        //echo "<pre>"; print_r(wpmp_getAllLevels()); echo  "</pre>";



        return $ret;
    }




    }



MultiLevelAffiliates::getInstance();

endif;
