<?php
/*
  Plugin Name: WPDM - Active Campaign Subscription
  Plugin URL: https://www.wpdownloadmanager.com/download/activecampaign-subscription/
  Description: Active Campaign Email Subscription Addon for WordPress Download Manager
  Version: 3.1.0
  Author: WordPress Download Manager
  Author URI: https://www.wpdownloadmanager.com/
 */

if (!defined('WPINC')) {
    die;
}


class WpdmActiveCampaign
{

    private static $instance;
    private $dir, $url;
    public $api_endpoint;
    public $api_token = false;
    public $conn_error = false;

    private function __construct()
    {
        $list_id = get_post_meta(get_the_ID(), '__wpdm_ac_list', true);

        $options = get_option('wpdm_ActiveCampaign');
        $this->api_endpoint = wpdm_valueof($options, 'listurl') . '/api/3/';
        $this->api_token = wpdm_valueof($options, 'token');
    }

    function searchTags()
    {
        $tags = $this->getTags(wpdm_query_var('kwrd'));
        $data = [];
        if (is_array($tags)) :
            foreach ($tags as $tag) {
                $data[] = ['value' => $tag->id.":".$tag->tag, 'name' => $tag->tag];
            }
        endif;
            wp_send_json($data);
        die();
    }

    function isJson($string)
    {
        json_decode($string);
        return (json_last_error() == JSON_ERROR_NONE);
    }

    function _get($action)
    {
        if (!$this->api_token) {
            $this->conn_error = true;
            return false;
        }
        $url = $this->api_endpoint . $action;
        $response = wpdm_remote_get($url, ['Api-Token' => $this->api_token]);
        if ($this->isJson($response)) $response = json_decode($response);
        return $response;
    }

    function _post($action, $data)
    {
        if (!$this->api_token) {
            $this->conn_error = true;
            return false;
        }
        $endpoint = $this->api_endpoint . $action;

        $data = wp_json_encode($data);

        $options = [
            'body' => $data,
            'headers' => [
                'Content-Type' => 'application/json',
                'Api-Token' => $this->api_token
            ],
            'timeout' => 60,
            'redirection' => 5,
            'blocking' => true,
            'httpversion' => '1.0',
            'sslverify' => false,
            'data_format' => 'body',
        ];

        $response = wp_remote_post($endpoint, $options);
        $response = wp_remote_retrieve_body($response);
        //$response = wpdm_remote_post($url,  $data, ['Api-Token' => $this->api_token]);
        if ($this->isJson($response)) $response = json_decode($response);
        return $response;
    }

    function getLists()
    {
        $lists = $this->_get('lists');
        if (!is_object($lists) || !isset($lists->lists)) {
            $this->conn_error = true;
            return false;
        }
        return $lists->lists;
    }

    function getTags($search = '')
    {
        if ($search !== '') $search = "?search={$search}";
        $tags = $this->_get('tags' . $search);
        if (!is_object($tags) || !isset($tags->tags)) {
            $this->conn_error = true;
            return false;
        }
        return $tags->tags;
    }

    function addContact($contact, $list = 0, $tags = [])
    {
        $contact = ['contact' => $contact];
        $response = $this->_post('contact/sync', $contact);
        $contact_id = $response->contact->id;
        if ($list > 0) {
            $response = $this->_post("contactLists", ['contactList' => ['contact' => $contact_id, 'list' => $list, 'status' => 1]]);
        }

        if (count($tags) > 0) {
            foreach ($tags as $tag) {
                $response = $this->_post("contactTags", ['contactTag' => ['contact' => $contact_id, 'tag' => $tag]]);
            }
        }
        return $response;
    }

    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
            self::$instance->actions();
            self::$instance->dir = dirname(__FILE__);
            self::$instance->url = WP_PLUGIN_URL . '/' . basename(self::$instance->dir);
        }
        return self::$instance;
    }

    private function actions()
    {
        register_activation_hook(__FILE__, array($this, 'activate'));
        register_deactivation_hook(__FILE__, array($this, 'deactivate'));

        if (is_admin()) {

            add_action("admin_enqueue_scripts", [$this, 'enqueueScripts']);
            add_action("wp_ajax_wpdm_activecamp_tags", [$this, 'searchTags']);

            add_filter('add_wpdm_settings_tab', array($this, 'settings_tab_ActiveCampaign'));
            add_action('wpdm_custom_form_field', array($this, 'list_selection'));
        }

        add_action('wpdm_before_email_download_link', array($this, 'pushToActiveCampaign'), 10, 2);
    }

    function enqueueScripts()
    {
        if (wpdm_query_var('post_type') === 'wpdmpro' && wpdm_query_var('page') === 'settings') {
            wp_enqueue_script('jquery-ui-core');
            wp_enqueue_script('jquery-ui-autocomplete');
        }

    }


    function list_selection()
    {

        $list_id = get_post_meta(get_the_ID(), '__wpdm_ac_list', true);
        $tag_ids = get_post_meta(get_the_ID(), '__wpdm_ac_tags', true);

        $options = get_option('wpdm_ActiveCampaign');
        $api_key = isset($options['token']) ? $options['token'] : '';
        $list_url = isset($options['listurl']) ? $options['listurl'] : '';


        $lists = $this->getLists();
        //$tags = $this->getTags();

        ?>

        <fieldset style="margin: 10px 0">
            <div class="form-group">
                <legend>Active Campaign List & Tags</legend>
                <label>Select List:</label><br/>
                <select class="form-control" name="file[ac_list]" id="ac_list" style="width: 300px">
                    <option value="">Use Global Selection</option>
                    <?php
                    if (is_array($lists)) :
                        foreach ($lists as $list) {
                            if (isset($list->id)) {
                                echo "<option value='$list->id' " . selected($list_id, $list->id, false) . ">$list->name</option>";
                            }
                        }
                    endif;
                    ?>
                </select>
            </div>

            <div class="form-group">

                <label for="list_id">Select Tags</label>

                <div class="panel panel-default" style="border-top: 1px solid #dddddd !important;margin: 5px 0 0 0 !important;">
                    <div class="panel-body">
                        <div id="camptags" class="list-group" style="margin: 0">
                            <?php
                            if (is_array($tag_ids)) :
                            foreach ($tag_ids as $tag_id){
                                $uniq = uniqid();
                                ?>
                                <div class="list-group-item" id="<?=$uniq; ?>"><input type="hidden" name="file[ac_tags][]" value="<?=$tag_id ?>"> <a class="uaco-del pull-right" onclick="jQuery(this.rel).remove()" rel="#<?=$uniq; ?>"><i class="far fa-times-circle"></i></a><?=$tag_id ?></div>
                            <?php }
                            endif;
                            ?>
                        </div>
                    </div>
                    <div class="panel-footer">
                        <input type="text" class="form-control" id="srctags" placeholder="Search Tag..." />
                    </div>
                </div>
            </div>
        </fieldset>
        <style>#ac_list_chosen {
                min-width: 300px;
            }</style>

        <script>
            jQuery(function ($) {

                function split(val) {
                    return val.split(/,\s*/);
                }

                function extractLast(term) {
                    return split(term).pop();
                }

                $("#srctags")
                    .bind("keydown", function (event) {
                        if (event.keyCode === $.ui.keyCode.TAB &&
                            $(this).data("ui-autocomplete").menu.active) {
                            event.preventDefault();
                        }
                    })
                    .autocomplete({
                        source: function (request, response) {
                            $.getJSON(ajaxurl, {
                                action: 'wpdm_activecamp_tags',
                                kwrd: extractLast(request.term)
                            }, response);
                        },
                        search: function () {

                            var term = extractLast(this.value);
                            if (term.length < 2) {
                                return false;
                            }
                        },
                        focus: function () {

                            return false;
                        },
                        select: function (event, ui) {
                            $('#camptags').prepend('<div  class="list-group-item" id="uaco-' + ui.item.value.replace(/[^a-zA-Z]/ig, '-') + '"><input type="hidden" name="file[ac_tags][]" value="' + ui.item.value + '" /> <a class="uaco-del pull-right" onclick="jQuery(this.rel).remove()" rel="#uaco-' + ui.item.value.replace(/[^a-zA-Z]/ig, '-') + '"><i class="far fa-times-circle"></i></a>' + ui.item.value + '</div>');
                            this.value = "";
                            return false;
                        }
                    });


            })
        </script>

        <?php
    }

    function settings_tab_ActiveCampaign($tabs)
    {
        $tabs['active-campaign'] = wpdm_create_settings_tab('active-campaign', 'Active Campaign', array($this, 'settingsActiveCampaign'), 'fa fa-envelope');
        return $tabs;
    }

    public function activate()
    {
        if (false == get_option('wpdm_ActiveCampaign')) {
            $option = array('key' => '');
            add_option('wpdm_ActiveCampaign', $option);
        }
    }

    public function deactivate()
    {

    }

    public function settingsActiveCampaign()
    {

        if (isset($_POST['api_key'])) {
            $options['token'] = stripslashes($_POST['api_key']);
            $options['listid'] = stripslashes($_POST['list_id']);
            $options['listurl'] = stripslashes($_POST['list_url']);
            $options['tagids'] = $_POST['tagids'];

            update_option('wpdm_ActiveCampaign', $options);

            die('Settings Saved Successfully.');
        }

        $options = get_option('wpdm_ActiveCampaign');
        $api_key = isset($options['token']) ? $options['token'] : '';
        $list_id = isset($options['listid']) ? $options['listid'] : '';
        $tag_ids = isset($options['tagids']) ? $options['tagids'] : '';
        $list_url = isset($options['listurl']) ? $options['listurl'] : '';
        $lists = $this->getLists();
        $tags = $this->getTags();

        ?>
        <div class="panel panel-default">
            <div class="panel-heading">Active Campaign Authentication</div>
            <?php
            if ($this->conn_error) { ?>
                <div class="panel-heading text-danger bg-white" style="font-weight: 400"><i class="fa fa-exclamation-triangle"></i> Access denied: Invalid credentials (URL and/or API key)
                </div>
                <?php
            } else { ?>
                <div class="panel-heading bg-white font-weight-normal" style="font-weight: 400"><i class="fa fa-check-double color-green"></i> You are successfully connected to the ActiveCampaign service!
                </div>
                <?php
            }
            ?>
            <div class="panel-body">
                <div class="form-group">
                    <label for="">API URL</label>
                    <input class="form-control" type="text" name="list_url" id="url" value="<?php echo $list_url; ?>"
                           placeholder="Enter Active Campaign API URL">
                </div>
                <div class="form-group">
                    <label for="api_key">API Key</label>
                    <input class="form-control" type="text" name="api_key" id="api_key" value="<?php echo $api_key; ?>"
                           placeholder="Enter Active Campaign API key">
                    <p class="help-block">Get your API URL and API key from the Settings > Developer > API Access</p>
                </div>
                <div class="form-group">
                    <label for="list_id">Select List</label>
                    <select class="form-control" name="list_id" id="list_id">
                        <option value="">No List Selected</option>
                        <?php
                        if (is_array($lists)) :
                            foreach ($lists as $list) {
                                if (isset($list->id)) {
                                    echo "<option value='$list->id' " . selected($list_id, $list->id, false) . ">$list->name</option>";
                                }
                            }
                        endif;
                        ?>
                    </select>
                    <p class="help-block">Save your API URL and key to get the lists dropdown</p>
                </div>
                <div class="form-group">

                    <label for="list_id">Select Tags</label>

                    <div class="panel panel-default" style="border-top: 1px solid #dddddd !important;margin: 5px 0 0 0 !important;">
                        <div class="panel-body">
                            <div id="camptags" class="list-group" style="margin: 0">
                                <?php foreach ($tag_ids as $tag_id){
                                    $uniq = uniqid();
                                    ?>
                                <div class="list-group-item" id="<?=$uniq; ?>"><input type="hidden" name="tagids[]" value="<?=$tag_id ?>"> <a class="uaco-del pull-right" onclick="jQuery(this.rel).remove()" rel="#<?=$uniq; ?>"><i class="far fa-times-circle"></i></a><?=$tag_id ?></div>
                                <?php } ?>
                            </div>
                        </div>
                        <div class="panel-footer">
                            <input type="text" class="form-control" id="srctags" placeholder="Search Tag..." />
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <script>
            jQuery(function ($) {

                function split(val) {
                    return val.split(/,\s*/);
                }

                function extractLast(term) {
                    return split(term).pop();
                }

                $("#srctags")
                    .bind("keydown", function (event) {
                        if (event.keyCode === $.ui.keyCode.TAB &&
                            $(this).data("ui-autocomplete").menu.active) {
                            event.preventDefault();
                        }
                    })
                    .autocomplete({
                        source: function (request, response) {
                            $.getJSON(ajaxurl, {
                                action: 'wpdm_activecamp_tags',
                                kwrd: extractLast(request.term)
                            }, response);
                        },
                        search: function () {

                            var term = extractLast(this.value);
                            if (term.length < 2) {
                                return false;
                            }
                        },
                        focus: function () {

                            return false;
                        },
                        select: function (event, ui) {
                            $('#camptags').prepend('<div  class="list-group-item" id="uaco-' + ui.item.value.replace(/[^a-zA-Z]/ig, '-') + '"><input type="hidden" name="tagids[]" value="' + ui.item.value + '" /> <a class="uaco-del pull-right" onclick="jQuery(this.rel).remove()" rel="#uaco-' + ui.item.value.replace(/[^a-zA-Z]/ig, '-') + '"><i class="far fa-times-circle"></i></a>' + ui.item.value + '</div>');
                            this.value = "";
                            return false;
                        }
                    });

                /*$('#srctags').autocomplete({
                    source: function (request, response) {
                        console.log(request);
                        $.get(ajaxurl, {action: 'wpdm_activecamp_tags', kwrd: request.term}, function (tags) {
                            $('select#tags').html(tags);
                            $('select#tags').trigger("chosen:updated");
                        });
                    }
                });*/
            })
        </script>
        <?php
    }

    public function pushToActiveCampaign($post, $file)
    {
        $name = $post['name'];

        if (strpos($name, ' ')) {
            $names = explode(' ', $name);
            $first_name = $names[0];
            $last_name = $names[1];
        } else {
            $first_name = $name;
            $last_name = $name;
        }


        $email = $post['email'];

        if (is_email($email)) {
            $option = get_option('wpdm_ActiveCampaign');
            $global_list_id = $option['listid'];
            $global_tag_ids = $option['tagids'];

            $post_list_id = get_post_meta($post['__wpdm_ID'], '__wpdm_ac_list', true);
            $post_tag_ids = get_post_meta($post['__wpdm_ID'], '__wpdm_ac_tags', true);
            if ($post_list_id == '' || !isset($post_list_id))
                $list_id = $global_list_id;
            else
                $list_id = $post_list_id;

            if(!$list_id)
                return;

            if (!$post_tag_ids || count($post_tag_ids) === 0)
                $tags = $global_tag_ids;
            else
                $tags = $post_tag_ids;

            $lists = $this->getLists();

            if(is_array($tags)) {
                foreach ($tags as &$tag) {
                    $tag = explode(":", $tag);
                    $tag = $tag[0];
                }
            }


            if ($this->conn_error) {
                echo "<p>Access denied: Invalid credentials (URL and/or API key).</p>";
                exit();
            }

            $contact = array(
                "email" => $email,
                "first_name" => $first_name,
                "last_name" => $last_name,
            );
            $this->addContact($contact, $list_id, $tags);

        }
    }

}

if (function_exists('WPDM'))
    WpdmActiveCampaign::getInstance();
