<?php
/*
Plugin Name: WPDM - Constant Contact
Plugin URL: http://www.wpdownloadmanager.com/
Description: Constant Contact Add-on for Download Manager Plugin
Version: 1.2.2
Author: Shaon
Author URI: http://www.wpdownloadmanager.com/
*/

if (!defined('WPINC')) {
    die;
}

class WpdmEmailConstantContact
{
    private static $instance;
    private $dir, $url, $api, $error;

    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
            self::$instance->dir = dirname(__FILE__);
            self::$instance->url = WP_PLUGIN_URL . '/' . basename(self::$instance->dir);
            if (!class_exists('WPDM_CONSTANT_CONTACT_API'))
                require_once self::$instance->dir . '/class.cc.php';
            $options = get_option('wpdm_email_constant_contact');
            $username = isset($options['cc_username']) ? $options['cc_username'] : '';
            $password = isset($options['cc_userpass']) ? $options['cc_userpass'] : '';
            if ($username != '' && $password != '') {
                // Create a new instance
                $new_cc = new WPDM_CONSTANT_CONTACT_API($username, $password);

                // Run a generic check to see if we can connect
                $new_cc->get_service_description();

                /**
                 * Test the instance to make sure it is valid
                 */
                if (is_object($new_cc) && (empty($new_cc->last_error) || (isset($new_cc->http_response_code) && $new_cc->http_response_code === 200))) {
                    //everything is good
                    self::$instance->api = &$new_cc;
                } else {
                    self::$instance->api = null;
                }
            } else {
                self::$instance->api = null;
            }
            self::$instance->actions();
        }
        return self::$instance;
    }

    private function actions()
    {
        //echo "Hello World";

        register_activation_hook(__FILE__, array($this, 'activate'));
        register_deactivation_hook(__FILE__, array($this, 'deactivate'));

        if (is_admin()) {
            add_filter('add_wpdm_settings_tab', array($this, 'wpdmcc_settings_tab'));
            //add_wdm_settings_tab("constant_contact", "Constant Contact", array($this,'settings'));
        }
        if (!is_admin()) {
        }

        add_action('wpdm_before_email_download_link', array($this, 'subscribeHook'), 10, 2);
        add_action('wppromem_user_signup', array($this, 'userSignup'), 10, 2);
    }

    function wpdmcc_settings_tab($tabs)
    {
        $tabs['constant_contact'] = wpdm_create_settings_tab('constant_contact', 'Constant Contact', array($this, 'settings'), $icon = 'fa fa-envelope');
        return $tabs;
    }

    public function activate()
    {
        //        if(false == get_option('wpdm_email_mailchimp')){
        //            $option = array('key'=>'', 'list_id' => '');
        //            add_option('wpdm_email_mailchimp',$option);
        //        }
    }

    public function deactivate()
    {
    }


    public static function getDir()
    {
        return self::$instance->dir;
    }

    public static function getUrl()
    {
        return self::$instance->url;
    }


    public function settings()
    {

        if (isset($_POST['cc_username'])) {
            $options['cc_username'] = stripslashes(trim($_POST['cc_username']));
            $options['cc_userpass'] = stripslashes(trim($_POST['cc_userpass']));
            $options['cc_list_id'] = stripslashes(trim($_POST['cc_list_id']));
            update_option('wpdm_email_constant_contact', $options);
            die('Settings Saved Successfully.. <script> location.reload(); </script>');
        }

        $options = get_option('wpdm_email_constant_contact', array());
        $cc_username = isset($options['cc_username']) ? $options['cc_username'] : '';
        $cc_userpass = isset($options['cc_userpass']) ? $options['cc_userpass'] : '';
        $list_id = isset($options['cc_list_id']) ? $options['cc_list_id'] : '';
        $not_connected_with_api = false;
        $lists = array();

        if ($this->api !== null) {
            //$list = $this->api->getContacts($cc_access_token);
            $lists = $this->api->get_all_lists();
            //var_dump($lists);
            //die();
        } else {
            $not_connected_with_api = true;
        }


?>
        <div class="panel panel-default">
            <div class="panel-heading">
                Constant Contact Account Settings
            </div>
                <div class="panel-heading">
                    <?php if ($not_connected_with_api) { ?>
                    <div class="media" style="font-weight: 400">
                        <div class="pull-left">
                            <i class="fa fa-exclamation-triangle" style="font-size: 36px;color: var(--color-danger);margin-right: 10px"></i>
                        </div>
                        <div class="media-body">
                            <?php echo 'You are not connected with the Constant Contact Service. <br> Please check the email/password on your <a href="http://constantcontact.com/login/" target="_blank">Constant Connect </a> website.'; ?>
                        </div>
                    </div>
                    <?php } else { ?>
                        <div style="font-weight: 400">
                            <i class="fa fa-check-double" style="margin-right: 5px;color: var(--color-success)"></i> You are successfully connected with the Constant Contact!
                        </div>
                    <?php }; ?>
                </div>

            <div class="panel-body">
                <div class="form-group">
                    <label for="cc_username">User Name</label>
                    <input type="text" name="cc_username" class="form-control" id="cc_username" value="<?php echo $cc_username; ?>">
                </div>
                <div class="form-group">
                    <label for="cc_userpass">Password</label>
                    <input type="password" name="cc_userpass" class="form-control" id="cc_userpass" value="<?php echo $cc_userpass; ?>">
                </div>

                <?php if (is_array($lists) && !empty($lists)) : ?>
                    <div class="form-group">
                        <label for="cc_list_id">Constant Contact List</label>
                        <select name="cc_list_id" id="cc_list_id" class="form-control">
                            <?php
                            if ($lists) :
                                foreach ($lists as $key => $value) :
                                    //print_r($value);
                                    echo "<option value='{$value['id']}' " . selected($list_id, $value['id'], false) . ">{$value['Name']}</option>";
                                endforeach;
                            endif;
                            ?>
                        </select>
                    </div>
                <?php endif; ?>
            </div>
        </div>
<?php

    }

    public function subscribeHook($post, $file)
    {
        if(!is_object($this->api)) return;
        $name = isset($post['custom_form_field'], $post['custom_form_field']['name']) ? stripslashes($post['custom_form_field']['name']) : '';
        $email = stripslashes($post['email']);
        $option = get_option('wpdm_email_constant_contact');
        $list_id = $option['cc_list_id'];
        //if email is valid subscribe
        if (is_email($email) && $list_id) {
            //check this mail already exist or not
            $contact = $this->api->query_contacts($email);
            //print_r($contact);
            if (is_array($contact) && !empty($contact)) {
                //update contact
                $updated = $this->api->update_contact($contact['id'], $email, $list_id, []);
            } else {
                //add contact
                $extra = array('FirstName' => $name);
                $contact = $this->api->create_contact($email, $list_id, $extra);
            }
        }
    }

    public function userSignup($user_id, $user_info)
    {
        if(!is_object($this->api)) return;
        $email = stripslashes($user_info['user_email']);
        $option = get_option('wpdm_email_constant_contact');
        $list_id = $option['cc_list_id'];
        //if email is valid subscribe
        if (is_email($email) && $list_id) {
            //check this mail already exist or not
            $contact = $this->api->query_contacts($email);
            //print_r($contact);
            if (is_array($contact) && !empty($contact)) {
                //update contact
                $updated = $this->api->update_contact($contact['id'], $email, $list_id, []);
            } else {
                //add contact
                $extra = array('FirstName' => $user_info['first_name'], 'LastName' => $user_info['last_name']);
                $contact = $this->api->create_contact($email, $list_id, $extra);
            }
        }
    }
}

if (defined('WPDM_Version'))
    WpdmEmailConstantContact::getInstance();
