<?php
/*
  Plugin Name: WPDM - ConvertKit
  Plugin URL: http://www.wpdownloadmanager.com/download/wpdm-convertkit
  Description: ConvertKit leads generation add-on for WordPress Download Manager
  Version: 1.1.0
  Author: Shahriar
  Author URI: http://www.wpdownloadmanager.com/
 */

if (!defined('WPINC')) {
    die;
}

class WpdmConvertkit {

    private static $instance;
    private $dir, $url;

    public static function getInstance() {
        if (self::$instance === null) {
            self::$instance = new self;
            self::$instance->actions();
            self::$instance->dir = dirname(__FILE__);
            self::$instance->url = WP_PLUGIN_URL . '/' . basename(self::$instance->dir);
        }
        return self::$instance;
    }

    private function actions() {
        register_activation_hook(__FILE__, array($this, 'activate'));
        register_deactivation_hook(__FILE__, array($this, 'deactivate'));

        if (is_admin()) {
            add_filter('add_wpdm_settings_tab', array($this, 'settings_tab_convertkit'));
        }
        if (!is_admin()) {
            
        }
        add_action('wpdm_before_email_download_link', array($this, 'pushToconvertkit'), 10, 2);
        add_action('wpdm_custom_form_field', array($this, 'custom_settings_in_package_settings'));
        add_action( 'user_register', array($this, 'newSignup'), 10, 1 );
        add_action( 'wppm_user_subscribe', array($this, 'newSignup'), 10, 2 );
    }

    function custom_settings_in_package_settings($postid) {
        $convertkit_form = get_post_meta(get_the_ID(), '__wpdm_convertkit_form', true);
        ?>
        <style>#convertkit_form_chosen{min-width: 300px;}</style>
        <fieldset style="margin-top: 10px">
            <legend>
                <?php esc_html_e('ConvertKit Form', 'wpdmpro'); ?>
                <i title="" class="info fa fa-info" data-original-title="<?php esc_attr_e('Select Form for this package only. If you want to use Global form set in WPDM settings then select Use Global Selection', 'wpdmpro'); ?>"></i>
            </legend>
            <select class="form-control" name="file[convertkit_form]" id="convertkit_form" >
                <option value="">Use Global Selection</option>
                <?php
                $options = get_option('wpdm_convertkit');
                $api_key = isset($options['ck_api_key']) ? $options['ck_api_key'] : '';
                $url = 'https://api.convertkit.com/v3/forms?api_key=' . $api_key;

                $body = array();
                $response = (wp_remote_get($url));
                if (is_array($response) && !is_wp_error($response)) {
                    $headers = $response['headers']; // array of http header lines
                    $body = $response['body']; // use the content
                    $data = json_decode($body, true);

                    foreach ($data['forms'] as $file => $fileInfo) {
                        ?>
                        <option value="<?php echo $fileInfo['id'] ?>" <?php echo selected($convertkit_form, $fileInfo['id']); ?>><?php echo $fileInfo['name'] ?></option>
                        <?php
                    }
                }
                ?>
            </select>
        </fieldset>
        <?php
    }

    function settings_tab_convertkit($tabs) {
        $tabs['convertkit'] = wpdm_create_settings_tab('convertkit', 'ConvertKit', array($this, 'settings'), 'fa fa-envelope');
        return $tabs;
    }

    public function activate() {
        if (false == get_option('wpdm_convertkit')) {
            $option = array('key' => '');
            add_option('wpdm_convertkit', $option);
        }
    }

    public function deactivate() {
        
    }

    public static function getDir() {
        return self::$instance->dir;
    }

    public static function getUrl() {
        return self::$instance->url;
    }

    public function settings() {

        if (isset($_POST['ck_api_key'])) {
            $options['ck_api_key'] = stripslashes($_POST['ck_api_key']);
            $options['ck_form_id'] = stripslashes($_POST['ck_form_id']);

            update_option('wpdm_convertkit', $options);
            update_option('__wpdm_ckrole', $_POST['__wpdm_ckrole']);
            die('Settings Saved Successfully.');
        }

        $options = get_option('wpdm_convertkit');
        $api_key = isset($options['ck_api_key']) ? $options['ck_api_key'] : '';
        $form_id = isset($options['ck_form_id']) ? $options['ck_form_id'] : '';
        $ckforms = array();
        $__wpdm_ckrole = get_option('__wpdm_ckrole');
        if(!is_array($__wpdm_ckrole)) $__wpdm_ckrole = array();
        ?>
        <div class="panel panel-default">
            <div class="panel-heading"><?php _e('ConvertKit Authentication','wpdm-convertkit'); ?></div>
            <div class="panel-body">
                <div class="form-group">
                    <label for="api_key"><?php _e('API Key','wpdm-convertkit'); ?></label>
                    <input class="form-control" type="text" name="ck_api_key" id="ck_api_key" value="<?php echo $api_key; ?>" placeholder="Enter ConvertKit API KEY">
                    <em style="color: #888;">Get your ConvertKit API Key <a href="https://app.convertkit.com/account/edit" target="_blank">here</a></em>
                </div>
                <div class="form-group">
                    <label for="form_id"><?php _e('Select Form','wpdm-convertkit'); ?></label>
                    <select class="form-control" name="ck_form_id" id="ck_form_id" >
                        <?php
                        $url = 'https://api.convertkit.com/v3/forms?api_key=' . $api_key;

                        $body = array();
                        $response = (wp_remote_get($url));
                        if (is_array($response) && !is_wp_error($response)) {
                            $headers = $response['headers']; // array of http header lines
                            $body = $response['body']; // use the content
                            $data = json_decode($body, true);

                            foreach ($data['forms'] as $file => $fileInfo) {
                                $ckforms[$fileInfo['id']] = $fileInfo['name'];
                                ?>
                                <option value="<?php echo $fileInfo['id'] ?>" <?php if ($form_id == $fileInfo['id']) echo 'selected'; ?>><?php echo $fileInfo['name'] ?></option>
                                <?php
                            }
                        }
                        ?>
                    </select>
                    <em style="color: #888;">Subscribers will be listed under this Form. This form will be used as default form when package specific form not available.</em>
                </div>
            </div>
        </div>

        <div class="panel panel-default">
            <div class="panel-heading"><?php _e('Role Assignment','wpdm-convertkit'); ?></div>
            <div class="panel-body1">

                <table class="table">
                    <thead>
                    <tr>
                        <th>User Role</th>
                        <th style="width: 50%">Form</th>
                    </tr>
                    </thead>
                    <tbody>
                    <?php
                    global $wp_roles;
                    $roles = array_reverse($wp_roles->role_names);
                    foreach( $roles as $role => $name ) {
                        ?>
                        <tr>
                            <td><?php echo $name; ?></td>
                            <td>
                                <select class="form-control" name="__wpdm_ckrole[<?php echo $role; ?>]" >
                                    <option value=""><?php _e('Select Form', 'wpdm-convertkit'); ?></option>
                                    <?php


                                    foreach ($ckforms as $formid => $formname) {
                                        ?>
                                        <option value="<?php echo $formid ?>" <?php if (isset($__wpdm_ckrole[$role]) && $__wpdm_ckrole[$role] == $formid) echo 'selected'; ?>><?php echo $formname ?></option>
                                        <?php
                                    }

                                    ?>
                                </select>
                            </td>
                        </tr>
                        <?php
                    }
                        ?>
                    </tbody>
                </table>

            </div>
        </div>
        <?php
    }

    public function pushToConvertkit($post, $file) {
        $name = $post['custom_form_field']['name'];
        //$names = explode(' ', $name);
        //$first_name = $names[0];
        //$last_name = $names[1];
        $email = $post['email'];

        if (is_email($email)) {
            $options = get_option('wpdm_convertkit');
            $api_key = isset($options['ck_api_key']) ? $options['ck_api_key'] : '';

            // Package specific Form
            $convertkit_form_id = get_post_meta($post['__wpdm_ID'], '__wpdm_convertkit_form', true);

            // Or Global Form
            if( $convertkit_form_id == '' || !isset($convertkit_form_id) )
                $convertkit_form_id = isset($options['ck_form_id']) ? $options['ck_form_id'] : '';

            if($convertkit_form_id != '') {
                $url = 'https://api.convertkit.com/v3/forms/' . $convertkit_form_id . '/subscribe';
                $body = array('api_key' => $api_key, 'email' => $email, 'name' => $name);

                $response = wp_remote_post($url, array('body' => $body));

                if (!is_wp_error($response)) return true;
            }
        }

    }

    public function newSignup($user_id, $role = null) {

        $user = get_user_by('id', $user_id);
        $email = $user->user_email;
        $name = $user->display_name;

        $wpdm_ckrole = get_option('__wpdm_ckrole');
        if(!is_array($wpdm_ckrole)) $wpdm_ckrole = array();
        $role = $role?$role:$user->roles[0];
        $convertkit_form_id = isset($wpdm_ckrole[$role])?$wpdm_ckrole[$role]:'';

        if (is_email($email) && $convertkit_form_id) {
            $options = get_option('wpdm_convertkit');
            $api_key = isset($options['ck_api_key']) ? $options['ck_api_key'] : '';


            if($convertkit_form_id != '') {
                $url = 'https://api.convertkit.com/v3/forms/' . $convertkit_form_id . '/subscribe';
                $body = array('api_key' => $api_key, 'email' => $email, 'name' => $name);

                $response = wp_remote_post($url, array('body' => $body));

                if (!is_wp_error($response)) return true;
            }
        }

    }



}

WpdmConvertkit::getInstance();
