<?php
/*
Plugin Name: WPDM - Download Notification
Description: Get Download notification When Someone Downloads
Plugin URI: https://www.wpdownloadmanager.com/download/download-notifications/
Author: WordPress Download Manager
Version: 1.8.1
Author URI: https://www.wpdownloadmanager.com/
*/
namespace WPDM\AddOn;

include __DIR__ . '/libs/vendor/autoload.php';

use Twilio\Rest\Client;
use WPDM\__\__;
use WPDM\__\Crypt;
use WPDM\__\Email;
use WPDM\__\Template;

class DownloadNotification
{

    function __construct()
    {

        add_filter('wpdm_package_settings_tabs', array($this, 'notification_settings_tab'));
        add_filter('add_wpdm_settings_tab', array($this, 'settings_tab'));
        //add_action("basic_settings_section", [$this, 'global_notification_settings']);
        add_action('wpdm_onstart_download', array($this, 'wpdm_download_notification'));
        add_action('wpdm_before_email_download_link', array($this, 'wpdm_before_email_download_link'), 10, 2);
        add_action('wpdm_email_templates', array($this, 'email_template'), 10, 2);


    }

    function email_template($templates)
    {
        $template = new Template();
        $datahtml = $template->assign('heading', "User and package info:")
            ->assign('content', ['[#download_info#]'])
            ->fetch('email-templates/ui-blocks/panel.php', WPDM_SRC_DIR.'__/views');
        $templates['download-notification'] = array(
            'label' => "Download Notification",
            'for' => 'admin',
            'default' => array(
                'subject' => __("Download Notification For: [#package_name#]", "download-manager"),
                'from_name' => get_option('blogname'),
                'from_email' => get_option('admin_email'),
                'to_email' => get_option('admin_email'),
                'message' => 'Someone just downloaded an item from your site. <br/><br/>' . $datahtml
            )
        );
        return $templates;
    }

    function notification_settings_tab($tabs)
    {
        $tabs['emlnot'] = array('name' => __('Download Notification', 'wpdm-email-notification'), 'callback' => array($this, 'notification_settings'));
        return $tabs;
    }

    static function notification_settings()
    {
        include(dirname(__FILE__) . '/tab-content.php');
    }

    function global_notification_settings()
    {

        if (wpdm_query_var('task') == 'wdm_save_settings' && wpdm_query_var('section') == 'dnot-settigs') {
            update_option('__wpdm_email_notification', $_POST['__wpdm_email_notification']);
            update_option('__wpdm_sms_notification', $_POST['__wpdm_sms_notification']);
            update_option('__wpdm_twilio_sid', $_POST['__wpdm_twilio_sid']);
            update_option('__wpdm_twilio_auth_token', $_POST['__wpdm_twilio_auth_token']);
            update_option('__wpdm_twilio_number', $_POST['__wpdm_twilio_number']);
            update_option('__wpdm_twilio_receiver', $_POST['__wpdm_twilio_receiver']);
            update_option('__wpdm_twilio_sms', $_POST['__wpdm_twilio_sms']);
            die('Settings Saved Successfully.');
        }

        $options = array(
            '__wpdm_email_notification' => array('type' => 'checkbox', 'id' => '__wpdm_email_notification', 'name' => '__wpdm_email_notification', 'placeholder' => '', 'label' => __('Enable email notification', 'wpdm-email-notification').' ( <a href="edit.php?post_type=wpdmpro&page=templates&_type=email&task=EditEmailTemplate&id=download-notification">Edit Email Template</a> )', 'value' => 1, 'checked' => get_option('__wpdm_email_notification', 0)),
            '__wpdm_sms_notification' => array('type' => 'checkbox', 'id' => '__wpdm_sms_notification', 'name' => '__wpdm_sms_notification', 'placeholder' => '', 'label' => __('Enable SMS notification', 'wpdm-email-notification'), 'value' => 1, 'checked' => get_option('__wpdm_sms_notification', 0)),
            //'__wpdm_en_mails' => array('type' => 'text', 'id' => '__wpdm_en_mails', 'name' => '__wpdm_en_mails', 'placeholder' => '', 'label' => 'Emails', 'description' => 'You can use multiple email separated by comma', 'value' => get_option('__wpdm_en_mails', '')),
            //'__wpdm_en_message' => array('type' => 'textarea', 'id' => '__wpdm_en_message', 'name' => '__wpdm_en_message', 'placeholder' => '', 'label' => 'Message', 'value' => get_option('__wpdm_en_message', '')),
        );

        $twilio_options = array(
            '__wpdm_twilio_sid' => array('type' => 'text', 'id' => '__wpdm_twilio_sid', 'name' => '__wpdm_twilio_sid', 'placeholder' => '', 'label' => 'SID', 'description' => 'Twilio SID', 'value' => get_option('__wpdm_twilio_sid', '')),
            '__wpdm_twilio_auth_token' => array('type' => 'text', 'id' => '__wpdm_twilio_auth_token', 'name' => '__wpdm_twilio_auth_token', 'placeholder' => '', 'label' => 'Auth Token', 'description' => 'Twilio Auth Token', 'value' => get_option('__wpdm_twilio_auth_token', '')),
            '__wpdm_twilio_number' => array('type' => 'text', 'id' => '__wpdm_twilio_number', 'name' => '__wpdm_twilio_number', 'placeholder' => '', 'label' => 'From Number', 'description' => 'Twilio number', 'value' => get_option('__wpdm_twilio_number', '')),
            '__wpdm_twilio_receiver' => array('type' => 'text', 'id' => '__wpdm_twilio_receiver', 'name' => '__wpdm_twilio_receiver', 'placeholder' => '', 'label' => 'Send SMS To', 'description' => 'receiver\'s mobile number', 'value' => get_option('__wpdm_twilio_receiver', '')),
            '__wpdm_twilio_sms' => array('type' => 'text', 'id' => '__wpdm_twilio_sms', 'name' => '__wpdm_twilio_sms', 'placeholder' => '', 'label' => 'Message', 'description' => 'Vars: {{package_name}} = package name, {{user_email}} = user email', 'value' => get_option('__wpdm_twilio_sms', '')),
            //'__wpdm_en_message' => array('type' => 'textarea', 'id' => '__wpdm_en_message', 'name' => '__wpdm_en_message', 'placeholder' => '', 'label' => 'Message', 'value' => get_option('__wpdm_en_message', '')),
        );

        echo "<div class='panel panel-default'><div class='panel-heading'>" . __('Download notification settings', 'wpdm-email-notification') . "</div><div class='panel-body'>" . wpdm_option_page($options) . "</div></div>";
        echo "<div class='panel panel-default'><div class='panel-heading'>" . __('Twilio SMS', 'wpdm-email-notification') . "</div><div class='panel-body'>" . wpdm_option_page($twilio_options) . "</div></div>";

    }

    function settings_tab($menus)
    {
        $menus['dnot-settigs'] = wpdm_create_settings_tab('dnot-settigs', __('Download Notification', 'wpdm-email-notification'), array($this, 'global_notification_settings'), 'fas fa-bell');
        return $menus;
        //array('id' => 'enot-settigs','icon'=>'fa fa-paper-plane',  'link' => 'edit.php?post_type=wpdmpro&page=settings&tab=enot-settigs', 'title' => 'License', 'callback' => 'wpdm_licnese');
    }

    function wpdm_download_notification($package)
    {
        if(get_option('__wpdm_sms_notification', 0))
            $this->sms_notification($package);

        $lns = get_post_meta($package['ID'], '__wpdm_email_notification', true);
        $gns = get_option('__wpdm_email_notification', 0);
        $neml = get_option('__wpdm_en_mails', get_option('admin_email'));
        $gmsg = get_option('__wpdm_en_message', '');
        if ($lns == 1 || ($lns == 0 && $gns == 1)) {
            global $current_user;
            $package_data = get_post($package['ID']);

            $message = "";
            $ip = __::get_client_ip();
            $message .= "<table style='width: 100%;' class='table'><tr><td>Downloader's IP:</td><td align='right'>" . $ip . "</td></tr>";
            if (is_user_logged_in())
                $message .= "<tr><td>Downloader's Email:</td><td align='right'>" . $current_user->user_email . "</td></tr>";
            else if (wpdm_query_var('subscriber')) {
                global $wpdb;
                $subscriber = (int)Crypt::decrypt(wpdm_query_var('subscriber'));
                if ($subscriber > 0) {
                    $subscriber = $wpdb->get_row("select * from {$wpdb->prefix}ahm_emails where id='{$subscriber}'");
                    $message .= "<tr><td>Downloader's Email:</td><td align='right'>" . $subscriber->email . "</td></tr>";
                    $cd = maybe_unserialize($subscriber->custom_data);
                    if (is_array($cd)) {
                        foreach ($cd as $key => $value) {
                            $key = ucfirst($key);
                            $message .= "<tr><td>{$key}:</td><td align='right'>{$value}</td></tr>";
                        }
                    }

                }
            }
            $message .= "<tr><td>Package:</td><td align='right'><a href='" . get_permalink($package['ID']) . "'>" . $package_data->post_title . "</a></td></tr></table>";

            $emails = get_post_meta($package['ID'], '__wpdm_en_mails', true);
            if ($lns == 0 || $emails == '') $emails = $neml;
            //$emails = explode(",", $emails);
            $params = array(
                'subject' => sprintf(__("Download Notification: %s"), $package_data->post_title, 'wpdm-email-notification'),
                'package_name' => $package_data->post_title,
                //'to_email' => $emails,
                'download_info' => $message
            );
            Email::send("download-notification", $params);
        }
    }

    function wpdm_before_email_download_link($postdata, $package)
    {
        $lns = get_post_meta($package['ID'], '__wpdm_email_notification', true);
        $gns = get_option('__wpdm_email_notification', 0);
        $neml = get_option('__wpdm_en_mails', get_option('admin_email'));
        $gmsg = get_option('__wpdm_en_message', '');
        $send_new_subscriber_notification = $lns == 1 || ($lns == 0 && $gns == 1);
        $send_new_subscriber_notification = apply_filters("wpdm_send_new_subscriber_notification", $send_new_subscriber_notification);
        if ($send_new_subscriber_notification) {
            global $current_user;
            $package_data = get_post($package['ID']);
            $headers = 'From:  ' . get_bloginfo('name') . "<" . get_option('admin_email') . ">\r\n";
            $headers .= 'Content-type: text/html' . "\r\n";
            $msg = get_post_meta($package['ID'], '__wpdm_en_message', true);
            if ($lns == 0 || trim($msg) == '') $msg = $gmsg;
            $message = "<div style='font-family: verdana;'>" . $msg . "<br/>";
            $ip = __::get_client_ip();
            $message .= "Downloader's IP: " . $ip . "<br/>";
            if (is_user_logged_in())
                $message .= "Loggedin User Email:" . $current_user->user_email . "<br/>";
            $form_data = "";
            $form_data .= "Downloader's Email: " . $_POST['email'] . "<br/>";
            if (isset($_POST['custom_form_field'])) {
                foreach ($_POST['custom_form_field'] as $name => $value) {
                    $name = ucwords($name);
                    $form_data .= "$name: $value<br/>";
                }
            }
            $message .= "Package: <a href='" . get_permalink($package['ID']) . "'>" . $package_data->post_title . "</a><br/>";
            $message .= $form_data;
            $message .= "</div>";
            $emails = get_post_meta($package['ID'], '__wpdm_en_mails', true);
            if ($lns == 0 || $emails == '') $emails = $neml;
            $emails = explode(",", $emails);
            foreach ($emails as $email) {
                $params = array(
                    'subject' => sprintf(__("New Subscriber From: %s"), $package_data->post_title, 'wpdm-email-notification'),
                    'to_email' => $email,
                    'package_name' => $package_data->post_title,
                    'download_info' => $message
                );

                Email::send("download-notification", $params);
            }
        }
    }

    function sms_notification($package)
    {
        global $current_user;

        // Your Account SID and Auth Token from twilio.com/console
        $sid = get_option('__wpdm_twilio_sid');
        $token = get_option('__wpdm_twilio_auth_token');

        $client = new Client($sid, $token);
        $message = str_replace(["{{package_name}}", "{{user_email}}"], [get_the_title($package['ID']), $current_user->user_email], get_option('__wpdm_twilio_sms'));
        try {
            $client->messages->create(
                // the number you'd like to send the message to
                get_option('__wpdm_twilio_receiver'),
                [
                    // A Twilio phone number you purchased at twilio.com/console
                    'from' => get_option('__wpdm_twilio_number'),
                    // the body of the text message you'd like to send
                    'body' => $message
                ]
            );
        } catch ( \Exception $e ) {
            //wpdmdd($e->getMessage());
        }

    }


}


if(defined('WPDM_VERSION'))
    new DownloadNotification();

