<?php
/*
Plugin Name: WPDM - Download Period
Description: WPDM - Download Period to help you to make a download available for a user for a certain period
Plugin URI: https://www.wpdownloadmanager.com/
Author: WordPress Download Manager
Version: 1.2.3
Author URI: https://www.wpdownloadmanager.com/
*/


class WPDM_Download_Period {

    function __construct(){

        add_filter('wpdm_package_settings_tabs', array($this, 'download_period_tab'));
        add_filter('wdm_before_fetch_template', array($this, 'before_fetch_template'), 999999);
        add_filter('wpdm_download_link', array($this, 'download_link'), 999999, 2);
        add_action('wpdm_onstart_download', array($this, 'before_download'), 999999);
        add_action('show_user_profile', array($this, 'user_profile_fields'));
        add_action('edit_user_profile', array($this, 'user_profile_fields'));
        add_action('personal_options_update', array($this, 'save_user_profile_fields'));
        add_action('edit_user_profile_update', array($this, 'save_user_profile_fields'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_script'));


    }

    function enqueue_script($hook){
        if($hook!='profile.php') return;
        wp_enqueue_script('jquery-ui-core');
        wp_enqueue_script('jquery-ui-datepicker');
        wp_enqueue_script('jquery-ui-slider');
        wp_enqueue_script('jquery-ui-sortable');
        wp_enqueue_script('jquery-ui-timepicker', WPDM_BASE_URL.'/js/jquery-ui-timepicker-addon.js',array('jquery','jquery-ui-core','jquery-ui-datepicker','jquery-ui-slider') );
        wp_enqueue_style('jqui-css', plugins_url('/download-manager/jqui/theme/jquery-ui.css'));
    }

    function download_period_tab($tabs){
        $tabs['dlperiod'] = array('name'=>'Download Period', 'callback' => array($this, 'download_period'));
        return $tabs;
    }

    static function download_period(){
        include(dirname(__FILE__).'/tab-content.php');
    }

    function before_fetch_template($package){
        global $current_user;

        $user_access_type = get_user_meta($current_user->ID, '__wpdm_access_type', true);

        $user_period = isset($package['download_period']) && isset($package['download_period'][$current_user->user_login])?$package['download_period'][$current_user->user_login]:array();
        $user_period = empty($user_period) && isset($package['download_period']) && isset($package['download_period'][$current_user->user_email])?$package['download_period'][$current_user->user_email]:$user_period;

        if(is_user_logged_in() && empty($user_period) && $user_access_type != 2){
            $user_period = array('s'=>get_the_author_meta( '__wpdm_download_open', $current_user->ID ), 'e' => get_the_author_meta( '__wpdm_download_close', $current_user->ID ));
        }
        //echo "<pre>".print_r($user_period, 1);die();
        if(is_user_logged_in() && empty($user_period) && $user_access_type == 2){
            //$user_period = array('s'=>get_the_author_meta( '__wpdm_download_open', $current_user->ID ), 'e' => get_the_author_meta( '__wpdm_download_close', $current_user->ID ));
            $pdate = strtotime(get_the_date("Y-m-d", $package['ID']));
            $sdate = strtotime(get_the_author_meta( '__wpdm_download_open', $current_user->ID ));
            $edate = strtotime(get_the_author_meta( '__wpdm_download_close', $current_user->ID ));

            if($pdate < $sdate || $pdate > $edate){
                $package['download_url'] = '#';
                $package['link_label'] = __('You do not have access to this package', 'wpdmpro');
                $package['download_link_extended'] = $package['download_link'] = "<div class='alert alert-danger'>{$package['link_label']}</div>";
            }
        }

        if( is_user_logged_in() && count($user_period) > 0 ){
            $package['publish_date'] = $user_period['s'];
            $package['expire_date'] = $user_period['e'];
        }

        if (isset($package['expire_date']) && $package['expire_date'] != "" && strtotime($package['expire_date']) < time()) {
            $package['download_url'] = '#';
            $package['link_label'] = __('Download was expired on', 'wpdmpro') . " " . date(get_option('date_format')." h:i A", strtotime($package['expire_date']));
            $package['download_link_extended'] = $package['download_link'] = "<div class='alert alert-danger'>{$package['link_label']}</div>";

        }

        if (isset($package['publish_date']) && $package['publish_date'] !='' && strtotime($package['publish_date']) > time()) {
            $package['download_url'] = '#';
            $package['link_label'] = __('Download will be available from ', 'wpdmpro') . " " . date(get_option('date_format')." h:i A", strtotime($package['publish_date']));
            $package['download_link_extended'] = $package['download_link'] = "<div class='alert alert-info'>{$package['link_label']}</div>";
        }
        //echo "<pre>".print_r($package['download_link'], 1);die();
        return $package;
    }

    function download_link($link, $package){
        global $current_user;

        $user_access_type = get_user_meta($current_user->ID, '__wpdm_access_type', true);

        $user_period = isset($package['download_period']) && isset($package['download_period'][$current_user->user_login])?$package['download_period'][$current_user->user_login]:array();
        $user_period = empty($user_period) && isset($package['download_period']) && isset($package['download_period'][$current_user->user_email])?$package['download_period'][$current_user->user_email]:$user_period;

        if(is_user_logged_in() && empty($user_period) && $user_access_type != 2){
            $user_period = array('s'=>get_the_author_meta( '__wpdm_download_open', $current_user->ID ), 'e' => get_the_author_meta( '__wpdm_download_close', $current_user->ID ));
        }
        //echo "<pre>".print_r($user_period, 1);die();
        if(is_user_logged_in() && empty($user_period) && $user_access_type == 2){
            //$user_period = array('s'=>get_the_author_meta( '__wpdm_download_open', $current_user->ID ), 'e' => get_the_author_meta( '__wpdm_download_close', $current_user->ID ));
            $pdate = strtotime(get_the_date("Y-m-d", $package['ID']));
            $sdate = strtotime(get_the_author_meta( '__wpdm_download_open', $current_user->ID ));
            $edate = strtotime(get_the_author_meta( '__wpdm_download_close', $current_user->ID ));

            if($pdate < $sdate || $pdate > $edate){
                $package['download_url'] = '#';
                return "<a href='#' class='wpdm-download-link ".wpdm_download_button_style()."' onclick='WPDM.notify(\"".__('You do not have access to this package', 'wpdmpro')."\", \"error\");return false;'>{$package['link_label']}</a>";
                //$package['download_link_extended'] = $package['download_link'] = "<div class='alert alert-danger'>{$package['link_label']}</div>";
            }
        }

        if( is_user_logged_in() && count($user_period) > 0 ){
            $package['publish_date'] = $user_period['s'];
            $package['expire_date'] = $user_period['e'];
        }

        if (isset($package['expire_date']) && $package['expire_date'] != "" && strtotime($package['expire_date']) < time()) {
            $package['download_url'] = '#';
            $msg = __('Download was expired on', 'wpdmpro') . " " . date(get_option('date_format')." h:i A", strtotime($package['expire_date']));
            return "<a href='#' class='wpdm-download-link ".wpdm_download_button_style()."' onclick='WPDM.notify(\"{$msg}\", \"error\");return false;'>{$package['link_label']}</a>";

        }

        if (isset($package['publish_date']) && $package['publish_date'] !='' && strtotime($package['publish_date']) > time()) {
            $package['download_url'] = '#';
            $msg = __('Download will be available from ', 'wpdmpro') . " " . date(get_option('date_format')." h:i A", strtotime($package['publish_date']));
            return "<a href='#' class='wpdm-download-link ".wpdm_download_button_style()."' onclick='WPDM.notify(\"{$msg}\", \"error\");return false;'>{$package['link_label']}</a>";
        }
        //echo "<pre>".print_r($package['download_link'], 1);die();
        return $link;
    }


    function before_download($package){
        global $current_user;

        $user_period = isset($package['download_period']) && isset($package['download_period'][$current_user->user_login])?$package['download_period'][$current_user->user_login]:array();
        $user_period = empty($user_period) && isset($package['download_period']) && isset($package['download_period'][$current_user->user_email])?$package['download_period'][$current_user->user_email]:$user_period;

        if(is_user_logged_in() && empty($user_period)){
            $user_period = array('s'=>get_the_author_meta( '__wpdm_download_open', $current_user->ID ), 'e' => get_the_author_meta( '__wpdm_download_close', $current_user->ID ));
        }

        if( is_user_logged_in() && count($user_period) > 0 ){
            $package['publish_date'] = $user_period['s'];
            $package['expire_date'] = $user_period['e'];
        }

        if (isset($package['expire_date']) && $package['expire_date'] != "" && strtotime($package['expire_date']) < time()) {
            $package['download_url'] = '#';
            $package['link_label'] = __('Download was expired on', 'wpdmpro') . " " . date(get_option('date_format')." h:i A", strtotime($package['expire_date']));
            wp_die("{$package['link_label']}");

        }

        if (isset($package['publish_date']) && $package['publish_date'] !='' && strtotime($package['publish_date']) > time()) {
            //$package['download_url'] = '#';
            $package['link_label'] = __('Download will be available from ', 'wpdmpro') . " " . date(get_option('date_format')." h:i A", strtotime($package['publish_date']));
            wp_die("{$package['link_label']}");
        }
        return $package;
    }

    function user_profile_fields( $user ) {
        if(!is_admin() || current_user_can('manage_options')) return;
        ?>

        <h3>Download Period</h3>

        <table class="form-table">

            <tr>
                <th><label for="do">Available From</label></th>

                <td>
                    <input type="text" name="download_open" id="do" value="<?php echo esc_attr( get_the_author_meta( '__wpdm_download_open', $user->ID ) ); ?>" class="regular-text" /><br />
                </td>
            </tr>
            <tr>
                <th><label for="dc">Expired On</label></th>

                <td>
                    <input type="text" name="download_close" id="dc" value="<?php echo esc_attr( get_the_author_meta( '__wpdm_download_close', $user->ID ) ); ?>" class="regular-text" /><br />
                </td>
            </tr>

            <tr>

                <th><label for="ac">User Access</label></th>
                <td>
                    <label><input type="radio" name="access_type" <?php checked(1, get_the_author_meta( '__wpdm_access_type', $user->ID )) ?> id="at" value="1" /> Allow current user access to all packages for above date range</label><br />
                    <label><input type="radio" name="access_type" <?php checked(2, get_the_author_meta( '__wpdm_access_type', $user->ID )) ?> id="at" value="2" /> Allow current user access to packages created within above date range</label><br />
                </td>
            </tr>

        </table>
        <script>
            jQuery(function($){
                try {
                    $('#do,#dc').datetimepicker({dateFormat: "yy-mm-dd", timeFormat: "hh:mm tt"});
                } catch(e){

                }
            });
        </script>
        <?php

    }

    function save_user_profile_fields( $user_id ) {

        if ( !current_user_can( 'edit_user', $user_id ) )
            return false;

        update_user_meta( $user_id, '__wpdm_download_open', $_POST['download_open'] );
        update_user_meta( $user_id, '__wpdm_download_close', $_POST['download_close'] );
        update_user_meta( $user_id, '__wpdm_access_type', $_POST['access_type'] );
    }






}

new WPDM_Download_Period();
 


