<?php
/*
Plugin Name: WPDM - File Hosting
Description: Covert your site into a full featured file hosting & sharing server
Plugin URI: https://www.wpdownloadmanager.com/download/file-hosting-sharing-add-on/
Author: WordPress Download Manager
Version: 1.5.0
Author URI: https://www.wpdownloadmanager.com/
Text Domain: wpdm-file-hosting
*/

use WPDM\__\Messages;

define('WPDMFH_BASE', plugins_url('wpdm-file-hosting'));
define('WPDMFH_TD', plugins_url('wpdm-file-hosting'));

class WPDMFileHosting{



    function __construct()
    {

        add_action('plugins_loaded', array($this, 'loadTextdomain') );
        add_action("wp_ajax_wpdm-filebrowser", array($this, 'fileBrowserHTML'));
        add_action("wp", array($this, 'createPackage'));
        add_action("wp", array($this, 'packageInfo'));
        add_action("wp", array($this, 'shareWithEmail'));
        add_action("wp_enqueue_scripts", array($this, 'Enqueue'));
        add_action("wp_ajax_packageSettings", array($this, 'packageSettings'));
        add_action("wp_ajax_savePackageSettings", array($this, 'savePackageSettings'));
        add_action("wp_ajax_folderSettings", array($this, 'folderSettings'));
        add_action("wp_ajax_saveFolderSettings", array($this, 'saveFolderSettings'));
        add_action("wp_ajax_untagFolder", array($this, 'untagFolder'));
        add_action("wp_ajax_untagFile", array($this, 'untagFile'));
        add_action("wp_ajax_importToMyFiles", array($this, 'importToMyFiles'));
        add_filter("wpdm_user_dashboard_menu", array($this, 'dashboardMenu'));
        //add_action("wp", array($this, 'DeleteFile'));

        // File Browser
        add_shortcode('wpdm-file-browser', array($this, 'fileBrowser'));


    }

    /**
     * @usage Load Language File
     */
    function loadTextdomain(){
        load_plugin_textdomain('wpdm-file-hosting', WP_PLUGIN_URL . "/wpdm-file-hosting/languages/", 'wpdm-file-hosting/languages/');
    }

    function dashboardMenu($menu){
        $menu = array_merge(array_splice($menu,0, 2), array('file-hosting' => array('icon' => 'fas fa-file-export','name'=> __('File Hosting', WPDMFH_TD), 'callback' => array($this, 'FileBrowser'))), $menu);
        return $menu;
    }

    public function Enqueue(){
        global $post;
        if((is_object($post) && has_shortcode($post->post_content,'wpdm-file-browser')) || wpdm_query_var('udb_page') === 'file-hosting'){
            wp_enqueue_script('thickbox');
            wp_enqueue_style('thickbox');
            wp_enqueue_script('media-upload');
            wp_enqueue_script('jquery-ui-core');
            wp_enqueue_script('jquery-ui-autocomplete');
            wp_enqueue_media();
        }
    }


    public function fileBrowser($params = array()){

        global $current_user, $WPDM;

        $ajaxurl = get_permalink();

        if(is_array($params)) extract($params);

        ob_start();
        if(!is_user_logged_in())
            echo WPDM()->user->login->form($params);
        else{
            $currentAccess = maybe_unserialize(get_option('__wpdm_front_end_access', array()));

            if (!array_intersect($currentAccess, $current_user->roles) && is_user_logged_in())
                echo  Messages::Error(wpautop(stripslashes(get_option('__wpdm_front_end_access_blocked'))), -1);
            else {
                if(!isset($params['root'])) {
                    $user_home = (int)get_user_meta($current_user->ID, '__wpdmfb_root_cat', true);
                    if (!$user_home || !term_exists($user_home, 'wpdmcategory')) {
                        $term = $this->CreateFolder($current_user->user_login, 0);
                        if (!is_wp_error($term) && isset($term['term_id'])) {
                            update_user_meta($current_user->ID, '__wpdmfb_root_cat', $term['term_id']);
                            $user_home = $term['term_id'];
                        }
                    }
                } else {
                    $user_home = $params['root'];
                    update_post_meta(get_the_ID(), '__wpdmfb_root_cat', $user_home);
                }
                include(dirname(__FILE__) . "/tpls/wpdm-file-browser-container.php");
            }
                //include(wpdm_tpl_path('wpdm-file-browser-container.php', dirname(__FILE__)."/tpls/"));
        }
        $html = ob_get_clean();
        return $html;

    }

    function ShareWithEmail(){
        global $current_user;
        if( isset($_REQUEST['task']) && $_REQUEST['task'] == 'sharewithemail' ){
            $eml = $_REQUEST['eml'];
            $message = $eml['msg']."<br/><br/><div style='margin-bottom:20px'><a href='{$eml['link']}'   class='btn1' style=\"border-radius:3px;padding:10px 20px;color: #ffffff;background: #1ABC9C;text-decoration:none;letter-spacing:1px;font-weight:bold;\" >Download Here</a><br/><br/>&mdash; {$current_user->display_name}</div><hr style='border:0;box-shadow:none;border-bottom:1px solid #dddddd;height:0;'/>";

            $params = array(
                'to_email' => esc_attr($_REQUEST['eml']['email']),
                'from_name' => $current_user->display_name,
                'from_email' => $current_user->user_email,
                'subject' => $current_user->display_name. " shared a file with you",
                'message' => stripslashes($message)
            );

            \WPDM\__\Email::send("default", $params);
            die('ok');
        }
    }

    public function fileBrowserHTML(){

        global $current_user, $wp_query;


        if(!is_user_logged_in()){
            wp_send_json(['breadcrumb' => 'Please login to get access', 'files' => WPDM()->user->login->form(array())]);
        }


        $this->DeleteFolder();
        $this->DeleteFile();

        $user_home = get_post_meta(get_the_ID(), '__wpdmfb_root_cat', true);
        if(!$user_home)
            $user_home = get_user_meta($current_user->ID, '__wpdmfb_root_cat', true);

        if(!$user_home || !term_exists($user_home, 'wpdmcategory')) {
            $term = $this->CreateFolder($current_user->user_login, 0);
            if(!is_wp_error($term) && isset($term['temr_id'])) {
                update_user_meta($current_user->ID, '__wpdmfb_root_cat', $term['term_id']);
                $user_home = $term['term_id'];
            }
        }

        $limit = 20;
        $parent = isset($_REQUEST['catg']) && $_REQUEST['catg'] > 0 ?(int)$_REQUEST['catg']:$user_home;


        // if this is a shared category
        $_users = maybe_unserialize(get_term_meta($parent, '__wpdm_user_access', true));
        if(!is_array($_users)) $_users = array();
        $shared_cat = $parent > 0 && $user_home !== $parent && in_array($current_user->user_login, $_users)?true:false;

        if(isset($_REQUEST['fbtask']) && $_REQUEST['fbtask'] == 'createfolder') {
            $slug = sanitize_title($_REQUEST['cname']);
            if (term_exists($_REQUEST['cname'], 'wpdmcategory'))
                $slug = $slug . "-" . uniqid();
            $term = $this->CreateFolder($_REQUEST['cname'], $parent, $slug);
        }


        if(!wpdm_query_var('shared'))
            $cats = get_terms( array('taxonomy' => 'wpdmcategory','hide_empty' => false, 'parent' => $parent));
        else {
            $cparams = array('taxonomy' => 'wpdmcategory', 'hide_empty' => false);
            if(wpdm_query_var('shared', 'int') === 1 && wpdm_query_var('catg', 'int') > 0){
                $cparams['parent'] = wpdm_query_var('catg', 'int');
            }
            $_cats = get_terms($cparams);
            $cats = array();
            foreach ($_cats as $cat){
                $users = maybe_unserialize(get_term_meta($cat->term_id, '__wpdm_user_access', true));
                if(is_array($users) && in_array($current_user->user_login, $users))
                    $cats[] = $cat;

            }
        }

        $cond[] = "uid='{$current_user->ID}'";
        $Q = wpdm_query_var('q','txt');
        $paged = $wp_query->query_vars['paged']?$wp_query->query_vars['paged']:1;

        $start = $paged?(($paged-1)*$limit):0;
        $field = wpdm_query_var('sfield')?wpdm_query_var('sfield'):'publish_date';
        $ord = wpdm_query_var('sorder')?wpdm_query_var('sorder'):'desc';

        $author = $current_user->ID;

        $params = array('post_status' => array('publish', 'pending', 'draft'), 'post_type' => 'wpdmpro', 'offset' => $start);
        $params['orderby'] = $field;
        $params['order'] = $ord;

        if(!wpdm_query_var('shared')) {
            $params['author__in'] = array($author);
            $params['tax_query'] = array(
                array(
                    'taxonomy' => 'wpdmcategory',
                    'field' => 'id',
                    'terms' => $parent,
                    'include_children' => false
                )
            );
        } else {

            $params['post_status'] = array('publish');
            $params['author__not_in'] = array($author);
            $params['meta_query']['relation'] = 'OR';
            $params['meta_query'][] = array(
                'key' => '__wpdm_user_access',
                'value' => '"' . $current_user->user_login . '"',
                'compare' => 'LIKE',
            );

            // All files inherited from user roles
            foreach($current_user->roles as $role){
                $params['meta_query'][] = array(
                    'key' => '__wpdm_access',
                    'value' => $role,
                    'compare' => 'LIKE',
                );
            }

            // All files assigned to ALL VISITORS
            $params['meta_query'][] = array(
                'key' => '__wpdm_access',
                'value' => 'guest',
                'compare' => 'LIKE',
            );


        }

        if($field=='download_count'){
            $params['orderby'] = 'meta_value_num';
            $params['meta_key'] = '__wpdm_download_count';
            $params['order'] = $ord;
        }

        if($Q) $params['s'] = $Q;

        if(wpdm_query_var('shared', 'int') === 1 && wpdm_query_var('catg', 'int') > 0){
            unset($params['meta_query']);
            unset($params['author__not_in']);
            $params['tax_query'] = array(
                array(
                    'taxonomy' => 'wpdmcategory',
                    'field' => 'id',
                    'terms' => wpdm_query_var('catg', 'int'),
                    'include_children' => false
                )
            );
            //wpdmprecho($params);
        }

        $packs = new WP_Query($params);

        if($shared_cat)
            $_GET['shared'] = $_REQUEST['shared'] = $_REQUEST['shared'] = 1;

        ob_start();
        include wpdm_tpl_path("wpdm-file-browser.php", __DIR__.'/tpls/');
        $files = ob_get_clean();

        ob_start();
        include wpdm_tpl_path("breadcrumb.php", __DIR__.'/tpls/');
        $breadcrumb = ob_get_clean();

        wp_send_json(['breadcrumb' => $breadcrumb, 'files' => $files]);

    }

    public function CreateFolder($name, $parent, $slug = ''){
        $slug = $slug?$slug:$name;
        if($term = term_exists($slug, 'wpdmcategory', $parent)) return $term;
        $ret =  wp_insert_term(
            $name,
            'wpdmcategory',
            array(
                'parent'=> $parent,
                'slug' => $slug
            )
        );

        if(is_array($ret) && isset($ret['term_id'])) return $ret;
        return false;
    }

    public function createPackage(){

        global $current_user;

        if(!isset($_REQUEST['__wpdm_createfbp'])) return false;

        $currentAccess = maybe_unserialize(get_option('__wpdm_front_end_access', array()));

        if(!is_user_logged_in()){
            die('-1');
        }

        if (!array_intersect($currentAccess, $current_user->roles) && is_user_logged_in()){
            die('-2');
        }


        $pack = $_REQUEST['pack'];
        $pack['post_type'] = 'wpdmpro';
        $hook = "create_package_frontend";
        $user_home = get_post_meta(get_the_ID(), '__wpdmfb_root_cat', true);
        if(!$user_home)
            $user_home = get_user_meta($current_user->ID, '__wpdmfb_root_cat', true);
        $status = isset($_REQUEST['status']) && $_REQUEST['status'] == 'draft'?'draft': get_option('__wpdm_ips_frontend','publish');
        $pack['post_status'] = $status;
        $pack['post_author'] = $current_user->ID;
        $pack['post_name'] = uniqid();
        $id = wp_insert_post($pack);
        if(isset($_REQUEST['cats']))
            $cats = isset($_REQUEST['cats']) && $_REQUEST['cats'][0] > 0 ?$_REQUEST['cats']:array($user_home);
        wp_set_post_terms( $id, $cats, 'wpdmcategory' );

        foreach ($_REQUEST['file'] as $meta_key => $meta_value) {
            $key_name = "__wpdm_" . $meta_key;
            update_post_meta($id, $key_name, $meta_value);
        }

        $meta = array('version'=>'1.0.0', 'download_count' =>0 , 'view_count' => 0, 'link_label' => 'Download', 'quota' => 0, 'access' => serialize(array('')), 'template'=>'', 'page_template' =>'', 'individual_file_download' => 1);
        foreach($meta as $k => $v){
            update_post_meta($id, "__wpdm_".$k, $v);
        }

        //do_action("wpdm_file_hosting_create_package", $id);

        die('ok');

    }

    public function DeleteFolder(){
        global $current_user;
        if(!isset($_REQUEST['dcat']) || !is_user_logged_in()) return;
        $cat = (int)$_REQUEST['dcat'];
        $user_home = get_post_meta(get_the_ID(), '__wpdmfb_root_cat', true);
        if(!$user_home)
            $user_home = get_user_meta($current_user->ID, '__wpdmfb_root_cat', true);
        $parents = \WPDM\Category\CategoryController::CategoryParents($cat);
        if( intval($parents[0]) !== intval($user_home) ) return;
        wp_delete_term($cat, 'wpdmcategory');
        die('ok');
    }

    public function DeleteFile(){
        global $current_user;
        if(!isset($_REQUEST['dfile']) || !is_user_logged_in()) return;
        $file = (int)$_REQUEST['dfile'];
        $terms = wp_get_post_terms($file, 'wpdmcategory', array("fields" => "ids"));
        $cat = $terms[0];
        $user_home = get_post_meta(get_the_ID(), '__wpdmfb_root_cat', true);
        if(!$user_home)
            $user_home = get_user_meta($current_user->ID, '__wpdmfb_root_cat', true);
        $parents = \WPDM\Category\CategoryController::CategoryParents($cat);
        if( intval($parents[0]) !== intval($user_home) ) return;
        wp_delete_post($file);
        die('ok');
    }


    public function packageInfo(){
        global $post, $wpdm_download_icon;
        $wpdm_download_icon = 'fa fa-download';
        if(isset($_GET['wpdmframe'])){
            $post = (array)$post;
            $post = wpdm_setup_package_data($post);

            ?>
            <!DOCTYPE html>
            <html  xmlns="http://www.w3.org/1999/xhtml">
            <head>
                <title><?php echo $post['title']; ?></title>
                <link rel="stylesheet" href="<?php echo WPDM_BASE_URL; ?>assets/bootstrap/css/bootstrap.css">
                <link href='http://fonts.googleapis.com/css?family=Montserrat:400,700|Open+Sans:400,600' rel='stylesheet' type='text/css'>
                <link href='https://maxcdn.bootstrapcdn.com/font-awesome/4.3.0/css/font-awesome.min.css' rel='stylesheet' type='text/css'>
                <script src="<?php echo includes_url(); ?>js/jquery/jquery.js"></script>
                <script src="<?php echo WPDM_BASE_URL; ?>assets/bootstrap/js/bootstrap.min.js"></script>
                <style>
                    *:not(.fa){
                        font-family: 'Open Sans', serif;
                        color: #444;
                    }
                    h3{
                        font-family: 'Montserrat', sans-serif !important;
                        font-weight: 600 !important;
                        font-size: 11pt !important;
                        margin-bottom: 5px !important;

                    }
                    a.btn{
                        font-family: 'Montserrat', sans-serif !important;
                        font-weight: 400 !important;
                        font-size: 8pt !important;
                        text-transform: uppercase;
                    }
                    .wpdm-download-link .fa{
                        margin-right: 5px !important;
                    }
                    .note{
                        font-family: 'courier new', mono-space;
                        font-size: 12px;
                        margin-bottom: 10px;
                        color: #888888;
                    }
                    ul.list-group li a.btn{
                        padding: 5px 6px;margin-top:0;font-size: 8px !important;margin-right: -4px;
                    }
                    ul.list-group li{
                        font-size: 10px;
                        text-align: left;
                        background: #ffffff;
                        line-height: 20px;
                    }
                    .modal-body{
                        font-size: 12px;
                    }
                    .modal-backdrop{
                        background: rgba(0,0,0,0.5) !important;
                    }
                </style>
            </head>
            <body class="w3eden">
            <div class="box" style="position: relative;background: #fafafa;width: 300px;border: 1px solid #dddddd;border-radius: 6px;padding: 50px 20px;text-align: center;margin: 10px auto">
                <?php echo $post['icon']; ?>
                <h3><?php echo $post['title']; ?></h3>
                <div class="note"><?php echo $post['file_size']; ?></div>
                <?php if(count($post['files'])>1){ echo "<ul class='list-group'>"; foreach($post['files'] as $fileid => $file){
                    $ofile = $file;
                    $file = preg_replace("/[0-9]+wpdm_/","", $file);
                    if(strlen($file)>30) $file = substr($file, 0, 20)."...".substr($file, strlen($file)-11);
                    echo "<li class='list-group-item'><a href='".wpdm_download_url($post, "ind=".$fileid)."' class='pull-right btn btn-xs btn-secondary'><i class='fa fa-download'></i></a> {$file}</li>";
                } echo "</ul>"; } ?>
                <?php echo $post['download_link']=='blocked'?"<button disabled class='btn btn-danger btn-sm btn-disabled'>".__('Not Allowed', WPDMFH_TD)."</button>":$post['download_link']; ?>

                <?php if(!is_user_logged_in()){ ?>
                    <a href="#" style="position: absolute;right: -1px;top:-1px;border-radius: 0 6px;outline: none !important"  data-toggle="modal" data-target="#memb" class="btn btn-danger"><i class="fa fa-lock"></i></a>
                <?php } else { ?>
                    <a href="#" style="position: absolute;right: -1px;top:-1px;border-radius: 0 6px;" target="_blank" class="btn btn-success"><i class="fa fa-user"></i></a>
                <?php } ?>

            </div>

            <div class="modal fade" id="memb" tabindex="-1" role="dialog" aria-labelledby="sharePackLabel" aria-hidden="true">
                <div class="modal-dialog" style="width: 300px">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h4 class="modal-title"><?php _e('Member', WPDMFH_TD); ?></h4>
                        </div>
                        <div class="modal-body">



                            <form name="loginform" id="loginform" action="" method="post" class="login-form" style="margin: 0">

                                <input type="hidden" name="permalink" value="<?php the_permalink(); ?>" />

                                <?php global $wp_query; if(isset($_SESSION['login_error'])&&$_SESSION['login_error']!='') {  ?>
                                    <div class="error alert alert-danger" >
                                        <b><?php _e('Login Failed!',WPDMFH_TD); ?></b><br/>
                                        <?php echo preg_replace("/<a.*?<\/a>\?/i","",$_SESSION['login_error']); $_SESSION['login_error']=''; ?>
                                    </div>
                                <?php } ?>
                                <p class="login-username">
                                    <label for="user_login"><?php _e('Username', WPDMFH_TD); ?></label>
                                    <input type="text" name="wpdm_login[log]" id="user_login" class="form-control input required text" value="" size="20" tabindex="38" />
                                </p>
                                <p class="login-password">
                                    <label for="user_pass"><?php _e('Password', WPDMFH_TD); ?></label>
                                    <input type="password" name="wpdm_login[pwd]" id="user_pass" class="form-control input required password" value="" size="20" tabindex="39" />
                                </p>

                                <?php do_action("wpdm_login_form"); ?>
                                <?php do_action("login_form"); ?>
                                <div class="row">
                                    <p class="login-remember col-md-8"><label><input name="rememberme" type="checkbox" id="rememberme" value="forever" tabindex="39" /> <?php _e('Remember Me', WPDMFH_TD); ?></label></p>
                                    <p class="login-submit col-md-4 text-right">
                                        <button type="submit" name="wp-submit" id="wp-submit" tabindex="40" class="btn btn-primary btn-sm"><i class="fa fa-lock"></i> &nbsp; <?php _e('Log In', WPDMFH_TD); ?></button>
                                        <input type="hidden" name="redirect_to" value="<?php echo isset($redirect)?$redirect:$_SERVER['REQUEST_URI']; ?>" />

                                    </p></div>

                                <?php _e('Forgot Password?', WPDMFH_TD); ?> <a href="<?php echo site_url('/wp-login.php?action=lostpassword'); ?>"><?php _e('Request New Password.', WPDMFH_TD); ?></a>


                            </form>





                        </div>
                        <div class="modal-footer">
                            <button type="button" onclick="window.open('<?php echo site_url('/wp-login.php?action=register'); ?>');" class="pull-left btn btn-sm btn-success"><i class="fa fa-user"></i> Signup</button>
                            <button type="button" class="btn btn-sm btn-secondary" data-dismiss="modal"><?php __('Close', WPDMFH_TD); ?></button>
                        </div>
                    </div><!-- /.modal-content -->
                </div><!-- /.modal-dialog -->
            </div><!-- /.modal -->

            </body>
            </html>
            <?php
            die();
        }
    }

    function packageSettings(){

        if(!wp_verify_nonce($_REQUEST['__nonce'], NONCE_KEY)) die('-1');
        $post = get_post((int)$_REQUEST['pid']);
        include \WPDM\__\Template::locate('wpdmfh-package-settings.php', dirname(__FILE__).'/tpls/');
        die();
    }

    function folderSettings(){

        if(!wp_verify_nonce($_REQUEST['__nonce'], NONCE_KEY)) die('-1');
        $cat = get_term((int)$_REQUEST['catid'], 'wpdmcategory');
        include \WPDM\__\Template::locate('wpdmfh-folder-settings.php', dirname(__FILE__).'/tpls/');
        die();
    }

    function savePackageSettings(){
        if(!wp_verify_nonce($_REQUEST['__wpdmfh_nonce'], NONCE_KEY)) die('-1');
        $pid = (int)$_REQUEST['pid'];
        //if(!current_user_can('edit_post', $pid)) die('-1');
        global $current_user;

        $currentAccess = maybe_unserialize(get_option( '__wpdm_front_end_access', array()));

        if (!is_user_logged_in() || !array_intersect($currentAccess, $current_user->roles))  die('-1');
        $author = get_post($pid)->post_author;
        if((int)$author !== (int)$current_user->ID) die('-1');

        $_REQUEST = $_REQUEST['_file'];
        $_REQUEST['ID'] = $pid;
        wp_update_post($_REQUEST);

        foreach ($_REQUEST['file'] as $k => $v){
            $k = "__wpdm_".esc_attr($k);
            update_post_meta($pid, $k, $v);
        }
        do_action("wpdm_file_hosting_create_package", $pid);
        die('ok');
    }

    function saveFolderSettings(){
        if(!wp_verify_nonce($_REQUEST['__wpdmfhf_nonce'], NONCE_KEY)) die('-1');
        $catid = (int)$_REQUEST['catid'];
        //if(!current_user_can('edit_post', $pid)) die('-1');
        global $current_user;

        $currentAccess = maybe_unserialize(get_option( '__wpdm_front_end_access', array()));

        if (!is_user_logged_in() || !array_intersect($currentAccess, $current_user->roles))  die('-1');

        //if((int)$author !== (int)$current_user->ID) die('-1');


        wp_update_term( $catid, 'wpdmcategory', $_REQUEST['cat'] );

        foreach ($_REQUEST['_cat'] as $k => $v){
            $k = "__wpdm_".esc_attr($k);
            update_term_meta($catid, $k, $v);
        }
        die('ok');
    }

    /**
     * Remove a folder to sharing area
     */

    function untagFolder(){
        if(!is_user_logged_in()) wp_send_json(array('success' => false, 'message' => '<b>Error!</b> Unauthorized Access!'));
        global $current_user;
        $folder = (int)$_REQUEST['folder'];
        $users = maybe_unserialize(get_term_meta($folder, '__wpdm_user_access', true));
        $index = array_search($current_user->user_login, $users);
        if($index !== false){
            unset($users[$index]);
            update_term_meta($folder, '__wpdm_user_access', $users);
            wp_send_json(array('success' => true, 'message' => '<b>Success!</b> Folder is removed!'));
        }
        wp_send_json(array('success' => false, 'message' => '<b>Error!</b> Unauthorized Access!'));

    }

    /**
     * Remove a package from sharing area
     */
    function untagFile(){
        if(!is_user_logged_in()) wp_send_json(array('success' => false, 'message' => '<b>Error!</b> Unauthorized Access!'));
        $current_user = wp_get_current_user();
        $pid = wpdm_query_var('pid', 'int');
        $users = maybe_unserialize(get_post_meta($pid, '__wpdm_user_access', true));
        if(!is_array($users)) $users = array();
        $index = array_search($current_user->user_login, $users);
        if($index !== false){
            unset($users[$index]);
            update_post_meta($pid, '__wpdm_user_access', $users);
            wp_send_json(array('success' => true, 'message' => '<b>Success!</b> Package is removed!'));
        } else {
            update_post_meta($pid, '__wpdm_unshared_'.$current_user->ID, 1);
            wp_send_json(array('success' => true, 'message' => '<b>Success!</b> Package is removed!'));
        }


    }

    function importToMyFiles(){

        if(!isset($_REQUEST['pid'])) wp_send_json(array('success' => false, 'message' => '<b>Error!</b> Unauthorized Access!'));

        $ID = (int)$_REQUEST['pid'];
        $new_ID = WPDM()->package->copy($ID, get_current_user_id());
        $user_home = get_post_meta(get_the_ID(), '__wpdmfb_root_cat', true);
        if(!$user_home)
            $user_root = get_user_meta(get_current_user_id(), '__wpdmfb_root_cat', true);
        wp_set_post_terms($new_ID, array($user_root), 'wpdmcategory');
        wp_send_json(array('success' => true, 'message' => '<b>Success!</b> Package is imported!'));

    }


}
if(function_exists('WPDM'))
    new WPDMFileHosting();

