<?php
/**
 * Plugin Name: WPDM - Lazy Download
 * Description: Set a time delay before starting downloads.
 * Plugin URI: https://www.wpdownloadmanager.com/download/lazy-download-add-on/
 * Author: WordPress Download Manager
 * Version: 2.7.3
 * Author URI: https://www.wpdownloadmanager.com/
 * Update URI: wpdm-lazy-download
 */

namespace WPDM\AddOn;

use WPDM\__\__;
use WPDM\__\Crypt;
use WPDM\__\Session;

if (defined('WPDM_VERSION')) {

    class LazyDownload
    {
        public $name = "Lazy Download";

        public function __construct()
        {
            add_action("init", [$this, 'clearTimer']);
            add_action("wpdm_download_speed", [$this, 'repeatTime']);
            add_action("wpdm_onstart_download", [$this, 'apply']);
            add_action("wpdm_package_settings_tr", [$this, 'packageSettings']);

            add_shortcode("wpdm_lazy_download", [$this, 'process']);

            add_filter("add_wpdm_settings_tab", [$this, 'settingsTab']);

	        add_filter('update_plugins_wpdm-lazy-download', [$this, "updatePlugin"], 10, 4);
        }

        function register($addons)
        {
            $addons[] = $this;
            return $addons;
        }


        function apply($package)
        {


            global $wp_roles;
            $current_user = wp_get_current_user();
            $ldglobal = (int)get_option("__wpdm_lazy_download", 0);
            $ldpackage = (int)get_post_meta($package['ID'], '__wpdm_lazy_download', true);

            if ($ldglobal === 1 && $ldpackage === 0)
                $ldpackage = 1;

            if ($ldpackage !== 1 || (int)Session::get('cleared_' . $package['ID'])) {
                Session::clear('cleared_' . $package['ID']);
                return;
            }

            if(wpdm_query_var('lazykey') !== '') {
                $valid = (int)Session::get(wpdm_query_var('lazykey', 'txt'));
                $valid = $valid > 0 ? $valid - 1 : 0;
                if($valid) {
	                Session::set(wpdm_query_var('lazykey', 'txt'), $valid);
                    return;
                }
                else
                    Session::clear(wpdm_query_var('lazykey', 'txt'));
            }

            $roles = @array_reverse($wp_roles->role_names);
            if (!$roles) $roles = array();
            $wpdm_lazy_download = get_option('_wpdm_lazy_download', array());
            if(is_user_logged_in()) {
                $uroles = $current_user->roles;
                $role = array_shift($uroles);
            } else
                $role = 'guest';

            $waiting_time = wpdm_valueof($wpdm_lazy_download, $role, ['validate' => 'int', 'default' => 0]);


            if ($waiting_time > 0 && (!Session::get('waiting_time_' . $package['ID']) || (int)Session::get('waiting_time_' . $package['ID']) !== -1)) {
                setcookie('wpdm_lazy_download_' . $package['ID'], $waiting_time, 3600, '/');
                setcookie('wpdm_lazy_download_id', $package['ID'], 3600, '/');
                $id = rtrim(base64_encode($package['ID'] . '|' . $waiting_time), '=');
                Session::set('fileid', $package['ID']);
                Session::set('waiting_time_' . $package['ID'], $waiting_time);
                Session::set('lazy_download_url_' . $package['ID'], $_SERVER['REQUEST_URI']);
                $download_url_validation_key = uniqid();
                Session::set($download_url_validation_key, 5);
                $download_url = add_query_arg(['lazykey' => $download_url_validation_key], $this->requestURI());
                $pack = md5($package['ID']);
                Session::set($pack, ["ID" => $package['ID'], "download_url" => $download_url, "waiting_time" => $waiting_time]);
                header("location: " . add_query_arg(['pack' => $pack], get_permalink($wpdm_lazy_download['waiting_page'])));

                die();
            } else {
                Session::set('waiting_time_' . $package['ID'], -1);
                setcookie('wpdm_lazy_download_' . $package['ID'], '0', 3600, '/');
                setcookie('wpdm_lazy_download_id', '0', 3600, '/');
            }
        }

	    function requestURI()
	    {
		    $uri = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
		    $uri = esc_url_raw($uri);
		    return $uri;
	    }

        function clearTimer()
        {
            if (!isset($_POST['wpdm_lazy_download_timer']) || $_POST['wpdm_lazy_download_timer'] != 'clear') return;
            Session::set('waiting_time_' . $_POST['pid'], -1);
            Session::set('cleared_' . $_POST['pid'], 1);
            setcookie('wpdm_lazy_download_' . $_POST['pid'], '0', 3600, '/');
            setcookie('wpdm_lazy_download_id', '0', 3600, '/');
            echo 'Cleared!';
            die();
        }

        function packageSettings()
        {
            $ldl = (int)get_post_meta(wpdm_query_var('post'), '__wpdm_lazy_download', true);
            ?>
            <tr id="lazy_download_row">
                <td>Lazy Download</td>
                <td>
                    <label><input <?php checked($ldl, 0); ?> type="radio" name="file[lazy_download]" value="0"> Use
                        Global </label>
                    <label style="padding:0 10px"><input <?php checked($ldl, 1); ?> type="radio"
                                                                                    name="file[lazy_download]"
                                                                                    value="1"> Enable </label>
                    <label><input <?php checked($ldl, 2); ?> type="radio" name="file[lazy_download]" value="2"> Disable</label>
                </td>
            </tr>
            <?php
        }

        function process($params = array())
        {

            if (is_array($params))
                @extract($params);
            $wpdm_lazy_download = get_option('_wpdm_lazy_download', array());
            //$lazy_download_id = (int)Session::get('fileid');
            $wpdm_token = Session::get(wpdm_query_var('pack'));
            $lazy_download_id = (int)__::valueof($wpdm_token, 'ID');
            if ($lazy_download_id === 0) return '';
            $lazy_download_url = __::valueof($wpdm_token, 'download_url');
            $class = isset($class) ? $class : 'progress-striped active';

            ob_start();
            $start_download = wpdm_valueof($wpdm_lazy_download, "start_download");
            if ($wpdm_lazy_download['page_animation'] == 'progressbar') {
                $waiting_time = (int)Session::get('waiting_time_' . $lazy_download_id) * 1000;
                include dirname(__FILE__) . "/templates/progress-bar.php";

            } else {
                $waiting_time = Session::get('waiting_time_' . $lazy_download_id);
                include dirname(__FILE__) . "/templates/countdown-timer.php";

            }
            $html = ob_get_clean();
            return $html;
        }

        function settingsTab($tabs)
        {
            $tabs['lazy-download'] = wpdm_create_settings_tab('lazy-download', 'Lazy Download', [$this, 'globalSettings'], 'fas fa-hourglass-half');
            return $tabs;
        }

        function globalSettings()
        {
            global $current_user;
            if (isset($_POST['_wpdm_lazy_download']) && count($_POST['_wpdm_lazy_download']) > 0) {
                update_option('_wpdm_lazy_download', $_POST['_wpdm_lazy_download']);
                update_option('__wpdm_lazy_download', $_POST['__wpdm_lazy_download']);
                die('Settings Saves Successfully!');
            }

            $wpdm_lazy_download = get_option('_wpdm_lazy_download', array());
            ?>
            <div class="panel panel-default">
                <div class="panel-heading"><b><?php _e('Set Waiting Time Before Start Download', 'wpdmpro'); ?></b>
                </div>
                <table class="table">
                    <tr>
                        <th>User Role</th>
                        <th>Waiting Time</th>
                    </tr>
                    <tr>
                        <td>Guests</td>
                        <td><input type="text" name="_wpdm_lazy_download[guest]" class="form-control"
                                   style="width: 80px;display: inline"
                                   value="<?php echo $wpdm_lazy_download['guest']; ?>"/> secs
                        </td>
                    </tr>
                    <?php
                    global $wp_roles;
                    $roles = array_reverse($wp_roles->role_names);
                    foreach ($roles as $role => $name) { ?>
                        <tr>
                            <td><?php echo $name; ?></td>
                            <td><input type="text" size="5" class="form-control" style="width: 80px;display: inline"
                                       name="_wpdm_lazy_download[<?php echo $role; ?>]"
                                       value="<?php echo $wpdm_lazy_download[$role]; ?>"> secs
                            </td>
                        </tr>
                    <?php } ?>
                </table>
            </div>
            <div class="panel panel-default">
                <div class="panel-heading"><b><?php _e('Other Settings', 'wpdmpro'); ?></b></div>
                <table class="table">
                    <tr>
                        <td colspan="2"><label
                                    style="margin-right: 30px"><input <?php checked(get_option('__wpdm_lazy_download', 0), 1); ?>
                                        type="radio" name="__wpdm_lazy_download" value="1"> Enable Lazy Download</label>
                            <label><input <?php checked(get_option('__wpdm_lazy_download', 0), 0); ?> type="radio"
                                                                                                      name="__wpdm_lazy_download"
                                                                                                      value="0"> Disable
                                Lazy Download</label></td>
                    </tr>
                    <tr>
                        <td>Waiting Page:</td>
                        <td><?php wp_dropdown_pages(array('name' => '_wpdm_lazy_download[waiting_page]', 'selected' => $wpdm_lazy_download['waiting_page'])); ?></td>
                    </tr>
                    <tr>
                        <td>Apply:</td>
                        <td>
                            <select name="_wpdm_lazy_download[apply]">
                                <option value="0">Once for a package in same session</option>
                                <option value="1" <?php selected($wpdm_lazy_download['apply'], 1); ?> >Everytime user
                                    click on download link
                                </option>
                            </select>
                        </td>
                    </tr>
                    <tr>
                        <td>Waiting Page Animation:</td>
                        <td>
                            <select name="_wpdm_lazy_download[page_animation]">
                                <option value="progressbar">Progress Bar</option>
                                <option value="counter" <?php selected($wpdm_lazy_download['page_animation'], 'counter'); ?> >
                                    Coundown Timer
                                </option>
                            </select>
                        </td>
                    </tr>
                    <tr>
                        <td>Start Download:</td>
                        <td>
                            <select name="_wpdm_lazy_download[start_download]">
                                <option value="auto">Automatically</option>
                                <option value="onclick" <?php selected($wpdm_lazy_download['start_download'], 'onclick'); ?> >
                                    On Button Click
                                </option>
                            </select>
                        </td>
                    </tr>
                </table>
            </div>
            <?php
        }

        function repeatTime($speed)
        {
            $wpdm_lazy_download = get_option('_wpdm_lazy_download', array());
            if ($wpdm_lazy_download['apply'] != 1) return $speed;
            Session::clear('waiting_time_' . wpdm_query_var('wpdmdl'));
            return $speed;
        }

	    function updatePlugin($update, $plugin_data, $plugin_file, $locales){
		    $id = basename(__DIR__);
		    $latest_versions = WPDM()->updater->getLatestVersions();
		    $latest_version = wpdm_valueof($latest_versions, $id);
		    $access_token = wpdm_access_token();
		    $update = [];
		    $update['id']           = $id;
		    $update['slug']         = $id;
		    $update['url']          = $plugin_data['PluginURI'];
		    $update['tested']       = true;
		    $update['version']      = $latest_version;
		    $update['package']      = $access_token !== '' ? "https://www.wpdownloadmanager.com/?wpdmpp_file={$id}.zip&access_token={$access_token}" : '';
		    return $update;
	    }
    }

    new LazyDownload();

}

