<?php
if (!defined('WPINC')) exit;


class WPDM_Mailchimp_Data_Manager
{
    /**
     * Singleton instance of the class
     *
     */
    static private $instance;


    /**
     * Holds the WPDM_Mailchimp_API object
     *
     */
    public $api;


    /**
     * Initiate the Mailchimp API Object
     *
     *
     */
    public function __construct()
    {
        if (!class_exists('WPDM_MailChimp_API')) {
            require_once WPDM_MAILCHIMP_PATH . 'includes/wpdm-mailchimp-api.php';
        }
        $this->api = WPDM_MailChimp_API::get_instance();
    }


    /**
     * get the Singleton Instance of the class
     *
     */
    static public function get_instance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
        }

        return self::$instance;
    }



    /**
     * get the settings data
     *
     */
    public function get_global_settings()
    {
        return get_option(WPDM_MAILCHIMP_OPTION_KEY);
    }



    /**
     * Save the global Settings options
     *
     */
    public function save_global_settings()
    {
        $options = $this->prepare_data_to_save();

       // pd($options);
        update_option(WPDM_MAILCHIMP_OPTION_KEY, $options);
        die('Settings Saved Successfully. If you changed or just added API key please <a href="#" style="font-weight: 800" onclick="location.reload();return false;">reload page</a>');
    }

    /**
     * Get mapped fields and data sources
     * @param $feature
     * @param $list_id
     * @return mixed|string
     */
    public function get_mapped_data($feature, $list_id){
        $data = get_option("__wpdmmc_".$feature.'_'.$list_id);
        return maybe_unserialize($data);
    }

    /**
     * Saved mapped fields and data sources
     */
    public function save_data_mapping(){
        $wpdm_mailchimp_data_mappinng  = wpdm_query_var('wpdm_mailchimp_data_mappinng');
        update_option("__wpdmmc_".wpdm_query_var('feature').'_'.wpdm_query_var('list_id'), $wpdm_mailchimp_data_mappinng);
        wp_send_json(['success' => true, 'data' => $wpdm_mailchimp_data_mappinng]);
    }

    /**
     * Prepares options during save settings
     *
     */
    private function prepare_data_to_save()
    {
        //delete_option(WPDM_MAILCHIMP_OPTION_KEY);
        $options = $this->get_global_settings();
        $post_data = $_POST[WPDM_MAILCHIMP_OPTION_KEY];
        $list_settings = $post_data['list_settings'];
        // p($options);
        $data = [
            'api_key' => $post_data['api_key'],
            'enable_double_optin' => $post_data['enable_double_optin'],
            'list_assignments' => $post_data['list_assignments'],
        ];
        // pd($post_data);
        if (!empty($list_settings['list_id'])) {
            $options['list_settings'][$list_settings['list_id']] = $list_settings;
        }

        $options = array_merge($options, $data);

        //pd($this->get_global_settings());

        return $options;
    }



    /**
     * Get the constant features like Email Lock, Customer, New User signup, Optin Form
     *
     * @return array [['id', 'title', 'obsolute_id]]
     *
     */
    public function get_constant_features()
    {
        $features = [
            [
                'name' => 'email_lock',
                'id' => WPDM_MAILCHIMP_ID_PREFIX . 'email_lock',
                'title' => 'Email Lock: ',
                'obsolute_id' => 'list_id',
                'note' => 'Emails submitted from Email Lock will be added to mailchimp list.'
            ],
            [
                'name' => 'customer',
                'id' => WPDM_MAILCHIMP_ID_PREFIX . 'customer',
                'title' => 'New Customer: ',
                'obsolute_id' => 'list_id_customers',
                'note' => 'Emails will be added to mailchimp list after order completion. Applied for Premium Package users.'
            ],
            [
                'name' => 'optin_form',
                'id' => WPDM_MAILCHIMP_ID_PREFIX . 'optin_form',
                'title' => 'Optin Form: ',
                'obsolute_id' => 'list_id_optin_form',
                'note' => 'Emails colleced by Optin Form <code>[wpdm_mailchimp_form]</code> will be added to mailchimp list',
            ],
            [
                'name' => 'user_signup',
                'id' => WPDM_MAILCHIMP_ID_PREFIX . 'user_signup',
                'title' => 'New User Signup: ',
                'obsolute_id' => 'list_id_user_signup',
                'note' => 'Email from new user signup/registration will be added to mailchimp list'
            ],
        ];

        return $features;
    }



    /**
     * get the role based feature like user_role_wpdpp_customer, user_role_subscriber
     *
     * @return array [['id', 'title']]
     *
     */
    public function get_user_role_features()
    {
        $title_suffix = ':';

        $roles = $this->get_user_roles();

        $features = [];
        foreach ($roles as $role_id => $role_name) {
            $features[] = [
                'name' => 'user_role_' . $role_id,
                'id' => WPDM_MAILCHIMP_ID_PREFIX . 'user_role_' . $role_id,
                'title' => $role_name . $title_suffix,
                'obsolute_id' => $role_id
            ];
        }

        return $features;
    }


    /**
     * gets the feature option data from db ['list_id' => '']
     *
     * if no key available in db options then return nulled array ['list_id' => null]
     *
     * @return array ['list_id' => ]
     *
     */
    public function get_feature_data($key)
    {
        $options = $this->get_global_settings();
        $list_assignments = isset($options['list_assignments']) ?  $options['list_assignments'] : [];
        if (!isset($list_assignments[$key])) {
            $list_assignments[$key] = [
                'list_id' => null
            ];
        }

        return $list_assignments[$key];
    }

    public function interest_rule_data_fields($fname, $lname, $email, $dataset){
        $_categories = get_the_terms( $dataset['packageID'], 'wpdmcategory' );
        $categories = wp_list_pluck($_categories, 'name');
        $category_ids = wp_list_pluck($_categories, 'term_id');
        $category_slugs = wp_list_pluck($_categories, 'slug');
        $categories = array_merge($categories, $category_ids, $category_slugs);
        $_tags = get_the_terms( $dataset['packageID'], 'post_tag' );
        $tags = wp_list_pluck($_tags, 'name');
        $tag_ids = wp_list_pluck($_tags, 'term_id');
        $tag_slugs = wp_list_pluck($_tags, 'slug');
        $tags = array_merge($tags, $tag_ids, $tag_slugs);
        $interest_rule_data_fields = [ 'first_name' => $fname, 'last_name' => $lname, 'email' => $email, 'package_name' => $dataset['package']['post_title'], 'package_category' => $categories, 'tags' => $tags];
        return $interest_rule_data_fields;

    }

    /**
     * Prepe=are and returns dataset
     * @return array
     */
    function get_dataset(){
        $dataset = array(
            'form'          => $_REQUEST,
            //'user'          => (array)get_userdata(get_current_user_id()),
            'server'        => $_SERVER
        );
        if(isset($_REQUEST['__wpdm_ID'])) {
            $dataset['package'] = get_post($_REQUEST['__wpdm_ID'], ARRAY_A);
            $dataset['packageID'] = (int)$_REQUEST['__wpdm_ID'];
        }
        $name = isset($_REQUEST['name']) ? $_REQUEST['name'] : '';
        if(isset($_REQUEST['custom_form_field'])){
            foreach ($_REQUEST['custom_form_field'] as $key => $value){
                $dataset['form'][$key] = $value;
            }
        }
        if (strpos($name, " ")) {
            list($first_name, $last_name)  = explode(" ", $name, 2);
        } else {
            $first_name  = $last_name = $name;
        }

        $dataset['form']['first_name'] = $first_name;
        $dataset['form']['last_name'] = $last_name;
        if(is_user_logged_in()){
            $user = get_userdata(get_current_user_id());
            $dataset['user'] = ['first_name' => $user->first_name, 'last_name' => $user->last_name, 'email' => $user->user_email, 'username' => $user->user_login, 'user_login' => $user->user_login, 'roles' => $user->roles];
        }
        return $dataset;
    }

    /**
     * Compare $match with $data based on $operator
     * @param $data
     * @param $match
     * @param $operator
     * @return bool
     */
    public function data_compare($data, $match, $operator){
        $matched = false;
        switch ($operator){
            case "is":
                if(is_array($data) && in_array($match, $data)) $matched   = true;
                if(is_object($data) && in_array($match, (array)$data)) $matched   = true;
                else if($data === $match) $matched = true;
                break;
            case "isnot":
                if(is_array($data) && !in_array($match, $data)) $matched   = true;
                if(is_object($data) && !in_array($match, (array)$data)) $matched   = true;
                else if($data !== $match) $matched = true;
                break;
            case ">":
                if(is_string($data) && $data > $match) $matched = true;
                break;
            case "<":
                if(is_string($data) && $data < $match) $matched = true;
                break;
            case "contains":
                if(is_array($data) && in_array($match, $data)) $matched   = true;
                if(is_object($data) && in_array($match, (array)$data)) $matched   = true;
                else if(substr_count($data, $match)) $matched = true;
                break;
            case "starts_with":
                if(is_array($data)) $data = implode("", $data);
                if(is_object($data)) $data = implode("", (array)$data);
                if(strpos($data, $match) === 0) $matched = true;
                break;
            case "ends_with":
                if(is_array($data)) $data = implode("", $data);
                if(is_object($data)) $data = implode("", (array)$data);
                if(strpos($data, $match) === (strlen($data) - strlen($match))) $matched = true;
                break;
        }
        return $matched;
    }


    /**
     * gets the single option data from db like api key, enable double optin
     *
     * if no key available in db options then return null
     *
     * @return string|null
     *
     */
    public function get_single_data($key)
    {
        $options = $this->get_global_settings();
        if (!isset($options[$key])) {
            $options[$key] = null;
        }


        return $options[$key];
    }


    public function get_list_settings($list_id)
    {
        $options = $this->get_global_settings();
        $settings = [];
        if (isset($options['list_settings']) && isset($options['list_settings'][$list_id])) {
            $settings  = $options['list_settings'][$list_id];
        }
        return $settings;
    }







    /**
     *
     * @return array of [role_id => role_name]
     */
    private function get_user_roles()
    {
        global $wp_roles;
        $roles = array_reverse($wp_roles->role_names);
        return $roles;
    }
}
