<?php
if (!defined('WPINC')) exit;


class WPDM_Mailchimp_Install_Manager
{
    /**
     * Singleton instance of the class
     *
     */
    static private $instance;


    /**
     * WPDM_Mailchimp_Data_Manager Object
     *
     */
    public $data_manager;


    /**
     * Initiate the Mailchimp API Object
     *
     * Fill the is_Connected and api property if successfully connected to the mailchimp server
     *
     */
    public function __construct()
    {
        $this->data_manager = WPDM_Mailchimp_Data_Manager::get_instance();
    }


    /**
     * get the Singleton Instance of the class
     *
     */
    static public function get_instance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
        }

        return self::$instance;
    }



    /**
     * Runs during the activation of the plugin
     *
     */
    public function activate_plugin()
    {
    }


    /**
     * Try to update plugin if any during admin init
     *
     */
    public function update_plugin()
    {
        $this->transform_to_new_data_structure();
    }



    /**
     * This helps to not break the old users mailchimp list
     *
     */
    private function transform_to_new_data_structure()
    {
        //$this->test_old_user_options(); // TODO remove this later
        //$this->test_fresh_user_options(); // TODO remove this Later

        //if new option key found then no need to proceed the transformation
        $new_options = get_option(WPDM_MAILCHIMP_OPTION_KEY) ?: [];

        $old_option_key = 'wpdm_email_mailchimp';
        $old_options = get_option($old_option_key);

        if (count($new_options) > 0) return;

        if (isset($old_options['key'])) {
            $new_options['api_key'] = $old_options['key'];
        }

        if (isset($old_options['double_optin'])) {
            $new_options['enable_double_optin'] = $old_options['double_optin'];
        }

        $constant_features = $this->data_manager->get_constant_features();
        foreach ($constant_features as $feature) {
            if (isset($old_options[$feature['obsolute_id']])) {
                $list_id = sanitize_text_field($old_options[$feature['obsolute_id']]);
                $info = [
                    'list_id' => $list_id
                ];

                $new_options['list_assignments'][$feature['name']] = $info;
            }
        }


        $has_list_id_user_role = isset($old_options['list_id_user_role']) && is_array($old_options['list_id_user_role']) && count($old_options['list_id_user_role']) > 0;
        if ($has_list_id_user_role) {
            $user_role_featues = $this->data_manager->get_user_role_features();
            foreach ($user_role_featues as $feature) {
                if (isset($old_options['list_id_user_role'][$feature['obsolute_id']])) {
                    $list_id = sanitize_text_field($old_options['list_id_user_role'][$feature['obsolute_id']]);
                    $info = [
                        'list_id' => $list_id
                    ];

                    $new_options['list_assignments'][$feature['name']] = $info;
                }
            }
        }

        save_option(WPDM_MAILCHIMP_OPTION_KEY, $new_options);

        // remove the old data structure
        delete_option($old_option_key);

        $saved_options = get_option(WPDM_MAILCHIMP_OPTION_KEY);
        // pd($old_options, $new_options, $saved_options);
    }




    /**
     * TODO For testing old user. Remove it later
     *
     */
    private function test_old_user_options()
    {
        delete_option(WPDM_MAILCHIMP_OPTION_KEY);

        $options = [
            'key' => '06abc1101eea9149e133e86544940782-us13',
            'double_optin' => 1,
            'list_id' => '2f0e15ccf5',
            'list_id_customers' => '2f0e15ccf5',
            'list_id_user_signup' => '31d6ab191f',
            'list_id_optin_form' => '9a8899e952',
            'list_id_user_role' => ['wpdmpp_customer' => '2f0e15ccf5', 'subscriber' => '9a8899e952'],
        ];


        add_option(WPDM_MAILCHIMP_OLD_OPTION_KEY, $options);
    }

    /**
     * TODO for testing Fresh User, remove it later
     *
     */
    private function test_fresh_user_options()
    {
        delete_option(WPDM_MAILCHIMP_OPTION_KEY);
        delete_option(WPDM_MAILCHIMP_OLD_OPTION_KEY);
    }
}
