<?php
if (!defined('WPINC')) exit;


class WPDM_Mailchimp_Push_Manager
{
    /**
     * Singleton instance of the class
     *
     */
    static private $instance;


    private $data_manager;


    /**
     * Initiate the Mailchimp API Object
     *
     *
     */
    public function __construct()
    {
        $this->data_manager = WPDM_Mailchimp_Data_Manager::get_instance();
    }


    /**
     * get the Singleton Instance of the class
     *
     */
    static public function get_instance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
        }

        return self::$instance;
    }


    /**
     * Send data from email lock to mailchimp list
     * @param $post
     * @param $file
     */
    public function push_to_email_lock_list($post, $file)
    {

        $dataset = $this->data_manager->get_dataset();
        $email      = $post['email'];
        $option     = $this->data_manager->get_global_settings();
        $all_lists  = maybe_unserialize(get_option('__wpdm_mailchimp_lists', array()));
        $list_id    = wpdm_valueof($option, 'list_assignments/email_lock/list_id');
        $pack_list  = get_post_meta($post['__wpdm_ID'], '__wpdm_mailchimp_list', true);

        if ($pack_list != '' && isset($all_lists[$pack_list]))
            $list_id = $pack_list;
        $double_optin = wpdm_valueof($option, 'double_optin');

        $data_mapping = $this->data_manager->get_mapped_data('wpdm_mailchimp_email_lock', $list_id);
        //wpdmprecho($list_id);
        //wpdmdd($data_mapping);
        //if email is valid subscribe
        if (is_email($email) && $list_id) {
            $this->insert_to_list($list_id, $email, wpdm_valueof($dataset, 'form/first_name'), wpdm_valueof($dataset, 'form/last_name'), $double_optin, $data_mapping, $dataset);
        }
    }

    public function push_to_customers_list($order_id)
    {

        global $wpdb;
        $order_det      = $wpdb->get_row("select * from {$wpdb->prefix}ahm_orders where order_id='$order_id'");
        $userid         = $order_det->uid;
        $billing_info   = unserialize($order_det->billing_info);
        $buyer_email    = isset($billing_info['order_email']) ? $billing_info['order_email'] : '';
        $guest_checkout = true;

        // Checkout by logged-in user
        if ($userid) {
            $guest_checkout = false;
            $user_info      = get_userdata($userid);
            $username       = $user_info->user_login;
            $fname          = $user_info->first_name;
            $lname          = $user_info->last_name;
            $buyer_email    = $user_info->user_email;

            if ($fname == '') $fname  = $username;
            if ($lname == '') $lname  = $username;
        }

        // Guest checkout
        if (!$userid) {
            $name   = isset($billing_info['first_name']) ? $billing_info['first_name'] : '';
            $name   = explode(" ", $name, 2);
            $fname  = $name[0];
            $lname  = isset($name[1]) ? $name[1] : $fname;
        }

        $email          = $buyer_email;
        $option         = $this->data_manager->get_global_settings();
        $list_id        = wpdm_valueof($option, 'list_assignments/customer/list_id');
        $double_optin = wpdm_valueof($option, 'double_optin');

        $dataset = $this->data_manager->get_dataset();
        $data_mapping = $this->data_manager->get_mapped_data('wpdm_mailchimp_customer', $list_id);
        //if email is valid subscribe
        if (is_email($email) && $list_id) {
            $this->insert_to_list($list_id, $email, $fname, $lname, $double_optin, $data_mapping, $dataset);
        }
    }

    public function push_to_registered_users_list($user_id)
    {

        $user_info  = get_userdata($user_id);
        $username   = $user_info->user_login;
        $fname      = $user_info->first_name;
        $lname      = $user_info->last_name;
        $user_email = $user_info->user_email;

        $email          = $user_email;
        //$option         = get_option('wpdm_email_mailchimp');
        $option     = $this->data_manager->get_global_settings();
        $list_id        = wpdm_valueof($option, 'list_assignments/user_signup/list_id');
        $double_optin   = wpdm_valueof($option, 'double_optin');
        $data_mapping = $this->data_manager->get_mapped_data('wpdm_mailchimp_user_signup', $list_id);
        $dataset = $this->data_manager->get_dataset();

        if($fname == '') $fname = wpdm_valueof($dataset, 'wpdm_reg/first_name');
        if($lname == '') $lname = wpdm_valueof($dataset, 'wpdm_reg/last_name');

        if ($fname == '') $fname  = $username;
        if ($lname == '') $lname  = $username;

        //if email is valid subscribe
        if (is_email($email) && $list_id) {
            $this->insert_to_list($list_id, $email, $fname, $lname, $double_optin, $data_mapping, $dataset);
        }
    }

    public function push_to_user_role_list($user_id, $role, $old_roles)
    {

        $user_info  = get_userdata($user_id);
        $username   = $user_info->user_login;
        $fname      = $user_info->first_name;
        $lname      = $user_info->last_name;
        $user_email = $user_info->user_email;

        if ($fname == '') $fname  = $username;
        if ($lname == '') $lname  = $username;

        $email          = $user_email;
        $option     = $this->data_manager->get_global_settings();
        $list_id        = wpdm_valueof($option, "list_assignments/user_role_{$role}/list_id");
        $data_mapping = $this->data_manager->get_mapped_data('wpdm_mailchimp_user_signup', $list_id);
        $dataset = $this->data_manager->get_dataset();
        $double_optin   = wpdm_valueof($option, 'double_optin');

        //if email is valid subscribe
        if (is_email($email) && $list_id) {
            $this->insert_to_list($list_id, $email, $fname, $lname, $double_optin, $data_mapping, $dataset);
        }
    }

    public function push_to_membership_level_list($user_id, $role)
    {

        $user_info  = get_userdata($user_id);
        $username   = $user_info->user_login;
        $fname      = $user_info->first_name;
        $lname      = $user_info->last_name;
        $user_email = $user_info->user_email;

        if ($fname == '') $fname  = $username;
        if ($lname == '') $lname  = $username;

        $email          = $user_email;
        $option     = $this->data_manager->get_global_settings();
        $list_id        = wpdm_valueof($option, "list_assignments/user_role_{$role}/list_id");
        $double_optin   = wpdm_valueof($option, 'double_optin');

        //if email is valid subscribe
        if (is_email($email) && $list_id) {
            $this->insert_to_list($list_id, $email, $fname, $lname, $double_optin);
        }
    }

    public function push_to_optin_form_list()
    {

        if (isset($_POST['wpdm_mailchimp_form'])) {
            $name   = $_POST['wpdm_mailchimp_form']['name'];
            $name   = explode(" ", $name, 2);
            $fname  = $name[0];
            $lname  = isset($name[1]) ? $name[1] : '';
            $email  = $_POST['wpdm_mailchimp_form']['email'];

            $option     = $this->data_manager->get_global_settings();
            $list_id        = wpdm_valueof($option, "list_assignments/optin_form/list_id");
            $double_optin = wpdm_valueof($option, 'double_optin');

            //if email is valid subscribe
            if (is_email($email) && $list_id) {
                //check this mail already exist or not
                $is_list_member = $this->data_manager->api->email_exists_in_list($email, $list_id);
                //if not subscribed then subscribed them to list
                $referer = site_url('/');
                if ($is_list_member == false) {
                    $merge_fields = array(
                        "FNAME" => $fname,
                        "LNAME" => $lname,
                        "ACTIVE" => "Yes",
                        "SOURCE" => $referer
                    );
                    $this->data_manager->api->subscribeEmail($list_id, $email, $merge_fields, new stdClass(),'html', $double_optin);

                    $msg['type']    = 'success';
                    $msg['title']   = 'Subscribed!';
                    $msg['msg']     = 'Thank you for the subscription!';
                    header("Content-type: application/json");
                    echo json_encode($msg);
                    die();
                }
            }

            $msg['type']    = 'danger';
            $msg['title']   = 'ERROR!';
            $msg['msg']     = 'You have already subscribed using this email!';
            header("Content-type: application/json");
            echo json_encode($msg);
            die();
        }
    }

    public function insert_to_list($list_id, $email, $fname, $lname, $double_optin, $data_mapping = array(), $dataset = array())
    {
        //first check user is already subscribed or not
        $is_list_member = $this->data_manager->api->email_exists_in_list($email, $list_id);
        //if not subscribed then subscribed them to list
        $referer = site_url('/');

        if ($is_list_member == false) {
            $merge_fields = array(
                "ACTIVE"    => "Yes",
                "SOURCE"    => $referer
            );

            foreach ($data_mapping['merge_fields'] as $ID => $map){
                if(wpdm_valueof($map, 'source') !== ''){
                    $source = wpdm_valueof($map, 'source');
                    if($source) {
                        $field = wpdm_valueof($map, 'field');
                        //Set field as value when data source is set as Aa Defined
                        if($source === 'asdefined') $merge_fields[$ID] = $field;
                        else {
                            //Get all data from selected srouce
                            $data = wpdm_valueof($dataset, $source);
                            if ($field !== '') {
                                //If field is not empty, search for the value for the given field in data array
                                $field_value = wpdm_valueof($data, $field);
                                if($field_value !== '')
                                    $merge_fields[$ID] = $field_value;
                            }
                        }
                    }
                }
            }

            $interests = [];
            $interest_rule_data_fields = $this->data_manager->interest_rule_data_fields($fname, $lname, $email, $dataset);
            if(isset($data_mapping['interests']) && is_array($data_mapping['interests'])) {
                foreach ($data_mapping['interests'] as $interest) {
                    $assignment_rule = $data_mapping['assign_interest'][$interest];
                    if ($assignment_rule['show'] === 'always')
                        $interests[$interest] = true;
                    if ($assignment_rule['show'] === 'when') {
                        $matched = $this->data_manager->data_compare(wpdm_valueof($interest_rule_data_fields, $assignment_rule['field_name']), $assignment_rule['value'], $assignment_rule['compare']);
                        if ($matched) $interests[$interest] = true;
                    }

                }
            }
            //wpdmdd($merge_fields);
            $response = $this->data_manager->api->subscribeEmail($list_id, $email, $merge_fields, (object)$interests,'html', $double_optin);
            /*wpdmprecho($email);
            wpdmprecho($merge_fields);
            wpdmdd($response);*/

        }
    }
}
