<?php
if (!defined('WPINC')) exit;


class WPDM_Mailchimp_Render_Manager
{
    /**
     * Singleton instance of the class
     *
     */
    static private $instance;


    /**
     * WPDM_Mailchimp_Data_Manager Object
     *
     */
    public  $data_manager;


    /**
     * Initiate the Mailchimp API Object
     *
     * Fill the is_Connected and api property if successfully connected to the mailchimp server
     *
     */
    public function __construct()
    {
        $this->data_manager = WPDM_Mailchimp_Data_Manager::get_instance();
    }


    /**
     * get the Singleton Instance of the class
     *
     */
    static public function get_instance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
        }

        return self::$instance;
    }



    /**
     * Create the Mailchimp setting tab in Download Manager Settings page
     *
     */
    public function settings_tab($tabs)
    {
        $tabs['mailchimp'] = wpdm_create_settings_tab('mailchimp', 'MailChimp', array($this, 'render_global_settings'), 'fab fa-mailchimp');
        return $tabs;
    }



    /**
     * Renders the global settings
     *
     */

    public function render_global_settings()
    {
        // USER clicked SAVE Settings Button


        if (isset($_POST[WPDM_MAILCHIMP_OPTION_KEY])) {
            $this->data_manager->save_global_settings();
        }

        //p($options);

        $lists = $this->data_manager->api->get_all_lists();
        $options = $this->data_manager->get_global_settings();


        $args = [
            'is_connected' =>  $this->data_manager->api->is_Connected(),
            'constant_features' => $this->data_manager->get_constant_features(),
            'user_role_features' => $this->data_manager->get_user_role_features(),
            'lists' => $lists,
            'options' => $options
        ];

        $file = WPDM_MAILCHIMP_PATH . 'templates/global-settings.php';
        print_wpdm_mailchimp_template($file, $args);
    }



    /**
     * Prepares the options data to be displayed in the html forms
     *
     */
    private function prepare_data_to_display($options)
    {
        return $options;
    }


    /**
     * renders the list selection field
     *
     */
    public function render_mailchimp_selection($args)
    {
        $file = WPDM_MAILCHIMP_PATH . '/templates/selection-template.php';
        print_wpdm_mailchimp_template($file, $args);
    }


    /**
     * renders the connection status
     *
     */
    public function render_connection_alert($args)
    {
        $file =  WPDM_MAILCHIMP_PATH . '/templates/connection-alert.php';
        print_wpdm_mailchimp_template($file, $args);
    }



    /**
     * Renders the map fields
     *
     */
    public function render_list_settings_tab($args = [])
    {
        $args = [
            'lists' => $this->data_manager->api->get_all_lists()
        ];

        $file = WPDM_MAILCHIMP_PATH . 'templates/list-settings-tab.php';
        print_wpdm_mailchimp_template($file, $args);
    }


    /**
     * Renders the list mapping forms
     *
     */
    public function render_list_mapping_forms()
    {
        $feature = wpdm_query_var('feature');
        $list_id = wpdm_query_var('list_id');
        $list = $this->data_manager->api->get_list($list_id);

        $args = [
            'list' => $list,
            'list_id' => $list_id,
            'interest_categories' => $this->data_manager->api->get_interest_categories($list_id),
            'merge_fields' => $this->data_manager->api->get_merge_fields($list_id),
            //'saved_settings' => $this->data_manager->get_list_settings($list_id)
            'saved_settings' => $this->data_manager->get_mapped_data($feature, $list_id)
        ];

        //pd($args);

        //wpdmprecho($args['saved_settings']);
        $file = WPDM_MAILCHIMP_PATH . 'templates/list-mapping-forms.php';
        //include $file;
        //die();
        echo print_wpdm_mailchimp_template($file, $args);
        die();
    }



    /**
     * Renders the mailchimp selection in package settings
     */
    public function render_mailchimp_selection_in_package_settings()
    {

        $lists = $this->data_manager->api->get_all_lists();
        $plist = get_post_meta(get_the_ID(), '__wpdm_mailchimp_list', true);

        $feature = [
            'id' => WPDM_MAILCHIMP_ID_PREFIX . 'package',
            'title' => 'Package Mailchimp: '
        ];

        $info = [
            'list_id' => $plist
        ];

        $args = [
            'feature' => $feature,
            'info' => $info,
            'lists' => $lists
        ];

        $file = WPDM_MAILCHIMP_PATH . 'templates/package-settings.php';
        print_wpdm_mailchimp_template($file, $args);
    }

    // file[mailchimp_list]
    // select name="file[mailchimp_list]" id="mailchimp_list" style="width: 300px"




    public function mailchimp_subscription_form()
    {
        global $current_user;

        $name = is_user_logged_in() ? $current_user->first_name . ' ' . $current_user->last_name : '';
        $email = is_user_logged_in() ? $current_user->user_email : '';
        ob_start();
?>
        <div class="w3eden">
            <div class="panel panel-default dashboard-panel">
                <div class="panel-heading"><?php echo apply_filters('wpdm_mailchimp_optin_form_title', 'Subscribe'); ?></div>
                <div class="panel-body">
                    <form id="wpdm-mailchimp-subscription-form" method="post">
                        <div class="row">
                            <div class="col-md-4">
                                <input type="text" required class="form-control" placeholder="Full Name" value="<?php echo $name; ?>" name="wpdm_mailchimp_form[name]">
                            </div>
                            <div class="col-md-4">
                                <input type="email" required class="form-control" placeholder="Email" value="<?php echo $email; ?>" name="wpdm_mailchimp_form[email]">
                            </div>
                            <div class="col-md-4">
                                <input type="submit" id="wpdm-mailchimp-subscription-form-submit" class="btn btn-success btn-block" value="Submit">
                            </div>
                        </div>
                    </form>
                </div>
            </div>
            <div id="wpdm-mailchimp-subscription-form-response"></div>
        </div>
        <script>
            jQuery(function($) {
                $('#wpdm-mailchimp-subscription-form').on('submit', function(e) {
                    e.preventDefault();
                    var wpdm_mailchimp_subscription_form_submit = $('#wpdm-mailchimp-subscription-form-submit').html();
                    $('#wpdm-mailchimp-subscription-form-submit').html("<i class='fa fa-refresh fa-spin'></i> Please Wait...").attr('disabled', 'disabled');
                    $(this).ajaxSubmit({
                        success: function(res) {
                            $('#wpdm-mailchimp-subscription-form-response').html("<div class='alert alert-" + res.type + "' data-title='" + res.title + "'>" + res.msg + "</div>");
                            $('#wpdm-mailchimp-subscription-form-submit').html(wpdm_mailchimp_subscription_form_submit).removeAttr('disabled');
                        }
                    });
                });
            });
        </script>
<?php
        return ob_get_clean();
    }
}
