<?php

/**
 * Plugin Name:  WPDM - MailChimp
 * Plugin URI: https://www.wpdownloadmanager.com/download/mailchimp-subscription/
 * Description: MailChimp Add-on for WordPress Download Manager Plugin
 * Author: W3 Eden, Inc.
 * Version: 1.5.2
 * Author URI: https://www.wpdownloadmanager.com/
 * Update URI: wpdm-mailchimp
 */

if (!defined('WPINC')) die;

define('WPDM_MAILCHIMP_VERSION', '1.5.2');

define('WPDM_MAILCHIMP_PATH', plugin_dir_path(__FILE__));
define('WPDM_MAILCHIMP_URL', plugin_dir_url(__FILE__));
define('WPDM_MAILCHIMP_OPTION_KEY', 'wpdm_mailchimp');
define('WPDM_MAILCHIMP_OLD_OPTION_KEY', 'wpdm_email_mailchimp');
define('WPDM_MAILCHIMP_ID_PREFIX', 'wpdm_mailchimp_');
//define('WPDM_MAILCHIMP_LIST_SETTINGS_KEY', WPDM_MAILCHIMP_OPTION_KEY . "[list_settings]");
define('WPDM_MAILCHIMP_LIST_SETTINGS_KEY', WPDM_MAILCHIMP_OPTION_KEY . "_data_mappinng");
define('WPDM_MAILCHIMP_LIST_ASSIGNMENT_KEY', WPDM_MAILCHIMP_OPTION_KEY . "[list_assignments]");


class WPDM_MailChimp
{
    /**
     *  Singleton instance of this class
     */
    private static $instance;


    /**
     * holds the WPDM_Mailchimp_Data_Manager object
     */
    public $data_manager;


    /**
     * holds the WPDM_Mailchimp_Render_Manager object
     */
    public $render_manager;


    /**
     * holds the WPDM_Mailchimp_Push_Manager object
     */
    public $push_manager;


    /**
     * holds the WPDM_Mailchimp_Install_Manager object
     */
    public $install_manager;


    /**
     * loads the dependencies and attach the hooks during construction
     *
     */
    private function __construct()
    {
        $this->load_dependencies();
        $this->add_hooks();
    }


    /**
     * get the singleton instance of the WPDM_Mailchimp class
     *
     */
    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
        }
        return self::$instance;
    }



    /**
     * Loads the dependencies and initiates data manager,render manager, push manager, install manager
     *
     */
    private function load_dependencies()
    {
        require_once WPDM_MAILCHIMP_PATH . 'includes/functions.php';


        if (!class_exists('WPDM_Mailchimp_Data_Manager')) {
            require_once 'includes/wpdm-mailchimp-data-manager.php';
        }
        $this->data_manager = WPDM_Mailchimp_Data_Manager::get_instance();


        if (!class_exists('WPDM_MailChimp_Render_Manager')) {
            require_once 'includes/wpdm-mailchimp-render-manager.php';
        }
        $this->render_manager = WPDM_Mailchimp_Render_Manager::get_instance();


        if (!class_exists('WPDM_MailChimp_Push_Manager')) {
            require_once 'includes/wpdm-mailchimp-push-manager.php';
        }
        $this->push_manager = WPDM_Mailchimp_Push_Manager::get_instance();


        if (!class_exists('WPDM_MailChimp_Install_Manager')) {
            require_once 'includes/wpdm-mailchimp-install-manager.php';
        }
        $this->install_manager = WPDM_Mailchimp_Install_Manager::get_instance();
    }





    /**
     * register the necessary action, filter, shortcode hooks
     *
     */
    private function add_hooks()
    {
        register_activation_hook(__FILE__, array($this->install_manager, 'activate_plugin'));

        if (is_admin()) {
            add_action('admin_enqueue_scripts', array($this, 'add_styles_and_scripts'));

            add_action('admin_init', array($this->install_manager, 'update_plugin'));

            // add settings tab in Download Manager Settings Page
            add_filter('add_wpdm_settings_tab',  array($this->render_manager, 'settings_tab'));

            // Add custom form field in a Package Settings
            add_action('wpdm_custom_form_field',  array($this->render_manager, 'render_mailchimp_selection_in_package_settings'));
        }

        // Shortcode for Optin Form
        add_shortcode('wpdm_mailchimp_form', array($this->render_manager, 'mailchimp_subscription_form'));

        //===================== PUSH hooks ==============================================
        add_action('wpdm_before_email_download_link', array($this->push_manager, 'push_to_email_lock_list'), 10, 2);

        //add_action('wpdmpp_order_completed', array($this->push_manager, 'push_to_customers_list'), 10, 2);
        add_action('wpdmpp_payment_completed', array($this->push_manager, 'push_to_customers_list'));

        add_action('wp', array($this->push_manager, 'push_to_optin_form_list'), 10, 2);

        // Fires immediately after a new user is registered. User role is not assigned yet.
        add_action('user_register', array($this->push_manager, 'push_to_registered_users_list'), 10, 2);

        // When setting user role After User Sign Up and in any other cases when user roles are being replaced by new one
        // Fires after the user’s role has changed. do_action( 'set_user_role', int $user_id, string $role, array $old_roles )
        add_action('set_user_role', array($this->push_manager, 'push_to_user_role_list'), 10, 3);

        // This is for Pro Membership Add-on.
        // Fires immediately after the user has been given a new role. do_action( 'add_user_role', int $user_id, string $role )
        add_action('add_user_role', array($this->push_manager, 'push_to_membership_level_list'), 10, 2);


        add_action('wp_ajax_wpdm_mailchimp', array($this, 'ajax_callback'));

        add_action('wp_ajax_wpdm_maichimp_load_list_mapping_forms', array( $this->render_manager,'render_list_mapping_forms'));
        add_action('wp_ajax_save_data_mapping', array( $this->data_manager,'save_data_mapping'));

	    add_filter('update_plugins_wpdm-mailchimp', [$this, "updatePlugin"], 10, 4);
    }


	function updatePlugin($update, $plugin_data, $plugin_file, $locales){
		$id = basename(__DIR__);
		$latest_versions = WPDM()->updater->getLatestVersions();
		$latest_version = wpdm_valueof($latest_versions, $id);
		$access_token = wpdm_access_token();
		$update = [];
		$update['id']           = $id;
		$update['slug']         = $id;
		$update['url']          = $plugin_data['PluginURI'];
		$update['tested']       = true;
		$update['version']      = $latest_version;
		$update['package']      = $access_token !== '' ? "https://www.wpdownloadmanager.com/?wpdmpp_file={$id}.zip&access_token={$access_token}" : '';
		return $update;
	}




    /**
     * Add the css js files
     *
     */
    public function add_styles_and_scripts()
    {
        if(wpdm_query_var('post_type') === 'wpdmpro' && wpdm_query_var('page') === 'settings') {
            wp_enqueue_style('wpdm-mailchimp-styles', WPDM_MAILCHIMP_URL . 'includes/css/admin.css', [], WPDM_MAILCHIMP_VERSION);
            wp_enqueue_script('wpdm-mailchimp-scripts', WPDM_MAILCHIMP_URL . 'includes/js/admin.js', [], WPDM_MAILCHIMP_VERSION, true);
        }
    }




    /**
     * 'wp_ajax_wpdm_mailchimp' hook callback
     *
     */
    public function ajax_callback()
    {
        if (isset($_GET['list_id']) && isset($_GET['category_id'])) {
            $list_id = $_GET['list_id'];
            $category_id = $_GET['category_id'];
            $interests = $this->data_manager->api->get_interests($list_id, $category_id);
            wp_send_json($interests);
        } else if (isset($_GET['list_id'])) {
            $list_id = $_GET['list_id'];
            $interestCategories = $this->data_manager->api->get_interest_categories($list_id);
            wp_send_json($interestCategories);
        }

        wp_send_json(['error' => 'nothing handled']);
    }


    function listMaps()
    {
        include __DIR__ . '/templates/map-cond.php';
        die();
    }
}



// create the WPDM_Mailchimp Object and assign it in a global variable
if(function_exists('WPDM')) {
    global $wpdm_mailchimp;
    $wpdm_mailchimp = WPDM_MailChimp::getInstance();
}
