<?php
namespace CAMPAIGN\ADMIN\SETTINGS;

if(!defined('WPINC')) {
    exit;
}

class GeneralSettings{
    private static $instance;
    private $messages, $errors, $dir, $url, $table,$utility;
    private $settings_api;
    public static function getInstance(){
        if(self::$instance === null){
            self::$instance = new self;
            self::$instance->dir = \CAMPAIGN\EdenCampaign::getDir();
            self::$instance->url = \CAMPAIGN\EdenCampaign::getUrl();
            self::$instance->messages = array();
            self::$instance->errors = array();
            self::$instance->utility = new \CAMPAIGN\UTIL\Utility();   
            global $wpdb;
            self::$instance->table = $wpdb->prefix . 'eden_campaign';
            self::$instance->actions();
            if(!class_exists('WPDM_NL_Settings_API')) {
                require_once self::$instance->dir . '/libs/settings-api/class.settings-api.php';
            }
            self::$instance->settings_api = new \WPDM_NL_Settings_API;
        }
        return self::$instance;
    }
    
    private function actions(){
        add_action( 'admin_init', array($this, 'admin_init') );
        add_action( 'admin_menu', array($this, 'admin_menu') );
        
        //test 
        add_action('wsa_form_top_eden_campaign_basics',array($this,'eden_campaign_basics'),10,1);
    }

    function admin_init() {
        //set the settings
        $this->settings_api->set_sections( $this->get_settings_sections() );
        $this->settings_api->set_fields( $this->get_settings_fields() );

        //initialize settings
        $this->settings_api->admin_init();
    }

    function admin_menu() {
        add_submenu_page('edit.php?post_type=eden_campaign', __('General Settings','eden_campaign'), __('General Settings','eden_campaign'), 'manage_options', 'campaign_general_settings', array($this,'settings'));
    }
    
    function settings(){
        echo '<div class="wrap wpdmnewsletter-settings">';
        $this->settings_api->show_navigation();
        $this->settings_api->show_forms();
        echo '</div>';
    }
    
    private function get_settings_sections() {
        $sections = array(
            array(
                'id' => 'eden_campaign_basics',
                'title' => __( 'Basic Settings', 'eden_campaign' )
            ),
            array(
                'id' => 'eden_campaign_email',
                'title' => __( 'Email Settings', 'eden_campaign' )
            ),
            array(
                'id' => 'eden_campaign_smtp',
                'title' => __( 'SMTP', 'eden_campaign' )
            ),
            array(
                'id' => 'eden_campaign_advanced',
                'title' => __( 'Advanced Settings', 'eden_campaign' )
            )
        );
        return $sections;
    }
    
    private function get_settings_fields() {
        $post_types = get_post_types( array('public'=>true), 'names' );
        foreach($post_types as $post_type) {
            $options[$post_type] = $post_type;
        }
        //Basic Settings
        $settings_fields['eden_campaign_basics'][] = array(
            'name' => 'post_type',
            'label' => __( 'Post Subscription Post Type', 'eden_campaign' ),
            'desc' => __( 'Checked post types which you want to add support for post subscriptions', 'eden_campaign' ),
            'type' => 'multicheck',
            'default' => 'no',
            'options' => $options
        );
        
        $settings_fields['eden_campaign_basics'][] = array(
            'name' => 'campaign_url',
            'label' => __( 'Profile Page URL', 'eden_campaign' ),
            'desc' => __( 'Create a page/post with shortcode [eden_campaign_subscriber] as content, copy page url and paste it here.', 'eden_campaign' ),
            'type' => 'text',
            'default' => '',
        );
        
        
        //Email Settings
        $settings_fields['eden_campaign_email'][] = array(
            'name' => 'sender_email',
            'label' => __( 'Sender Email Address', 'eden_campaign' ),
            'desc' => __( 'Use an email address within your domain name here.', 'eden_campaign' ),
            'type' => 'text',
            'default' => get_option('admin_email')
        );
        
        $settings_fields['eden_campaign_email'][] = array(
            'name' => 'sender_name',
            'label' => __( 'Sender Name', 'eden_campaign' ),
            'desc' => __( 'Enter name here, eg. your blog name', 'eden_campaign' ),
            'type' => 'text',
            'default' => get_bloginfo('name')
        );
        
        $settings_fields['eden_campaign_email'][] = array(
            'name' => 'return_path',
            'label' => __( 'Return Path', 'eden_campaign' ),
            'desc' => __( 'Email address where delivery error messages are sent by mailing systems (eg. mailbox full, invalid address etc)', 'eden_campaign' ),
            'type' => 'text',
            'default' => get_option('admin_email')
        );
        
        $settings_fields['eden_campaign_email'][] = array(
            'name' => 'reply_to',
            'label' => __( 'Reply To', 'eden_campaign' ),
            'desc' => __( 'This is the email address where subscribers will reply', 'eden_campaign' ),
            'type' => 'text',
            'default' => get_option('admin_email')
        );
        
                
        
        //SMTP Settings
        $settings_fields['eden_campaign_smtp'][] = array(
            'name' => 'enable',
            'label' => __( 'Enable SMTP', 'eden_campaign' ),
            'desc' => __( 'Select Enabled, if you want to send email from your SMTP account', 'eden_campaign' ),
            'type' => 'select',
            'default' => '0',
            'options' => array(
                '0' => 'Disabled',
                '1' => 'Enabled'
            )
        );
        
        $settings_fields['eden_campaign_smtp'][] = array(
            'name' => 'host',
            'label' => __( 'SMTP Host', 'eden_campaign' ),
            'desc' => __( 'Enter your SMTP host/server address. eg. To use Gmail try host "smtp.gmail.com"', 'eden_campaign' ),
            'type' => 'text',
        );
        
        $settings_fields['eden_campaign_smtp'][] = array(
            'name' => 'port',
            'label' => __( 'SMTP Port', 'eden_campaign' ),
            'desc' => __( 'Enter your SMTP host/server port. eg. If you use Gmail as your SMTP server, SMTP Port will be "465"', 'eden_campaign' ),
            'type' => 'text',
            'default' => 25
        );
        
        $settings_fields['eden_campaign_smtp'][] = array(
            'name' => 'security',
            'label' => __( 'Connection Security', 'eden_campaign' ),
            'desc' => __( 'If authentication is required for your server SMTP, Select a protocol from here. eg. For gmail select TLS', 'eden_campaign' ),
            'type' => 'select',
            'default' => '',
            'options' => array(
                '' => 'No Secure Protocol',
                'ssl' => 'SSL',
                'tls' => 'TLS'
            )
        );
        
        $settings_fields['eden_campaign_smtp'][] = array(
            'name' => 'user',
            'label' => __( 'Username', 'eden_campaign' ),
            'desc' => __( 'Enter Username of your SMTP account', 'eden_campaign' ),
            'type' => 'text',
        );
        
        $settings_fields['eden_campaign_smtp'][] = array(
            'name' => 'password',
            'label' => __( 'Password', 'eden_campaign' ),
            'desc' => __( 'Enter Password for your SMTP account', 'eden_campaign' ),
            'type' => 'password',
        );
        
        
        //advance settings
        
        $settings_fields['eden_campaign_advanced'][] = array(
            'name' => 'scheduler_max',
            'label' => __( 'Max Emails Per Hour', 'eden_campaign' ),
            'desc' => __( '', 'eden_campaign' ),
            'type' => 'text',
        );
        
        $settings_fields['eden_campaign_advanced'][] = array(
            'name' => 'php_time_limit',
            'label' => __( 'PHP Max Execution Time', 'eden_campaign' ),
            'desc' => __( 'Sets the PHP max execution time in seconds, overriding the default of your server.', 'eden_campaign' ),
            'type' => 'text',
        );

        return $settings_fields;
    }
    
    
    //
    
    public function eden_campaign_basics($args){
        //print_r($args);
    }
    
    
}

