<?php
namespace CAMPAIGN\ADMIN\SETTINGS;

if(!defined('WPINC')) {
    exit;
}

class SubscriberSettings{
    private static $instance;
    private $messages, $errors, $dir, $url, $table,$utility;
    private $settings_api;
    public static function getInstance(){
        if(self::$instance === null){
            self::$instance = new self;
            self::$instance->dir = \CAMPAIGN\EdenCampaign::getDir();
            self::$instance->url = \CAMPAIGN\EdenCampaign::getUrl();
            self::$instance->messages = array();
            self::$instance->errors = array();
            self::$instance->utility = new \CAMPAIGN\UTIL\Utility();   
            global $wpdb;
            self::$instance->table = $wpdb->prefix . 'eden_campaign';
            self::$instance->actions();
            if(!class_exists('WPDM_NL_Settings_API')) {
                require_once self::$instance->dir . '/libs/settings-api/class.settings-api.php';
            }
            self::$instance->settings_api = new \WPDM_NL_Settings_API;
        }
        return self::$instance;
    }
    
    private function actions(){
        add_action( 'admin_init', array($this, 'admin_init') );
        add_action( 'admin_menu', array($this, 'admin_menu') );
    }

    function admin_init() {
        //set the settings
        $this->settings_api->set_sections( $this->get_settings_sections() );
        $this->settings_api->set_fields( $this->get_settings_fields() );

        //initialize settings
        $this->settings_api->admin_init();
    }

    function admin_menu() {
        add_submenu_page('edit.php?post_type=eden_campaign', __('Subscriber Settings','campaign'), __('Subscriber Settings'), 'manage_options', 'campaign_subscriber_settings', array($this,'settings'));
    }
    
    function settings(){
        echo '<div class="wrap wpdmnewsletter-settings">';
        $this->settings_api->show_navigation();
        $this->settings_api->show_forms();
        echo '</div>';
    }
    
    private function get_settings_sections() {
        $sections = array(
            array(
                'id' => 'campaign_subscriber_basic',
                'title' => __( 'General Settings', 'eden_campaign' )
            ),
            array(
                'id' => 'campaign_subscriber_subscribe',
                'title' => __( 'Subscriber Settings', 'eden_campaign' )
            ),
            array(
                'id' => 'campaign_subscriber_unsubscribe',
                'title' => __( 'Unsubscribe Settings', 'eden_campaign' )
            )
        );
        return $sections;
    }
    
    private function get_settings_fields() {
        //subscriber basic settings
        
        $settings_fields['campaign_subscriber_basic'][] = array(
            'name' => 'opt_in',
            'label' => __( 'Opt In', 'eden_campaign' ),
            'desc' => __('Double Opt In means subscribers need to confirm their email address by an activation link sent them on a activation email message.<br> Single Opt In means subscribers do not need to confirm their email address.', 'eden_campaign' ),
            'type' => 'select',
            'default' => '0',
            'options' => array(
                '0' => 'Double Opt In',
                '1' => 'Single Opt In'
            )
        );
        
        $settings_fields['campaign_subscriber_basic'][] = array(
            'name' => 'email_notification',
            'label' => __( 'Email Notification', 'eden_campaign' ),
            'desc' => __( 'Select Yes, if you want to get notification, when a user subscribe or unsubscribe to any campaign list', 'eden_campaign' ),
            'type' => 'select',
            'default' => '0',
            'options' => array(
                '0' => 'No',
                '1' => 'Yes'
            )
        );
        
        $settings_fields['campaign_subscriber_basic'][] = array(
            'name' => 'notify_email',
            'label' => __( 'Email Address', 'eden_campaign' ),
            'desc' => __( 'Email Address to get admin notification', 'eden_campaign' ),
            'type' => 'text',
            'default' => get_option('admin_email')
        );
        
        
        //subscribe settings
        
        $settings_fields['campaign_subscriber_subscribe'][] = array(
            'name' => 'confirmation_msg',
            'label' => __( 'Subscription Success Message', 'eden_subscriber' ),
            'desc' => __( 'This message will be shown if email subscription is successful.', 'eden_subscriber' ),
            'type' => 'textarea',
            'sanitize_callback' => 'stripslashes',
            'default' => "You have successfully subscribed to the newsletter. 
You'll receive a confirmation email in few minutes. 
Please follow the link in it to confirm your subscription. 
If the email takes more than 15 minutes to appear in your mailbox, please check
your spam folder."
        );
        
        $settings_fields['campaign_subscriber_subscribe'][] = array(
            'name' => 'confirmation_email_subject',
            'label' => __( 'Confirmation Email Subject', 'eden_campaign' ),
            'desc' => __( 'Email subject field for confirmation email', 'eden_campaign' ),
            'type' => 'text',
            'sanitize_callback' => 'stripslashes',
            'default' => 'Please confirm subscription - ##site_name## newsletter'
        );
        
        $settings_fields['campaign_subscriber_subscribe'][] = array(
            'name' => 'confirmation_email',
            'label' => __( 'Confirmation Email Message', 'eden_subscriber' ),
            'desc' => __( 'Confirmation email', 'eden_subscriber' ),
            'type' => 'textarea',
            'sanitize_callback' => 'stripslashes',
            'default' => "<p>Hi ##name##,</p>
<p>A newsletter subscription request for this email address was
received. Please confirm it by clicking ##subscribe_here##. If you cannot
click the link, please use the following link.</p>

<p>##subscribe_url##</p>

<p>If you did not make this subscription request, just ignore this
message.</p>
<p>Thank you!<br>
<a href='##site_url##'>##site_name##</a></p>"
        );
        
        
        $settings_fields['campaign_subscriber_subscribe'][] = array(
            'name' => 'activation_message',
            'label' => __( 'Message after activation' , 'eden_subscriber' ),
            'desc' => __( 'Message after successful activation', 'eden_subscriber' ),
            'type' => 'textarea',
            'sanitize_callback' => 'stripslashes',
            'default' => "<p>Your subscription has been confirmed! Thank you ##name##!</p>"
        );
        
        $settings_fields['campaign_subscriber_subscribe'][] = array(
            'name' => 'subscription_success_email',
            'label' => __( 'Send Subscription success email ?', 'eden_campaign' ),
            //'desc' => __( '', 'eden_campaign' ),
            'type' => 'checkbox'
        );
        
        
        $settings_fields['campaign_subscriber_subscribe'][] = array(
            'name' => 'subscription_success_email_subject',
            'label' => __( 'Success Email Subject', 'eden_campaign' ),
            //'desc' => __( 'Email subject field for confirmation email', 'eden_campaign' ),
            'type' => 'text',
            'default' => 'Welcome ##name##'
        );
        
        $settings_fields['campaign_subscriber_subscribe'][] = array(
            'name' => 'subscription_success_email_body',
            'label' => __( 'Success Email Message', 'eden_subscriber' ),
            //'desc' => __( 'Confirmation email', 'eden_subscriber' ),
            'type' => 'textarea',
            'sanitize_callback' => 'stripslashes',
            'default' => "<p>This message confirms your subscription to the ##site_name## newsletter.</p>
<p>Thank you!<br>
<a href='##site_url##'>##site_name##</a></p>
<p>To unsubscribe, <a href='##unsubscribe_url##'>click here</a>.  To change subscriber options,
<a href='##profile_url##'>click here</a>.</p>"
        );
        
        $settings_fields['campaign_subscriber_subscribe'][] = array(
            'name' => 'already_subscribed_msg',
            'label' => __( 'Already Subscribed Message', 'eden_subscriber' ),
            //'desc' => __( 'Confirmation email', 'eden_subscriber' ),
            'type' => 'textarea',
            'sanitize_callback' => 'stripslashes',
            'default' => "<p>This email address is already subscribed.</p>"
        );
        
        
        //campaign_subscriber_unsubscribe
        
        $settings_fields['campaign_subscriber_unsubscribe'][] = array(
            'name' => 'unsubscribe_email_subject',
            'label' => __( 'Unsubscribe Mail Subject', 'eden_subscriber' ),
            //'desc' => __( 'Confirmation email', 'eden_subscriber' ),
            'type' => 'text',
            'sanitize_callback' => 'stripslashes',
            'default' => "Please confirm unsubscription - ##site_name## newsletter"
        );
        
        $settings_fields['campaign_subscriber_unsubscribe'][] = array(
            'name' => 'unsubscribe_email_msg',
            'label' => __( 'Unsubscribe Email Message', 'eden_subscriber' ),
            //'desc' => __( 'Confirmation email', 'eden_subscriber' ),
            'type' => 'textarea',
            'sanitize_callback' => 'stripslashes',
            'default' => "<p>Please confirm that you want to unsubscribe by <a href='##unsubscribe_url##'>clicking here</a>.</p>"
        );
        
        
        $settings_fields['campaign_subscriber_unsubscribe'][] = array(
            'name' => 'unsubscribe_success_msg',
            'label' => __( 'Unsubscribe Success Message', 'eden_subscriber' ),
            //'desc' => __( 'Confirmation email', 'eden_subscriber' ),
            'type' => 'textarea',
            'sanitize_callback' => 'stripslashes',
            'default' => "<p>Your subscription has been deleted. Thank you.</p>"
        );
        
        
        
        

        return $settings_fields;
    }
}

