<?php
namespace CAMPAIGN\INIT;

if(!defined('WPINC')) {
    exit;
}

class PostType{
    private static $instance;
    private $dir, $url;
    private $util;
    public static function getInstance(){
        if(self::$instance === null){
            self::$instance = new self;
            self::$instance->dir = \CAMPAIGN\EdenCampaign::getDir();
            self::$instance->url = \CAMPAIGN\EdenCampaign::getUrl();
            self::$instance->actions();
        }
        return self::$instance;
    }

    private function actions(){
        add_action( 'init', array($this,'newsLetterPostType'), 0 );
        add_action( 'admin_print_scripts-post-new.php', array($this,'postScript'), 11 );
        add_action( 'admin_print_scripts-post.php', array($this,'postScript'), 11 );
        add_action( 'admin_print_styles-post-new.php', array($this,'postStyle'), 11 );
        add_action( 'admin_print_styles-post.php', array($this,'postStyle'), 11 );
        add_action( 'admin_enqueue_scripts', array($this,'adminScripts'), 11 );

        add_filter( 'enter_title_here', array($this,'changeTitle'), 8 );

        add_action( 'add_meta_boxes_eden_campaign', array($this,'metaBoxes'));
        add_action( 'save_post', array( $this, 'saveMeta' ) );

        //remove Subscriber Category Metabox
        add_action( 'admin_menu' , array($this,'removeMeta'));

        //hide unnecessary options from Publish metabox
        add_action('admin_head-post.php', array($this,'hidePublishingActions'));
        add_action('admin_head-post-new.php', array($this,'hidePublishingActions'));

        //add option to publish metabox
        add_action( 'post_submitbox_misc_actions', array($this,'publishMeta') );

        $this->util = new \CAMPAIGN\UTIL\Utility();
    }

    public function hidePublishingActions(){
        $my_post_type = 'eden_campaign';
        global $post;
        if($post->post_type == $my_post_type){
            echo '
                <style type="text/css">
                    #minor-publishing-actions,
                    .misc-pub-post-status, .misc-pub-visibility{
                        display:none;
                    }
                </style>
            ';
        }
    }

    public function removeMeta(){
        remove_meta_box('tagsdiv-subscriber_cat', 'eden_campaign', 'side');
    }

    public function saveMeta($post_id){

//        echo '<pre>'; print_r($_POST); echo "</pre>";
//        die();

        if (!isset($_POST['post_type']) )
            return $post_id;

        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
            return $post_id;

        if(get_post_type($post_id) !== "eden_campaign")
            return $post_id;


        if(isset($_REQUEST['editor_meta_nonce']) && check_admin_referer('editor_meta','editor_meta_nonce')){
            $data = isset($_POST['mycustomeditor']) ? $_POST['mycustomeditor'] :'';
            update_post_meta($post_id, '_campaign_content', $data);
        }

        if(isset($_REQUEST['info_meta_nonce']) && check_admin_referer('info_meta','info_meta_nonce')){
            $data = isset($_POST['campaign_meta']) ? array_map('stripslashes', $_POST['campaign_meta']) :'';
            $data = array_map('trim', $data);

            update_post_meta($post_id, '_campaign_info', $data);
        }


        if(isset($_REQUEST['schedule_meta_nonce']) && check_admin_referer('schedule_meta','schedule_meta_nonce')){
            $data = isset($_POST['campaign_schedule']) ? array_map('stripslashes', $_POST['campaign_schedule']) :'';
            $data = array_map('trim', $data);
            //print_r($data);
            //die;
            update_post_meta($post_id, '_campaign_schedule', $data);
        }


        if(isset($_REQUEST['send_now_nonce']) && check_admin_referer('send_now','send_now_nonce')){
            //die();
            $on = isset($_POST['send_now']) ?  $_POST['send_now'] : '';
            update_post_meta($post_id, '_send_now', $on);

            //send data to data base... for the first time
            //check campaign already exist on eden_email_queue or not....
            if($on == 'on'){
                global $wpdb;
                $query = "SELECT * FROM $wpdb->eden_email_queue WHERE post_id='$post_id'";
                $res = $wpdb->get_row($query);
                //die(print_r($res));
                if(!empty($res)) {
                    //already in database
                    //print_r($res);
                    //die;
                }
                else {
                    $data = maybe_unserialize(get_post_meta($post_id, '_campaign_schedule', true));
                    //insert new data
                    $db_data['post_id'] = $post_id;
                    $db_data['msg_type'] = 2;
                    if($data['repeat_campaign'] == "on") {
                        $db_data['recurrent'] = 1;
                    }
                    else {
                        $db_data['recurrent'] = 0;
                    }
                    $db_data['total_sent'] = 0;
                    $db_data['created'] = date("Y-m-d H:i:s");
                    //$db_data['send_on'] = strtotime($data['delivery_date'] . ' ' . $data['delivery_time']);

                    $date = explode('-', $data['delivery_date']);
                    $time = explode(':', $data['delivery_time']);
                    $send_on = mktime($time[0],$time[1],$time[2],$date[1],$date[2],$date[0]);
                    $db_data['send_on'] = $send_on;

                    $format = array("%d", "%d", "%d", "%d", "%s","%d");

                    $wpdb->insert($wpdb->eden_email_queue,$db_data,$format);

                }
            }



        }

        if(isset($_REQUEST['subscriber_list_nonce']) && check_admin_referer('subscriber_list','subscriber_list_nonce')){
            $data = isset($_POST['eden_subscriber_category']) ?  $_POST['eden_subscriber_category'] : '';
            //die($data);
            update_post_meta($post_id, '_subscriber_category', $data);
        }

        if(isset($_REQUEST['eden_template_meta_nonce']) && $_REQUEST['eden_template_meta_nonce'] != ''){
            if(check_admin_referer('eden_template_meta','eden_template_meta_nonce')){
                $data = isset($_POST['template_name']) ? stripslashes($_POST['template_name']) :'';
                update_post_meta($post_id, '_campaign_template', $data);
            }
        }

    }

    public function metaBoxes($post){
        add_meta_box('campaign_info', __('Campaign Information','eden_campaign'), array($this,'campaignInfoMeta'),'eden_campaign','normal','high');
        add_meta_box('template_info', 'Templates', array($this,'templateMeta'),'eden_campaign','normal','high');
        add_meta_box('editor', 'Content', array($this,'editorMeta'),'eden_campaign');
        add_meta_box('campaign_schedule', __('Campaign Schedule','eden_campaign'), array($this,'campaignScheduleMeta'),'eden_campaign','side','default');
        add_meta_box('subscriber_category', __('Subscriber List','eden_campaign'), array($this,'subscriberCategoryMeta'),'eden_campaign','side','default');

    }

    public function publishMeta(){
        global $post;
            if (get_post_type($post) != 'eden_campaign') {
                return ;
            }
        $data = isset($_GET['post']) ? get_post_meta($_GET['post'],'_send_now',true) : '';
            wp_nonce_field( 'send_now', 'send_now_nonce' );
        ?>
            <div class="misc-pub-section misc-pub-section-last" style="border-top: 1px solid #eee;">
                <label for="send_now"><input type="checkbox" name="send_now" value="on" id="send_now" <?php if(isset($data) && $data=='on') {echo "checked='checked' readonly='readonly'";} ?> /> Add To Email Queue Now ? </label>
            </div>
        <?php
    }

    public function subscriberCategoryMeta($post){
        $data = maybe_unserialize(get_post_meta($post->ID,'_subscriber_category',true));
        $allList = $this->util->getTerms();
        wp_nonce_field( 'subscriber_list', 'subscriber_list_nonce' );
        if(!empty($allList)):
            echo "<ul>";
            foreach($allList as $list_id => $list_name):
            ?>
                <li>
                    <label for="cat_<?php echo $list_id; ?>">
                        <input type="checkbox" name="eden_subscriber_category[]" id="cat_<?php echo $list_id; ?>" value="<?php echo $list_id; ?>" <?php if(!empty($data) && in_array($list_id, $data)) echo "checked='checked'" ?> class="popular-category subscriber_list" />
                        <?php echo $list_name; ?>
                    </label>
                </li>
            <?php
            endforeach;
            echo "</ul>";

        else:

            echo __("No List Found",'eden_campaign');

        endif;
        ?>
                <script type="text/javascript">
                    jQuery(function($){

                        $('#publish').click(function(){

                            if($('.subscriber_list').is(':checked')) {
                                return true;
                            }
                            else {
                                alert('Please select at lesat one subscriber list');
                                return false;
                            }

                        });

                    });

                </script>
        <?php
    }

    public function campaignScheduleMeta($post){

        $data = maybe_unserialize(get_post_meta($post->ID, '_campaign_schedule', true));
        //print_r($data);
        //die;
        if(empty($data)) {
            $data = array();
            $data['delivery_date'] = "";
            $data['delivery_time'] = "";
            $data['repeat_campaign'] = "";
            $data['frequency_count'] = "";
            $data['frequency_occur'] = "";
        }

    ?>
        <?php wp_nonce_field( 'schedule_meta', 'schedule_meta_nonce' ); ?>
        <table>
            <tbody>
                <tr valign="top">
                    <th scope="row">
                        <label for="delivery_date">
                            <?php _e('Delivery Date','eden_campaign'); ?>
                        </label>
                    </th>

                    <td>
                        <input type="text" name="campaign_schedule[delivery_date]" id="delivery_date" class="widefat" readonly="readonly"  value="<?php echo $data['delivery_date']; ?>" />
                        <p class="discription"></p>
                    </td>
                </tr>

                <tr valign="top">
                    <th scope="row">
                        <label for="delivery_time">
                            <?php _e('Delivery Time','eden_campaign'); ?>
                        </label>
                    </th>

                    <td>
                        <input type="text" name="campaign_schedule[delivery_time]" id="delivery_time" class="widefat" readonly="readonly"  value="<?php echo $data['delivery_time']; ?>" />
                        <p class="discription"></p>
                    </td>
                </tr>

                <tr valign="top">
                    <th scope="row">
                        <label for="repeat_campaign">
                            <?php _e('Repeat Campaign','eden_campaign'); ?>
                        </label>
                    </th>

                    <td>
                        <input type="checkbox" name="campaign_schedule[repeat_campaign]" id="repeat_campaign" class="widefat" value="on" <?php if(isset($data['repeat_campaign']) && $data['repeat_campaign']=="on") {echo "checked='checked' readonly='readonly'" ; } ?> />
                        <p class="discription"></p>
                    </td>
                </tr>

                <tr valign="top" class="hide">
                    <th scope="row">
                        <label for="delivery_frequency">
                            <?php _e('Frequency','eden_campaign'); ?>
                        </label>
                    </th>

                    <td>
                        <select name="campaign_schedule[frequency_count]" id="frequency_count">
                        <?php
                            for($i = 1; $i<=30; $i++) echo "<option value='$i'>$i</option>";
                        ?>
                        </select>
                        <select name="campaign_schedule[frequency_occur]">
                            <option value="day">Day</option>
                            <option value="month">Month</option>
                            <option value="year">Year</option>
                        </select>
                        <p class="discription"></p>
                    </td>
                </tr>
            </tbody>
        </table>

        <script type='text/javascript'>
            jQuery(function($){
                //$('#delivery_date').datetimepicker();

                function hideText(){
                    var hide = '<?php echo isset($data['repeat_campaign'])?$data['repeat_campaign']:''; ?>';
                    if(hide == "") {
                        $('.hide').hide();
                    }
                    else {
                        $('.hide').show();
                    }
                }
                hideText();

                $('#repeat_campaign').click(function() {
                    var $this = $(this);
                    // $this will contain a reference to the checkbox
                    if ($this.is(':checked')) {
                        $('.hide').show();
                    } else {
                        // the checkbox was unchecked
                        $('.hide').hide();
                    }
                });

                $('#delivery_date').datepicker({
                    changeMonth: true,
                    changeYear: true,
                    //showButtonPanel: true,
                    dateFormat: 'yy-mm-dd',
                    //autoSize: true,
                    minDate: '+0d'
                  });
                 $('#delivery_time').timepicker({
                     timeFormat: 'HH:mm:ss'
                 });
            });
        </script>
    <?php
    }


    public function campaignInfoMeta($post){
        $data = maybe_unserialize(get_post_meta($post->ID,'_campaign_info',true));
        if(empty($data) || $data == ""){
            $data = array('from_name' => '',  'email_subject' => '', 'from_email' => '', 'delivery_date' => '');
        }

    ?>
        <?php wp_nonce_field( 'info_meta', 'info_meta_nonce' ); ?>
        <table class="form-table">
            <tbody>
                <tr valign="top">
                    <th scope="row">
                        <label for="from_name">
                            <?php _e('From Name','eden_campaign'); ?>
                        </label>
                    </th>

                    <td>
                        <input type="text" name="campaign_meta[from_name]" id="from_name" class="regular-text" value="<?php echo $data['from_name']; ?>" />
                        <p class="discription"></p>
                    </td>
                </tr>

                <tr valign="top">
                    <th scope="row">
                        <label for="email_subject">
                            <?php _e('Email Subject','eden_campaign'); ?>
                        </label>
                    </th>

                    <td>
                        <input type="text" name="campaign_meta[email_subject]" id="email_subject" class="regular-text"  value="<?php echo $data['email_subject']; ?>" />
                        <p class="discription"></p>
                    </td>
                </tr>

                <tr valign="top">
                    <th scope="row">
                        <label for="from_email">
                            <?php _e('From Email','eden_campaign'); ?>
                        </label>
                    </th>

                    <td>
                        <input type="email" name="campaign_meta[from_email]" id="from_email" class="regular-text"  value="<?php echo $data['from_email']; ?>" />
                        <p class="discription"></p>
                    </td>
                </tr>



            </tbody>
        </table>

        <script type="text/javascript">

        </script>
    <?php

    }








    public function templateMeta($post){
        $templates = $this->util->getTemplates();
        //print_r($templates);
        $template = get_post_meta($post->ID,'_campaign_template', true);
        if($template === "" || 1){
            //show template part , hide content part,
            //if template is selected show content part



        ?>
        <?php wp_nonce_field( 'eden_template_meta', 'eden_template_meta_nonce' ); ?>
        <table class="form-table">
            <tr valign="top">
                <th scope="row">
                    <label for="template">
                        <?php _e('Select A Template','eden_campaign'); ?>
                    </label>
                </th>

                <td>
                    <select name="template_name" id="template_meta" class="regular-text">
                        <option value=""><?php _e('Select a template','eden_campaign'); ?></option>
                        <?php
                            if(!empty($templates)):
                                foreach ($templates as $key => $url):
                                    echo "<option value='{$key}' ".  selected($template, $key, false).">" . ucfirst($key) . "</option>";
                                endforeach;
                            endif;
                        ?>
                    </select>
                    <p class="description">
                       Selecting new template will erase current template
                    </p>
                </td>
            </tr>
        </table>
        <p class="submit">
            <button type="button" id="select_template" class="button button-secondary"><?php _e('Apply Template','eden_campaign');?></button>
        </p>

        <br class="clear">
            <script type="text/javascript">
                var template_selected = <?= $template ? 'true' : 'false'; ?>;
                jQuery(function($){
                    //$('#editor').hide();
                    $('#select_template').on('click',function(){
                        if(confirm("Selecting new template will erase current template\nDo you really want to select this template?")){
                            template_selected = true;
                            $('#select_template').html('Please Wait...');
                            var template = $('#template_meta').val();
                            //alert(template);
                            if(template === "") {
                                // $('#editor').hide();
                            }
                            else {
                                //alert('hi');

                                jQuery.ajax({
                                    type : "post",
                                    dataType : "json",
                                    url : "<?php echo admin_url( 'admin-ajax.php' ); ?>",
                                    data : {action: "eden_template_change", template_name: template, nonce: '<?php echo wp_create_nonce( "ajax_nonce" ); ?>'},
                                    success: function(response) {
                                        //console.log(response);
                                        if(response.type == "success") {
                                            //$('#mycustomeditor').html(response.data);
                                            //tinyMCE.getInstanceById('mycustomeditor').setContent(response.data);
                                            tinyMCE.get(0).setContent(response.data);
                                            //console.log(response.data);
                                            //jQuery("#vote_counter").html(response.vote_count)
                                        }
                                        else {
                                            console.log(response.type);
                                            alert(response.type);
                                        }
                                        $('#select_template').html('Apply Template');
                                    }
                                });

                            }
                        }
                    });



                });
            </script>
        <?php
        }
        else {
            //hide template part and show only content part

        ?>
            <script type="text/javascript">
                jQuery(function($){
                    //$('#template_info').hide();
                    //$('#editor').show();
                });
            </script>
        <?php

        }


    } // end templateMeta

    public function editorMeta($post){
        $editor_id = 'mycustomeditor';
        $util = new \CAMPAIGN\UTIL\Utility();
        //print_r($util);
        $util->getTemplates();
        $content = get_post_meta($post->ID, '_campaign_content', true);
        wp_nonce_field( 'editor_meta', 'editor_meta_nonce' );
        wp_editor( $content, $editor_id);

        ?>
        <script type="text/javascript">
            jQuery(function($){
                $('#publish').click(function(){
                    if(template_selected === false) {
                        alert('Please Pick a template and click Apply Template Button');

                        return false;
                    }
                    else {
                        $("#template_meta").removeAttr('disabled');
                        return true;
                    }
                });
            });
        </script>
        <?php

    } // end editorMeta



     public function changeTitle($title){
        $screen = get_current_screen();

        if  ( 'eden_campaign' == $screen->post_type ) {
             $title = __('Name Your Campaign','eden_campaign');
        }

        return $title;
     }


     public function postStyle(){
        global $post_type;
        if( $post_type == 'eden_campaign' ) {
            //wp_enqueue_style('thickbox');
            //wp_enqueue_style( 'jquery-ui-datepicker' );
            //wp_enqueue_style('datepicker', $this->url .'/assets/css/datePicker.css');
            wp_enqueue_style('jquery-ui', 'http://ajax.aspnetcdn.com/ajax/jquery.ui/1.10.3/themes/ui-lightness/jquery-ui.min.css');
            wp_enqueue_style('datepicker', $this->url .'/assets/css/dateTimePicker.css');
        }
    }

    public function adminScripts(){
        wp_enqueue_style('wpdm-newsletter-admin-styles', plugins_url('wpdm-newsletter/assets/css/admin.css'));
    }

    public function postScript(){
        global $post_type;
        if( $post_type == 'eden_campaign' ) {
            //wp_enqueue_script(array('jquery', 'editor', 'thickbox', 'media-upload'));
            //wp_enqueue_script('post_js', $this->url . '/assets/js/post_js.js');
            wp_enqueue_script('jquery');
            wp_enqueue_script('jquery-ui-datepicker');
            wp_enqueue_script('jquery-ui-slider');

            wp_enqueue_script('datepicker', $this->url .'/assets/js/dateTimePicker.js',
                    array('jquery', 'jquery-ui-core','jquery-ui-slider'),
			time(),
			true
                    );

        }
    }

    public function newsLetterPostType(){
        register_post_type( "eden_campaign",
            array(
                'labels' => array(
                    'name'                  => __( 'Campaigns', 'campaign' ),
                    'singular_name'         => __( 'Campaign', 'campaign' ),
                    'menu_name'             => _x( 'Campaign', 'Admin menu name', 'campaign' ),
                    'add_new'               => __( 'Add Campaign', 'campaign' ),
                    'add_new_item'          => __( 'Add New Campaign', 'campaign' ),
                    'edit'                  => __( 'Edit', 'campaign' ),
                    'edit_item'             => __( 'Edit Campaign', 'campaign' ),
                    'new_item'              => __( 'New Campaign', 'campaign' ),
                    'view'                  => __( 'View Campaign', 'campaign' ),
                    'view_item'             => __( 'View Campaign', 'campaign' ),
                    'search_items'          => __( 'Search Campaigns', 'campaign' ),
                    'not_found'             => __( 'No Campaigns found', 'campaign' ),
                    'not_found_in_trash'    => __( 'No Campaigns found in trash', 'campaign' ),
                    'parent'                => __( 'Parent Campaign', 'campaign' )
                ),
                'description' 		=> __( 'This is where you can add new products to your store.', 'campaign' ),
                'public' 		=> true,
                'show_ui' 		=> true,
                'capability_type' 	=> 'post',
                'map_meta_cap'		=> true,
                'publicly_queryable' 	=> false,
                'exclude_from_search' 	=> true,
                'hierarchical' 		=> false, // Hierarchical causes memory issues - WP loads all records!
                'rewrite' 		=> true,
                'query_var' 		=> false,
                'supports' 		=> array( 'title', 'thumbnail' ),
                'has_archive' 		=> false,
                'show_in_nav_menus' 	=> false,
                'menu_icon'             => 'dashicons-email-alt'
            )

);
    }
}

