<?php
namespace CAMPAIGN\UTIL;

use PHPMailer\PHPMailer\PHPMailer;
use WPDM\__\Email;

if(!defined('WPINC')) {
    exit;
}

class Mailer{
    private static $instance;
    protected $mailer,              //PhpMailer class instance
            $util,                  //Utility Class instance
            $time_start,            //
            $time_limit,            //
            $email_limit = 10,      // Per run, every 5 minutes
            $limits_set = false,    //
            $max_emails = 20;       //Maximum email per hour

    public static function getInstance(){
        if(self::$instance === null){
            self::$instance = new self;
            self::$instance->dir = \CAMPAIGN\EdenCampaign::getDir();
            self::$instance->url = \CAMPAIGN\EdenCampaign::getUrl();
            self::$instance->actions();
            self::$instance->time_start = time();
        }
        return self::$instance;
    }

    protected function actions(){
        //SMTP
        require_once ABSPATH . WPINC . '/PHPMailer/PHPMailer.php';
        require_once ABSPATH . WPINC . '/PHPMailer/SMTP.php';

        $this->mailer = null;
        $this->util = new \CAMPAIGN\UTIL\Utility();
    }

    public function cronHandler(){
        global $wpdb;

        // Do not accept job activation before at least 4 minutes are elapsed from the last run.
        //if ($this->check_transient('_wp_eden_campaign', \CAMPAIGN\CRON_INTERVAL) == false)
            //return;

        // Configure ready state for email queue
        echo "Cron Started " . time();
        $wpdb->query("UPDATE $wpdb->eden_email_queue SET status=1 WHERE (status=0 OR (status=3 AND recurrent=1))  AND send_on < " . time());

        // Retrieve all email in "sending" status
        $campaigns = $wpdb->get_results("select * from " . $wpdb->eden_email_queue . " where status='1' and send_on<" . time() . " order by id asc");

        //echo '<pre>';print_r($campaigns);echo '</pre>';

		$msg = "WPDM Newsletter cron executed for the following items:<ul>";
        foreach ($campaigns as &$campaign) {
	        $msg .= "<li>ID#{$campaign->id} - POST#{$campaign->post_id} {$campaign->email_subject}</li>";
            if (!$this->sendMail($campaign))
                break;
            else {

            }
        }

		if(count($campaigns) > 0) {
			Email::send( "default", [
				'to_email' => get_option( 'admin_email' ),
				'subject'  => "WPDM Newsletter Cron",
				'message'  => $msg . "</ul>"
			] );
		}


	    // Remove the semaphore so the delivery engine can be activated again
        $this->delete_transient('wp_eden_campaign');
    }

    public function sendMail($campaign){
        global $wpdb;
        $wpdb->show_errors();

        $this->mailer = null;
        //check campaign type eg post update or campaign
        if($campaign->msg_type == '1') {
            // Post update
            // now get all emails
            $emails = maybe_unserialize(get_post_meta($campaign->post_id, '_eden_campaign_subscriber', true));
			if(!is_array($emails)) $emails = [];
			$lists = maybe_unserialize(get_post_meta($campaign->post_id, '_sendto_list', true));
			if(is_array($lists) && count($lists) > 0) {
				$cond = [];
				foreach ( $lists as $list ) {
					if((int)$list > 0)
						$cond[] = "l.list_id = $list";
				}
				if(count($cond) > 0) {
					$cond    = implode( " or ", $cond );
					$sql     = "SELECT s.email FROM `{$wpdb->prefix}eden_subscriber_list` l LEFT JOIN {$wpdb->prefix}eden_subscriber s on l.subscriber_id = s.id where {$cond}";
					$_emails = $wpdb->get_results( $sql );
					foreach ( $_emails as $_email ) {
						$emails[] = $_email->email;
					}
				}
			}

            $emails = array_unique($emails);

            $last_email = (int) $campaign->last_email;
            $sender = array(
                'from_email' => $campaign->from_email,
                'from_name' => $campaign->from_name
            );
            //echo $last_email;
            if(!empty($emails)) {
                $cnt = count($emails);
                for(;$last_email<$cnt; $last_email++){
                    // Before try to send, check the limits.

                    if ($this->checkLimits())
                        return false;
                    if(!is_email($emails[$last_email])) {
                        $user = get_userdata($emails[$last_email]);
                        $user_email = $user->user_email;
                    } else {
                        $user_email = $emails[$last_email];
                    }
                    $user = null;

                    $headers['Precedence'] = 'bulk';

                    $subject = $this->replaceSubject($campaign->email_subject);
                    $message = $this->replaceMessage($campaign->message);

                    if($this->mailTo($user_email, $subject, $message, $headers, $sender)){
                        //mail send successfull
                        $this->email_limit--;
                        //update db table
                        $query = "UPDATE " . $wpdb->eden_email_queue . " SET total_sent=total_sent+1, last_email=" . ($last_email+1) . " WHERE id=" . $campaign->id;
                        $wpdb->query($query);
                        echo "mail sent success";
                    }

                    else {
                        //unsuccessfull
                        echo "Mail sent failed";
                        return false;
                    }
                }
                //all mail sent successfully
                //update db table
                $wpdb->query("UPDATE $wpdb->eden_email_queue SET status=3 WHERE id=" . $campaign->id);
                //$wpdb->print_error();
            }
            else {
                //no subscriber found...
                //just update db table
                $wpdb->query("UPDATE $wpdb->eden_email_queue SET status=3 WHERE id=" . $campaign->id);
                //$wpdb->print_error();
            }

        }
        elseif($campaign->msg_type == '2'){
            //campaign
            //first get campaign auidence --> Subscriber Category
            //echo 'message type 2';
            $subscriber_category = maybe_unserialize(get_post_meta($campaign->post_id, '_subscriber_category', true));
            if(!is_array($subscriber_category)) {
                $subscriber_category = (array)$subscriber_category;
            }
            $concat_cat = implode(', ', $subscriber_category);
            $campaign_info = maybe_unserialize(get_post_meta($campaign->post_id, '_campaign_info', true));
            $campaign_content = get_post_meta($campaign->post_id, '_campaign_content', true);

            //now get all email address for this subscriber category
            $sender = array(
                'from_email' => trim($campaign_info['from_email']),
                'from_name' => trim($campaign_info['from_name'])
            );

            $query = "SELECT distinct s.* FROM `{$wpdb->eden_subscriber}` s, `{$wpdb->eden_subscriber_list}` l  WHERE l.subscriber_id = s.id and l.list_id IN ($concat_cat) and l.active=1 and s.active=1";
            $query .= " AND s.id>" . $campaign->last_email . " ORDER BY s.id LIMIT " . $this->max_emails;

            $emails = $wpdb->get_results($query);

            if(!empty($emails)){
                foreach ($emails as $email){
                    if ($this->checkLimits())
                        return false;

                    $headers['Precedence'] = 'bulk';

                    $subject = $this->replaceSubject($campaign_info['email_subject']);
                    $message = $this->replaceMessage($campaign_content);

                    if($this->mailTo($email->email, $subject, $message, $headers,$sender)){
                        //mail send successfull
                        $this->email_limit--;
                        //update db table
                        $query = "UPDATE " . $wpdb->eden_email_queue . " SET total_sent=total_sent+1, last_email=" . ($email->id) . " WHERE id=" . $campaign->id;
                        $wpdb->query($query);
                        echo "mail sent success";
                    }

                    else {
                        //unsuccessfull
                        echo "Mail sent failed";
                        return false;

                    }
                }
            }
            else {
                //no email found...
                $campaign_schedule = maybe_unserialize(get_post_meta($campaign->post_id, '_campaign_schedule', true));
                $query = "UPDATE $wpdb->eden_email_queue SET status=3 ";

                if($campaign_schedule['repeat_campaign'] == 'on') {
                    $frequency = $campaign_schedule['frequency_count'];
                    $frequency_occur = $campaign_schedule['frequency_occur'];
                    if($frequency_occur=="day"){
                        $next = DAY_IN_SECONDS*$frequency;
                    }
                    elseif($frequency_occur=="month"){
                        $next = DAY_IN_SECONDS * 30 * $frequency;
                    }
                    elseif($frequency_occur=="year"){
                        $next = YEAR_IN_SECONDS * $frequency;
                    }

                    $time = $campaign->send_on + $next;

                    $query .= " , send_on=$time , recurrent=1 ";

                }
                else {
                    $query .= " , recurrent=0";
                }
                $query .= " WHERE id=" . $campaign->id;

                //echo $query . '<br>';
                $wpdb->query($query);
            }
        }

        return true;
    }

    private function mailTo($to, $subject, $message, $headers = null,$sender=array()){
        /*
        if ($this->mailer == null)
            $this->phpMailerInit($sender);

        // Simple message is asumed to be html
        if (!is_array($message)) {
            $this->mailer->IsHTML(true);
            $message = str_replace("\r\n", "\n", $message);
            $message = str_replace("\r", "\n", $message);
            $message = str_replace("\n", "\r\n", $message);
            $this->mailer->Body = $message;
        }

        $this->mailer->Subject = $subject;

        $this->mailer->ClearCustomHeaders();
        if (!empty($headers)) {
            foreach ($headers as $key => $value) {
                $this->mailer->AddCustomHeader($key . ': ' . $value);
            }
        }

        $this->mailer->ClearAddresses();
        $this->mailer->AddAddress($to);
        wpdmdd($this->mailer);
        $this->mailer->Send();
        */
	    wpdmprecho("Sending email to: {$to}, subject: {$subject}");

        if(!is_array($headers)) $headers = [];
        $headers[] = "From: <{$sender['from_email']}> {$sender['from_name']}\r\n";
	    usleep(100000);
		$ret = Email::send("default", ['to_email' => $to, 'subject' => $subject, 'message' => $message, 'from_name' => $sender['from_name'], 'from_email' => $sender['from_email']]);
        //$ret = wp_mail($to,$subject,$message, $headers);
		if($ret)
			wpdmprecho("Request Success!");
		else
			wpdmprecho("Request Failed!");

        /*if ($this->mailer->IsError()) {
            $error = $this->mailer->ErrorInfo;
            echo $error;
            // If the error is due to SMTP connection, the mailer cannot be reused since it does not clean up the connection on error.
            $this->mailer = null;
            return false;
        }*/
        return true;
    }

    private function replaceSubject($subject){
        return $subject;
    }

    private function replaceMessage($message){
        return $message;
    }

    private function checkLimits(){
        global $wpdb;

        if (!$this->limits_set) {

            $max_time = \CAMPAIGN\CRON_INTERVAL;

            // Actually it should be set on startup, anyway the scripts use as time base the startup time
            if ($this->util->getOption('eden_campaign_advanced','php_time_limit') != '') {
                @set_time_limit((int)$this->util->getOption('eden_campaign_advanced','php_time_limit'));
            }

            $max_time = (int) (@ini_get('max_execution_time') * 0.95);
            if ($max_time == 0 || $max_time > \CAMPAIGN\CRON_INTERVAL) $max_time = (int)(\CAMPAIGN\CRON_INTERVAL*0.95);

            $this->time_limit = $this->time_start + $max_time;

            $max = $this->util->getOption('eden_campaign_advanced','scheduler_max');
            if (!is_numeric($max))
                $max = 100;
            $this->email_limit = max(floor($max / 12), 1);

            $wpdb->query("set session wait_timeout=300");
            // From default-constants.php
            if (function_exists('memory_get_usage') && ( (int) @ini_get('memory_limit') < 128 ))
                @ini_set('memory_limit', '256M');

            $this->limits_set = true;
        }

        // The time limit is set on constructor, since it has to be set as early as possible
        if (time() > $this->time_limit) {
            return true;
        }

        if ($this->email_limit <= 0) {
            return true;
        }
        return false;
    }

    protected function phpMailerInit($sender=array()) {
        $this->mailer = new PHPMailer();

        $smtp_options = array();
        $smtp_options['enable'] = $this->util->getOption('enable','eden_campaign_smtp');
        $smtp_options['host'] = $this->util->getOption('host','eden_campaign_smtp');
        $smtp_options['port'] = $this->util->getOption('port','eden_campaign_smtp');
        $smtp_options['user'] = $this->util->getOption('user','eden_campaign_smtp');
        $smtp_options['pass'] = $this->util->getOption('password','eden_campaign_smtp');
        $smtp_options['secure'] = $this->util->getOption('security','eden_campaign_smtp');

        //print_r($smtp_options);
        //die();

        if ($smtp_options['enable'] == 1) {
            //echo 'smtp enabled';
            $this->mailer->IsSMTP();
            $this->mailer->Host = $smtp_options['host'];
            if ($smtp_options['port'] != '')
                $this->mailer->Port = (int) $smtp_options['port'];

            if ($smtp_options['user'] != '') {
                $this->mailer->SMTPAuth = true;
                $this->mailer->Username = $smtp_options['user'];
                $this->mailer->Password = $smtp_options['pass'];
            }
            $this->mailer->SMTPKeepAlive = true;
            $this->mailer->SMTPSecure = $smtp_options['secure'];
        } else {
            $this->mailer->IsMail();
        }

        $this->mailer->CharSet = 'UTF-8';

        $return_path = $this->util->getOption('return_path','eden_campaign_email');
        if ($return_path != '') {
            $this->mailer->Sender = $return_path;
        }
        if ($this->util->getOption('reply_to','eden_campaign_email') != '') {
            $this->mailer->AddReplyTo($this->util->getOption('reply_to','eden_campaign_email'));
        }

        //setup sender information
        if(empty($sender)){
            //no sender is given
            $this->mailer->From = $this->util->getOption('sender_email','eden_campaign_email');
            $this->mailer->FromName = $this->util->getOption('sender_name','eden_campaign_email');
        }
        else {
            $this->mailer->From = $sender['from_email'];
            $this->mailer->FromName = $sender['from_name'];
        }

    }

    private function check_transient($name,$time) {
        //usleep(rand(0, 1000000));
        if (($value = get_transient($name)) !== false) {
            return false;
        }
        set_transient($name, time(), $time);

        return true;
    }

    function delete_transient($name = '') {
        delete_transient($name);
    }
}
