<?php
namespace CAMPAIGN\UTIL;

if(!defined('WPINC')) {
    exit;
}

class SubscriberList extends \WP_List_Table {
    private $utility;
    function __construct(){
        global $status, $page;
        $this->utility = new \CAMPAIGN\UTIL\Utility();        
        //Set parent defaults
        parent::__construct( array(
            'singular'  => 'Subscriber',     //singular name of the listed records
            'plural'    => 'Subscribers',    //plural name of the listed records
            'ajax'      => false        //does this table support ajax?
        ) );
        
    }
    
    function get_columns(){
        $columns = array(
            'cb'        => '<input type="checkbox" />', //Render a checkbox instead of text
            'fname'     => 'First Name',
            'lname'     => 'Last Name',
            'email'     => 'Email',
            'list_id'   => 'Campaign List',
            'gender'    => 'Gender',
            'active'    => 'Status',
            'user'      => 'Registered User',
            'updated'   => 'Added'
        );
        return $columns;
    }
    
    function get_sortable_columns() {
        $sortable_columns = array(
            'email'     => array('email',false),     //true means it's already sorted
        );
        return $sortable_columns;
    }
    
    function column_cb($item){
        return sprintf(
            '<input type="checkbox" name="%1$s[]" value="%2$s" />',
            /*$1%s*/ $this->_args['singular'],  //Let's simply repurpose the table's singular label ("movie")
            /*$2%s*/ $item->id               //The value of the checkbox should be the record's id
        );
    }
    
    function column_default($item, $column_name){
        global $wpdb;
        switch($column_name){
            case 'updated':
                return sprintf("%s",$item->$column_name);
            case 'list_id':
                $lists = $this->utility->getTerms();
                $query = "SELECT list_id FROM {$wpdb->eden_subscriber_list} WHERE subscriber_id={$item->id} and active=1";
                $results = $wpdb->get_results($query,ARRAY_A);
                $str = "";
                if(!empty($results)){
                    foreach ($results as $key => $row):
                        $str .= $lists[$row['list_id']];
                        if(isset($results[$key+1])){
                            $str .= ', ';
                        }
                    endforeach;
                }
                
                return sprintf("%s",$str);
                
            case 'fname': 
                $actions = array(
                    'edit'      => sprintf('<a href="?post_type=%s&page=%s&edit=%s">Edit</a>',$_REQUEST['post_type'],$_REQUEST['page'],$item->id),
                    'delete'    => sprintf('<a href="?post_type=%s&page=%s&delete=%s">Delete</a>',$_REQUEST['post_type'],$_REQUEST['page'],$item->id),
                );
                $fname = isset($item->fname) && $item->fname != "" ? $item->fname : 'N/A';
                //Return the title contents
                return sprintf('%1$s %2$s',
                    /*$1%s*/ $fname,
                    /*$3%s*/ $this->row_actions($actions)
                );
            case 'lname':
                $lname = isset($item->lname) && $item->lname != "" ? $item->lname : 'N/A';
                return sprintf('%s',$lname);
            case 'email':    
            case 'lname':
                return sprintf("%s",$item->$column_name);
            case 'gender':
                $ret = "";
                if($item->gender == 0) {
                    $ret = "Male";
                }
                elseif($item->gender == 1){
                    $ret = "Female";
                }
                else {
                    $ret = "Not Specified";
                }
                return sprintf("%s",$ret);
            case 'active':
                $str = "";
                if($item->active == 1) {
                    $str = "Active";
                }
                elseif($item->active == 0) {
                    $str = "Inactive";
                }
                
                return sprintf("%s",$str);
            case 'user':
                $str = '';
                if($item->user_id == NULL){
                    $str = "No";
                }
                elseif(is_numeric($item->user_id)){
                    $str = "Yes";
                }
                return sprintf('%s',$str);
            default:
                //return print_r($item,true); //Show the whole array for troubleshooting purposes
        }
    }
    
    function get_bulk_actions() {
        $actions = array(
            'delete'    => 'Delete'
        );
        return $actions;
    }
    
    function process_bulk_action() {
        global $wpdb;
        //Detect when a bulk action is being triggered...
        if( 'delete'===$this->current_action() ) {
            if(current_user_can('manage_options')){
                $subs = $_GET['subscriber'];
                foreach($subs as &$sub){
                    $sub = (int)$sub;
                }
                $wpdb->query("DELETE FROM {$wpdb->eden_subscriber} WHERE id in (".implode(",", $subs).")");
            }
            die('Items deleted! Redirecting...<script>location.href = "'.$_SERVER['HTTP_REFERER'].'";</script>');
        }
    }
    
    function extra_tablenav( $which ) {
	if ( $which == "top" ){
            $lists = $this->utility->getTerms();
            echo "<select name='subscriber_list_cat' id='subscriber_list_cat'><option value='0'>View All List</option>";
            foreach ($lists as $key => $name):
                echo "<option value='$key' ".  selected($_GET['subscriber_list_cat'], $key, false).">$name</option>";
            endforeach;
            echo "</select>";
            echo '<input type="submit" name="" id="post-query-submit" class="button" value="Filter">';
            $_GET['subscriber_status'] = isset($_GET['subscriber_status'])?intval($_GET['subscriber_status']):'';
            ?>
            <select name="subscriber_status">
                <option value=""><?php _e('All Subscribers','eden_campaign'); ?></option>
                <option value="1" <?php selected($_GET['subscriber_status'], '1'); ?>><?php _e('Active Subscribers','eden_campaign'); ?></option>
                <option value="0" <?php selected($_GET['subscriber_status'], '0'); ?>><?php _e('Inactive Subscribers','eden_campaign'); ?></option>
                <option value="2" <?php selected($_GET['subscriber_status'], '2'); ?>><?php _e('Registered Users','eden_campaign'); ?></option>
                <option value="3" <?php selected($_GET['subscriber_status'], '3'); ?>><?php _e('Un-Registered Users','eden_campaign'); ?></option>
            </select>
            <input type="submit" name="" class="button" value="Filter" />
            <?php
	}
	if ( $which == "bottom" ){
		//The code that goes after the table is there
		//echo"Hi, I'm after the table";
	}
    }
    
    

    function prepare_items() {
        global $wpdb, $_wp_column_headers;
	$screen = get_current_screen();
        $this->process_bulk_action();
        
        $list_cat = isset($_REQUEST['subscriber_list_cat']) ? wpdm_query_var('subscriber_list_cat', 'int') : 0;
        $s = wpdm_query_var('s', 'txt');
        $status = wpdm_query_var('subscriber_status', 'txt');
        
        if($list_cat != 0){
            $query = "SELECT a.*, b.list_id FROM {$wpdb->prefix}eden_subscriber a, {$wpdb->prefix}eden_subscriber_list b ";
            //$query .= " , {$wpdb->eden_subscriber_list} s ";
        }
        else {
            $query = "SELECT * FROM {$wpdb->prefix}eden_subscriber";
        }
        
	/* search and filter parameters */
        
        if(($list_cat != 0) || ($s != '') || ($status != '')) {
            $query .= " WHERE ";
        }
        
        if($s != ""){
            $query .= " Concat(fname, '', lname, '', email) LIKE '%".  $s ."%' ";
        }
        
        if($list_cat != 0){
            $list_id = (int) $list_cat;
            if($s != '') {
                $query .= " AND ";
            }
            $query .= " b.subscriber_id=a.id AND b.list_id=$list_id AND b.active=1";
        }
        
        if($status != ''){
            if($list_cat != 0 || $s != "") {
                $query .= " AND ";
            }
            $status = (int) $status;
            if($list_cat != 0) {
                if($status=='2') {
                    $query .= " a.user_id != NULL ";
                }
                elseif($status == '3') {
                    $query .= " a.user_id == NULL ";
                }
                else {
                    $query .= " a.active=$status ";
                }
                
                
            }
            else {
                if($status=='2') {
                    $query .= " user_id != 'NULL' ";
                }
                elseif($status == '3') {
                    $query .= " user_id IS NULL ";
                }
                else {
                    $query .= " active=$status ";
                }
            }
            
        }
        
        /* -- Ordering parameters -- */
        $orderby = !empty($_GET["orderby"]) ? esc_sql($_GET["orderby"]) : 'ASC';
        $order = !empty($_GET["order"]) ? esc_sql($_GET["order"]) : '';
        if(!empty($orderby) & !empty($order)){ $query.=' ORDER BY '.$orderby.' '.$order; }
        
        //echo $query;
        
        
        
        
        /* -- Pagination parameters -- */
        $totalitems = $wpdb->query($query); //return the total number of affected rows
        $perpage = 10;
        $paged = !empty($_GET["paged"]) ? (int)($_GET["paged"]) : 1;
        if(empty($paged) || !is_numeric($paged) || $paged<=0 ){ $paged=1; }
        $totalpages = ceil($totalitems/$perpage);
        if(!empty($paged) && !empty($perpage)){
                $offset=($paged-1)*$perpage;
            $query.=' LIMIT '.(int)$offset.','.(int)$perpage;
        }
        
        /* -- Register the Columns -- */
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = array($columns, $hidden, $sortable);
        
	/* -- Register the pagination -- */
        $this->set_pagination_args( array(
                "total_items" => $totalitems,
                "total_pages" => $totalpages,
                "per_page" => $perpage,
        ) );
        //echo $query;
	/* -- Fetch the items -- */
        $this->items = $wpdb->get_results($query);
       
    }
    
    
}

