<?php
namespace CAMPAIGN;
/*
Plugin Name: WPDM - Newsletters
Plugin URI: https://www.wpdownloadmanager.com/
Description: WPDM - Newsletters add-on will help you to notify all subscribers about new posts, downloads and their updates.
Version: 3.2.6
Author: Shaon
Author URI: https://www.wpdownloadmanager.com/
Update URI: wpdm-newsletter
*/

if(!defined('WPINC')) {
    exit;
}

if(!defined(__NAMESPACE__.'\\CRON_INTERVAL')) {
    define(__NAMESPACE__.'\\CRON_INTERVAL', 300);
}

define("WPDMNL_TEXT_DOMAIN", "wpdm-newsletter");

class EdenCampaign{
    private static $instance;
    private $dir, $url;

    private function actions(){
        spl_autoload_register( array( $this, 'autoload' ) );
        register_activation_hook(__FILE__, array($this,'activate'));
        register_deactivation_hook(__FILE__, array($this,'deactivate'));

        //add new cron schedules
        add_filter('cron_schedules', array($this, 'cronSchedules'));

        //cron job setup hooks
        add_action( 'wp', array($this,'setupSchedule') );
        add_action( 'wp_eden_campain_event', array($this,'doThisEveryFive'));
        add_action( 'wp_enqueue_scripts', array($this,'siteScripts'));

        //if (defined('DOING_CRON') && DOING_CRON)
            //return;

        //manual cron for testing
        add_action('wp',array($this,'cronHandle'));
        add_action('wp_loaded',array($this,'subscriberHandle'));

	    add_filter('update_plugins_wpdm-newsletter', [$this, "updatePlugin"], 10, 4);

        if(!is_admin()){
            $shortcode = \CAMPAIGN\SHORTCODE\shortCode::getInstance();
        }

        if(is_admin()){
            //admin menu
            $menu = ADMIN\adminMenu::getInstance();

            //admin settings menu pages
            ADMIN\SETTINGS\GeneralSettings::getInstance();
            ADMIN\SETTINGS\SubscriberSettings::getInstance();
        }

        //init hooks
        $post = INIT\PostType::getInstance();
        $taxonomy = INIT\Taxonomy::getInstance();
        $post_meta = INIT\PostSubscribeMeta::getInstance();

        if ( defined('DOING_AJAX') ) {
            if(!class_exists('NewsletterAjax')){
                require_once 'ajax.php';
            }
            $ajax = \NewsletterAjax::getInstance();
        }

        $action_hook = \CAMPAIGN\ActionHooks::getInstance();
        $filter_hook = \CAMPAIGN\FilterHooks::getInstance();

        // Newsletter Subscriber Widget
        require_once $this->dir . '/campaign/widget/subscriberwidget.php';
    }

    public function siteScripts(){
        wp_enqueue_style('wpdm-newsletter-site-styles', plugins_url('wpdm-newsletter/assets/css/site.css'));
    }

    public function subscriberHandle(){
        if(isset($_REQUEST['task']) && $_REQUEST['task'] == "eden_subscriber"){
            $obj = \CAMPAIGN\UTIL\SubscriberHandle::getInstance();
            $obj->showProfile();
        }
    }

    public function cronHandle(){
        if(isset($_REQUEST['cron_handle']) && $_REQUEST['cron_handle'] == 1){

            //check if cron is running
            //$newvalue = get_option('test_cron',0);
            //print_r($newvalue); die();

            $mailer = \CAMPAIGN\UTIL\Mailer::getInstance();
            $mailer->cronHandler();
            die();
        }
    }

    public function doThisEveryFive(){
        //do this every five minutes
        $mailer = \CAMPAIGN\UTIL\Mailer::getInstance();
        $mailer->cronHandler();

        // Updates test_cron value by 1 each run
        $newvalue =(int) get_option('test_cron',0);
        update_option('test_cron', $newvalue + 1);
    }

    // Custom cron Recurrence ( wp_eden_campaign )
    public function cronSchedules($schedules){
        $schedules['wp_eden_campaign'] = array(
            'interval' => 300, // 5*60 seconds
            'display' => 'WPDM Newsletter'
        );
        return $schedules;
    }

    public function setupSchedule(){
        if ( ! wp_next_scheduled( 'wp_eden_campain_event' ) ) {
            wp_schedule_event(time()+30, 'wp_eden_campain', 'wp_eden_campain_event');
        }
    }

    public function activate(){
        $db = INSTALL\DB::getInstance();
        $options = INSTALL\Options::getInstance();
        //wp_clear_scheduled_hook( 'wp_eden_campain_hook' );
        //wp_schedule_event(time(), 'wp_eden_campain', 'wp_eden_campain_hook');

        // During plugin activation ( added this in version 3.2.0 )
        if ( ! wp_next_scheduled( 'wp_eden_campain_event' ) ) {
            //wp_schedule_event(time(), 'wp_eden_campain', 'wp_eden_campain_event');
            wp_schedule_event(time(), 'hourly', 'wp_eden_campain_event');
        }
    }

    public function deactivate(){
        //remove cron hook
        wp_clear_scheduled_hook( 'wp_eden_campain_event' );
    }

    public static function getInstance(){
        if(self::$instance === null){
            self::$instance = new self;
            self::$instance->dir = dirname(__FILE__);
            self::$instance->url = WP_PLUGIN_URL . '/' . basename(self::$instance->dir);
            self::$instance->actions();

            //table
            global $wpdb;
            $wpdb->eden_subscriber = $wpdb->prefix . 'eden_subscriber';
            $wpdb->eden_email_queue = $wpdb->prefix . 'eden_email_queue';
            $wpdb->eden_subscriber_list = $wpdb->prefix . 'eden_subscriber_list';
        }
        return self::$instance;
    }

    public static function getDir(){
        return self::$instance->dir;
    }

    public static function getUrl(){
        return self::$instance->url;
    }

    private function autoload($class){
        $class = dirname(__FILE__) . '/' . str_replace('\\', '/', strtolower($class)) . '.php';
        // echo $class . "<br>";
        if(file_exists($class)){
            require_once $class;
            //echo $class. "<br>";
        }
    }

	function updatePlugin($update, $plugin_data, $plugin_file, $locales){
		$id = basename(__DIR__);
		$latest_versions = WPDM()->updater->getLatestVersions();
		$latest_version = wpdm_valueof($latest_versions, $id);
		$access_token = wpdm_access_token();
		$update = [];
		$update['id']           = $id;
		$update['slug']         = $id;
		$update['url']          = $plugin_data['PluginURI'];
		$update['tested']       = true;
		$update['version']      = $latest_version;
		$update['package']      = $access_token !== '' ? "https://www.wpdownloadmanager.com/?wpdmpp_file={$id}.zip&access_token={$access_token}" : '';
		return $update;
	}

}

$wp_campaign = EdenCampaign::getInstance();


//echo '<pre>'; print_r( _get_cron_array() ); echo '</pre>';
