<?php
/*
  Plugin Name: WPDM - Opt-in Magic
  Plugin URI: https://www.wpdownloadmanager.com/
  Description: Show email to download subscription form in a popup
  Author: WordPress Download Manager
  Version: 1.2.0
  Author URI: https://www.wpdownloadmanager.com/
 */


namespace WPDM\AddOn;

if (!defined('ABSPATH')) die();

define('WPDM_OP_URL', plugins_url('/', __FILE__));
define('WPDM_OP_BASE', dirname(__FILE__).'/');

class OptinPopup{
    function __construct()
    {
        add_action("wp_footer", array($this, 'iframe'));
        add_action("init", array($this, 'init'));
        //add_filter( 'add_wpdm_settings_tab', array( $this, 'settingsTab' ) );
        add_action('add_meta_boxes', array($this, 'editorMetaBox'));
        add_action('init', array($this, 'loadPreview'));
        add_action('wp_enqueue_scripts', array($this, 'enqueueScripts'));
        add_action('admin_enqueue_scripts', array($this, 'adminEnqueueScripts'));
        add_action('wp_ajax_wpdmopp_config', array($this, 'loadConfig'));
        add_action('wp_ajax_wpdm_op_plist', array($this, 'searchPosts'));
        add_action('wp_ajax_nopriv_wpdm_op_form_handler', array($this, 'formHandler'));
        add_action('wp_ajax_wpdm_op_form_handler', array($this, 'formHandler'));
        add_action('save_post', array($this, 'handleSavePost'));

    }

    function init(){
        $this->registerPostType();
        $this->trigger();
        $this->shortCodes();
    }

    function shortCodes(){
        add_shortcode("form_extended", function(){
            ob_start();
            $id = wpdm_query_var('wpdmoptinpopup');
            if(!$id)
                $id = wpdm_query_var('pid');
            include WPDM_OP_BASE.'/tpls/form-extended.php';
            $form = ob_get_clean();
            return $form;
        });

        add_shortcode("form_simple", function($params = array()){
            ob_start();
            $id = wpdm_query_var('wpdmoptinpopup');
            if(!$id)
                $id = wpdm_query_var('pid');
            include WPDM_OP_BASE.'/tpls/form-simple.php';
            $form = ob_get_clean();
            return $form;
        });

        add_shortcode("form_line", function($params = array()){
            ob_start();
            $id = wpdm_query_var('wpdmoptinpopup');
            if(!$id)
                $id = wpdm_query_var('pid');
            include WPDM_OP_BASE.'/tpls/form-line.php';
            $form = ob_get_clean();
            return $form;
        });
    }

    public static function templates(){
        $templates = array();

        $templates['default'] = array(
            'name' => 'Default',
            'screenshot' => plugins_url('assets/images/default.png', __FILE__),
            'template' => wpdm_tpl_path('optinpopups/default/template.php', dirname(__FILE__).'/tpls'),
            'config' => wpdm_tpl_path('optinpopups/default/config.php', dirname(__FILE__).'/tpls')
        );

        $templates['plain'] = array(
            'name' => 'Plain #1',
            'screenshot' => plugins_url('assets/images/plain.png', __FILE__),
            'template' => wpdm_tpl_path('optinpopups/plain/template.php', dirname(__FILE__).'/tpls'),
            'config' => wpdm_tpl_path('optinpopups/plain/config.php', dirname(__FILE__).'/tpls')
        );

        $templates['plain2'] = array(
            'name' => 'Plain #2',
            'screenshot' => plugins_url('assets/images/plain2.png', __FILE__),
            'template' => wpdm_tpl_path('optinpopups/plain2/template.php', dirname(__FILE__).'/tpls'),
            'config' => wpdm_tpl_path('optinpopups/plain2/config.php', dirname(__FILE__).'/tpls')
        );

        $templates['extended1'] = array(
            'name' => 'Extended #1',
            'screenshot' => plugins_url('assets/images/extended1.png', __FILE__),
            'template' => wpdm_tpl_path('optinpopups/extended1/template.php', dirname(__FILE__).'/tpls'),
            'config' => wpdm_tpl_path('optinpopups/extended1/config.php', dirname(__FILE__).'/tpls')
        );

        $templates['coupon'] = array(
            'name' => 'Coupon',
            'screenshot' => plugins_url('assets/images/coupon.png', __FILE__),
            'template' => wpdm_tpl_path('optinpopups/coupon/template.php', dirname(__FILE__).'/tpls'),
            'config' => wpdm_tpl_path('optinpopups/coupon/config.php', dirname(__FILE__).'/tpls')
        );

        $templates['blockad'] = array(
            'name' => 'AdBlock',
            'screenshot' => plugins_url('assets/images/blockad.png', __FILE__),
            'template' => wpdm_tpl_path('optinpopups/blockad/template.php', dirname(__FILE__).'/tpls'),
            'config' => wpdm_tpl_path('optinpopups/blockad/config.php', dirname(__FILE__).'/tpls')
        );

        $templates['canvas'] = array(
            'name' => 'Blank Canvas',
            'screenshot' => plugins_url('assets/images/canvas.png', __FILE__),
            'template' => wpdm_tpl_path('optinpopups/canvas/template.php', dirname(__FILE__).'/tpls'),
            'config' => wpdm_tpl_path('optinpopups/canvas/config.php', dirname(__FILE__).'/tpls')
        );


        //$templates = apply_filters("wpdm_optin_popup_templates", $templates);
        return $templates;
    }

    public function registerPostType()
    {
        $labels = array(
            'name' => __('Optin Popups', 'wpdm-optinmagic'),
            'singular_name' => __('Optin Popup', 'wpdm-optinmagic'),
            'add_new' => __('Add New', 'wpdm-optinmagic'),
            'add_new_item' => __('Add New Popup', 'wpdm-optinmagic'),
            'edit_item' => __('View Popup', 'wpdm-optinmagic'),
            'new_item' => __('New Popup', 'wpdm-optinmagic'),
            'all_items' => __('Optin Popups', 'wpdm-optinmagic'),
            'view_item' => __('View Popup', 'wpdm-optinmagic'),
            'search_items' => __('Search Popups', 'wpdm-optinmagic'),
            'not_found' => __('No Popup Found', 'wpdm-optinmagic'),
            'not_found_in_trash' => __('No Popups found in Trash', 'wpdm-optinmagic'),
            'parent_item_colon' => '',
            'menu_name' => __('Optin Popups', 'wpdm-optinmagic')

        );

        $args = array(
            'labels' => $labels,
            'public' => false,
            'publicly_queryable' => false,
            'show_ui' => true,
            //'show_in_menu' => 'edit.php?post_type=wpdmpro',
            'show_in_nav_menus' => true,
            'query_var' => false,
            'rewrite' => array('slug' => 'email', 'with_front' => false),
            'capability_type' => 'post',
            'has_archive' => false,
            'hierarchical' => false,
            'menu_icon' => 'dashicons-feedback',
            'exclude_from_search' => true,
            'supports' => array('title')

        );


        register_post_type('wpdm-optinmagic', $args);


    }

    function enqueueScripts(){
        $allops = wp_count_posts('wpdm-optinmagic');
        if(isset($allops->publish) && $allops->publish > 0) {
            wp_enqueue_script('jquery');
            wp_enqueue_style("wpdm-optinmagic-css", plugins_url('assets/css/front.css', __FILE__));
        }
    }

    function adminEnqueueScripts(){
        if(get_post_type() == 'wpdm-optinmagic') {
            wp_enqueue_style('wpdm-font-awesome' );
            wp_enqueue_script('wpdm-admin-bootstrap');
            wp_enqueue_style('wpdm-admin-bootstrap');
            wp_enqueue_script('chosen', plugins_url('/download-manager/assets/js/chosen.jquery.min.js'), array('jquery'));
            wp_enqueue_style('chosen-css', plugins_url('/download-manager/assets/css/chosen.css'));
            wp_enqueue_style('jqui-css', plugins_url('/download-manager/assets/jqui/theme/jquery-ui.css'));
            wp_enqueue_style('wpdm-admin-styles', plugins_url('/download-manager/assets/css/admin-styles.css'), 9999);
        }
    }

    function editorMetaBox()
    {
        add_meta_box("popup-settings-metabox", __('Popup Settings', 'wpdm-optinmagic'), array($this, 'popupSettings'), 'wpdm-optinmagic');
        add_meta_box("display-settings-metabox", __('Display Settings', 'wpdm-optinmagic'), array($this, 'displaySettings'), 'wpdm-optinmagic');
        add_meta_box("triggerSettings-metabox", __('Trigger', 'wpdm-optinmagic'), array($this, 'triggerSettings'), 'wpdm-optinmagic', 'side', 'core');
        add_meta_box("availability-metabox", __('Availability Period', 'wpdm-optinmagic'), array($this, 'availabilityPeriod'), 'wpdm-optinmagic', 'side', 'core');
        add_meta_box("reward-metabox", __('Completion Reward', 'wpdm-optinmagic'), array($this, 'completionReward'), 'wpdm-optinmagic', 'side', 'core');
    }


    function trigger(){
        if(wpdm_query_var('wpdmoptinpopup') != ''){
            $this->container();
            die();
        }
    }

    function container(){
        include wpdm_tpl_path("popup-container.php", __DIR__.'/tpls/');
    }

    function iframe(){
        $allops = get_posts(array('post_type' => 'wpdm-optinmagic', 'post_status' => 'publish', 'posts_per_page' => 999999));
        $clientIP = wpdm_get_client_ip();
        $clientLocation = wpdm_remote_get("https://ipapi.co/{$clientIP}/country/");
        echo "<script type='text/javascript' src='".plugins_url('assets/js/front.js', __FILE__)."'></script>";
        foreach ($allops as $_post) {
            $id = $_post->ID;
            include "tpls/iframe.php";
        }
    }

    function settingsTab($tabs){
        $tabs['optinpopup'] = wpdm_create_settings_tab('optinpopup', 'Opt-in Popup', array( $this, 'settings' ), $icon = 'fa fa-window-restore');
        return $tabs;
    }

    function displaySettings(){
        include "tpls/metaboxes/display-settings.php";
    }

    function triggerSettings(){
        include "tpls/metaboxes/trigger-settings.php";
    }

    function settings(){
        include "tpls/metaboxes/settings.php";
        die();
    }

    function popupSettings(){
        include "tpls/metaboxes/settings.php";

    }

    function availabilityPeriod(){
        include "tpls/metaboxes/availability-period.php";
    }
    function completionReward(){
        include "tpls/metaboxes/completion-reward.php";
    }

    function loadConfig(){
        $templates = self::templates();
        $id = wpdm_query_var('pid');
        $template = $templates[wpdm_query_var('__wpdmoptplcfg')];
        include $template['config'];
        die();
    }

    function loadPreview(){
        if(!isset($_GET['__wpdmoptpl'])) return;
        $templates = self::templates();
        $id = wpdm_query_var('pid');
        $template = $templates[wpdm_query_var('__wpdmoptpl')];
        include "tpls/preview.php";
        die();
    }

    public static function fetchTemplate($id, $template){
        ob_start();
        include $template['template'];
        $content = ob_get_clean();
//        $vars = array();
//        foreach ($template['config'] as $id => $var){
//            $vars[$id] = $var['value'];
//        }
//        $content = str_replace(array_keys($vars), array_values($vars), $content);
        return $content;
    }

    public static function __($id, $var, $default = ''){
        $data = get_post_meta($id, $var, true);
        if($data == '') $data = $default;
        return $data;
    }

    function handleSavePost($post_id)
    {

        if (wp_is_post_revision($post_id) || (get_post_type($post_id) != 'wpdm-optinmagic'))
            return;
        $post = get_post($post_id);

        foreach ($_POST as $var => $val){
            if(strstr($var, '_wpdm_op_')){
                update_post_meta($post_id, $var, $val);
            }
        }

    }

    function searchPosts()
    {

        $packages = new \WP_Query(array('s' => esc_sql($_REQUEST['query']), 'post_type' => esc_sql(wpdm_query_var('posttype'))));
        $data = array();
        while ($packages->have_posts()) {
            $packages->the_post();
            $data[] = ['id' => get_the_ID(), 'name' => get_the_title()];
        }

        header("Content-type: application/json");
        echo json_encode($data);
        die();
    }

    function formHandler(){
        global $wpdb;
        if(wp_verify_nonce($_REQUEST['__nonce'], NONCE_KEY.'wpdm_op_form_handler')){
            $pid = \WPDM\AddOn\OptinPopup::__($_REQUEST['__opm'], '__wpdm_op_download','');
            $package = get_post($pid);
            $download_url = $pid > 0?\WPDM\Package::expirableDownloadLink($pid, 3):'';

            $wpdb->insert("{$wpdb->prefix}ahm_emails", array('email' => $_POST['email'], 'pid' => $pid, 'date' => time(), 'custom_data' => serialize($_POST)));

            \WPDM\Email::send("email-lock", array('to_email' => $_POST['email'], 'package_name' => $package->post_title, 'download_url' => $download_url));

            header("Content-type: application/json");
            $data = array('download_url' => $download_url);
            echo json_encode($_POST);
            die();
        }
        die('x');
    }

    static function countries(){
        $country_array = array(
            "AF" => "Afghanistan",
            "AL" => "Albania",
            "DZ" => "Algeria",
            "AS" => "American Samoa",
            "AD" => "Andorra",
            "AO" => "Angola",
            "AI" => "Anguilla",
            "AQ" => "Antarctica",
            "AG" => "Antigua and Barbuda",
            "AR" => "Argentina",
            "AM" => "Armenia",
            "AW" => "Aruba",
            "AU" => "Australia",
            "AT" => "Austria",
            "AZ" => "Azerbaijan",
            "BS" => "Bahamas",
            "BH" => "Bahrain",
            "BD" => "Bangladesh",
            "BB" => "Barbados",
            "BY" => "Belarus",
            "BE" => "Belgium",
            "BZ" => "Belize",
            "BJ" => "Benin",
            "BM" => "Bermuda",
            "BT" => "Bhutan",
            "BO" => "Bolivia",
            "BA" => "Bosnia and Herzegovina",
            "BW" => "Botswana",
            "BV" => "Bouvet Island",
            "BR" => "Brazil",
            "BQ" => "British Antarctic Territory",
            "IO" => "British Indian Ocean Territory",
            "VG" => "British Virgin Islands",
            "BN" => "Brunei",
            "BG" => "Bulgaria",
            "BF" => "Burkina Faso",
            "BI" => "Burundi",
            "KH" => "Cambodia",
            "CM" => "Cameroon",
            "CA" => "Canada",
            "CT" => "Canton and Enderbury Islands",
            "CV" => "Cape Verde",
            "KY" => "Cayman Islands",
            "CF" => "Central African Republic",
            "TD" => "Chad",
            "CL" => "Chile",
            "CN" => "China",
            "CX" => "Christmas Island",
            "CC" => "Cocos [Keeling] Islands",
            "CO" => "Colombia",
            "KM" => "Comoros",
            "CG" => "Congo - Brazzaville",
            "CD" => "Congo - Kinshasa",
            "CK" => "Cook Islands",
            "CR" => "Costa Rica",
            "HR" => "Croatia",
            "CU" => "Cuba",
            "CY" => "Cyprus",
            "CZ" => "Czech Republic",
            "CI" => "Côte d’Ivoire",
            "DK" => "Denmark",
            "DJ" => "Djibouti",
            "DM" => "Dominica",
            "DO" => "Dominican Republic",
            "NQ" => "Dronning Maud Land",
            "DD" => "East Germany",
            "EC" => "Ecuador",
            "EG" => "Egypt",
            "SV" => "El Salvador",
            "GQ" => "Equatorial Guinea",
            "ER" => "Eritrea",
            "EE" => "Estonia",
            "ET" => "Ethiopia",
            "FK" => "Falkland Islands",
            "FO" => "Faroe Islands",
            "FJ" => "Fiji",
            "FI" => "Finland",
            "FR" => "France",
            "GF" => "French Guiana",
            "PF" => "French Polynesia",
            "TF" => "French Southern Territories",
            "FQ" => "French Southern and Antarctic Territories",
            "GA" => "Gabon",
            "GM" => "Gambia",
            "GE" => "Georgia",
            "DE" => "Germany",
            "GH" => "Ghana",
            "GI" => "Gibraltar",
            "GR" => "Greece",
            "GL" => "Greenland",
            "GD" => "Grenada",
            "GP" => "Guadeloupe",
            "GU" => "Guam",
            "GT" => "Guatemala",
            "GG" => "Guernsey",
            "GN" => "Guinea",
            "GW" => "Guinea-Bissau",
            "GY" => "Guyana",
            "HT" => "Haiti",
            "HM" => "Heard Island and McDonald Islands",
            "HN" => "Honduras",
            "HK" => "Hong Kong SAR China",
            "HU" => "Hungary",
            "IS" => "Iceland",
            "IN" => "India",
            "ID" => "Indonesia",
            "IR" => "Iran",
            "IQ" => "Iraq",
            "IE" => "Ireland",
            "IM" => "Isle of Man",
            "IL" => "Israel",
            "IT" => "Italy",
            "JM" => "Jamaica",
            "JP" => "Japan",
            "JE" => "Jersey",
            "JT" => "Johnston Island",
            "JO" => "Jordan",
            "KZ" => "Kazakhstan",
            "KE" => "Kenya",
            "KI" => "Kiribati",
            "KW" => "Kuwait",
            "KG" => "Kyrgyzstan",
            "LA" => "Laos",
            "LV" => "Latvia",
            "LB" => "Lebanon",
            "LS" => "Lesotho",
            "LR" => "Liberia",
            "LY" => "Libya",
            "LI" => "Liechtenstein",
            "LT" => "Lithuania",
            "LU" => "Luxembourg",
            "MO" => "Macau SAR China",
            "MK" => "Macedonia",
            "MG" => "Madagascar",
            "MW" => "Malawi",
            "MY" => "Malaysia",
            "MV" => "Maldives",
            "ML" => "Mali",
            "MT" => "Malta",
            "MH" => "Marshall Islands",
            "MQ" => "Martinique",
            "MR" => "Mauritania",
            "MU" => "Mauritius",
            "YT" => "Mayotte",
            "FX" => "Metropolitan France",
            "MX" => "Mexico",
            "FM" => "Micronesia",
            "MI" => "Midway Islands",
            "MD" => "Moldova",
            "MC" => "Monaco",
            "MN" => "Mongolia",
            "ME" => "Montenegro",
            "MS" => "Montserrat",
            "MA" => "Morocco",
            "MZ" => "Mozambique",
            "MM" => "Myanmar [Burma]",
            "NA" => "Namibia",
            "NR" => "Nauru",
            "NP" => "Nepal",
            "NL" => "Netherlands",
            "AN" => "Netherlands Antilles",
            "NT" => "Neutral Zone",
            "NC" => "New Caledonia",
            "NZ" => "New Zealand",
            "NI" => "Nicaragua",
            "NE" => "Niger",
            "NG" => "Nigeria",
            "NU" => "Niue",
            "NF" => "Norfolk Island",
            "KP" => "North Korea",
            "VD" => "North Vietnam",
            "MP" => "Northern Mariana Islands",
            "NO" => "Norway",
            "OM" => "Oman",
            "PC" => "Pacific Islands Trust Territory",
            "PK" => "Pakistan",
            "PW" => "Palau",
            "PS" => "Palestinian Territories",
            "PA" => "Panama",
            "PZ" => "Panama Canal Zone",
            "PG" => "Papua New Guinea",
            "PY" => "Paraguay",
            "YD" => "People's Democratic Republic of Yemen",
            "PE" => "Peru",
            "PH" => "Philippines",
            "PN" => "Pitcairn Islands",
            "PL" => "Poland",
            "PT" => "Portugal",
            "PR" => "Puerto Rico",
            "QA" => "Qatar",
            "RO" => "Romania",
            "RU" => "Russia",
            "RW" => "Rwanda",
            "RE" => "Réunion",
            "BL" => "Saint Barthélemy",
            "SH" => "Saint Helena",
            "KN" => "Saint Kitts and Nevis",
            "LC" => "Saint Lucia",
            "MF" => "Saint Martin",
            "PM" => "Saint Pierre and Miquelon",
            "VC" => "Saint Vincent and the Grenadines",
            "WS" => "Samoa",
            "SM" => "San Marino",
            "SA" => "Saudi Arabia",
            "SN" => "Senegal",
            "RS" => "Serbia",
            "CS" => "Serbia and Montenegro",
            "SC" => "Seychelles",
            "SL" => "Sierra Leone",
            "SG" => "Singapore",
            "SK" => "Slovakia",
            "SI" => "Slovenia",
            "SB" => "Solomon Islands",
            "SO" => "Somalia",
            "ZA" => "South Africa",
            "GS" => "South Georgia and the South Sandwich Islands",
            "KR" => "South Korea",
            "ES" => "Spain",
            "LK" => "Sri Lanka",
            "SD" => "Sudan",
            "SR" => "Suriname",
            "SJ" => "Svalbard and Jan Mayen",
            "SZ" => "Swaziland",
            "SE" => "Sweden",
            "CH" => "Switzerland",
            "SY" => "Syria",
            "ST" => "São Tomé and Príncipe",
            "TW" => "Taiwan",
            "TJ" => "Tajikistan",
            "TZ" => "Tanzania",
            "TH" => "Thailand",
            "TL" => "Timor-Leste",
            "TG" => "Togo",
            "TK" => "Tokelau",
            "TO" => "Tonga",
            "TT" => "Trinidad and Tobago",
            "TN" => "Tunisia",
            "TR" => "Turkey",
            "TM" => "Turkmenistan",
            "TC" => "Turks and Caicos Islands",
            "TV" => "Tuvalu",
            "UM" => "U.S. Minor Outlying Islands",
            "PU" => "U.S. Miscellaneous Pacific Islands",
            "VI" => "U.S. Virgin Islands",
            "UG" => "Uganda",
            "UA" => "Ukraine",
            "SU" => "Union of Soviet Socialist Republics",
            "AE" => "United Arab Emirates",
            "GB" => "United Kingdom",
            "US" => "United States",
            "ZZ" => "Unknown or Invalid Region",
            "UY" => "Uruguay",
            "UZ" => "Uzbekistan",
            "VU" => "Vanuatu",
            "VA" => "Vatican City",
            "VE" => "Venezuela",
            "VN" => "Vietnam",
            "WK" => "Wake Island",
            "WF" => "Wallis and Futuna",
            "EH" => "Western Sahara",
            "YE" => "Yemen",
            "ZM" => "Zambia",
            "ZW" => "Zimbabwe",
            "AX" => "Åland Islands",
        );
        return $country_array;
    }



}
if(defined('WPDM_Version'))
    new OptinPopup();
