<?php
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

if (!class_exists('WPDMPackageList')) {

    class WPDMPackageList
    {

        function __construct()
        {
        }

        // Returns Template Tag outout for Page and Link Template
        function add_to_list_button($vars)
        {
            $options = get_option('_wpdm_pl_options', array());
            $label = isset($options['label']) ? ' '.$options['label'] : ' Add to list';
            $icon = isset($options['icon']) ? $options['icon'] : 'fa fa-bookmark-o';

            $btn = '<div class="add-to-list-button-wrap">
                        <a href="'.admin_url('admin-ajax.php').'?action=wpdm_add2list_options&p='.$vars['ID'].'" class="btn btn-primary add-to-pack-list" data-product="'.$vars['ID'].'">
                            <i class="'.$icon.'"></i>'.$label.'
                        </a>
                    </div>';

            // Add to list button
            $vars['add_to_list'] = $btn;

            // Provides better customization opportunity
            $vars['add_to_list_url'] = admin_url('admin-ajax.php').'?action=wpdm_add2list_options&p='.$vars['ID'].'" class="btn btn-primary add-to-pack-list" data-product="'.$vars['ID'];

            // Automatically adds add to list button next to download link
            if(isset($options['after_download_link']))
            $vars['download_link'] .= $btn;

            return $vars;
        }

        function create_package_list($current_user, $name, $privacy){
            global $wpdb;
            $result = $wpdb->insert( $wpdb->prefix.'wpdm_package_lists',
                array(
                    'owner_id' => $current_user,
                    'name' => $name,
                    'privacy' => $privacy,
                    'items' => 0,
                    'created' => time(),
                    'updated' => time(),
                ),
                array(
                    '%d',
                    '%s',
                    '%d',
                    '%d',
                    '%d',
                    '%d',
                )
            );
            return $result;
        }

        // Return Package Lists by provided user id
        function get_pack_lists_by_user($user_id){
            global $wpdb;
            $lists = $wpdb->get_results("select * from {$wpdb->prefix}wpdm_package_lists where owner_id={$user_id}");

            if($lists )
                return $lists;
            else {
                $wpdb->insert("{$wpdb->prefix}wpdm_package_lists", array('name' => 'Wish List', 'owner_id' => $user_id, 'privacy' => '1', 'created' => time(), 'updated' => time() ));
                $lists = $wpdb->get_results("select * from {$wpdb->prefix}wpdm_package_lists where owner_id={$user_id}");
                return $lists;
            }

        }

        // Returns package id array
        function get_list_items($list_id){
            global $wpdb;
            $list_items = $wpdb->get_col('SELECT package_id FROM ' . $wpdb->prefix.'wpdm_package_list_items' . ' WHERE list_id = ' . $list_id );
            return $list_items;
        }

        function get_list_info($list_id){
            global $wpdb;
            $list_details = $wpdb->get_row("select * from {$wpdb->prefix}wpdm_package_lists where list_id={$list_id}");
            return $list_details;
        }

        // Return list id
        function get_list_id_by_name($name){
            global $wpdb;
            $list_id = $wpdb->get_col('SELECT list_id FROM ' . $wpdb->prefix.'wpdm_package_lists' . ' WHERE name = "' . $name.'"' );
            return $list_id;
        }


        function add_product_to_list($product_id, $list_id, $user_id)
        {
            global $wpdb;
            $list_data = $wpdb->get_row('SELECT * FROM ' . $wpdb->prefix.'wpdm_package_lists' . ' WHERE list_id = ' . $list_id );
            $list_items = $wpdb->get_var('SELECT id FROM ' . $wpdb->prefix.'wpdm_package_list_items' . ' WHERE list_id = ' . $list_id .' and package_id = '.$product_id );

            // Package already in list
            if($list_items > 0){
                return false;
            }

            // Insert package in list
            if ($list_data->owner_id == $user_id) {
                global $wpdb;
                $result = $wpdb->insert( $wpdb->prefix.'wpdm_package_list_items',
                    array(
                        'list_id' => $list_id,
                        'package_id' => $product_id,
                        'added' => time(),
                    ),
                    array(
                        '%d',
                        '%d',
                        '%d',
                    )
                );
            }

            if (!$result) {
                // Insert failed
                return 'error';
            } else {
                // Update number of items in this list ( Increase by one )
                $items = $list_data->items + 1;
                $wpdb->update("{$wpdb->prefix}wpdm_package_lists", array('items' => $items,'updated' => time() ), array('list_id' => $list_id),array('%d','%d'));

                return true;
            }
        }

        function remove_package_from_list($product_id, $list_id, $user_id)
        {
            global $wpdb;
            $list_data = $wpdb->get_row('SELECT * FROM ' . $wpdb->prefix.'wpdm_package_lists' . ' WHERE list_id = ' . $list_id );
            $list_items = $wpdb->get_var('SELECT id FROM ' . $wpdb->prefix.'wpdm_package_list_items' . ' WHERE list_id = ' . $list_id .' and package_id = '.$product_id );

            if ($list_data->owner_id == $user_id) {
                $result = $wpdb->delete(
                    "{$wpdb->prefix}wpdm_package_list_items",
                    array(
                        'package_id' => $product_id,
                        'list_id' => $list_id
                    ),
                    array(
                        '%d',
                        '%d'
                    )
                );
            }

            if (!$result) {
                return false;
            } else {
                $items = $list_data->items - 1;
                $wpdb->update("{$wpdb->prefix}wpdm_package_lists", array('items' => $items,'updated' => time() ), array('list_id' => $list_id),array('%d','%d'));
                return true;
            }

        }

        // When a package is deleted, remove it from all lists
        function remove_package_from_all_lists($product_id){
            global $wpdb;
            $wpdb->delete(
                "{$wpdb->prefix}wpdm_package_list_items",
                array(
                    'package_id' => $product_id,
                ),
                array(
                    '%d',
                )
            );
        }

        function delete_package_list($list_id){
            global $wpdb;
            $list_data = $wpdb->get_row('SELECT * FROM ' . $wpdb->prefix.'wpdm_package_lists' . ' WHERE list_id = ' . $list_id );
            $user_id = get_current_user_id();
            if ($list_data->owner_id == $user_id) {
                $result = $wpdb->delete(
                    "{$wpdb->prefix}wpdm_package_lists",
                    array(
                        'owner_id' => $user_id,
                        'list_id' => $list_id
                    ),
                    array(
                        '%d',
                        '%d'
                    )
                );

                if (!$result) {
                    return false;
                } else {
                    $wpdb->delete(
                        "{$wpdb->prefix}wpdm_package_list_items",
                        array(
                            'list_id' => $list_id,
                        ),
                        array(
                            '%d'
                        )
                    );
                    return true;
                }
            }
        }

        function get_pack_lists_paged(){
            global $wpdb;
            $page = isset($_GET['listpage']) ? $_GET['listpage'] : 1;
            $offset = ( $page - 1 ) * 10;

            $lists = $wpdb->get_results("select * from {$wpdb->prefix}wpdm_package_lists WHERE privacy='0' LIMIT {$offset},10");

            if($lists )
                return $lists;
            else return array();
        }

    }

}