<?php
/**
 * Plugin Name: WPDM - Package Lists
 * Description: Let user create and manage their package lists.
 * Plugin URI: https://www.wpdownloadmanager.com/download/package-lists-collections/
 * Author: Shahriar
 * Version: 1.3.1
 * Author URI: https://www.wpdownloadmanager.com/
 * Update URI: wpdm-package-lists
 */
if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('WPDM_PL')) {

    class WPDM_PL
    {
        private static $PackListAPI;

        function __construct()
        {

            if (!defined("WPDM_PL_PLUGIN_DIR")) {
                define('WPDM_PL_PLUGIN_DIR', dirname(__FILE__));
            }

            require('includes/class.WPDMPackageList.php');
            self::$PackListAPI = new WPDMPackageList();

            add_action('plugins_loaded', array($this, 'load_textdomain'));
            add_action('wp_enqueue_scripts', array($this, 'package_list_scripts'));
            add_action('wp_head', array($this, 'package_list_js_vars'));

            add_action('wp_ajax_wpdm_add2list_options', array($this, 'add_to_list_options'));
            add_action('wp_ajax_nopriv_wpdm_add2list_options', array($this, 'add_to_list_options'));

            add_action('wp_ajax_wpdm_add2list', array($this, 'add_to_list'));
            add_action('wp_ajax_wpdm_remove_list_item', array($this, 'remove_list_item'));
            add_action('wp_ajax_wpdm_create_new_list', array($this, 'create_new_list'));
            add_action('wp_ajax_wpdm_delete_list', array($this, 'wpdm_delete_list'));

            add_action('delete_post', array($this, 'remove_from_all_lists'));

            // Admin Settings and User Dashboard Tab
            add_filter('add_wpdm_settings_tab', array($this, 'package_lists_settings_tab' ));
            add_filter('wpdm_user_dashboard_menu', array($this, 'DashboardMenu'));

            // WPDM Template Tag [add_to_list]
            add_filter('wdm_before_fetch_template',array(self::$PackListAPI,'add_to_list_button'),10,1);

            // Shortcodes
            add_shortcode('wpdm_package_list', array($this, 'public_package_lists'));
        }

        static function install()
        {
            global $wpdb;
            require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

            $sqls[] = "CREATE TABLE IF NOT EXISTS `{$wpdb->prefix}wpdm_package_lists` (
                      `list_id` int(11) NOT NULL AUTO_INCREMENT,
                      `name` TEXT,
  					  `owner_id` int(11) NOT NULL,
                      `privacy` TINYINT( 1 ) NOT NULL DEFAULT 0,
                      `items` int(11) NOT NULL DEFAULT 0,
                      `created` int(11) NOT NULL,
                      `updated` int(11) NOT NULL,
  					  PRIMARY KEY (`list_id`)
				      )";

            $sqls[] = "CREATE TABLE IF NOT EXISTS `{$wpdb->prefix}wpdm_package_list_items` (
                      `id` int(11) NOT NULL AUTO_INCREMENT,
  					  `list_id` int(11) NOT NULL,
                      `package_id` int(11) NOT NULL,
                      `added` int(11) NOT NULL,
  					  PRIMARY KEY (`id`)
				      )";

            foreach($sqls as $sql){
                dbDelta($sql);
            }

        }

        function load_textdomain()
        {
            load_plugin_textdomain('wpdm-package-list', false, dirname(plugin_basename(__FILE__)) . '/lang');
        }

        function package_lists_settings_tab($stabs){
            $stabs['package-lists'] = wpdm_create_settings_tab('package-lists', 'Package Lists', array($this, 'wpdm_package_lists_settings'), $icon = 'far fa-list-alt');
            return $stabs;
        }

        function DashboardMenu($menu){
            $menu = array_merge(array_splice($menu,0, 4), array('package-list' => array('icon' => 'fas fa-list', 'name'=> 'Package Lists', 'callback' => array($this, 'MyLists'))), $menu);
            return $menu;
        }

        function MyLists($params = array()){
            global $current_user;

            $ajaxurl = site_url('/');

            if(is_array($params)) extract($params);

            ob_start();
            if(!is_user_logged_in())
                include(wpdm_tpl_path('wpdm-be-member.php'));
            else{
                include(WPDM_PL_PLUGIN_DIR.'/includes/lists.dashboard.php');
            }
            $html = ob_get_clean();

            return $html;
        }

        function wpdm_package_lists_settings()
        {
            global $current_user;
            if (isset($_POST['_wpdm_pl_options']) && count($_POST['_wpdm_pl_options']) > 0) {
                update_option('_wpdm_pl_options', $_POST['_wpdm_pl_options']);
                die('Settings Saved Successfully!');
            }
            $options = get_option('_wpdm_pl_options', array());
            $icon = isset($options['icon']) ? $options['icon'] : 'fa fa-bookmark-o';
            $icons = array(
                'noicon' => 'No Icon',
                'fa fa-star' => 'Star',
                'fa fa-list' => 'List',
                'fa fa-th-list' => 'List',
                'fa fa-list-alt' => 'List',
                'fa fa-heart' => 'Heart Solid',
                'far fa-heart' => 'Heart',
                'fa fa-plus' => 'Plus',
                'far fa-plus-square' => 'Plus Alt',
                'fa fa-plus-circle' => 'Plus Circle',
                'fa fa-plus-square' => 'Plus Square',
                'fa fa-bookmark' => 'Bookmark Solid',
                'far fa-bookmark' => 'Bookmark',
                'fa fa-folder' => 'Folder Solid',
                'far fa-folder' => 'Folder',
            );
            //print_r($options);
            ?>
            <style type="text/css">
                i.noicon{padding: 5px;}
                label.xdicon{
                    float: left;
                    min-width: 30px !important;
                    max-width: 30px !important;
                    min-height: 30px !important;
                    max-height: 30px !important;
                    text-align: center;
                    line-height: 16px;
                    font-size: 14px;
                    padding:5px 7px;
                    display: inline-table;
                    border: 1px solid #dddddd;
                    border-radius: 2px;
                    transition: all 0.3s ease-in-out;
                    margin: 3px;
                }
                label.xdicon i{
                    width: 16px !important;
                }
                .xdicon:hover{
                    border: 1px solid #1E8CBE;
                    transition: all 0.3s ease-in-out;
                }
                .xdicon.active{
                    border: 1px solid #1E8CBE;
                    background: #1E8CBE;
                    color: #ffffff;
                    transition: all 0.3s ease-in-out;
                }
            </style>
            <script>
                jQuery(function($){
                    $('.xdicon').click(function(){
                        $('.xdicon').removeClass('active');
                        $(this).addClass('active');
                    });
                });
            </script>
            <div class="panel panel-default">
                <div class="panel-heading"><?php _e('Package List Options', 'wpdmpro'); ?></div>
                <div class="panel-body">
                    <p style="border: 1px solid #ddd;border-radius: 3px;padding: 15px;">
                        <em>Use <b style="color: #337ab7;">[add_to_list]</b> template tag in Link and Page template to generate <b style="color: #337ab7;">Add to List</b> button.
                            You can use <b style="color: #337ab7;">[add_to_list_url]</b> template tag to get only URL and place it in your own button ( For better customizability ) </em>
                    </p>

                    <fieldset style="margin-bottom: 20px;">
                        <legend><?php _e("Button Properties","wpdmpro"); ?></legend>
                        <div class="form-group">
                            <label for="_wpdm_pl_options[label]"><b><?php _e('Button Label',''); ?></b></label>
                            <input class="form-control" type="text" name="_wpdm_pl_options[label]" value="<?php echo isset($options['label'])? $options['label'] :''; ?>">
                        </div>
                        <div class="form-group">
                            <label for="_wpdm_pl_options[icon]"><b><?php _e('Button Icon',''); ?></b></label>
                            <div style="height: 60px;padding: 10px;border: 1px solid #ddd;border-radius:3px;">
                                <div style="overflow: auto;">
                                    <div style="clear: both"></div>
                                    <?php
                                    if($icon != '')
                                        echo "<label class='xdicon active' title='{$icons[$icon]}'><input style='display:none;' type=radio name='_wpdm_pl_options[icon]' value='{$icon}' checked=checked ><i class='{$icon}'></i></label>";
                                    foreach($icons  as $class => $name){
                                        if($icon != $class)
                                            echo "<label class='xdicon' title='$name'><i class='$class'></i><input style='display:none' type='radio' name='_wpdm_pl_options[icon]' value='{$class}' ".checked($class, $icon, false)." title='{$name}' /></label>";
                                    }
                                    ?>
                                    <div style="clear: both"></div>
                                </div>
                            </div>
                        </div>
                    </fieldset>

                    <fieldset style="margin-bottom: 20px;">
                        <legend><?php _e("Auto generate list button","wpdmpro"); ?> <span class="info infoicon" title="Extends [download_link] template tag. No need to use [add_to_list] tag, when this option is active">(i)</span></legend>
                        <ul>
                            <li><label><input <?php if(isset($options['after_download_link'])) echo 'checked=checked'; ?> type="checkbox" value="1" name="_wpdm_pl_options[after_download_link]"> <?php _e("Place <b>Add to list</b> button after Download / Add to Cart button","wpdmpro"); ?></label></li>
                        </ul>
                    </fieldset>

                    <fieldset style="margin-bottom: 20px;">
                        <legend><?php _e("Shortcode Page","wpdmpro"); ?> <span class="info infoicon" title="This page will be used to show shared public lists">(i)</span></legend>
                        <?php
                        wp_dropdown_pages(array(
                            'name' => '_wpdm_pl_options[shortcode_page]',
                            'id' => '_wpdm_pl_options[shortcode_page]',
                            'show_option_none' => __('None Selected', 'wpdmpro'),
                            'option_none_value' => '' ,
                            'selected' => isset($options['shortcode_page']) ? $options['shortcode_page'] : ''
                            )
                        );
                        ?>
                        <br><br> Place <em>[wpdm_package_list]</em> shortcode in selected page.
                    </fieldset>

                    <fieldset style="margin-bottom: 20px;">
                        <legend><?php _e("Enable List Sharing Networks","wpdmpro"); ?></legend>
                        <ul>
                            <li><label><input <?php if(isset($options['facebook'])) echo 'checked=checked'; ?> type="checkbox" value="1" name="_wpdm_pl_options[facebook]"> <?php _e("Facebook","wpdmpro"); ?></label></li>
                            <li><label><input <?php if(isset($options['gplus'])) echo 'checked=checked'; ?> type="checkbox" value="1" name="_wpdm_pl_options[gplus]"> <?php _e("Google+","wpdmpro"); ?></label></li>
                            <li><label><input <?php if(isset($options['twitter'])) echo 'checked=checked'; ?> type="checkbox" value="1" name="_wpdm_pl_options[twitter]"> <?php _e("Twitter","wpdmpro"); ?></label></li>
                            <li><label><input <?php if(isset($options['linkedin'])) echo 'checked=checked'; ?> type="checkbox" value="1" name="_wpdm_pl_options[linkedin]"> <?php _e("LinkedIn","wpdmpro"); ?></label></li>
                            <li><label><input <?php if(isset($options['pinterest'])) echo 'checked=checked'; ?> type="checkbox" value="1" name="_wpdm_pl_options[pinterest]"> <?php _e("Pinterest","wpdmpro"); ?></label></li>
                        </ul>
                    </fieldset>

                </div>
            </div>
            <?php
        }

        function package_list_js_vars()
        {
            ?>
            <script type="text/javascript">
            </script>
            <?php
        }

        function package_list_scripts()
        {
            wp_enqueue_style('wpdm-package-list-css',plugins_url('/wpdm-package-lists/assets/css/style.css'));
            wp_enqueue_script('wpdm-package-list',plugins_url('/wpdm-package-lists/assets/js/app.js'),array('jquery'));
            wp_enqueue_style('wpdm-package-list-colorbox-style',plugins_url('/wpdm-package-lists/assets/colorbox/colorbox.css'));
            wp_enqueue_script('wpdm-package-list-colorbox',plugins_url('/wpdm-package-lists/assets/colorbox/jquery.colorbox-min.js'), array('jquery'));
        }

        function add_to_list_options()
        {
            if (is_user_logged_in()) {
                global $wpdb;
                $product_id = intval($_REQUEST['p']);
                $user_id = get_current_user_id();
                $lists = self::$PackListAPI->get_pack_lists_by_user($user_id);
                ?>
                <div id="modal-add-to-list" class="">
                    <div class="atl-wrapper">
                        <h2><?php _e('My Lists', ''); ?></h2>
                        <div class="collections">
                            <div class="ajax-res-msg"><span><?php _e('Please wait...'); ?></span></div>
                            <ul class="collections-list">
                                <?php
                                foreach ($lists as $list):

                                    $items = self::$PackListAPI->get_list_items($list->list_id);

                                    // Update number of items in list ( This is to handle deleted package situation )
                                    if(count($items) != $list->items){
                                        $wpdb->update("{$wpdb->prefix}wpdm_package_lists", array('items' => count($items) ), array('list_id' => $list->list_id),array('%d'));
                                    }

                                    $class = (in_array($product_id, $items)) ? 'item-in-list' : '';
                                    ?>
                                    <li class="collection-item">
                                        <div class="thumbwrap">
                                            <?php if($list->privacy == '1'):?>
                                            <span class="modal-list-privacy" title="Private List"><i class="fa fa-lock"></i></span>
                                            <?php endif; ?>
                                            <?php if ($class == '') { ?>
                                                <img class="add-to-list-ajax" data-package="<?php echo $product_id; ?>"
                                                     data-list="<?php echo $list->list_id; ?>"
                                                     src="<?php echo plugins_url('/wpdm-package-lists/assets/images/list.png'); ?>">
                                            <?php } else { ?>
                                                <img class="remove-list-item-ajax <?php echo $class; ?>"
                                                     data-package="<?php echo $product_id; ?>"
                                                     data-list="<?php echo $list->list_id; ?>"
                                                     src="<?php echo plugins_url('/wpdm-package-lists/assets/images/list.png'); ?>">
                                            <?php } ?>
                                        </div>
                                        <div class="info">
                                            <h3 class="pack-list-title"><?php echo $list->name; ?></h3>
                                            <p class="num-of-items"><span class="items-in-<?php echo $list->list_id; ?>"><?php echo $list->items; ?></span> Items</p>
                                        </div>
                                    </li>
                                <?php endforeach; ?>
                                <li class="collection-item wpdm-new-pack-list">
                                    <div class="thumbwrap">
                                        <div class="wpdm-list-privacy">
                                            <span class="pri-list privacy-state active" data-privacy="1">Private</span><span class="pub-list privacy-state" data-privacy="0">Public</span>
                                        </div>
                                        <img class="new-list-item" data-package="<?php echo $product_id; ?>"
                                             src="<?php echo plugins_url('/wpdm-package-lists/assets/images/add-list.png'); ?>">
                                    </div>
                                    <div class="info">
                                        <h3 class="pack-list-title new-list-name" contenteditable="true" style="color: #2080d3"><?php _e('Click to edit name'); ?></h3>
                                        <p class="no-item-yet"><?php _e('Current item will be added to this list',''); ?></p>
                                    </div>
                                </li>
                            </ul>
                        </div>
                        <div class="button-wrapper">
                            <a href="#" class="create-new-pack-list wpdm-btn-active">+ <?php _e('Create New Package List',''); ?></a>
                            <a href="#" class="save-new-pack-list wpdm-btn-disabled"><?php _e('Save New List',''); ?></a>
                        </div>
                    </div>
                </div>
                <?php
                die();
            }else{
                ?>
                <div id="modal-add-to-list" class="">
                    <div class="atl-wrapper">
                        <h2><?php _e('My Lists', ''); ?></h2>
                        <div class="collections" style="padding: 50px;text-align: center;border: none;">
                            Please Login to manage package lists.
                        </div>
                    </div>
                </div>
                <?php
                die();
            }
        }

        function add_to_list()
        {
            $response = false;

            if (is_user_logged_in()) {
                $product_id = intval($_REQUEST['p']);
                $list_id = intval($_REQUEST['list']);
                $user_id = get_current_user_id();

                if ($product_id > 0 && $list_id > 0) {
                    $response = self::$PackListAPI->add_product_to_list($product_id, $list_id, $user_id);
                }
            }

            if($response == true)
                die(json_encode(array('response' => $response,'msg' => __('Successfully added to list','') )));
            else if($response == 'error')
                die(json_encode(array('response' => $response,'msg' => __('Opps! Something went wrong!!','') )));
            else
                die(json_encode(array('response' => $response,'msg' => __('Package already in list!','') )));
        }

        function remove_list_item()
        {
            $response = false;

            if (is_user_logged_in()) {
                $product_id = intval($_REQUEST['p']);
                $list_id = intval($_REQUEST['list']);
                $user_id = get_current_user_id();

                if ($product_id > 0 && $list_id > 0) {
                    $response = self::$PackListAPI->remove_package_from_list($product_id, $list_id, $user_id);
                }
            }

            if($response == true)
                die(json_encode(array('response' => $response,'msg' => __('Package removed from list','') )));
            else
                die(json_encode(array('response' => $response,'msg' => __('Package could not be deleted from list','') )));

        }

        function remove_from_all_lists($post_id){
            self::$PackListAPI->remove_package_from_all_lists($post_id);
        }

        function create_new_list(){
            $response = false;

            if (is_user_logged_in()) {
                $product_id = intval($_REQUEST['p']);
                $list_name = $_REQUEST['name'];
                $privacy = $_REQUEST['privacy'];
                $user_id = get_current_user_id();

                if ($product_id > 0 && $list_name != '') {
                    $response = self::$PackListAPI->create_package_list($user_id, $list_name, $privacy);
                    if($response){
                        $list_id = self::$PackListAPI->get_list_id_by_name($list_name); // Accepts an array
                        $list_id = intval($list_id[0]);
                        $response = self::$PackListAPI->add_product_to_list($product_id, $list_id, $user_id);
                    }
                }
            }

            if($response == true)
                die(json_encode(array('response' => $response,'msg' => __('Successfully added to list',''), 'list_id'=> $list_id )));
            else if($response == 'error')
                die(json_encode(array('response' => $response,'msg' => __('Opps! Something went wrong!!','') )));
            else
                die(json_encode(array('response' => $response,'msg' => __('Package already in list!','') )));
        }

        function wpdm_delete_list()
        {
            $response = false;

            if (is_user_logged_in()) {
                $list_id = intval($_REQUEST['list']);

                if ($list_id > 0) {
                    $response = self::$PackListAPI->delete_package_list($list_id);
                }

                if ($response == true)
                    die(json_encode(array('response' => $response, 'msg' => __('List has been deleted', ''))));
                else
                    die(json_encode(array('response' => $response, 'msg' => __('Sorry something went wrong!...Please reload page and try again', ''))));
            }
        }

        function public_package_lists(){
            ob_start();

            include(WPDM_PL_PLUGIN_DIR.'/includes/lists.shortcode.php');

            $html = ob_get_clean();
            return $html;
        }


    }

}


function wpdm_package_lists_admin_notice()
{
    ?>
    <div class="error">
        <p><?php _e('Please activate WP Download Manager. WPDM Package Lists requires WP Download Manager to work properly.', 'wcwl'); ?></p>
    </div>
    <?php
}

function wpdmpl_depedency_check()
{
    if (defined('WPDM_VERSION')) {
        new WPDM_PL();
    } else {
        add_action('admin_notices', 'wpdm_package_lists_admin_notice');
    }
}
add_action('plugins_loaded', 'wpdmpl_depedency_check', 11);

add_filter("update_plugins_wpdm-package-lists", function ($update, $plugin_data, $plugin_file, $locales){
    $id = 'wpdm-package-lists';
    $latest_versions = WPDM()->updater->getLatestVersions();
    $latest_version = wpdm_valueof($latest_versions, $id);
    $access_token = wpdm_access_token();
    $update = [];
    $update['id']           = $id;
    $update['slug']         = $id;
    $update['url']          = wpdm_valueof($plugin_data, 'PluginURI');
    $update['tested']       = true;
    $update['version']      = $latest_version;
    $update['package'] = $access_token !== '' ? "https://www.wpdownloadmanager.com/?wpdmpp_file={$id}.zip&access_token={$access_token}" : '';
    return $update;
}, 10, 4);

register_activation_hook(__FILE__, array('WPDM_PL', 'install'));
