<?php
/**
 * Plugin Name: WPDM - PAD Importer
 * Plugin URI: http://www.wpdownloadmanager.com/download/pad-file-importer
 * Description: Create a Download Manger package from a PAD( Portable Application Description ) file.
 * Author: Shahriar
 * Author URI: http://www.wpdownloadmanager.com
 * Version: 1.0.0
 */

if (defined('WPDM_Version')) {

    class WPDM_PAD_Importer{

        function __construct()
        {
            $this->Init_Hooks();
            $this->ShortCodes();
        }

        function Init_Hooks(){
            add_filter( 'wpdm_package_settings_tabs', array( $this, 'custom_pad_info' ) );
            add_filter( 'wdm_before_fetch_template', array( $this, 'custom_tags_for_pad_info'), 10, 1 );
            add_action( 'wpdm_template_editor_menu', array( $this, 'template_editor_menu' ));
            add_filter( 'add_wpdm_settings_tab', array($this, 'pad_importer_settings_tab' ));
            add_filter( 'post_row_actions', array($this, 're_sync_pad_button'), 10, 2);
            add_action( 'init', array($this, 're_sync_pad') );
        }

        function ShortCodes(){
            add_shortcode( 'pad-submission-form', array( $this, 'pad_submission_form' ) );
        }

        function pad_importer_settings_tab($stabs){
            $stabs['pad-importer'] = wpdm_create_settings_tab('pad-importer', 'PAD Importer', array($this, 'pad_importer_settings'), $icon = 'fa fa-file-code-o');
            return $stabs;
        }

        function re_sync_pad_button($actions, $post){

            // Return if pacakge is not created from PAD file
            if( empty( get_post_meta( $post->ID, '__wpdm_pad_file_url', true ) ) ) return $actions;

            // Add resync button
            if($post->post_type == 'wpdmpro')
                $actions['re_sync_pad'] = '<a title="'.__('Re Sync package data from PAD URL','wpdmpro').'" href="'.admin_url( 'edit.php?post_type=wpdmpro&task=resync_pad&package=' . $post->ID ).'" class="re_sync_pad"><i class="fa fa-refresh text-success"></i></a>';

            return $actions;
        }

        function re_sync_pad(){
            if( isset($_GET['task']) && $_GET['task'] == 'resync_pad' && current_user_can('edit_posts') ){
                $pad_url = get_post_meta( $_GET['package'], '__wpdm_pad_file_url', true );
                $email = get_post_meta( $_GET['package'], '__wpdm_pad_submitted_by', true );

                $response = $this->pad_2_package($pad_url, $email, 'update', $_GET['package']);

                add_action( 'admin_notices', array($this, 'pad_resync_notice_success') );

            }
        }

        function pad_importer_settings(){
            global $current_user;
            if ( isset( $_POST['_wpdm_pad_importer_access'] ) > 0 ) {
                update_option('_wpdm_pad_importer_access', $_POST['_wpdm_pad_importer_access']);
                update_option('__wpdm_pad_import_link_template', $_POST['__wpdm_pad_import_link_template']);
                update_option('__wpdm_pad_import_page_template', $_POST['__wpdm_pad_import_page_template']);
                update_option('_wpdm_pad_importer_access_blocked', $_POST['_wpdm_pad_importer_access_blocked']);
                update_option('_wpdm_pad_importer_auto_author', $_POST['_wpdm_pad_importer_auto_author']);
                die('Settings Saved Successfully!');
            }
            ?>

            <div class="panel panel-default">
                <div class="panel-heading"><?php echo __('PAD File Importer Options','wpdmpro'); ?></div>
                <div class="panel-body">

                    <div class="form-group">
                        <label><?php echo __('Allowed User Roles to Submit PAD File','wpdmpro'); ?></label>
                        <select name="_wpdm_pad_importer_access[]" class="chzn-select role" multiple="multiple" id="fronend-ui-access" style="min-width: 450px">

                            <?php
                            $currentAccess = maybe_unserialize(get_option( '_wpdm_pad_importer_access', array()));
                            $selz = '';
                            if(  $currentAccess ) $selz = (in_array('guest',$currentAccess))?'selected=selected':'';
                            ?>
                            <option value="guest" <?php echo $selz  ?>><?php echo __("All Visitors","wpdmpro"); ?></option>
                            <?php
                            global $wp_roles;
                            $roles = array_reverse($wp_roles->role_names);
                            foreach( $roles as $role => $name ) {
                                if(  $currentAccess )
                                    $sel = (in_array($role,$currentAccess))?'selected=selected':'';
                                else
                                    $sel = '';
                                ?>
                                <option value="<?php echo $role; ?>" <?php echo $sel  ?>> <?php echo $name; ?></option>
                            <?php } ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label><?php echo __('Guest Submitted packages will be assigned to:','wpdmpro'); ?></label><br/>
                        <?php
                        $selected = get_option( '_wpdm_pad_importer_auto_author' );
                        ?>
                        <?php wp_dropdown_users( array('name' => '_wpdm_pad_importer_auto_author', 'id' => 'user_select_dropdown' , 'selected' => $selected, 'show_option_none' => 'Select User' ,'show' => 'display_name') ); ?>
                    </div>

                    <div class="form-group">
                        <label><?php echo __('Message For Blocked Users:','wpdmpro'); ?></label>
                        <textarea id="_wpdm_pad_importer_access_blocked" name="_wpdm_pad_importer_access_blocked" class="form-control"><?php echo stripslashes(get_option('_wpdm_pad_importer_access_blocked'));?></textarea>
                    </div>
                    <div class="form-group">
                        <label><?php echo __('Select Default Link Template','wpdmpro'); ?></label><br/>

                        <?php
                        echo WPDM\admin\menus\Templates::Dropdown(array('name' => '__wpdm_pad_import_link_template', 'selected' => get_option('__wpdm_pad_import_link_template')));
                        ?>
                        <em><?php echo __('Selected link template will be used by default for packages created from PAD file.','wpdmpro'); ?></em>
                    </div>
                    <div class="form-group">
                        <label><?php echo __('Select Default Page Template','wpdmpro'); ?></label><br/>

                        <?php
                        echo WPDM\admin\menus\Templates::Dropdown(array('name' => '__wpdm_pad_import_page_template', 'selected' => get_option('__wpdm_pad_import_page_template'), 'type' => 'page'));
                        ?>
                        <em><?php echo __('Selected page template will be used by default for packages created from PAD file.','wpdmpro'); ?></em>
                    </div>

                    <div class="alert alert-info">You can create a custom link template from <strong>Downloads >> Templates</strong> page using available special template tags for PAD File data.</div>
                </div>
            </div>
            <?php
        }

        function template_editor_menu(){
            ?>
            <li class="dropdown">
                <a href="#" id="droppi" role="button" class="dropdown-toggle" data-toggle="dropdown">PAD File Data<b class="caret"></b></a>
                <ul class="dropdown-menu" role="menu" aria-labelledby="droppi">
                    <li role="presentation"><a role="menuitem" tabindex="-1" href="#[program_target_platform]">Program Target Platform</a></li>
                    <li role="presentation"><a role="menuitem" tabindex="-1" href="#[program_os_support]">Program OS Support</a></li>
                    <li role="presentation"><a role="menuitem" tabindex="-1" href="#[program_system_requirements]">Program System Requirements</a></li>
                    <li role="presentation"><a role="menuitem" tabindex="-1" href="#[application_info_url]">Application Info URL</a></li>
                    <li role="presentation"><a role="menuitem" tabindex="-1" href="#[application_order_url]">Application Order URL</a></li>
                    <li role="presentation"><a role="menuitem" tabindex="-1" href="#[application_screenshot_url]">Application Screenshot URL</a></li>
                    <li role="presentation"><a role="menuitem" tabindex="-1" href="#[company_name]">Company Name</a></li>
                    <li role="presentation"><a role="menuitem" tabindex="-1" href="#[company_website_url]">Company Website URL</a></li>
                </ul>
            </li>

            <?php
        }

        function custom_tags_for_pad_info($vars){

            $vars['program_target_platform'] = get_post_meta($vars['ID'], '__wpdm_program_target_platform', true);
            $vars['program_os_support'] = get_post_meta($vars['ID'], '__wpdm_program_os_support', true);
            $vars['program_system_requirements'] = get_post_meta($vars['ID'], '__wpdm_program_system_requirements', true);
            $vars['application_info_url'] = get_post_meta($vars['ID'], '__wpdm_application_info_url', true);
            $vars['application_order_url'] = get_post_meta($vars['ID'], '__wpdm_application_order_url', true);
            $vars['application_screenshot_url'] = get_post_meta($vars['ID'], '__wpdm_application_screenshot_url', true);
            $vars['company_name'] = get_post_meta($vars['ID'], '__wpdm_company_name', true);
            $vars['company_website_url'] = get_post_meta($vars['ID'], '__wpdm_company_website_url', true);

            return $vars;
        }

        function pad_submission_form(){
            global $current_user;
            $currentAccess = maybe_unserialize(get_option('_wpdm_pad_importer_access', array()));

            if ( ! array_intersect($currentAccess, $current_user->roles) && is_user_logged_in() || !in_array('guest', $currentAccess ) && ! is_user_logged_in() )
                return "<div class='w3eden'><div class='alert alert-danger'>" . wpautop(stripslashes(get_option('_wpdm_pad_importer_access_blocked', __('Sorry, Your Are Not Allowed!','wpdmpro')))) . "</div></div>";

            $URL = isset($_POST['URL']) ? esc_url( $_POST['URL'] ) : '';
            $email = isset($_POST['email']) ? $_POST['email'] : '';
            $response = '';

            if( $URL != '' ):
                $response = $this->pad_2_package($URL, $email, 'insert');
            endif;
            ?>

            <div class="w3eden">
                <?php
                if ( isset( $response['code'] ) && $response['code'] != 0 ) {
                    echo '<div class="alert alert-warning">';
                    echo $response['message'];
                    echo '</div>';
                }

                if ( isset( $response['code'] ) && $response['code'] == 0 ){
                    echo '<div class="alert alert-success">';
                    echo $response['message'];
                    echo '</div>';
                }
                ?>
                <div class="panel panel-default">
                    <div class="panel-heading">Submit PAD file URL</div>
                    <div class="panel-body">

                        <form method='POST'>
                            <div class="form-group">
                                <label for="URL">PAD File URL</label>
                                <input type="text" name="URL" class="form-control" placeholder="" value="<?php echo $URL; ?>">
                            </div>
                            <?php if( in_array('guest', $currentAccess ) && ! is_user_logged_in() ): ?>
                                <div class="form-group">
                                    <label for="email">Email Address</label>
                                    <input type="email" name="email" class="form-control" required placeholder="" value="<?php echo $email; ?>">
                                </div>
                            <?php endif; ?>

                            <button type="submit" class="btn btn-success">Submit</button>
                        </form>

                    </div>
                </div>
            </div>
            <?php
        }

        function upload_image_to_media_library($postID, $url, $alt = "blabla") {

            require_once(ABSPATH . '/wp-load.php');
            require_once(ABSPATH . "wp-admin" . '/includes/image.php');
            require_once(ABSPATH . "wp-admin" . '/includes/file.php');
            require_once(ABSPATH . "wp-admin" . '/includes/media.php');


            $tmp = download_url( $url );
            $desc = $alt;
            $file_array = array();

            // Set variables for storage
            // fix file filename for query strings
            preg_match('/[^\?]+\.(jpg|jpe|jpeg|gif|png)/i', $url, $matches);
            $file_array['name'] = basename($matches[0]);
            $file_array['tmp_name'] = $tmp;

            // If error storing temporarily, unlink
            if ( is_wp_error( $tmp ) ) {
                @unlink($file_array['tmp_name']);
                $file_array['tmp_name'] = '';
            }

            // do the validation and storage stuff
            $id = media_handle_sideload( $file_array, $postID, $desc);

            // If error storing permanently, unlink
            if ( is_wp_error($id) ) {
                @unlink($file_array['tmp_name']);
                return $id;
            }

            return $id;
        }

        function pad_2_package($URL, $email, $action_type, $ID = ''){

            include_once plugin_dir_path(__FILE__) . 'include/padfile.php';
            include_once plugin_dir_path(__FILE__) . 'include/padvalidator.php';

            $PAD = new PADFile($URL);

            if ($PAD->Load()):

                $Program_Name = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/Program_Name");
                $Program_Version = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/Program_Version");
                $File_Size_Bytes = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/File_Info/File_Size_Bytes");
                $File_Size_K = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/File_Info/File_Size_K");
                $File_Size_MB = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/File_Info/File_Size_MB");
                $Program_Target_Platform = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/Program_Target_Platform");
                $Program_OS_Support = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/Program_OS_Support");
                $Program_Categories = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/Program_Categories");
                $Program_Language = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/Program_Language");
                $Program_System_Requirements = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/Program_System_Requirements");

                $Program_Release_Day = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/Program_Release_Day");
                $Program_Release_Month = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/Program_Release_Month");
                $Program_Release_Year = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/Program_Release_Year");
                $Program_Cost_Dollars = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/Program_Cost_Dollars");
                $Program_Type = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/Program_Type");
                $Program_Change_Info = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/Program_Change_Info");
                $Limitations = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Info/Limitations");

                $Application_Info_URL = $PAD->XML->GetValue("XML_DIZ_INFO/Web_Info/Application_URLs/Application_Info_URL");
                $Application_Order_URL = $PAD->XML->GetValue("XML_DIZ_INFO/Web_Info/Application_URLs/Application_Order_URL");
                $Application_Screenshot_URL = $PAD->XML->GetValue("XML_DIZ_INFO/Web_Info/Application_URLs/Application_Screenshot_URL");
                $Download_URLs[0] = $PAD->XML->GetValue("XML_DIZ_INFO/Web_Info/Download_URLs/Primary_Download_URL");
                $Download_URLs[1] = $PAD->XML->GetValue("XML_DIZ_INFO/Web_Info/Download_URLs/Secondary_Download_URL");
                $Download_URLs[2] = $PAD->XML->GetValue("XML_DIZ_INFO/Web_Info/Download_URLs/Additional_Download_URL_1");
                $Download_URLs[3] = $PAD->XML->GetValue("XML_DIZ_INFO/Web_Info/Download_URLs/Additional_Download_URL_2");
                $Application_Icon_URL = $PAD->XML->GetValue("XML_DIZ_INFO/Web_Info/Application_URLs/Application_Icon_URL");
                $Application_XML_File_URL = $PAD->XML->GetValue("XML_DIZ_INFO/Web_Info/Application_URLs/Application_XML_File_URL");

                $Char_Desc_2000 = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Descriptions/English/Char_Desc_2000");
                $Char_Desc_80 = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Descriptions/English/Char_Desc_80");
                $Keywords = $PAD->XML->GetValue("XML_DIZ_INFO/Program_Descriptions/English/Keywords");

                $Company_Name = $PAD->XML->GetValue("XML_DIZ_INFO/Company_Info/Company_Name");
                $Company_WebSite_URL = $PAD->XML->GetValue("XML_DIZ_INFO/Company_Info/Company_WebSite_URL");

                $access_roles = array('0' => 'guest');

                $postdata = array(
                    'post_title' => $Program_Name,
                    'post_content' => utf8_encode($Char_Desc_2000),
                    'post_excerpt' => utf8_encode($Char_Desc_80),
                    'post_type' => 'wpdmpro',
                    'post_status' => 'publish',
                );

                if (!is_user_logged_in()) $postdata['post_author'] = get_option('_wpdm_pad_importer_auto_author');

                if($action_type == 'insert')
                    $post_id = wp_insert_post($postdata);

                if($action_type == 'update'){
                    $postdata['ID'] = $ID;
                    $post_id = wp_update_post($postdata);
                }

                update_post_meta($post_id, '__wpdm_version', $Program_Version);
                update_post_meta($post_id, '__wpdm_files', array_filter( $Download_URLs ) );
                update_post_meta($post_id, '__wpdm_icon', $Application_Icon_URL);
                update_post_meta($post_id, '__wpdm_package_size', $File_Size_MB . " MB");
                update_post_meta($post_id, '__wpdm_access', $access_roles);

                update_post_meta($post_id, '__wpdm_template', get_option('__wpdm_pad_import_link_template'));
                update_post_meta($post_id, '__wpdm_page_template', get_option('__wpdm_pad_import_page_template'));

                wp_set_post_tags($post_id, $Keywords);

                $cats = explode(',', $Program_Categories);
                foreach ($cats as $index => $term) {
                    if ((int)$term > 0) $term = (int)$term;
                    if (term_exists($term, 'wpdmcategory')) {
                        $eterm = term_exists($term, 'wpdmcategory');
                        $cats[$index] = $eterm['term_id'];
                    } else {
                        $tinf = wp_insert_term($term, 'wpdmcategory');
                        if (is_array($tinf) && isset($tinf['term_id']))
                            $cats[$index] = $tinf['term_id'];

                    }
                }
                wp_set_post_terms($post_id, $cats, 'wpdmcategory');


                update_post_meta($post_id, '__wpdm_program_target_platform', $Program_Target_Platform);
                update_post_meta($post_id, '__wpdm_program_os_support', $Program_OS_Support);
                update_post_meta($post_id, '__wpdm_program_system_requirements', $Program_System_Requirements);
                update_post_meta($post_id, '__wpdm_application_info_url', $Application_Info_URL);
                update_post_meta($post_id, '__wpdm_application_order_url', $Application_Order_URL);
                update_post_meta($post_id, '__wpdm_application_screenshot_url', $Application_Screenshot_URL);
                update_post_meta($post_id, '__wpdm_company_name', $Company_Name);
                update_post_meta($post_id, '__wpdm_company_website_url', $Company_WebSite_URL);
                update_post_meta($post_id, '__wpdm_pad_file_url', $Application_XML_File_URL);


                // Guest Submission, save user email
                update_post_meta($post_id, '__wpdm_pad_submitted_by', $email);

                // Set Featured Image
                $urlinfo = pathinfo($Application_Screenshot_URL);
                $attachment_id = $this->upload_image_to_media_library($post_id, $Application_Screenshot_URL, $urlinfo['filename']);
                if( !is_wp_error($attachment_id) ) set_post_thumbnail($post_id, $attachment_id);

            endif;


            $response = array();

            if (isset($PAD->LastError)) {

                switch ($PAD->LastError) {
                    case ERR_NO_URL_SPECIFIED:
                        $response['message'] = "No URL specified.";
                        $response['code'] = 1;
                        break;
                    case ERR_READ_FROM_URL_FAILED:
                        $response['message'] = "Cannot open URL.<br/>";
                        if ($PAD->LastErrorMsg != "") $response['message'] .= $PAD->LastErrorMsg;
                        $response['code'] = 2;
                        break;
                    case ERR_PARSE_ERROR:
                        $response['message'] = "Parse Error: " . $PAD->ParseError;
                        $response['code'] = 3;
                        break;
                    case ERR_NO_ERROR:
                        $response['message'] = "Download Package has been created successfully from PAD file.";
                        $response['code'] = 0;
                        break;
                }
            }

            return $response;
        }

        function pad_resync_notice_success() {
            ?>
            <div class="notice notice-success is-dismissible">
                <p><?php _e( 'Package data re-synced with PAD file!', '' ); ?></p>
            </div>
            <?php
        }

        function custom_pad_info($tabs){

            global $post;

            if( empty( get_post_meta( $post->ID, '__wpdm_pad_file_url', true ) ) ) return $tabs;

            if(is_admin())
                $tabs['pad'] = array('name' => __('Custom PAD Data', ""), 'callback' => array( $this, 'custom_pad_info_html' ) );

            return $tabs;
        }

        function custom_pad_info_html(){
            global $post;
            ?>

            <div id="pad-settings" class="tab-pane">
                <table cellpadding="5" id="pad_file_settings_table" cellspacing="0" width="100%" class="table table-bordered table-hover">
                    <tr>
                        <td width="200px"><?php echo __('Target Platform:','wpdmpro'); ?></td>
                        <td><input size="10" type="text" class="form-control input-sm" style="width: 100px" name="file[program_target_platform]" value="<?php echo esc_attr(get_post_meta($post->ID,'__wpdm_program_target_platform',true)); ?>" /></td>
                    </tr>

                    <tr>
                        <td><?php echo __('OS Support:','wpdmpro'); ?></td>
                        <td><input size="10" type="text" class="form-control input-sm" name="file[program_os_support]" value="<?php echo htmlspecialchars(get_post_meta($post->ID,'__wpdm_program_os_support',true)); ?>" /></td>
                    </tr>

                    <tr id="stock_row">
                        <td><?php echo __('System Requirements:','wpdmpro'); ?></td>
                        <td><input size="10" class="form-control input-sm" type="text" name="file[program_system_requirements]" value="<?php echo esc_attr(get_post_meta($post->ID,'__wpdm_program_system_requirements',true)); ?>" /></td>
                    </tr>

                    <tr id="downliad_limit_row">
                        <td valign="top"><?php echo __('Application Info URL:','wpdmpro'); ?></td>
                        <td><input size="10" class="form-control input-sm" style="width: 500px;" type="text" name="file[application_info_url]" value="<?php echo esc_attr(get_post_meta($post->ID,'__wpdm_application_info_url',true)); ?>" /></td>
                    </tr>

                    <tr id="view_count_row">
                        <td><?php echo __('Application Order URL:','wpdmpro'); ?></td>
                        <td><input size="10" type="text" class="form-control input-sm" style="width: 500px;" name="file[application_order_url]" value="<?php echo esc_attr(get_post_meta($post->ID,'__wpdm_application_order_url',true)); ?>" /></td>
                    </tr>

                    <tr id="download_count_row">
                        <td><?php echo __('Company Name:','wpdmpro'); ?></td>
                        <td><input size="10" style="width: 200px" type="text" class="form-control input-sm" name="file[company_name]" value="<?php echo esc_attr(get_post_meta($post->ID,'__wpdm_company_name',true)); ?>" /></td>
                    </tr>

                    <tr id="package_size_row">
                        <td><?php echo __('Company Website URL:','wpdmpro'); ?></td>
                        <td><input size="10" style="width: 500px" class="form-control input-sm" type="text" name="file[company_website_url]" value="<?php echo esc_attr(get_post_meta($post->ID,'__wpdm_company_website_url',true)); ?>" /></td>
                    </tr>

                    <tr id="package_size_row">
                        <td><?php echo __('PAD File URL:','wpdmpro'); ?></td>
                        <td><input size="10" class="form-control input-sm" type="text" name="file[pad_file_url]" value="<?php echo esc_attr(get_post_meta($post->ID,'__wpdm_pad_file_url',true)); ?>" /></td>
                    </tr>

                    <tr id="package_size_row">
                        <td><?php echo __('Submitted By:','wpdmpro'); ?></td>
                        <td><input size="10" style="width: 500px" class="form-control input-sm" type="text" name="file[pad_submitted_by]" value="<?php echo esc_attr(get_post_meta($post->ID,'__wpdm_pad_submitted_by',true)); ?>" /></td>
                    </tr>

                </table>
                <div class="clear"></div>
            </div>

            <?php
        }


    }

    new WPDM_PAD_Importer();

}

