<?php

/**
 * Plugin Name: WPDM - PDF Stamper
 * Plugin URL: https://www.wpdownloadmanager.com/download/wordpress-pdf-stamper-plugin/
 * Description: Apply Text or Image based Watermarks to PDF Downloads
 * Version: 2.0.6
 * Author: WordPress Download Manager
 * Author URI: https://www.wpdownloadmanager.com/
 */

use WPDM\__\Crypt;
use WPDM\__\FileSystem;
if (!defined('WPINC')) {
    die;
}

class WpdmPdfStampers
{
    private static $instance;
    private $dir, $url;

    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
            self::$instance->actions();
            self::$instance->dir = dirname(__FILE__);
            self::$instance->url = WP_PLUGIN_URL . '/' . basename(self::$instance->dir);
        }
        return self::$instance;
    }

    private function actions()
    {

        register_activation_hook(__FILE__, array($this, 'activate'));
        register_deactivation_hook(__FILE__, array($this, 'deactivate'));

        if (is_admin()) {
            add_action('load-wpdmpro_page_settings', array($this, 'addScripts'));
            //settings page entry
            add_filter("add_wpdm_settings_tab", array($this, 'settingsTab'));
            //add metabox
            add_filter('wpdm_package_settings_tabs', array($this, 'addMetaBox'));
        }
        if (!is_admin()) {
            add_action('wpdm_onstart_download', array($this, 'fileProcess'), 9999, 1);
        }

    }

    function settingsTab($tabs)
    {
        $tabs['pdf-stamper'] = \WPDM\Admin\Menu\Settings::createMenu("pdf-stamper", "PDF Stamper", array($this, 'settings'), 'fa fa-file-pdf');
        return $tabs;
    }

    public function fileProcess($package)
    {
        $filesclone = $allfiles = WPDM()->package->getFiles($package['ID'], true);

        $indfile = null;

        if (isset($_GET['ind']) && isset($allfiles[sanitize_text_field($_GET['ind'])]))                    // Package has only attached files
            $indfile = $allfiles[sanitize_text_field($_GET['ind'])];
        elseif (isset($_GET['ind']) && array_key_exists($_GET['ind'], $allfiles))                       // Package has only attached dir
            $indfile = $allfiles[$_GET['ind']];
        else if(count($allfiles) === 1)                                                                                           // Package has only attached files and download requested without `ind`
            $indfile = array_shift($filesclone);
        if(!$indfile) return;

        $ext = FileSystem::fileExt($indfile);

        //check for file extension
        if ($ext === 'pdf') {
            $tmp = explode("wp-content", $indfile);
            $tmp = end($tmp);
            $upload_dir = wp_upload_dir();
            $upload_base_url = $upload_dir['baseurl'];
            $upload_dir = $upload_dir['basedir'];
            $indfile = str_replace($upload_base_url, $upload_dir, $indfile);


            if (strpos($indfile, "://")) return;
            //get filepath
            if (file_exists(UPLOAD_DIR . $indfile))
                $filepath = UPLOAD_DIR . $indfile;
            else if (file_exists($indfile))
                $filepath = $indfile;
            else if (file_exists(WP_CONTENT_DIR . $tmp)) //path fix on site move
                $filepath = WP_CONTENT_DIR . $tmp;
            else {
                //wpdm_download_data('file-not-found.txt','File not found or deleted from server');
                //die();
                return;
            }

            $filename = basename($filepath);
            $filename = preg_replace("/([0-9]+)[wpdm]+_/", "", $filename);

            //wpdm_download_file($filepath, $filename, $speed, 1, $package);

            global $current_user;

            $oid = '';
            if (wpdm_query_var('wpdmppd') != '') {
                $wpdmdd = Crypt::decrypt(wpdm_query_var('wpdmppd'), true);
                $oid = $wpdmdd['oid'];
            }

            WPDM()->downloadHistory->add($package['ID'], $indfile, $oid);

            //process filepath to create new file
            $this->processPDF($filepath, $filename, $package['ID']);
        }
    }

    private function processPDF($filepath, $filename, $post_id)
    {

        $post_meta = get_post_meta($post_id, '__wpdm_pdf_stamper', true);
        $options = get_option('wpdm_pdf_stamper', array());
        $oid = '';

        if (wpdm_query_var('wpdmppd') != '') {
            $wpdmdd = Crypt::decrypt(wpdm_query_var('wpdmppd'), true);
            $oid = $wpdmdd['oid'];
        }

        if (is_array($options)) { // && is_array($post_meta)
            //do i need to process this file ?

            // assign default values
            $should_stamp_default = isset($options['general']['should_stamp_default']) ? $options['general']['should_stamp_default'] : 'yes';
            $bypass = isset($post_meta['bypass']) ? $post_meta['bypass'] : 'global';

            $shouldStamp = ($should_stamp_default == 'yes' && ($bypass == 'global' || $bypass == 'no') ) ||
                             ($should_stamp_default == 'no' && $bypass == 'no' ) ;
            if (!$shouldStamp) {
                //skip stamping
                return;
            }




            define('FPDF_FONTPATH', $this->dir .  '/libs/fpdf1.7/font/');
            require_once($this->dir . '/libs/fpdf1.7/fpdf.php');
            require_once($this->dir . '/libs/fpdi1.5.2/fpdi.php');
            require_once($this->dir . '/libs/fpdi_protection1.0.5/FPDI_Protection.php');

            //do i need to encrypt this file
            if (isset($post_meta['encrypt']) && $post_meta['encrypt'] == 'yes') {
                //initiate FPDI_Protection()
                $pdf = new FPDI_Protection();

                //now set password and permissions
                $permissions = isset($post_meta['permission']) ? $post_meta['permission'] : array();
                $user_pass = '';
                $owner_pass = null;

                if (isset($post_meta['password1']) && $post_meta['password1'] == 'yes') {
                    $user_pass = isset($post_meta['open_pass']) && $post_meta['open_pass'] != '' ? $post_meta['open_pass'] : $oid;
                }

                if (isset($post_meta['password2']) && $post_meta['password2'] == 'yes') {
                    $owner_pass = isset($post_meta['owner_pass']) && $post_meta['owner_pass'] != '' ? $post_meta['owner_pass'] : (($oid != '') ? $oid : null);
                }

                $pdf->SetProtection($permissions, $user_pass, $owner_pass);
            } else {
                //initiate FPDI
                $pdf = new FPDI();
            }

            if ($oid != '') {
                if (class_exists('\WPDMPP\Libs\Order')) {
                    $order = new \WPDMPP\Libs\Order();
                    $order_data = $order->GetOrder($oid); //object
                    $arr['{date}'] = date(get_option('date_format'), $order_data->date);
                    $arr['{order_id}'] = $oid;
                    $billing = maybe_unserialize($order_data->billing_info);
                    if (!isset($billing['last_name'])) $billing['last_name'] = '';
                }
            }

            //now render text/image
            if (isset($options['general']['watermark_type']) && $options['general']['watermark_type'] == 'text') {

                $arr['{sitename}']      = get_bloginfo('name');
                $arr['{br}']            = "\n";
                $arr['{name}']          = isset($billing) ? $billing['first_name'] . " " . $billing['last_name'] : '';
                $arr['{fullname}']      = isset($billing) ? $billing['first_name'] . " " . $billing['last_name'] : '';
                $arr['{username}']      = isset($billing) ? $billing['first_name'] . " " . $billing['last_name'] : '';
                $arr['{email}']         = isset($billing, $billing['order_email']) ? $billing['order_email'] : '';
                $arr['{date}']          = get_the_date('', $post_id);
                $arr['{publish_date}']  = get_the_date('', $post_id);
                $arr['{download_date}'] = date(get_option('date_format'), time());
                $arr['{year}']          = date("Y");

                if (is_user_logged_in()) {
                    global $current_user;
                    $billing_shipping = unserialize(get_user_meta($current_user->ID, 'user_billing_shipping', true));
                    if (isset($billing_shipping['billing'])) $billing = $billing_shipping['billing'];

                    $arr['{name}']          = $current_user->user_firstname;
                    $arr['{fullname}']      = ($current_user->first_name != '' ? $current_user->first_name : $billing['first_name']) . ' ' . ($current_user->last_name != '' ? $current_user->last_name : $billing['last_name']);
                    $arr['{username}']      = $current_user->user_login;
                    $arr['{display_name}']  = $current_user->display_name;
                    $arr['{email}']         = $current_user->user_email;
                }

                $vars = WPDM()->package->prepare($post_id)->packageData;

                foreach ($vars as $key => $val) {
                    if (!is_array($val) && !is_object($val))
                        $arr["[$key]"] = $val;
                }

                $key = array_keys($arr);
                $val = array_values($arr);

                // Converting UTF-8 encoded test
                $text = utf8_decode(stripcslashes(str_replace($key, $val, $options['general']['watermark_text'])));

                //now select font, font_size, color etc
                $style = $options['style'];
                $font = $style['font'];
                $font_size = $style['font_size'];
                $font_offset = (int) $style['font_offset'] ? $style['font_offset'] : 1;
                $font_style = @implode('', $style['font_style']);
                $font_color = $style['font_color'];
            } else if (isset($options['general']['watermark_type']) && $options['general']['watermark_type'] == 'image') {
                $image = $options['general']['watermark_image'];
            }

            $watermark_opacity = isset($options['style']['watermark_opacity']) ? $options['style']['watermark_opacity'] : 50;
            $watermark_pages = $options['general']['watermark_pages'];
            //set positions
            $horizontal = $options['position']['horizontal'];
            $vertical = $options['position']['vertical'];
            $horizontal_advanced = $options['position']['horizontal_advanced'];
            $vertical_advanced = $options['position']['vertical_advanced'];

            // get the page count
            $pageCount = $pdf->setSourceFile($filepath);
            // iterate through all pages
            for ($pageNo = 1; $pageNo <= $pageCount; $pageNo++) {
                // import a page
                $templateId = $pdf->importPage($pageNo);
                // get the size of the imported page
                $size = $pdf->getTemplateSize($templateId);

                // create a page (landscape or portrait depending on the imported page size)
                if ($size['w'] > $size['h']) {
                    $pdf->AddPage('L', array($size['w'], $size['h']));
                } else {
                    $pdf->AddPage('P', array($size['w'], $size['h']));
                }
                //print_r($size);
                //die;

                //now calculate x, y
                $align = 'L';
                $x = $y = 5;

                if ($horizontal_advanced != '' && $vertical_advanced != '') {
                    $x = $horizontal_advanced;
                    $y = $vertical_advanced;
                } else {
                    if ($horizontal == 'left') {
                        $align = 'L';
                    } else if ($horizontal == 'right') {
                        if ($options['general']['watermark_type'] == 'image') {
                            $x = $horizontal_advanced !== '' ? $horizontal_advanced : $size['w'] - 40;
                        }
                        $align = 'R';
                    }
                    //x = 190 , y = 290 ; bottom right

                    if ($vertical == 'bottom') {
                        if ($options['general']['watermark_type'] == 'image') {
                            $y = $vertical_advanced !== '' ? $vertical_advanced : $size['h'] - 40;
                        } else {
                            $y = $vertical_advanced !== '' ? $vertical_advanced : $size['h'] - 30;
                        }
                    }
                }


                // use the imported page
                $pdf->useTemplate($templateId);

                // Do I need to stamp this page? This is a boolean flag calculated from the settings for each page.
                $stampThis = false;

                if ($watermark_pages === 'all') {
                    $stampThis = true;
                } else if ($watermark_pages === 'last') {
                    if ($pageCount === $pageNo) {
                        $stampThis = true;
                    }
                } else if ($watermark_pages == 'first') {
                    if ($pageNo == 1) {
                        $stampThis = true;
                    }
                } else if ($watermark_pages == 'odd') {
                    if ($pageNo % 2 == 1) {
                        $stampThis = true;
                    }
                } else if ($watermark_pages == 'even') {
                    if ($pageNo % 2 == 0) {
                        $stampThis = true;
                    }
                } else if ($watermark_pages == 'all_except_first') {
                    if ($pageNo != 1) {
                        $stampThis = true;
                    }
                }
                //die($watermark_pages . $stampThis);
                // Stamp the PDF, in case the flag is true
                if ($stampThis) {
                    if ($options['general']['watermark_type'] == 'text') {
                        //die($font);
                        $pdf->SetFont($font, $font_style, $font_size);
                        $pdf->SetAutoPageBreak(false);
                        list($r, $g, $b) = sscanf($font_color, "#%02x%02x%02x");
                        $pdf->SetTextColor($r, $g, $b);
                        $text_bg = "#dd9933";
                        if (isset($text_bg) && $text_bg != '') {
                            list($rb, $gb, $bb) = sscanf($text_bg, "#%02x%02x%02x");
                            $pdf->SetFillColor(976, 245, 458);
                        }
                        $pdf->SetXY($x, $y);
                        //$pdf->Write(8, 'A complete document imported with FPDI');
                        //die($text);
                        $pdf->MultiCell(0, $font_offset, $text, 0, $align);
                    } else if ($options['general']['watermark_type'] == 'image') {

                        //$stamp_image = $options['general']['watermark_image'];
                        $stamp_image = self::prepareWaterMark($options['general']['watermark_image'], $watermark_opacity);

                        $pdf->Image($stamp_image, $x, $y);
                    }
                }
            }

            // Output the new PDF
            $pdf->Output($filename, 'D');
            //$pdf->Output();
            die;
        }
    }

    public static function prepareWaterMark($img, $watermark_opacity)
    {

        if (!class_exists('Imagick')) return $img;
        if (file_exists(WPDM_CACHE_DIR . basename($img)))
            return WPDM_BASE_URL . 'cache/' . basename($img);
        $image = new Imagick($img);
        $image->setImageOpacity($watermark_opacity / 100);
        $image->writeImage(WPDM_CACHE_DIR . basename($img));
        return WPDM_BASE_URL . 'cache/' . basename($img);
    }

    public function settings()
    {
        if (isset($_POST['pdf_stamp'])) {
            update_option('wpdm_pdf_stamper', $_POST['pdf_stamp']);
            die('Settings Saved Successfully.');
        }

        include __DIR__.'/tpls/settings.php';
    }

    public function addMetaBox($tabs)
    {
        $tabs['wpdm_pdf_stampers'] = array('name' => __('PDF Stamper', "wpdmpro"), 'callback' => array($this, 'metaBoxCallBack'));
        return $tabs;
    }

    public function metaBoxCallBack()
    {

        include __DIR__.'/tpls/metabox-tab.php';

    }

    public function addScripts()
    {
        wp_enqueue_style('wp-color-picker');
        wp_enqueue_script('wp-color-picker');
    }

    public function activate()
    {
    }

    public function deactivate()
    {
    }

    public static function getDir()
    {
        return self::$instance->dir;
    }

    public static function getUrl()
    {
        return self::$instance->url;
    }
}

if (defined('WPDM_VERSION'))
    WpdmPdfStampers::getInstance();
