<?php
/*
Plugin Name: WPDM - PDF Viewer
Description: PDF Viewer for WordPress Download Manager
Plugin URI: https://www.wpdownloadmanager.com/download/wordpress-pdf-viewer/
Author: WordPress Download Manager
Version: 3.0.1
Author URI: https://www.wpdownloadmanager.com/
Text Domain: wpdm-pdf-viewer
Update URI: wpdm-pdf-viewer
*/

namespace WPDM\AddOn;

class PDFViwer{
    private $viewer;
    function __construct()
    {
        add_filter("wp", array($this, 'viewer'));
        add_filter("wpdm_doc_viewer", array($this, 'embedCode'), 999999, 4);
        add_filter("wdm_before_fetch_template", array($this, 'pdfGallery'), 10);
        add_filter("wpdm_single_file_download_link", array($this, 'fileAction'), 10, 3);
        add_filter("wp_footer", array($this, 'footer'), 10, 3);

	    add_filter('update_plugins_wpdm-pdf-viewer', [$this, "updatePlugin"], 10, 4);
    }

    public static function viewerURL($pid, $file_id){
        return add_query_arg(["__wpdm_pdf_viewer" => "{$pid}|{$file_id}"], home_url('/'));
    }

    function embedCode($html, $pid, $url, $ext){
        $up = parse_url($url);
        //if(isset($up['host'], $_SERVER['HTTP_HOST']) && $up['host'] != $_SERVER['HTTP_HOST'] && !strstr($url, 'locked')) return $html;
        $files = WPDM()->package->getFiles($pid);
        $file_id = -1;
        foreach ($files as $id => $file){
            $filetype = wp_check_filetype( $file );
            $ext = strtolower($filetype['ext']);
            if($ext == 'pdf') {
               $file_id = $id;
               break;
            }
        }
        //wpdmdd($file_id);
        if($file_id === -1) return $html;
        $this->viewer = self::viewerURL($pid, $file_id);
        //wpdmdd( $this->viewer);
        $html = "<iframe id='viewer-{$pid}' class='thumbnail' src='{$this->viewer}' style='width: 100%;height: 700px;margin-bottom: 15px;border: 1px solid #dddddd;padding: 0;background: #f9f9fa'></iframe></iframe>";
        return $html;
    }

    function pdfGallery($package){
        $pid = $package['ID'];
        $files = WPDM()->package->getFiles($pid);
        $file_info = get_post_meta($pid, '__wpdm_fileinfo', true);
        $file_info = maybe_unserialize($file_info);
        $apvws = get_post_meta($pid, '__wpdm_additional_previews', true);
        $apvws = maybe_unserialize($apvws);
        $gallery ="<div class='ttip' title='Select PDF to view'><select class='form-control wpdm-custom-select' style='margin-bottom: 15px' onchange=\"jQuery('#viewer-{$pid}') . attr('src', jQuery(this).val());return false;\">";
        $x = 0;
        foreach ($files as $id => $file){
            $filetype = wp_check_filetype( $file );
            $ext = strtolower($filetype['ext']);
            if($ext == 'pdf') {
                $durl = self::viewerURL($pid, $id); // home_url("/?wpdmdl={}&ind={}&open=1");
                $urls[] = $durl;
                $file_title = isset($file_info[$id], $file_info[$id]['title']) && $file_info[$id]['title'] != ''?$file_info[$id]['title']:$file;
                $gallery .= "<option value='{$durl}'>{$file_title}</option> ";
                $x++;
            }
        }
        $gallery .= "</select></div>";
        if(isset($urls))
            $gallery = $this->embedCode("", $package['ID'], $urls[0], "").$gallery;
        $package['pdf_gallery'] = $gallery;
        return $package;

    }

    function viewer(){

        if(wpdm_query_var('__wpdm_pdf_viewer') != ''){
            include wpdm_tpl_path("viewer.php", __DIR__.'/tpls');
            die();
        }

    }

    function fileAction($actions, $fileID, $package)
    {
        $file = wpdm_valueof($package, "files/{$fileID}");
        $ext = pathinfo($file, PATHINFO_EXTENSION);
        if(strtolower($ext) !== 'pdf') return $actions;
        $actions = "<a data-toggle='modal' data-target='#wpdm-pdf-preview' href='".self::viewerURL($package['ID'], $fileID)."' class='btn btn-sm btn-info mr-1 wpdm-pdf-preview'>View</a>".$actions;
        return $actions;
    }

    function footer()
    {
        //if(!is_singular("wpdmpro")) return;
        ?>
        <div class="w3eden">
            <div class="modal" tabindex="-1" id="wpdm-pdf-preview">
                <div class="modal-dialog modal-dialog-centered" style="width: 900px;max-width: 100%;">
                    <div class="modal-content" style="box-shadow: 0 0 20px rgba(0,0,0,0.2);border-radius: 4px;overflow: hidden">
                        <div class="modal-body p-0">
                            <iframe id="wpdm-pdf-preview-frame" src="data:text/plain;base64,TG9hZGluZyBQREYgRmlsZS4uLg==" style="width: 100%;border: 0;height: 700px;margin: 0 0 -8px;padding: 0"></iframe>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <script>
            jQuery(function ($){
                $('.wpdm-pdf-preview').on('click', function (){
                    $('#wpdm-pdf-preview-frame').attr('src', "data:text/plain;base64,TG9hZGluZyBQREYgRmlsZS4uLg==");
                    $('#wpdm-pdf-preview-frame').attr('src', $(this).attr('href'));
                });
            });
        </script>
        <style>
            #wpdm-pdf-preview {
                background: rgba(0,0,0,0.4);
            }
        </style>
        <?php
    }

	function updatePlugin($update, $plugin_data, $plugin_file, $locales){
		$id = basename(__DIR__);
		$latest_versions = WPDM()->updater->getLatestVersions();
		$latest_version = wpdm_valueof($latest_versions, $id);
		$access_token = wpdm_access_token();
		$update = [];
		$update['id']           = $id;
		$update['slug']         = $id;
		$update['url']          = $plugin_data['PluginURI'];
		$update['tested']       = true;
		$update['version']      = $latest_version;
		$update['package']      = $access_token !== '' ? "https://www.wpdownloadmanager.com/?wpdmpp_file={$id}.zip&access_token={$access_token}" : '';
		return $update;
	}


}

if(defined('WPDM_VERSION'))
    new PDFViwer();
