<?php
/*
Plugin Name: WPDM - SendinBlue
Plugin URL: http://www.wpdownloadmanager.com/
Description: SendinBlue integration for Download Manager Plugin
Version: 1.0.0
Author: WordPress Download Manager
Author URI: http://www.wpdownloadmanager.com/
Update URI: wpdm-sendinblue
*/

namespace WPDM\AddOn;

use GuzzleHttp\Client;
use SendinBlue\Client\Api\ContactsApi;
use SendinBlue\Client\Configuration;
use WPDM\Admin\Menu\Settings;

if ( ! defined( 'WPINC' ) ) {
    die;
}

require_once __DIR__.'/vendor/autoload.php';

class SendinBlue{
    private static $instance;
    private $dir, $url;

    public static function getInstance() {
        if(self::$instance === null) {
            self::$instance = new self;
            self::$instance->actions();
            self::$instance->dir = dirname(__FILE__);
            self::$instance->url = WP_PLUGIN_URL . '/' . basename(self::$instance->dir);
        }
        return self::$instance;
    }

    private function actions() {
        register_activation_hook(__FILE__, array($this,'activate'));
        register_deactivation_hook(__FILE__, array($this,'deactivate'));


        if(is_admin()){
            add_filter('add_wpdm_settings_tab',  array($this,'settings_tab'));
        }

        add_action('wpdm_before_email_download_link',array($this,'pushToSendinblue'),10,2);

        add_action("admin_head", [$this, 'admin_head']);

    }

    function admin_head()
    {
        ?>
        <style>
            .sbp {
                fill: var(--color-primary);
            }
            .svg-sendinblue {
                background: url('<?= self::$instance->url ?>/sendinblue.svg');
                background-size: cover;
                display: inline-block;
                width: 16px;
                height: 16px;
                float: left;
            }
            li.active .svg-sendinblue{
                background: url('<?= self::$instance->url ?>/sendinblue-white.svg');
                background-size: cover;
                display: inline-block;
                width: 16px;
                height: 16px;
                float: left;
            }
        </style>
        <?php
    }

    function settings_tab($tabs){
        $tabs['wpdm-sendinblue'] = Settings::createMenu('wpdm-sendinblue', 'SendinBlue', array($this,'settings'), 'svg-sendinblue');
        return $tabs;

    }

    public function activate(){

    }

    public function deactivate(){

    }

    public static function getDir(){
        return self::$instance->dir;
    }

    public static function getUrl(){
        return self::$instance->url;
    }


    public function settings(){

        if(isset($_POST['__wpdm_sendinblue_apikey'])){
            //update_option('__wpdm_sendinblue_apikey_name',wpdm_query_var('__wpdm_sendinblue_apikey_name'));
            update_option('__wpdm_sendinblue_apikey',wpdm_query_var('__wpdm_sendinblue_apikey'));
            update_option('__wpdm_sendinblue_list',wpdm_query_var('__wpdm_sendinblue_list'));
            die('Settings Saved Successfully.');
        }

	    $keyname = 'api-key'; //get_option('__wpdm_sendinblue_apikey_name');
	    $key = get_option('__wpdm_sendinblue_apikey');

	    $result = [];
        if($key) {
	        $config = Configuration::getDefaultConfiguration()->setApiKey( 'api-key', $key );

	        $apiInstance = new ContactsApi(
		        new Client(),
		        $config
	        );
	        $limit       = 10;
	        $offset      = 0;

	        try {
		        $result = $apiInstance->getLists( $limit, $offset )->getLists();
	        } catch ( \Exception $e ) {
		        echo 'Exception when calling ContactsApi->getFolderLists: ', $e->getMessage(), PHP_EOL;
	        }
        }

        ?>
        <div class="panel panel-default">
            <div class="panel-heading">Sendinblue Authentication</div>
            <div class="panel-body">
                <!--div class="form-group">
                    <label for="lead_source">API Key Name</label>
                    <input class="form-control" type="text" name="__wpdm_sendinblue_apikey_name" id="kn" value="<?php echo get_option('__wpdm_sendinblue_apikey_name'); ?>" placeholder="API Key Name">
                </div-->
                <div class="form-group">
                    <label for="lead_source">API Key</label>
                    <input class="form-control" type="text" name="__wpdm_sendinblue_apikey" id="k" value="<?php echo get_option('__wpdm_sendinblue_apikey'); ?>" placeholder="API Key">
                </div>

                <div class="form-group">
                    <label for="lead_source">Select List</label>
                    <select class="form-control" type="text" name="__wpdm_sendinblue_list" id="sbl" value="<?php echo get_option('__wpdm_sendinblue_list'); ?>" >
                        <?php foreach ($result as $list) { ?>
                            <option value="<?= $list['id']; ?>" <?php selected(get_option('__wpdm_sendinblue_list'), $list['id']) ?>><?= $list['name']; ?></option>
                        <?php } ?>
                    </select>
                </div>

            </div>


        </div>
        <?php
    }


    public function pushToSendinblue($post, $file)
    {

        $keyname = 'api-key';// get_option('__wpdm_sendinblue_apikey_name');
        $key = get_option('__wpdm_sendinblue_apikey');

        if(!$key) return;

        $name = $post['name'];
        $names = explode(' ', $name);
        $first_name = $names[0];
        $last_name = wpdm_valueof($names, 1, $names[0]);

        $email = $post['email'];

        if (is_email($email)) {

	        $credentials = Configuration::getDefaultConfiguration()->setApiKey($keyname, $key);

	        $apiInstance = new ContactsApi(
		        new Client(),
		        $credentials
	        );

	        $createContact = new \SendinBlue\Client\Model\CreateContact([
		        'email' => $email,
		        'updateEnabled' => true,
		        'attributes' => [ 'FIRSTNAME' => $first_name, 'LASTNAME' => $last_name ],
		        'listIds' =>[(int)get_option('__wpdm_sendinblue_list')]
	        ]);

	        try {
		        $result = $apiInstance->createContact($createContact);
	        } catch (\Exception $e) {
		        print_r($e);
		        echo 'Exception when calling ContactsApi->createContact: ', $e->getMessage(), PHP_EOL;
	        }


        }
    }

}

if(defined('WPDM_VERSION')) {
	SendinBlue::getInstance();

	add_filter( 'update_plugins_wpdm-sendinblue', function ( $update, $plugin_data, $plugin_file, $locales ) {
		$id                = basename( __DIR__ );
		$latest_versions   = WPDM()->updater->getLatestVersions();
		$latest_version    = wpdm_valueof( $latest_versions, $id );
		$access_token      = wpdm_access_token();
		$update            = [];
		$update['id']      = $id;
		$update['slug']    = $id;
		$update['url']     = $plugin_data['PluginURI'];
		$update['tested']  = true;
		$update['version'] = $latest_version;
		$update['package'] = $access_token !== '' ? "https://www.wpdownloadmanager.com/?wpdmpp_file={$id}.zip&access_token={$access_token}" : '';

		return $update;
	}, 10, 4 );

}

