<?php
/**
 * Plugin Name:  WPDM - User Reviews
 * Plugin URI: https://www.wpdownloadmanager.com/download/user-review-add-on/
 * Description: Help you to add user review form with wpdm pro packages
 * Author: WordPress Download Manager
 * Version: 1.7.6
 * Author URI: https://www.wpdownloadmanager.com/
 * Update URI: wpdm-user-reviews
 */

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}
global $wpdm_user_reviews;

class WPDM_User_Reviews{
    public function __construct()
    {
        add_action( 'init', array( $this, 'wpdm_post_type_reviews' ) );
        add_filter( 'wdm_before_fetch_template', array( $this, 'wpdm_add_review_tag' ), 10, 3 );
        add_action( 'init', array( $this, 'wpdm_save_user_review' ) );
        add_action( 'add_meta_boxes', array( $this, 'wpdm_review_metaboxes' ) );
        add_filter( 'the_content', array( $this, 'wpdm_package_review' ), 99 );
        add_shortcode( 'wpdm_package_review', array( $this, 'wpdm_package_review_shortcode' ) );
        add_filter( 'wp_enqueue_scripts', array( $this, 'wpmp_rating_scripts' ) );

        add_action( 'manage_wpdmreview_posts_columns', array( $this, 'wpdm_reviews_columnsTH' ) );
        add_action( 'manage_wpdmreview_posts_custom_column', array( $this, 'wpdm_reviews_columnsTD' ), 10, 2);
        add_filter( 'pre_get_posts', array( $this, 'wpdm_filter_reviews' ) );
        add_action("wp_head", array($this, 'rating_css'));
	    add_filter('update_plugins_wpdm-user-reviews', [$this, "updatePlugin"], 10, 4);
    }

    function wpdm_post_type_reviews()
    {
        $labels = array(
            'name'                  => 'Reviews',
            'singular_name'         => 'Review',
            'add_new'               => 'Add New',
            'add_new_item'          => 'Add New Review',
            'edit_item'             => 'Edit Review',
            'new_item'              => 'New Review',
            'all_items'             => 'All Reviews',
            'view_item'             => 'View Review',
            'search_items'          => 'Search Review',
            'not_found'             => 'No reviews found',
            'not_found_in_trash'    => 'No reviews found in Trash',
            'parent_item_colon'     => '',
            'menu_name'             => 'Reviews'
        );

        $args = array(
            'labels'                => $labels,
            'public'                => true,
            'publicly_queryable'    => true,
            'show_ui'               => true,
            'show_in_menu'          => true,
            'query_var'             => true,
            'rewrite'               => array('slug' => 'review'),
            'capability_type'       => 'post',
            'has_archive'           => true,
            'hierarchical'          => true,
            'supports'              => array('title', 'editor'),
            'menu_icon'             => 'dashicons-star-half'
        );

        register_post_type('wpdmreview', $args);
    }

    function wpdm_count_reviews($pid){
        global $wpdb;
        $reviews = get_posts("post_type=wpdmreview&meta_key=pid&meta_value=$pid&post_parent=0");
        return count($reviews);
    }
    function wpdm_get_average_reviews($pid)
    {
        global $wpdb;
        $reviews = get_posts("post_type=wpdmreview&meta_key=pid&meta_value=$pid&post_parent=0");

        $sum_reviews = 0;
        foreach ($reviews as $review) {
            $sum_reviews += $review->rating;
        }
        if (count($reviews) > 0)
            $average_review = number_format($sum_reviews / count($reviews), 1);
        else
            $average_review = 0;
        wp_reset_query();
        return $average_review;
    }

    function wpdm_show_reviews($pid, $parent)
    {
        global $wpdb;
        $reviews = get_posts("post_type=wpdmreview&meta_key=pid&meta_value=$pid&post_parent=$parent");
        $html = '';
        $reply_style = $parent == 0 ? '' : 'style="margin-left: 50px;"';
        ob_start();
        foreach ($reviews as $review) {
            $rating = $parent == 0 ? "<div style='margin-right:20px' class='rateit pull-left' data-rateit-value='{$review->rating}' data-rateit-ispreset='true' data-rateit-readonly='true'></div>" : "";
            $rate = $review->rating;
            include( wpdm_tpl_path('single-review.php', dirname(__FILE__).'/tpls/') );
            echo $this->wpdm_show_reviews($pid, $review->ID);
        }
        $html = ob_get_clean();
        return $html;
    }

    function wpmp_rating_scripts()
    {
        //wp_enqueue_script("wpdm-rating", plugins_url('wpdm-user-reviews/rateit/jquery.rateit.min.js'), array('jquery'));
        //wp_enqueue_style("wpdm-rating", plugins_url('wpdm-user-reviews/rateit/rateit.css'));
    }

    function package_review_summary( $pid ){
        $avgrating = $this->wpdm_get_average_reviews($pid);
        $avgrating_html = "<div class='rateit' data-rateit-value='{$avgrating}' data-rateit-ispreset='true' data-rateit-readonly='true'></div>";

        ob_start();
        include( wpdm_tpl_path('review-summary.php', dirname(__FILE__).'/tpls/') );
        $review_summary_html = ob_get_clean();

        return $review_summary_html;
    }

    function wpdm_reviews($pid)
    {
        global $current_user;

        $email = is_user_logged_in() ? $current_user->user_email : '';
        $name = is_user_logged_in() ? $current_user->display_name : '';
        $review_summary = $this->package_review_summary( $pid );
        $reviews = $this->wpdm_show_reviews($pid, 0);

        ob_start();
        include( wpdm_tpl_path('review-form.php', dirname(__FILE__).'/tpls/') );
        $review_form = ob_get_clean();

        if( ! $this->user_has_review_cap( $pid ) )
            $review_form = apply_filters( 'wpdm_user_review_restrcition_message', "<div class='alert alert-info'>You are not allowed to post review.</div>" );

        return $review_summary.$reviews.$review_form;
    }

    function user_has_review_cap( $pid ){
	    $current_user = wp_get_current_user();

        // Login required to post review
        if( ! is_user_logged_in() && apply_filters('wpdm_review_login_required', true ) )
            return false;

        // Package access required to post review
        if( ! wpdm_user_has_access( $pid ) && apply_filters('wpdm_review_package_access_required', true ) )
            return false;

        // Package Purchase required to post review
        if( ! $this->user_has_purchased_package( $pid ) && apply_filters('wpdm_review_purchase_required', true ) )
            return false;

        // Package download required to post review
        if( ! $this->user_has_downloaded_package( $pid ) && apply_filters('wpdm_review_download_required', true ) )
            return false;

        return true;
    }

    function user_has_purchased_package($pid){

        if ( ! class_exists('\WPDMPP\Libs\Order') ) return true;
        if ( (int) get_post_meta( $pid, '__wpdm_base_price', true) == 0 ) return true;
        global $wpdmpp;

        if($wpdmpp::hasPurchased($pid)) return true;

        return false;
    }

    function user_has_downloaded_package($pid){
        global $wpdb, $current_user;
        if( is_user_logged_in() ){
            $stats = $wpdb->get_results("select * from {$wpdb->prefix}ahm_download_stats where uid = '{$current_user->ID}' and pid = '{$pid}' LIMIT 1");
            if ( count( $stats ) > 0 ) return true;
        }
        return false;
    }

    function wpdm_add_review_tag($vars, $template, $type)
    {
        if (!isset($vars['ID'])) return $vars;

        $vars['wpdm_reviews'] = $this->wpdm_reviews($vars['ID']);
        $vars['avg_rating'] = $rating = $this->wpdm_get_average_reviews($vars['ID']);
        $vars['review_count'] = $this->wpdm_count_reviews($vars['ID']);
        ob_start();
        self::rating_stars($rating, true);
        $rating_stars = ob_get_clean();
        $vars['rating_stars'] = $rating_stars;
        $vars['rating_stars_fa'] = $this->wpdm_package_rating_avg($vars['ID'], false);
        return $vars;
    }

    function wpdm_package_rating_avg($pid, $echo = true)
    {
        $rating = $this->wpdm_get_average_reviews($pid);
        $lwr = floor($rating);

        $fs = '<i class="fa fa-star"></i>';
        $hs = '<i class="fa fa-star-half-o"></i>';
        $bs = '<i class="fa fa-star-o"></i>';
        $str = str_repeat($fs, $lwr);
        if ($lwr != $rating) {
            $str .= $hs;
            $lwr++;
        }
        $str .= str_repeat($bs, 5 - $lwr);
        if (!$echo) return $str;
        echo $str;

    }

    function wpdm_show_rating_dashicons($rating, $echo = true)
    {
        $fs = '<i class="dashicons-before dashicons-star-filled"></i>';
        $hs = '<i class="dashicons-before dashicons-star-half"></i>';
        $bs = '<i class="dashicons-before dashicons-star-empty"></i>';

        $str = '';
        for ($i = 1; $i <= 5; $i++) {
            if ($rating >= $i) $str .= $fs;
            elseif ($rating < $i && $rating > $i - 1) $str .= $hs;
            else $str .= $bs;
        }

        if (!$echo) return $str;
        echo $str;
    }

    function wpdm_save_user_review()
    {
        if (!isset($_POST['wpdmtask']) || $_POST['wpdmtask'] != 'save_review') return;
        global $wpdb, $current_user;

        if ( is_user_logged_in() ) {
            $_POST['wpdm_review']['uid'] = $current_user->ID;
            $_POST['wpdm_review']['status'] = 1;
        }

        $_POST['wpdm_review']['ip'] = $_SERVER['REMOTE_ADDR'];
        $_POST['wpdm_review']['date'] = time();

        /* H o n e y p o t */
        if ( isset( $_POST['name'] ) && $_POST['name'] != "" ) die('-1');

	    $found = new WP_Query(['post_type'     => 'wpdmreview','post_status'   => ['pending', 'publish'], 'meta_query' => [
		    'relation' => 'AND',
		   [
			    'key'   => 'pid',
			    'value' => $_POST['wpdm_review']['pid'],
		    ],
            [
			    'key'   => 'email',
			    'value' => $_POST['wpdm_review']['email'],
		    ]
	    ]]);

        if($found->found_posts > 0) {
            die('You already reviewed here once!');
        }

        $postid = wp_insert_post(array(
            'post_type'     => 'wpdmreview',
            'post_title'    => $_POST['wpdm_review']['title'],
            'post_content'  => $_POST['wpdm_review']['review'],
            'post_status'   => 'pending',
            'post_parent'   => $_POST['wpdm_review']['reply'],
            'post_author'   => -1,
        ));

        update_post_meta($postid, 'ip', $_SERVER['REMOTE_ADDR']);
        update_post_meta($postid, 'name', $_POST['wpdm_review']['name']);
        update_post_meta($postid, 'email', $_POST['wpdm_review']['email']);
        update_post_meta($postid, 'rating', $_POST['wpdm_review']['rating']);
        update_post_meta($postid, 'pid', $_POST['wpdm_review']['pid']);

        $headers = "From: " . stripslashes(get_option('blogname')) . " <" . get_option('admin_email') . ">\r\nContent-type: text/html\r\n";
        $to = get_option('admin_email');
        $message = "A new review has been posted by ".$_POST['wpdm_review']['name'].". Approve this review here ". get_edit_post_link($postid)."<br/><br/>";

        $message .= "Reviewer's Name: ".$_POST['wpdm_review']['name']."<br/>";
        $message .= "Reviewer's Email: ".$_POST['wpdm_review']['email']."<br/>";
        $message .= "Rating: ".$_POST['wpdm_review']['rating']."<br/>";
        $message .= "Review Content: ".$_POST['wpdm_review']['review']."<br/>";

        wp_mail($to, "Review Notification!", $message, $headers);

        die('ok');
    }

    function wpdm_review_metaboxes()
    {
        add_meta_box('wpdm_review_meta', __('Review Meta', 'wpdmpro'), array( $this, 'wpdm_review_meta' ), 'wpdmreview', 'side' );
    }

    function wpdm_review_meta($post)
    {
        $pack = get_post(get_post_meta($post->ID, 'pid', true));
        echo $this->wpdm_show_rating_dashicons($post->rating, false);
        echo "<br/><br/>";
        echo '<i class="dashicons-before dashicons-download"></i> <a href="'.get_permalink($pack->ID).'" target=_blank >'.$pack->post_title."</a>";
        echo "<br/><br/>";
        echo '<i class="dashicons-before dashicons-admin-users"></i> '.$post->name;
        echo "<br/><br/>";
        echo '<i class="dashicons-before dashicons-email"></i> '.$post->email;
    }

    function wpdm_package_review($content)
    {
        if (defined('WPDM_THEME_SUPPORT') && WPDM_THEME_SUPPORT == true) return $content;
        if (get_post_type() != 'wpdmpro') return $content;

        $content = $content . "<div class='w3eden'>" . $this->wpdm_reviews( get_the_ID() ) . "</div>";
        return $content;
    }

    function wpdm_package_review_shortcode($params)
    {
        $content = "<div class='w3eden'>" . $this->wpdm_reviews( $params['id'] ) . "</div>";
        return $content;
    }

    function wpdm_reviews_columnsTH($defaults) {
        unset($defaults['author']);
        $otf['package'] = 'Package';
        $otf['rating'] = "Rating";
        $otf['reviewer'] = "Reviewer";
        \WPDM\__\__::array_splice_assoc( $defaults, 2, 0, $otf );
        return $defaults;
    }

    function wpdm_reviews_columnsTD($column_name, $post_ID) {
        if ($column_name == 'rating') {
            $rating = get_post_meta($post_ID, 'rating', true);
            echo '<a href="edit.php?post_type=wpdmreview&review_stars='.$rating.'" >'.$this->wpdm_show_rating_dashicons($rating, false)."</a>";
        }
        if ($column_name == 'package') {
            $pack = get_post( get_post_meta($post_ID, 'pid', true));
            echo '<a href="edit.php?post_type=wpdmreview&review_for='.($pack->ID).'" >'.$pack->post_title."</a>";
        }

        if ($column_name == 'reviewer') {
            $pack = get_post( get_post_meta($post_ID, 'pid', true));
            $reviewer = get_post_meta($post_ID, 'name', true);
            echo '<a href="edit.php?post_type=wpdmreview&reviewer='.($reviewer).'" >'.$reviewer."</a>";
        }
    }

    function wpdm_filter_reviews($query){

        if ( isset( $_GET['review_for'] ) ) {
            $query->meta_query[] = array(
                'key' => 'pid',
                'value' => (int)$_GET['review_for']
            );
        }

        if ( isset( $_GET['review_stars'] ) ) {
            $query->meta_query[] = array(
                'key' => 'rating',
                'value' => esc_sql($_GET['review_stars'])
            );
        }
        if ( isset( $_GET['reviewer'] ) ) {
            $query->meta_query[] = array(
                'key' => 'name',
                'value' => esc_sql($_GET['reviewer'])
            );
        }
        $query->query_vars['meta_query'] = $query->meta_query;

        return $query;
    }

    static function rating_stars($rate, $static = false){

        $fill = 20*(double)$rate;
        ?>

        <div class="star__ratings__<?php if($static) echo " __static"; ?>">
            <div class="star__ratings__full" style="width: <?php echo $fill; ?>% !important;">
                <i class='fas fa-star text-primary'></i><i class='fas fa-star text-primary'></i><i class='fas fa-star text-primary'></i><i class='fas fa-star text-primary'></i><i class='fas fa-star text-primary'></i>
            </div>
            <div class="star__ratings__blank">
                <i class='far fa-star text-primary' data-value="1"></i><i data-value="2" class='far fa-star text-primary'></i><i data-value="3" class='far fa-star text-primary'></i><i data-value="4" class='far fa-star text-primary'></i><i data-value="5" class='far fa-star text-primary'></i>
            </div>
        </div>

        <?php

    }

    function rating_css(){
        ?>
        <style>
            .wpdm-reviews-input{
                opacity: 0;
                position: absolute;
                top: 0;
                left: 0;
                height: 0;
                width: 0;
                z-index: -1;
            }
            #wpdm-submit-review-button{
                margin-top: 20px;
            }

            .star__ratings__{
                position: relative;
                height: 32px;
                width: 152px;
                display: inline-block;
                cursor: pointer;
                font-size: 20pt;
            }
            .star__ratings__ i{
                vertical-align: top;
            }
            .panel-footer .star__ratings__{
                height: 16px;
                width: 130px;
                font-size: 12pt;
            }
            .star__ratings__ .star__ratings__blank,
            .star__ratings__ .star__ratings__full{
                position: absolute;
                height: 32px;
                white-space: nowrap;
                top: 0;
                left: 0;
                overflow: hidden;
            }
            ul#attire-mbl-menu{
                padding-left: 25px !important;
            }
            .softlay-mbl-logo {
                width: 150px;
                height: 58px;
                display: inline-block !important;
            }
            .softlay-mbl-logo img {
                max-height: 58px !important;
                padding: 15px 20px !important;
            }
            .star__ratings__ .star__ratings__full{
                width: 70%;
                overflow: hidden;
            }
        </style>
        <script>
            jQuery(function ($) {
                $('.star__ratings__.__static').each(function (item) {
                    $(this).css('width', $(this).find('.star__ratings__blank').width())
                });
            });
        </script>
        <?php
    }

	function updatePlugin($update, $plugin_data, $plugin_file, $locales){
		$id = basename(__DIR__);
		$latest_versions = WPDM()->updater->getLatestVersions();
		$latest_version = wpdm_valueof($latest_versions, $id);
		$access_token = wpdm_access_token();
		$update = [];
		$update['id']           = $id;
		$update['slug']         = $id;
		$update['url']          = $plugin_data['PluginURI'];
		$update['tested']       = true;
		$update['version']      = $latest_version;
		$update['package']      = $access_token !== '' ? "https://www.wpdownloadmanager.com/?wpdmpp_file={$id}.zip&access_token={$access_token}" : '';
		return $update;
	}
}

if( defined('WPDM_VERSION') ) {
    $wpdm_user_reviews = new WPDM_User_Reviews();
}

