<?php
if(!defined('WPINC')) {
    exit;
}

class WpdmWebHookAdmin {
    private static $instance;
    private $messages, $errors, $dir, $url, $old, $hooks;
    
    public static function getInstance(){
        if(self::$instance === null){
            self::$instance = new self;
            self::$instance->dir = dirname(__FILE__);
            self::$instance->url = WP_PLUGIN_URL . '/' . basename(self::$instance->dir);
            self::$instance->messages = array();
            self::$instance->errors = array();
            global $wpdb;
            self::$instance->table = $wpdb->prefix . "ahm_wpdm_webhook";
            self::$instance->old = admin_url('edit.php?post_type=wpdmpro&page=wpdm-web-hook');
            if(!class_exists('WpdmWebHookList')) {
                require_once self::$instance->dir . '/hook-list.php';
            }
            self::$instance->hooks = WpdmWebHook::getHooks();
            self::$instance->actions();
        }
        return self::$instance;
    }
    
    
    
    private function actions(){
        if(isset($_REQUEST['page']) && $_REQUEST['page']=='wpdm-web-hook'):
            global $wpdb;
        
            ob_start();
            if(isset($_REQUEST['add_new'])){
                $this->addNew();
            }
            elseif(isset($_REQUEST['edit'])){
                $this->edit();
            }
            elseif(isset ($_REQUEST['delete'])){
                $this->delete();
            }
            else {
                $this->listTable();
            }
            
            
            $content = ob_get_clean();
            //$wpdb->show_errors();
            //$wpdb->print_error();
            
            echo $this->getHeader();
            echo $content;
            echo $this->getFooter();
            
        endif;
    }
    
    
    
    private function addNew(){
        global $wpdb;
        
        if(!empty($_POST) && check_admin_referer('add_new_webhook')){
            $hook = isset($_POST['hook']) ? stripslashes(trim($_POST['hook'])) : "";
            $url = isset($_POST['url']) ? stripslashes($_POST['url']) : "";
            $status = isset($_POST['status']) ? (int)$_POST['status'] : "1";
            
            
            $data = array(
                'hook' => $hook,
                'url' => $url,
                'status' => $status
            );
            
            if($hook === ''){
                $this->errors['hook'] = "Please select a hook...";
            }
            
            if($url === '') {
                $this->errors['url'] = "Please enter a URL...";
            }
            else {
                if(filter_var($data['url'], FILTER_VALIDATE_URL) === FALSE){
                    $this->errors['url'] = "Please enter a valid URL...";
                }
                    
            }
            
            //check for already exist email for given subscripion
            
            
            if(empty($this->errors) && empty($this->messages)){
                $data['added'] = time();
                $format = array('%s','%s','%d','%d');
                
                
                if($wpdb->insert($this->table,$data,$format)){
                    do_action('wpdm_webhook_changed');
                    $this->messages[] = "Web Hook Added Successfully...";
                    $this->listTable();
                }
                else {
                    $this->messages[] = "Something Went Wrong. Please check you input";
                    
                    $this->formTable($data);
                }
            }
            else {
                $this->formTable($data);
            }
            
        }
        else {
            $this->formTable();
        }
        
    }
    
    private function edit(){
        global $wpdb;
        if(!empty($_POST) && check_admin_referer('edit_webhook_' . absint($_GET['edit']))){
            $hook = isset($_POST['hook']) ? stripslashes(trim($_POST['hook'])) : "";
            $url = isset($_POST['url']) ? stripslashes($_POST['url']) : "";
            $status = isset($_POST['status']) ? (int)$_POST['status'] : "1";
            
            
            $data = array(
                'hook' => $hook,
                'url' => $url,
                'status' => $status
            );
            
            if($hook === ''){
                $this->errors['hook'] = "Please select a hook...";
            }
            
            if($url === '') {
                $this->errors['url'] = "Please enter a URL...";
            }
            else {
                if(filter_var($data['url'], FILTER_VALIDATE_URL) === FALSE){
                    $this->errors['url'] = "Please enter a valid URL...";
                }
                    
            }
            
            if(empty($this->errors) && empty($this->messages)){
                
                $format = array('%s','%s','%d');
                $where = array('id' => absint($_REQUEST['edit']));
                $format_where = array('%d');
                
                $wpdb->update($this->table,$data,$where,$format,$format_where);
                $this->messages[] = 'Web Hook Updated Successfully...';
                do_action('wpdm_webhook_changed');
                //$wpdb->show_errors();
                //$wpdb->print_error();
                $this->listTable();
            }
        }
        else {
            
            $data = $wpdb->get_row(
                        $wpdb->prepare('SELECT * FROM ' . $this->table .' WHERE id=%d', array(absint($_REQUEST['edit'])))
                        ,ARRAY_A
                    );
            
            $this->formTable($data);
        }
    }
    
    
    private function delete(){
        global $wpdb;
        $id = isset($_GET['delete']) ? absint($_GET['delete']) : '';
        if(!empty($_POST) && check_admin_referer('delete_webhook_' . $id)){
            $wpdb->query($wpdb->prepare("DELETE FROM {$this->table} WHERE id=%d",array($_REQUEST['delete'])));
            $this->messages[] = "Web Hook Deleted";
            do_action('wpdm_webhook_changed');
            $this->listTable();
        }
        else{
        
    ?>
            <form method="post">
            <?php   wp_nonce_field('delete_webhook_' . $id); ?>

                <h3>Are you sure, you want to delete ?</h3>
                <p class="submit">
                    <input type="submit" name="submit" id="submit" class="button button-primary" value="Delete">
                    <input type="button" value="Back" class="button button-secondary" onclick="window.location='<?php echo add_query_arg(array('post_type' => $_REQUEST['post_type'], 'page' => $_REQUEST['page']),'edit.php?' );  ?>'">
                </p>
            </form>
    <?php
         }
    }
    
    private function formTable($data = array()){
        if(empty($data)){
            $data = array(
                    'hook' => '',
                    'url' => '',
                    'status' => '1'
                );
        }
    ?>
        <form method="post">
            <?php
                if(isset($_REQUEST['add_new'])){
                    echo '<h3>Add New WebHook</h3>';
                    wp_nonce_field('add_new_webhook');
                }
                elseif (isset ($_REQUEST['edit'])) {
                    $id = absint($_GET['edit']);
                    echo '<h3>Edit WebHook</h3>';
                    wp_nonce_field('edit_webhook_' . $id);
                }
            ?>
        <table class="form-table">
            <tr class="form-field">
                <th scope="row" valign="top">
                    <label for="hook"><?php _e('Select Hoook',''); ?> :</label>
                </th>
                <td>
                    <select class="form" name="hook">
                        <?php
                            if(!empty($this->hooks)):
                                foreach ($this->hooks as $hook => $details):
                                    $selected = "";
                                    if($hook === $data['hook']) $selected = "selected='selected'";
                                    echo "<option value='$hook' $selected>$hook</option>";
                                endforeach;
                            endif;
                        ?>
                    </select>
                    <p class="description"><?php if(isset($this->errors['hook'])) echo $this->errors['hook']; ?></p>
                </td>
            </tr>
            
            <tr class="form-field">
                <th scope="row" valign="top">
                    <label for="url"><?php _e('URL',''); ?> :</label>
                </th>
                <td>
                    <input type="text" name="url" value="<?php echo $data['url'];?>" id="url" class="form">
                    <p class="description"><?php if(isset($this->errors['url'])) echo $this->errors['url']; ?></p>
                </td>
            </tr>
            
           <tr class="form-field">
                <th scope="row" valign="top">
                    <label for="status"><?php _e('Status','eden_campaign'); ?> :</label>
                </th>
                <td>
                    <select name="status" class="form">
                        <option value="1" <?php selected($data['status'], '1'); ?>><?php _e('Active',''); ?></option>
                        <option value="0" <?php selected($data['status'], '0'); ?>><?php _e('Inactive',''); ?></option>
                    </select>
                    <p class="description"><?php if(isset($this->errors['status'])) echo $this->errors['status']; ?></p>
                </td>
            </tr>
            
        </table> 
            
        <p class="submit">
            <input type="submit" name="submit" id="submit" class="button button-primary" value="<?php if(isset($_REQUEST['add_new'])) {echo "Add"; } else {echo "Update" ;} ?>">
            <input type="button" value="Back" class="button button-secondary" onclick="window.location='<?php echo add_query_arg(array('post_type' => $_REQUEST['post_type'], 'page' => $_REQUEST['page']),'edit.php?' );  ?>'">
        </p>
        
    </form>

    <?php
    }
    
    private function listTable(){
        
        $table  = new WpdmWebHookList();
        $table->prepare_items();
    ?>
        <form id="movies-filter" method="get">
            <p class="search-box">
                <label class="screen-reader-text" for="post-search-input">Search Hooks:</label>
                <input type="search" id="post-search-input" name="s" value="<?php if(isset($_REQUEST['s']) && $_REQUEST['s'] != "" )  echo stripslashes($_REQUEST['s']); ?>">
                <input type="submit" name="" id="search-submit" class="button" value="Search Hooks">
            </p>
            <!-- For plugins, we also need to ensure that the form posts back to our current page -->
            <input type="hidden" name="post_type" value="<?php echo $_REQUEST['post_type'] ?>">
            <input type="hidden" name="page" value="<?php echo $_REQUEST['page'] ?>" />
            <!-- Now we can render the completed list table -->
            <?php $table->display() ?>
        </form>
    <?php
    
    }
    
    
    
    private function getHeader(){
        $message = "";
        if(!empty($this->messages)):
            $message = '<div id="" class="updated"><p>';
            foreach($this->messages as $key => $msg):
                $message .= $msg . "<br/>";
            endforeach;
            $message .= "</p></div>";
        endif;
        
        if(!empty($this->errors)):
            $message = '<div id="" class="updated error"><p>';
            foreach($this->errors as $key => $msg):
                $message .= $msg . "<br/>";
            endforeach;
            $message .= "</p></div>";
        endif;
    ?>
        <div class="wrap">
            <h2>WPDM - WebHook 
                <a href="<?php echo "?post_type={$_REQUEST['post_type']}&page={$_REQUEST['page']}&add_new=1" ?>" class="add-new-h2 <?php if(isset($_REQUEST['add_new']) && $_REQUEST['add_new']=='1') { echo 'active';} ?>">Add New</a>
            </h2>
            <?php echo $message; ?>
            <br>
    <?php
    }
    
    private function getFooter(){
        
        
    ?>
        </div>
    <?php
    
    }
 
    
}

