<?php
if(!defined('WPINC')) {
    exit;
}

class WpdmWebHookList extends \WP_List_Table {
    private $table;
    function __construct(){
        global $status, $page,$wpdb;
        //Set parent defaults
        $this->table = $wpdb->prefix . "ahm_wpdm_webhook";
        
        parent::__construct( array(
            'singular'  => 'Web Hook',     //singular name of the listed records
            'plural'    => 'Web Hooks',    //plural name of the listed records
            'ajax'      => false        //does this table support ajax?
        ) );
        
        
    }
    
    function get_columns(){
        $columns = array(
            'cb'        => '<input type="checkbox" />', //Render a checkbox instead of text
            'hook'      => 'Web Hook',
            'url'     => 'URL',
            'status'     => 'Status',
            'updated'   => 'Updated'
        );
        return $columns;
    }
    
    function get_sortable_columns() {
        $sortable_columns = array(
            'hook'     => array('hook',false),     //true means it's already sorted
        );
        return $sortable_columns;
    }
    
    function column_cb($item){
        return sprintf(
            '<input type="checkbox" name="%1$s[]" value="%2$s" />',
            /*$1%s*/ $this->_args['singular'],  //Let's simply repurpose the table's singular label ("movie")
            /*$2%s*/ $item->id               //The value of the checkbox should be the record's id
        );
    }
    
    function column_default($item, $column_name){
        global $wpdb;
        switch($column_name){
            case 'hook':
                $actions = array(
                    'edit'      => sprintf('<a href="?post_type=%s&page=%s&edit=%s">Edit</a>',$_REQUEST['post_type'],$_REQUEST['page'],$item->id),
                    'delete'    => sprintf('<a href="?post_type=%s&page=%s&delete=%s">Delete</a>',$_REQUEST['post_type'],$_REQUEST['page'],$item->id),
                    //'usages'    => sprintf('<a href="?post_type=%s&page=%s&usages=%s">Usages</a>',$_REQUEST['post_type'],$_REQUEST['page'],$item->id),
                );
                
                return sprintf('%1$s %2$s',
                    /*$1%s*/ $item->$column_name,
                    /*$3%s*/ $this->row_actions($actions)
                );

            case 'url':
            case 'updated':
                return sprintf("%s",$item->$column_name);
                
            case 'status':
                $str = '';
                if($item->$column_name == '1') {
                    $str = 'Active';
                }
                elseif($item->$column_name == '0') {
                    $str = 'Inactive';
                }
                
                return sprintf("%s",$str);
                
            default:
                //return print_r($item,true); //Show the whole array for troubleshooting purposes
        }
    }
    
    function get_bulk_actions() {
        $actions = array(
            'delete'    => 'Delete'
        );
        return $actions;
    }
    
    function process_bulk_action() {
        
        //Detect when a bulk action is being triggered...
        if( 'delete' === $this->current_action() ) {
            //print_r($_GET['subscriber']);
            wp_die('Items deleted (or they would be if we had items to delete)!');
        }
    }
    
    function extra_tablenav( $which ) {
	if ( $which == "top" ){
            
            ?>
            <select name="hook_status">
                <option value="-1"><?php _e('Show All Status',''); ?></option>
                <option value="1" <?php selected($_GET['hook_status'], '1'); ?>><?php _e('Active Hooks',''); ?></option>
                <option value="0" <?php selected($_GET['hook_status'], '0'); ?>><?php _e('Inactive Hooks',''); ?></option>
            </select>
            
            <input type="submit" name="" class="button" value="Filter" />
            <?php
	}
	if ( $which == "bottom" ){
		//The code that goes after the table is there
		//echo"Hi, I'm after the table";
	}
    }
    
    

    function prepare_items() {
        global $wpdb, $_wp_column_headers;
	$screen = get_current_screen();
        $this->process_bulk_action();
        
        $status = isset($_REQUEST['hook_status']) ? mysql_real_escape_string($_GET['hook_status']) : -1;
        $s = isset($_REQUEST['s']) ? mysql_real_escape_string($_GET['s']) : "";
        
        $query = "SELECT * FROM `{$this->table}`";
        
        
	/* search and filter parameters */
        
        if(($s != '') || ($status >= 0)) {
            $query .= " WHERE";
        }
        
        if($s != ""){
            $query .= " hook LIKE '%".  $s ."%' ";
        }
        
        if($status >= 0){
            if($s != '') {
                $query .= " AND";
            }
            $query .= " status='$status'";
        }
        
        /* -- Ordering parameters -- */
        $orderby = !empty($_GET["orderby"]) ? mysql_real_escape_string($_GET["orderby"]) : 'ASC';
        $order = !empty($_GET["order"]) ? mysql_real_escape_string($_GET["order"]) : '';
        if(!empty($orderby) & !empty($order)){ $query.=' ORDER BY '.$orderby.' '.$order; }
        
        //echo $query;
        
        
        
        /* -- Pagination parameters -- */
        $totalitems = $wpdb->query($query); //return the total number of affected rows
        $perpage = 10;
        $paged = !empty($_GET["paged"]) ? mysql_real_escape_string($_GET["paged"]) : '';
        if(empty($paged) || !is_numeric($paged) || $paged<=0 ){ $paged=1; }
        $totalpages = ceil($totalitems/$perpage);
        if(!empty($paged) && !empty($perpage)){
                $offset=($paged-1)*$perpage;
            $query.=' LIMIT '.(int)$offset.','.(int)$perpage;
        }
        
        /* -- Register the Columns -- */
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = array($columns, $hidden, $sortable);
        
	/* -- Register the pagination -- */
        $this->set_pagination_args( array(
                "total_items" => $totalitems,
                "total_pages" => $totalpages,
                "per_page" => $perpage,
        ) );
        //echo $query;
	/* -- Fetch the items -- */
        $this->items = $wpdb->get_results($query);
       
    }
    
    
}

