<?php
/*
Plugin Name:  WPDM - Data API
Plugin URI: http://wpdownloadmanager.com/
Description: Access Download Manager Remotely
Author: Shaon
Version: 2.0.0
Author URI: http://wpdownloadmanager.com/
*/
if (!defined('WPINC')) {
    exit();
}
if (!class_exists('WpdmApiTasks')) {
    require_once dirname(__FILE__) . '/api_task.php';
}

class WpdmAPI extends WpdmApiTasks
{
    private static $instance;
    private $dir, $url;

    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
            self::$instance->actions();
            self::$instance->dir = dirname(__FILE__);
            self::$instance->url = WP_PLUGIN_URL . '/' . basename(self::$instance->dir);
        }
        return self::$instance;
    }

    function save_settings()
    {
        if (isset($_POST['_wpdm_save_apis'])) {
            if (!isset($_POST['_wpdm_pn_ondownload']))
                delete_option('_wpdm_pn_ondownload');
            if (!isset($_POST['_wpdm_pn_onsale']))
                delete_option('_wpdm_pn_onsale');
        }
    }

    private function actions()
    {
        register_activation_hook(__FILE__, array($this, 'activate'));
        register_deactivation_hook(__FILE__, array($this, 'deactivate'));

        if (is_admin()) {
            add_action('basic_settings_section', array($this, 'adminSettings'));
            add_action('init', array($this, 'save_settings'));
        }

        if (!is_admin()) {
            add_action("init", array($this, "save_reg_id"));
            if (get_option('_wpdm_pn_onsale', 0) == 1)
                add_action("wpdmpp_complete_order", array($this, "send_push_on_complete_order"));
            if (get_option('_wpdm_pn_ondownload', 0) == 1)
                add_action("wpdm_onstart_download", array($this, "send_push_on_download"));
        }
        if (!is_admin() && isset($_REQUEST['wpdm_api'])) {
            add_action('init', array($this, 'handleApiRequest'));
        }
        if (defined('DOING_AJAX')) {
            add_action('wp_ajax_wpdm_change_api_key', array($this, 'generateToken'));
        }
    }

    public function handleApiRequest()
    {
        $result = array('message' => 'Api Called...');

        if (isset($_REQUEST['wpdm_api']) && isset($_REQUEST['task'])) {

            $key = stripslashes($_REQUEST['wpdm_api']);
            $option = get_option('_wpdm_api_key');
            if ($key === $option) {

                $task = stripslashes($_REQUEST['task']);
                if (method_exists($this, $task)) {
                    $result = $this->$task();
                } else {
                    $result['message'] = "Invalid API Task...";
                }
            } else {
                $result['message'] = "Invalid Api Key";
            }
        } else {
            $result['message'] = "Invalid API Request";
        }
        header('Content-type: application/json');
        header('Accept: application/json');
        //echo "<pre>";
        echo json_encode($result);
        //print_r($result);
        //echo "</pre>";
        die();

    }

    public function activate()
    {

    }

    public function deactivate()
    {

    }

    public function adminSettings()
    {
        $api_key = get_option('_wpdm_api_key');
        ?>

        <div class="panel panel-default">
            <div class="panel-heading">
                <b>API Settings</b>
            </div>
            <div class="panel-body">
                <input type="hidden" name="_wpdm_save_apis" value="1">
                <table class="table">
                    <tr>
                        <td>
                            <label for="wpdm_api_key"><?php _e('API Key', 'downloadmanager'); ?></label>

                            <div class="input-group">
                                <input class="form-control" type="text" name="_wpdm_api_key" id="wpdm_api_key"
                                       value="<?php echo $api_key; ?>"/>
                    <span class="input-group-btn">
                    &nbsp;<button style="margin-left: 10px" type="button" id="generate_wpdm_api_key"
                                  class="btn btn-default">Regenerate
                        </button>
                        </span>
                            </div>
                        </td>
                    </tr>
                    <tr>
                        <td>
                            <label><input type="checkbox" name="_wpdm_pn_ondownload"
                                          value="1" <?php checked(get_option('_wpdm_pn_ondownload', 0), 1) ?>> Send Push
                                Notification when someone downloads</label>
                        </td>
                    </tr>
                    <tr>
                        <td>
                            <label><input type="checkbox" name="_wpdm_pn_onsale"
                                          value="1" <?php checked(get_option('_wpdm_pn_onsale', 0), 1) ?> > Send Push
                                Notification when someone purchase from your store</label>
                        </td>
                    </tr>
                </table>

            </div>
        </div>
        <script type="text/javascript">
            jQuery(function ($) {
                $('#generate_wpdm_api_key').click(function () {
                    var nonce = '<?php echo wp_create_nonce( "ajax_nonce" ); ?>';
                    jQuery.ajax({
                        type: "post",
                        dataType: "json",
                        url: "<?php echo admin_url( 'admin-ajax.php' ); ?>",
                        data: {action: "wpdm_change_api_key", nonce: nonce},
                        success: function (response) {
                            //console.log(response);
                            if (response.type === "success") {
                                if (response.key) {
                                    $('#wpdm_api_key').val(response.key);
                                }
                            }
                        }
                    });


                    return false;
                });
            });
        </script>
    <?php

    }


    public function save_reg_id()
    {
        if (isset($_REQUEST['SaveRegID'], $_REQUEST['key']) && $_REQUEST['SaveRegID'] != '') {
            $key = $_REQUEST['key'];
            $api_key = get_option('_wpdm_api_key');
            @wp_mail('shaon.cse99.cuet@gmail.com', 'GCM Push Reg Key', print_r($_REQUEST, 1), "From: noreply@wpdownloadmanager.com\r\n");
            if ($api_key == $key) {
                update_option('gcm_device_id', $_REQUEST['SaveRegID']);
                die('OK');
            }
            die('Invalid API Key');
        }
    }

    public function send_push_on_download($package)
    {

        $uinfo = "";
        if(is_user_logged_in()){
            global $current_user;
            $uinfo = "Username: {$current_user->user_login}\r\nEmail: {$current_user->user_email}";
        }
        $msg = array(
            'title' => "New Download: {$package['post_title']}",
            'message' => "Package Name: {$package['post_title']}\r\nIP: {$_SERVER['REMOTE_ADDR']}\r\n{$uinfo}",
            'subtitle' => 'New Download',
            'tickerText' => "New Download: {$package['post_title']}",
            'vibrate' => 1,
            'sound' => 1,
            'largeIcon' => 'large_icon',
            'smallIcon' => 'small_icon'
        );
        self::send_push_notification_gcm($msg);
    }


    public function send_push_on_complete_order($id)
    {
        $order = new Order();
        $orderdata = $order->GetOrder($id);
        $amount = $orderdata->total;
        $amount = number_format($amount,2);
        $cs = wpdmpp_currency_sign();
        $msg = array(
            'title' => "New Sale: $id ( {$cs}{$amount} )",
            'message' => "New Sale: $id" . "\r\n" . 'Total Amount: '. $cs . $amount,2 . "\r\n",
            'subtitle' => 'New Sale',
            'tickerText' => "New Sale: $id ( ${$amount} )",
            'vibrate' => 1,
            'sound' => 1,
            'largeIcon' => 'large_icon',
            'smallIcon' => 'small_icon'
        );
        self::send_push_notification_gcm($msg);
    }

    static function send_push_notification_gcm($message)
    {
        // Set POST variables
        $url = 'https://android.googleapis.com/gcm/send';

        $fields = array(
            'registration_ids' => array(get_option('gcm_device_id', '')),
            'data' => $message,
        );

        $headers = array(
            'Authorization: key= AIzaSyDbkOYgWwSBhCXLFQ4F_ysvJKFI4ZD-XNE',
            'Content-Type: application/json'
        );
        //print_r($headers);
        // Open connection
        $ch = curl_init();

        // Set the url, number of POST vars, POST data
        curl_setopt($ch, CURLOPT_URL, $url);

        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

        // Disabling SSL Certificate support temporarly
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($fields));

        // Execute post
        $result = curl_exec($ch);
        if ($result === FALSE) {
            //@wp_mail('shaon.cse99.cuet@gmail.com', 'Push Error', curl_error($ch), "From: noreply@wpdownloadmanager.com\r\n");
            return curl_error($ch);
        }

        // Close connection
        curl_close($ch);
        //@wp_mail('shaon.cse99.cuet@gmail.com', 'Push Ret', $result . print_r($fields, 1), "From: noreply@wpdownloadmanager.com\r\n");
        return $result;
    }

    public function generateToken()
    {
        $result['type'] = '';
        if (check_ajax_referer('ajax_nonce', 'nonce', false)) {
            $better_token = "";
            $uid = uniqid("", true);
            $data = "";
            $data .= $_SERVER['REQUEST_TIME'];
            $data .= $_SERVER['HTTP_USER_AGENT'];
            $data .= $_SERVER['LOCAL_ADDR'];
            $data .= $_SERVER['LOCAL_PORT'];
            $data .= $_SERVER['REMOTE_ADDR'];
            $data .= $_SERVER['REMOTE_PORT'];
            $toHash = $uid . md5($data); //unique id

            // Avoid Collision Attacks with different algorithms
            $tempHash = '';
            $algorithms = array('sha512', 'ripemd320', 'whirlpool');
            foreach ($algorithms as $algo) {
                $tempHash .= hash($algo, $toHash);
            }
            //reset hash length
            $toHash = hash('whirlpool', $tempHash);
            $better_token = substr($toHash, 0, 16);

            $result['type'] = "success";
            $result['key'] = "$better_token";
        } else {
            $result['type'] = "Nonce Error";
        }


        //echo result 
        if (!empty($_SERVER['HTTP_X_REQUESTED_WITH']) && strtolower($_SERVER['HTTP_X_REQUESTED_WITH']) == 'xmlhttprequest') {
            $result = json_encode($result);
            echo $result;
        } else {
            header("Location: " . $_SERVER["HTTP_REFERER"]);
        }

        die();

    }
}


WpdmAPI::getInstance();