<?php

namespace WPDM\WPPM\Auth;


use WPDM\__\__MailUI;
use WPDM\__\Messages;

if (!defined('ABSPATH')) exit;




class AuthManager
{
    /**
     * holds singleton instance of the class
     */
    private static $instance;

    /**
     * Get singleton instance of the class
     *
     */
    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
        }
        return self::$instance;
    }


    /**
     * Constructor
     *
     */
    private function __construct()
    {
        add_action('wp_ajax_nopriv_' .  WPPM_SIGNUP_ACTION, array($this, 'actionProcessSignup'));
        add_action('init', [$this, 'download']);
    }


    public function renderSignupFormFields()
    {
        $args = [];
        $file = wpdm_tpl_path("signup-form-fields.php",  get_stylesheet_directory() . '/wppromembership', __DIR__);
        \wppm_render_template($file, $args);
    }



    public function actionProcessSignup()
    {
        $signup_data = \wpdm_query_var(WPPM_SIGNUP_FORM_DATA_KEY);
        // wp_send_json($signup_data);

        //TODO sanitize data

        if (!empty($signup_data)) {
            //signup request
            $result =  $this->trySignup($signup_data);
            // wp_send_json($result);

            if (is_int($result)) {
                //successful signup; now login
                $user = $this->login($signup_data['user_login'], $signup_data['user_pass']);
                wp_send_json($user);
            } else {
                //errors
                wp_send_json(['errors' => $result], 400);
            };
        }
    }


    /**
     *
     * @return true|array[errors]
     */
    private function validateSignupData($data)
    {
        // first_name , last_name, user_email, user_login, user_pass
        extract($data);

        $errors = [];

        // validate email
        if (!is_email($user_email)) {
            $errors[] =  __("Invalid Email address.", "wppromembership");
        } elseif (email_exists($user_email)) {
            $errors[] =  __("Email already exists.", "wppromembership");
        }

        //validate username
        if (empty($user_login)) {
            $errors[] =  __("Invalid username.", "wppromembership");
        } elseif (username_exists($user_login)) {
            $errors[] =  __("Username already exists.", "wppromembership");
        }

        //validate password
        if (empty($user_pass)) {
            $errors[] =  __("Invalid password.", "wppromembership");
        }


        if (count($errors) > 0) {
            return $errors;
        }

        return true;
    }



    /**
     * first validate the data then try signup
     *
     * @return int(user_id)| array errors
     */
    private function trySignup($data)
    {
        extract($data);
        $errors = [];

        $validation = $this->validateSignupData($data);

        if ($validation === true) {
            // do signup
            return $this->signup($data);
        } else {
            // send validation errors
            $errors = $validation;
        }

        return $errors;
    }


    /**
     * use this function after successfull validation
     *
     * @return user_id|false
     */
    private function signup($data)
    {
        // user_email, user_login, user_pass, first_name , last_name,
        extract($data);

        //create new wp user
        $user_id = wp_create_user($user_login, $user_pass, $user_email);

        if ($user_id) {

            $first_name = isset($first_name) ? $first_name : '';
            $last_name = isset($last_name) ? $last_name : '';
            $display_name = ($first_name && $last_name) ? $first_name . " " . $last_name : $user_login;

            $user_data = array(
                'ID' => $user_id,
                'display_name' => $display_name,
                'first_name' => $first_name,
                'last_name' => $last_name
            );
            wp_update_user($user_data);

            $data = wp_parse_args($data, $user_data);

            //To User
            $usparams = array('to_email' => $user_email, 'name' => $display_name, 'first_name' => $first_name, 'last_name' => $last_name, 'user_email' => $user_email, 'username' => $user_login, 'password' => $user_pass);

            foreach ($_POST['wppm_signup_data'] as $key => $value) {
                $usparams["user_" . $key] = $value;
            }

            //Filter user email params
            $usparams = apply_filters("wpdm_signup_user_mail_params", $usparams, $user_id);

            \WPDM\__\Email::send("user-signup", $usparams);

            //To Admin
            $ip = wpdm_get_client_ip();
            $data = array(
                array('Name', $display_name),
                array('Username', $user_login),
                array('Email', $user_email),
                array('IP', $ip)
            );
            $css = array('col' => array('background: #edf0f2 !important'), 'td' => 'border-bottom:1px solid #e6e7e8');
            $table = __MailUI::table(null, $data, $css);

            $params['name'] = $display_name;
            $params['username'] = $user_login;
            $params['email'] = $user_email;
            $params['user_ip'] = $ip;
            $params['edit_user_btn'] = "<a class='button' style='display:block;margin:10px 0 0;text-decoration: none;text-align:center;' href='" . admin_url('user-edit.php?user_id=' . $user_id) . "'> " . __("Edit User", "download-manager") . " </a>";
            //Include all data from signup form
            foreach ($_POST['wppm_signup_data'] as $key => $value) {
                $params["user_" . $key] = $value;
            }

            //Filter admin email params
            $params = apply_filters("wpdm_signup_admin_mail_params", $params, $user_id);
            \WPDM\__\Email::send("user-signup-admin", $params);


            // signup complete hook
            do_action("wppm_after_signup", $data);

            return $user_id;
        }

        return false;
    }


    /**
     *
     * @return WP_User|WP_Error
     */
    public function login($user_login, $user_pass)
    {
        $creds = array();
        $creds['user_login'] = $user_login;
        $creds['user_password'] = $user_pass;
        $creds['remember'] = "forever";
        return wp_signon($creds, false);
    }

    /**
     * Handles file download
     */
    function download(){

        if(!isset($_GET['wppmdl'])) return;

        global $current_user, $wppmuser;

        $download = "";
        $file = $ID = (int)$_GET['wppmdl'];
        if(!WPDM()->package->userHasAccess(get_current_user_id(), wpdm_query_var('wppmdl'))) {
            $msg = get_option('wpdm_permission_msg');
            if($msg === '') $msg = __('Permission Denied!', 'wppromembership');
            Messages::error($msg, 1);
        }

        do_action("wppm_before_start_download", $ID);

        // Log the download
        WPDM()->downloadHistory->add($ID, '');

        $download_limit = WPPM()->user_manager->downloadLimit();
        $user_download_count = WPPM()->user_manager->downloadCount();
        if($user_download_count >= $download_limit && $download_limit > 0 && function_exists('wpdm_dd_update_user_download')) Messages::error("Download Limit Exceeded!", 1);


        $files = WPDM()->package->getFiles($ID);

        //do_action('before_wppm_download', $package);

        if (count($files) > 1)
            $download = WPDM()->package->zip($ID);
        else if (count($files) > 0)
            $download = array_shift($files);


        if(is_wp_error($download) || $download == '' )
            wpdm_download_data("no-files-there.txt", "No file is attached with this package yet!");

        if(!strpos($download, ':/')) {
            if (!file_exists($download)) $download = UPLOAD_DIR . $download;
            if (!file_exists($download)) wpdm_download_data("no-files-there.txt", "File not found!");
        }

        //if(function_exists('wpdm_dd_update_user_download'))
        //    wpdm_dd_update_user_download(array('ID' => $ID));

        //Download limit implementation
        global $wpdm_download_limit;
        if(is_object($wpdm_download_limit) && method_exists($wpdm_download_limit, 'updateUserDownload')){
            $wpdm_download_limit->updateUserDownload(array('ID' => $ID));
        }


        if(strstr($download,'s3.amazonaws.com/') && class_exists('WPDM_AmazonS3')){
            $wpdmawss3 = new \WPDM_AmazonS3();
            $wpdmawss3->downloadFile($download);
            die();
        } else if(strstr($download,'s3.amazonaws.com/') && !class_exists('WPDM_AmazonS3')){
            Messages::error('Please enable Amazon S3 Add-on', 1);
        }

        if(strpos($download, ':/'))
            header("Location: ".$download);
        else
            wpdm_download_file($download, basename($download));

        do_action('after_wppm_download', $package);

        die();
    }

}
