<?php
if (!defined('ABSPATH')) exit;

global $wppm, $current_user;
?>

<div class="w3eden" id="wppmcheckout">

    <!-- Checkout form -->
    <form name="checkout" enctype='multipart/form-data' action="" method="post" id="checkout-form" class="sbscr-form"
          role="form">
        <?php if (is_user_logged_in()) : ?>
            <!-- Loggedin user info -->
            <div class="panel card panel-success mb-3">
                <div class="panel-body card-body text-center lead" style="font-size:12pt">
                    <?php printf(__('You are logged in as <strong>%s ( %s )</strong>', 'wppromembership'), $current_user->display_name, $current_user->user_login); ?>
                </div>
                <div class="panel-footer card-footer text-center">
                    <a class="btn btn-xs btn-primary"
                       href="<?php echo wpdm_logout_url(get_the_permalink()) ?>"><?php _e('Login from a different account', 'wppromembership'); ?></a>
                </div>
            </div>

            <?php
            do_action('wppm_before_signup_fields');
        else : ?>
            <!-- signup form fields -->
            <div class="panel panel-default card">
                <div class="panel-heading card-header"><?php _e('Account Info', 'wppromembership'); ?></div>
                <div class="panel-body card-body">
                    <?php $wppm->auth_manager->renderSignupFormFields() ?>
                </div>
            </div>

            <!-- Already Have an account? -->
            <div class="panel panel-default card mt-3 mb-3">
                <div class="panel-body card-body" style="line-height: 30px;">

                    <div class="pull-right float-right">
                        <a class="btn btn-primary btn-sm" data-toggle="modal" data-target="#loginmodal"
                           href="#"><?php _e('Login', 'wppromembership'); ?></a>
                    </div>
                    <?php _e('Already have an account?', 'wppromembership'); ?>
                </div>
            </div>

        <?php endif ?>

        <!-- render plan selection list -->
        <div class="form-group">
            <div class="panel panel-default card panel-plans">
                <div class="panel-heading card-header"><?php echo __('Membership Plans', 'wppromembership'); ?></div>
                <?php $wppm->plan_manager->renderPlanSelection(); ?>
            </div>
        </div>

        <?php if (is_user_logged_in()) : ?>
            <!-- render payment system selection -->
            <div id="coupon">
                <?php WPPM()->coupon_manager->renderCouponField() ?>
            </div>

            <div id='wppm-pms-selection'>
                <?php $wppm->payment_system_manager->renderPaymentSystemSelection(); ?>
            </div>

            <!-- Payment system interface to pay -->
            <div id="payment-system-interface" class="panel panel-default">

            </div>
        <?php endif ?>

        <!-- Signup and Continue button -->
        <?php if (!is_user_logged_in()) : ?>
            <div class="form-group">
                <button type="submit" role="signup" name="wp-submit" id="wp-submit"
                        class="btn btn-primary btn-lg btn-block">
                    <?php _e('Signup & Continue', 'wppromembership'); ?>
                    <i class="icon icon-angle-right"></i>
                </button>
            </div>
        <?php endif ?>

        <div id="wppm-errors" class="alert alert-danger" style="display:none"></div>

    </form>

    <!-- hidden Popup login form. display when login btn clicked -->
    <?php if (!is_user_logged_in()) : ?>
        <div class="modal fade" id="loginmodal" tabindex="-1" role="dialog" aria-labelledby="loginmodalTitle"
             aria-hidden="true">
            <div class="modal-dialog modal-dialog-centered" role="document">
                <div class="modal-content"
                     style="background: transparent !important;box-shadow: none !important;border: 0 !important;padding: 0;margin: 0">
                    <div class="modal-body">
                        <?php echo do_shortcode("[wpdm_login_form]"); ?>
                    </div>
                </div>
            </div>
        </div>
    <?php endif; ?>
</div>


<script>
    jQuery(function ($) {
        var signupForm = $('#checkout-form'); // TODO signup form should have its own form
        var errorsDiv = $("#wppm-errors");

        //SIGNUP handler
        var signupBtn = $('button[role=signup]');
        var signupBtnOriginalLabel = signupBtn.html();

        signupBtn.click(function (e) {
            e.preventDefault();
            if (!validate_cofirm_pass()) return;

            var signupData = signupForm.serialize();
            var postUrl = "<?= add_query_arg('action', WPPM_SIGNUP_ACTION, admin_url('admin-ajax.php')); ?>";

            signupBtn.html("<i class='fa fa-cog fa-spin'></i> Please Wait...");

            $.post(postUrl, signupData, function (res) {
                console.log(res);
                signupBtn.html(signupBtnOriginalLabel);
                location.reload(true);
            }, 'json')
                .fail(function (res) {
                    var data = res.responseJSON;
                    console.log(data);
                    showErrors(data);
                    signupBtn.html(signupBtnOriginalLabel);
                });
        });

        function showErrors(data) {
            errorsDiv.html("").hide();
            if (data && 'errors' in data) {
                errorsDiv.show();
                $.each(data.errors, function (i, err) {
                    errorsDiv.append("<li>" + err + "</li>");
                })
            }
        }

        function validate_cofirm_pass() {
            if ($('#wppm_confirm_pass').val() !== $('#wppm_password').val()) {
                $('#wppm_confirm_pass').parent('.input-wrapper').addClass('input-error');
                WPDM.beep();
                WPDM.notify(
                    "<?= __(" Password did not match with the confirm password ", "wppromembership") ?>",
                    "error ",
                    "top - right ",
                    7000);
                return false;
            } else {
                $('#wppm_confirm_pass').parent('.input-wrapper').removeClass('input-error');
                return true;
            }
        }
    });
</script>

<script>
    var planRadios = jQuery("input[type=radio][role=plan-selection]");

    var pmsSelection = jQuery('#wppm-pms-selection');
    var pmsRadios = jQuery("input[type=radio][role=payment-system]");
    var pmsInterface = jQuery("#payment-system-interface");

    var couponSection = jQuery('#coupon');
    var couponApplyBtn = jQuery('#apply-coupon-btn');
    var couponCodeInput = jQuery('#coupon-code');
    var couponCodeInfo = jQuery('#coupon-info');


    function getSelectedPlanId() {
        let id = planRadios.filter(":checked").val();
        return id !== undefined ? id : null;
    }

    function getCouponCode() {
        return couponCodeInput.val() !== undefined ? couponCodeInput.val() : null;
    }

    function getSelectedPaymentSystemId() {
        let id = pmsRadios.filter(":checked").val();
        return id !== undefined ? id : null;
    }

    function renderPaymentSystemSelection() {

    }


    // Renders the payment system interface for the selected plan & payment system
    function renderPaymentSystemInterface() {
        pmsInterface.html("");

        var selectedPlanRadio = planRadios.filter(":checked");
        var planId = getSelectedPlanId();
        var paymentSystemId;

        if (selectedPlanRadio.hasClass("free")) {
            paymentSystemId = "free";
            pmsSelection.slideUp();
        } else {
            paymentSystemId = getSelectedPaymentSystemId();
            pmsSelection.slideDown();
        }


        if (!planId || !paymentSystemId) return;


        var data = {
            'payment_system_id': paymentSystemId,
            'plan_id': planId,
            'coupon_code': getCouponCode()
        };

        console.log(data);
        //  return;

        var postUrl = "<?= add_query_arg('action', WPPM_AJAX_ACTION_RENDER_PAYMENT_SYSTEM_INTERFACE, admin_url('admin-ajax.php')); ?>";
        WPDM.blockUI('#checkout-form');
        jQuery.post(postUrl, data, function (res) {
            // console.log(res);
            pmsInterface.html("");
            pmsInterface.slideDown();
            pmsInterface.append(res);
            WPDM.unblockUI('#checkout-form');
        })
            .fail(function (res) {
                var data = res.responseJSON;
                console.log(data);
                //showErrors(data);
            });
    }


    jQuery(function ($) {

        if (getSelectedPlanId()) {
            couponSection.show();
            pmsSelection.show();
        } else {
            couponSection.hide();
            pmsSelection.hide();
        }

        if (planRadios.filter(":checked").is(':disabled')) {
            pmsInterface.slideUp();
        }

        if (planRadios.filter(".free").is(':checked')) {
            pmsSelection.slideUp();
        }

        planRadios.click(function () {
            if ($(this).hasClass('free')) {
                pmsSelection.slideUp();
            } else {
                pmsSelection.slideDown();
            }

        });


        // refresh payment interface if payment system changed
        pmsRadios.change(function () {
            //console.log(this.value);
            if (this.value) {
                renderPaymentSystemInterface();
            }

        });

        //we need to refresh the payment interface if plan selection changed
        planRadios.change(function () {
            if (this.value) {
                renderPaymentSystemInterface();
            }
        })

        //if initially no payment system is selected then select the first payment sytem
        if (pmsRadios.filter(":checked").length == 0) {
            pmsRadios.filter(":first").trigger('click');
        }


        //renderPaymentSystemInterface();

    });
</script>

<script>
    jQuery(function ($) {

        couponCodeInput.focus(function () {
            couponApplyBtn.html("Apply");
        });

        couponApplyBtn.click(function () {

            let errorText = '';
            if (couponCodeInput.val() === '') {
                errorText += "<strong class='color-red'>Enter a coupon code.</strong>";
            } else if (!getSelectedPlanId()) {
                errorText += "<strong class='color-red'>Please Select A Plan befor applying coupon code.</strong>";
            }

            if (errorText !== '') {
                couponApplyBtn.html("<i class=\"fas fa-exclamation-triangle\"></i>");
                couponCodeInfo.html(errorText).slideDown();
                return false;
            }

            $(this).html("<i class='fas fa-sun fa-spin'></i>");

            var postUrl = "<?= add_query_arg('action', WPPM_AJAX_ACTION_VALIDATE_COUPON_CODE, admin_url('admin-ajax.php')); ?>";
            var data = {
                plan_id: getSelectedPlanId(),
                coupon_code: couponCodeInput.val()
            };
            // console.log(data);

            $.post(postUrl, data, function (res) {
                if (res.is_free) {
                    planRadios.filter(":checked").addClass("free");
                } else {
                    planRadios.filter(":checked").removeClass("free");
                }
                couponCodeInfo.html(res.message).slideDown();
                couponApplyBtn.html("<i class=\"fas fa-check-double\"></i>");

                renderPaymentSystemInterface();

            }, 'json').fail(function (res) {
                data = res.responseJSON;
                couponApplyBtn.html("<i class=\"fas fa-exclamation-triangle\"></i>");
                couponCodeInfo.html(data.message).slideDown();
                return false;
            });

        });

    });
</script>

<script>
    function redirectToWPPMAccountPage() {
        redirectUrl = "<?= WPPM()->account_manager->getAccountPagePermalink() ?>";
        redirectUrl ? location.href = redirectUrl : location.reload();
    }
</script>

<script>
    //add required to required fields
    jQuery('.wpmp_required').after('<span class="wpmp_asterisk"> *</span>');

    //unhighlight error fields when the user edits them
    jQuery('.wpmp_error').bind("change keyup input", function () {
        jQuery(this).removeClass('wpmp_error');
    });
</script>


<style>
    .text-info p {
        margin: 0;
    }

    .note,
    .note p,
    .note strong {
        color: #888888;
        font-size: 12px !important;
        font-weight: 400;
        line-height: 1.2;
    }

    .w3eden .plan-list h3 {
        font-size: 11pt;
        margin: 0 0 5px 0;
    }

    .plan-list label,
    .pm-list label {
        cursor: pointer;
    }

    .w3eden .plan-list input[type=radio],
    .w3eden .pm-list input[type=radio] {
        transform: scale(1.5);
    }

    .w3eden .plan-list.list-group .list-group-item.active,
    .w3eden .pm-list.list-group .list-group-item.active {
        background: rgba(0, 0, 0, 0.01) !important;
        color: #333333 !important;
    }

    #wppmcheckout {
        position: relative;
        max-width: 450px;
        margin: 0 auto;
        padding: 20px;
    }

    #wppmcheckout .panel {
        box-shadow: 0 0 5px rgba(0, 0, 0, 0.05) !important;
        border-radius: 5px;
        overflow: hidden;
    }

    .w3eden .pm-list .media .pull-left input[type=checkbox] {
        margin: 0;
        line-height: 30px;
    }

    .w3eden .pm-list .media .pull-left {
        line-height: 30px;
    }

    .w3eden .pm-list .media .media-body h3 {
        margin: 0 !important;
        padding: 0 !important;
        line-height: 30px;
        font-size: 12pt;
    }

    .w3eden .pm-list.list-group {
        border: 0 !important;
    }

    .w3eden .plan-list.list-group label.list-group-item,
    .w3eden .pm-list.list-group label.list-group-item,
    .w3eden .pm-list.list-group {
        border-radius: 0 !important;
        border-left: 0 !important;
        border-right: 0 !important;
    }

    .w3eden .plan-list.list-group label.list-group-item:first-child,
    .w3eden .pm-list.list-group label.list-group-item:first-child {
        border-top: 0 !important;
    }

    .w3eden .plan-list.list-group label.list-group-item:last-child,
    .w3eden .pm-list.list-group label.list-group-item:last-child {
        border-bottom: 0 !important;
    }

    .alert.alert-progress {
        margin-top: 20px;
        background: #08BDF9;
        color: #ffffff;
    }

    .alert.alert-progress i.fa {
        margin-right: 10px;
        margin-left: 5px;
    }
</style>
