<?php

namespace WPDM\WPPM\Core;

use WPDM\__\Session;

if (!defined('ABSPATH')) exit;


/**
 * This class handles all of the alerts. Tells the admin if something was added successfully or not.
 *
 */
class AlertManager
{

	/**
	 * holds singleton instance of the class
	 */
	private static $instance;

	/**
	 * holds alerts
	 */
	private $alerts = [];


	/**
	 * private constructor of the class
	 * so this class cannot be created outside
	 *
	 */
	private function __construct()
	{
		$this->addHooks();
	}


	/**
	 * add hooks
	 *
	 */
	private function addHooks()
	{
		//add_action('init', array($this, 'initSession'));
		add_action('admin_notices', array($this, 'renderAlerts'));
	}


	/**
	 * start php session if not already started
	 */
	public function initSession()
	{
		if (!session_id()) {
			session_start();
		}
	}


	/**
	 * get the singleton instance of the class
	 */
	public static function getInstance()
	{
		if (self::$instance === null) {
			self::$instance = new self;
		}

		return self::$instance;
	}


	/**
	 * This function passes the alert message into the arrray $alerts
	 *
	 * @param $message This is the variable that contains the message to given as an alert.
	 * @param $type This variable holds either success/error and displays the correct message accordingly.
	 */
	private function addAlert($message, $type)
	{
		array_push($this->alerts, [
			'message' => $message,
			'type' => $type
		]);

		$this->updateSessionData();
	}


	private function updateSessionData()
	{
		Session::set("wppm_alerts", $this->alerts);
	}


	/**
	 * add success alert
	 *
	 */
	public function addSuccessAlert($message)
	{
		return $this->addAlert($message, 'success');
	}


	/**
	 * add error alert
	 *
	 */
	public function addErrorAlert($message)
	{
		return $this->addAlert($message, 'error');
	}


	/**
	 *
	 * @return array
	 */
	private function getAlertsFromSession()
	{
		return Session::get('wppm_alerts');
	}


	/**
	 *
	 *
	 */
	private function removeAlertsSession()
	{
		Session::clear('wppm_alerts');
	}

	/**
	 * This function shows the alerts. It shows success or error messages.
	 *
	 */
	public function renderAlerts()
	{
		$alerts = $this->getAlertsFromSession();
		$this->removeAlertsSession();

		$alerts_html = "";
		if(is_array($alerts)) {
            foreach ($alerts as $alert) {
                if ($alert['type'] == "success") {
                    $alerts_html .= "<div id=\"message\" class=\"notice notice-success is-dismissible\"><p><strong>" . __('Success!', WPPM_TEXTDOMAIN) . " </strong>" . $alert['message'] . "</p></div>";
                }
                if ($alert['type'] == "error") {
                    $alerts_html .= "<div id=\"message\" class=\"notice notice-error\"><p><strong>" . __('Error!', WPPM_TEXTDOMAIN) . " </strong>" . $alert['message'] . "</p></div>";
                }
            }
        }
		echo apply_filters(WPPM_FILTER_ALERT_MESSAGES, $alerts_html);
	}
}
