<?php

namespace WPDM\WPPM\Core;

use DateTime;

trait DateTimeInterval
{

    protected $from_date;

    protected $to_date;

    /**
     * 
     * @return self
     */
    public function setFromDate(DateTime $date = null)
    {
        $this->from_date = $date;

        return $this;
    }


    /**
     * 
     * @return DateTime|null
     */
    public function getFromDate()
    {
        return $this->from_date;
    }


    /**
     * 
     * @return self
     */
    public function setToDate(DateTime $date = null)
    {
        $this->to_date = $date;

        return $this;
    }


    /**
     * 
     * @return DateTime|null
     */
    public function getToDate()
    {
        return $this->to_date;
    }


    /**
     * @param period TODAY|THIS_MONTH|THIS_YEAR|ANYTIME
     * 
     * @return self
     * 
     */
    public function setInterval($period = 'ANYTIME')
    {
        switch (strtoupper($period)) {
            case 'TODAY':
                $from_date = new DateTime('today');
                $this->setFromDate($from_date);

                $to_date = clone $from_date;
                $to_date->modify('+1 day');
                $t = $to_date->getTimestamp() - 1;
                $to_date->setTimestamp($t);
                $this->setToDate($to_date);
                break;

            case 'THIS_MONTH':
                $from_date = new DateTime('first day of this month');
                $this->setFromDate($from_date);

                $to_date = clone $from_date;
                $to_date->modify('last day of this month')->modify('+1 day');
                $t = $to_date->getTimestamp() - 1;
                $to_date->setTimestamp($t);
                $this->setToDate($to_date);
                break;

            case 'THIS_YEAR':
                $this->setFromDate(new DateTime('first day of january'));
                $this->setToDate(new DateTime('first day of december'));
                break;

            case 'ANYTIME':
                $this->setFromDate(null);
                $this->setToDate(null);
                break;
        }

        return $this;
    }


    /**
     * @param month 01,02,03, ...
     * @param year 2020, 2019, 2018 ...
     * 
     */
    public function setIntervalMonth($month, $year)
    {
        if (empty($year)) $year = date('Y');
        if (empty($month)) $month =  date('m');

        $from_date = new DateTime("first day of {$year}-{$month}");
        $to_date = clone $from_date;
        $to_date->modify('last day of this month')->modify('+1 day');
        $t = $to_date->getTimestamp() - 1;
        $to_date->setTimestamp($t);

        $this->setFromDate($from_date);
        $this->setToDate($to_date);

        return $this;
    }


    /**
     * @param year 2020, 2019 ...
     * 
     * @return self
     * 
     */
    public function setIntervalYear($year)
    {
        $this->setFromDate(new DateTime("first day of january {$year}"));

        $this->setToDate(new DateTime("last day of december {$year}"));

        return $this;
    }
}
