<?php

namespace WPDM\WPPM\Coupon;

use WPDM\WPPM\Plan\PlanManager;

class CouponManager
{

    /**
     * holds singleton instance of the class
     */
    private static $instance;


    /**
     * get the singleton instance of the class
     */
    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
        }

        return self::$instance;
    }


    /**
     * private constructor of the class
     * so this class cannot be created outside
     * 
     */
    private function __construct()
    {
        add_action('wp_ajax_' . WPPM_AJAX_ACTION_VALIDATE_COUPON_CODE, array($this, 'validateCouponCode'));
    }


    /**
     * 
     * 
     */
    public function renderCouponsPage()
    {
        if (isset($_REQUEST['wppm_coupon_nonce']) && wp_verify_nonce($_REQUEST['wppm_coupon_nonce'])) {
            $coupon = wpdm_query_var('coupon');
            $this->saveCoupon($coupon);
        }

        if (wpdm_query_var('action') === 'DELETE_COUPON') {
            $coupon_id = wpdm_query_var('coupon_id');
            $coupon = Coupon::get($coupon_id);
            if ($coupon) {
                $coupon->delete();
            }
        }

        $args = [
            'coupons' => Coupon::getAll(),
            'plans' => PlanManager::getInstance()->getPlans()
        ];

        $file = __DIR__ . '/coupon-list.php';
        wppm_render_template($file, $args);
    }


    /**
     * 
     * 
     */
    public function saveCoupon($data = [])
    {
        $coupon = new Coupon($data);
        $coupon->save();
    }


    /**
     * 
     * 
     */
    public function renderCouponField()
    {
        $args = [];

        $file = __DIR__ . '/apply-coupon-field.php';
        wppm_render_template($file, $args);
    }


    /**
     * ajax callback
     * 
     */
    public function validateCouponCode()
    {
        $coupon_code = wpdm_query_var('coupon_code');
        $plan_id = wpdm_query_var('plan_id');
        $plan = PlanManager::getInstance()->getPlan($plan_id);

        $coupon = Coupon::getByCode($coupon_code);
        if ($plan && $coupon && $coupon->isApplicableInPlan($plan_id)) {

            $plan->applyCoupon($coupon);
            $coupon->increaseUsageCount();
            
            $message = "Congrats! <strong>  {$coupon->getDiscountText()}  </strong> discount will be applied. <br> 
                New Price: <strong> {$plan->getBillingText()} </strong>" ;

            wp_send_json([
                'message' => $message,
                'is_free' => $plan->isFree()
            ], 200);
            exit;
        }

        wp_send_json(['message' => '<strong class="color-red">Invalid coupon code.</strong>'], 404);
        exit;
    }
}
