<?php

namespace WPDM\WPPM\Email;


use WPDM\__\__;

if (!defined('ABSPATH')) exit;



/**
 * Plan custom post type
 *
 * Used to manage CPT Plan
 *
 */
class EmailCPT
{
    /**
     * holds singleton instance of the class
     */
    private static $instance;

    /**
     * Custom Post type name
     */
    private $post_type = 'wppm_email';

    /**
     * holds Plan Obj
     */
    private $_plan;


    /**
     * Get singleton instance of the class
     *
     */
    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
        }
        return self::$instance;
    }


    /**
     * Constructor
     *
     */
    private function __construct()
    {
        $this->addHooks();
    }


    /**
     * add the necessary hooks
     *
     */
    private function addHooks()
    {
        add_action('init', array($this, 'actionRegisterPostType'));

        add_action("manage_{$this->post_type}_posts_columns", array($this, 'columnsTH'));
        add_action("manage_{$this->post_type}_posts_custom_column", array($this, 'columnsTD'), 10, 2);

        add_action('save_post', array($this, 'savePlan'));
    }


    /**
     * Registers the post type
     *
     */

    public function actionRegisterPostType()
    {
        $labels = array(
            'name'                       => 'Emails',
            'singular_name'              => 'Email',
            'menu_name'                  => 'Emails',
            'all_items'                  => 'All Emails',
            'parent_item'                => 'Parent Email',
            'parent_item_colon'          => 'Parent Email:',
            'new_item_name'              => 'New Email',
            'add_new_item'               => 'Add New Email',
            'edit_item'                  => 'Edit Email',
            'update_item'                => 'Update Email',
            'separate_items_with_commas' => 'Separate Emails with commas',
            'search_items'               => 'Search Emails',
            'add_or_remove_items'        => 'Add or remove Emails',
            'choose_from_most_used'      => 'Choose from the most used Emails',
            'not_found'                  => 'Not Found',
        );


        $args = array(
            //'labels'          => $labels,
            'menu_icon'       => 'dashicons-awards',
            'description'     => 'This post type manages the Plans',
            'public'          => false,
            'register_meta_box_cb' => array($this, 'addMetaboxes'),
            'hierarchical'    => false,
            'exclude_from_search' => false,
            'publicly_queryable' => false,
            'show_ui'         => false,
            'show_in_menu'    => false,
            'supports'        => array('title', 'editor'),
            'query_var'       => false,
            'rewrite'         => false,
            'capability_type' => 'post',
            'can_export'      => true
        );

        register_post_type($this->post_type, $args);
    }

    function adminMenu()
    {
        add_submenu_page("edit.php?post_type=wppm_plan", __('Emails', WPPM_TEXTDOMAIN), __('Emails', WPPM_TEXTDOMAIN), WPDM_ADMIN_CAP, 'wppm-emails', [$this, 'pmAdmin']);
    }

    function columnsTH($defaults) {
        if(get_post_type() != $this->post_type) return $defaults;
        $plan_columns['initial_amount'] = 'Initial Amount';
        $plan_columns['billing_amount'] = "Billing Amount";
        $plan_columns['trail'] = 'Trail';
        $plan_columns['subscribers'] = 'Subscribers';
        __::array_splice_assoc( $defaults, 2, 0, $plan_columns );
        return $defaults;
    }


    function columnsTD($column_name, $post_ID) {

        if(get_post_type() != $this->post_type) return;

        $plan = WPPM()->plan_manager->getPlan($post_ID);

        if ($column_name == 'billing_amount') {
            if($plan->getBillingAmount() > 0)
                echo $plan->getBillingAmount()." / ".$plan->getBillingPeriodCount()." ".$plan->getBillingPeriod();
            else
                _e('Free', WPPM_TEXTDOMAIN);

        }
        if ($column_name == 'initial_amount') {

            echo $plan->getInitialAmount();

        }
        if ($column_name == 'trail') {
            if($plan->hasTrial())
                echo $plan->getTrialAmount()." @ ". $plan->getTrialPeriodCount()." ".$plan->getTrialPeriod();
            else
                echo "<i class='fa fa-times-circle'></i>";

        }
        if ($column_name == 'subscribers') {
            echo $plan->getActiveSubscibersCount();
        }

    }



    /**
     * Add the metaboxes in edit plan
     *
     */
    public function addMetaboxes()
    {
        $metaboxes = $this->getMetaboxes();
        foreach ($metaboxes as $metabox) {
            add_meta_box(
                $metabox['id'],         // Unique ID of meta box
                $metabox['title'],         // Title of meta box
                $metabox['render_callback'],     // Callback function
                $this->post_type,
                $metabox['context'],
                $metabox['priority']
            );
        }
    }


    /**
     * list of the metaboxes to be added
     *
     */
    private function getMetaboxes()
    {
        return [
            [
                'id' => 'wppm-plan-confirmation',
                'title' => 'Confirmation Message',
                'render_callback' => array($this, 'renderMetaboxConfirmation'),
                'context' => 'normal',
                'priority' => 'high'
            ],
            [
                'id' => 'wppm-plan-features',
                'title' => 'Plan Features',
                'render_callback' => array($this, 'renderMetaboxFeatures'),
                'context' => 'normal',
                'priority' => 'high'
            ],
            [
                'id' => 'wppm-plan-billing-details',
                'title' => 'Billing Details',
                'render_callback' => array($this, 'renderMetaboxBillingDetails'),
                'context' => 'side',
                'priority' => 'high'
            ],
            [
                'id' => 'wppm-plan-others',
                'title' => 'Other settings',
                'render_callback' => array($this, 'renderMetaboxOtherSettings'),
                'context' => 'side',
                'priority' => 'low'
            ],
            [
                'id' => 'wppm-payment-systems-plan-info',
                'title' => 'Payment Systems Plan Info',
                'render_callback' => array($this, 'renderMetaboxPaymentSystemsPlanInfo'),
                'context' => 'normal',
                'priority' => 'low'
            ],


        ];
    }


    /**
     * get the plan meta data with defaults merged
     *
     */
    public function getPlanMeta($plan_id)
    {
        $meta = get_post_meta($plan_id) ?: [];
        return $meta;
    }


    /**
     *
     * @return array [WP_Post Object]
     */
    public function getPlanPosts($filters = [])
    {
        $query_args = array(
            'post_parent'    => 0,
            'post_type'      => $this->post_type,
            'post_status'    => 'publish'
        );

        if (isset($filters['ids']) && count($filters['ids']) > 0) {
            $query_args['include'] = $filters['ids'];
        }

        // if limit not set, then fetch all
        $query_args['numberposts'] = isset($filters['limit']) ? intval($filters['limit']) : -1;

        if (isset($filters['meta'])) {
            $query_args['meta_key'] = $filters['meta']['key'];
            $query_args['meta_value'] = $filters['meta']['value'];
        }

        $plans = get_posts($query_args);
        return $plans;
    }


    /**
     * get a plan post
     *
     */
    public function getPlanPost($plan_id)
    {
        return get_post($plan_id);
    }


    /**
     * Save a plan post
     *
     */
    public function savePlan($post_id)
    {
        $is_valid_nonce = false;

        if (isset($_POST[WPPM_PLAN_CPT_NONCE])) {

            if (wp_verify_nonce($_POST[WPPM_PLAN_CPT_NONCE], WPPM_ACTION_PLAN_CPT_NONCE)) {
                $is_valid_nonce = true;
            }
        }

        $is_autosave = wp_is_post_autosave($post_id);
        $is_revision = wp_is_post_revision($post_id);

        if ($is_autosave || $is_revision || !$is_valid_nonce) return;


        //old plan
        $old_plan = $this->getPlan($post_id);

        $metas = wpdm_query_var(WPPM_PLAN_META_DATA, 'html') ?: [];

        foreach ($metas as $key => $value) {
            update_post_meta(
                $post_id,
                WPPM_PLAN_META_PREFIX . $key,
                $value
            );
        }

        $plan = $this->getPlan($post_id, true);
        $plan_comparator = new PlanComparator($plan, $old_plan);

        //pd($plan, $old_plan);
        do_action(WPPM_ACTION_AFTER_PLAN_CPT_SAVE, $plan, $plan_comparator);
    }


    /**
     * Get Plan from mem cache if available
     * For performance
     *
     * @return Plan object
     */
    private function getPlan($post_id, $refresh = false)
    {
        if ($refresh === true || $this->_plan == null) {
            $this->_plan = new Plan(get_post($post_id));
        }

        return $this->_plan;
    }



    // ========================================== RENDERING ==========================================================


    /**
     * Plan Confirmation meta box
     *
     * callback during add_meta_box execution
     *
     */
    public function renderMetaboxConfirmation($post)
    {
        $plan = $this->getPlan($post->ID);
        //pd($post);
        $args = [
            'plan' => $plan
        ];

        wp_nonce_field(WPPM_ACTION_PLAN_CPT_NONCE, WPPM_PLAN_CPT_NONCE);
        $this->renderRelativeTemplate('metaboxes/metabox-plan-confirmation.php', $args);
    }


    /**
     * Plan features meta box
     *
     */
    public function renderMetaboxFeatures($post)
    {
        $plan = $this->getPlan($post->ID);

        $args = [
            'plan' => $plan
        ];

        $this->renderRelativeTemplate('metaboxes/metabox-plan-features.php', $args);
    }


    /**
     * Plan Billing details meta box
     *
     */
    public function renderMetaboxBillingDetails($post)
    {

        $periods = [
            ['id' => 'DAY', 'name' => __('DAY(s)', 'wppromembership')],
            ['id' => 'WEEK', 'name' => __('WEEK(s)', 'wppromembership')],
            ['id' => 'MONTH', 'name' => __('MONTH(s)', 'wppromembership')],
            ['id' => 'YEAR', 'name' => __('YEAR(s)', 'wppromembership')],
        ];

        $plan = $this->getPlan($post->ID);

        $args = [
            'plan' => $plan,
            'billing_periods' => $periods,
            'currency_symbol' => '$' //TODO get it from wppm
        ];

        $this->renderRelativeTemplate('metaboxes/metabox-plan-billing-details.php', $args);
    }


    /**
     * Other settings meta box
     *
     */
    public function renderMetaboxOtherSettings($post)
    {
        $plan = $this->getPlan($post->ID);

        $args = [
            'plan' => $plan,
        ];

        $this->renderRelativeTemplate('metaboxes/metabox-plan-other-settings.php', $args);
    }


    /**
     * Renders Payment Systems Plan info
     *
     */
    public function renderMetaboxPaymentSystemsPlanInfo($post)
    {
        global $wppm;
        $plan = $this->getPlan($post->ID);
        $payment_systems = $wppm->payment_system_manager->getRemotePaymentSystems();

        $args = [
            'plan' => $plan,
            'payment_systems' => $payment_systems
        ];

        $this->renderRelativeTemplate('metaboxes/metabox-payment-systems-plan-info.php', $args);
    }


    /**
     * render a file relative to this file directory
     *
     */
    private function renderRelativeTemplate($file_name, $args)
    {
        $file = plugin_dir_path(__FILE__) . $file_name;
        return wppm_render_template($file, $args);
    }


    // ========================================================== RENDERING END ===================================================


}
