<?php

namespace WPDM\WPPM\Email;

use DateTime;
use Exception;
use W3Eden\WPUtility\WPUtility;
use W3Eden\WPUtility\Email\Email;
use WPDM\__\__MailUI;
use WPDM\WPPM\Subscription\Subscription;

if (!defined('ABSPATH')) exit;


class EmailManager
{
    /**
     * holds singleton instance of the class
     */
    private static $instance;

    /**
     * Get singleton instance of the class
     *
     */
    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
        }
        return self::$instance;
    }


    /**
     * Constructor
     *
     */
    private function __construct()
    {
        $this->addHooks();
    }


    /**
     * add hooks
     */
    public function addHooks()
    {
        add_filter('wputility_filter_add_email_template', array($this, 'addEmailTemplates'));
        add_action('wp_ajax_wppm_email_event_message', array($this, 'emailEventMessage'), 10, 2);
        //add_filter(WPPM_FILTER_REGISTER_GLOBAL_SETTINGS_TAB, array($this, 'registerEmailSettingsTab'));
        add_filter('wpdm_email_templates', array($this, 'addEmailTemplates'));

        //  add_action(WPPM_EVENT_SEND_SUBSCRIPTION_EXPIRATION_REMINDERS, array($this, 'sendSubscriptionExpirationReminders'));
        // add_action('wppm_after_signup', array($this, 'sendSignupNotification'));
        add_action('wppm_user_subscriptions_changed', array($this, 'sendUserSubscriptionsChangedNotification'), 10, 2);
    }


    /**
     * Callback Register General settings tab in global settings page
     *
     */
    public function registerEmailSettingsTab($tabs)
    {
        $tab = [
            'id' => 'email-settings',
            'title' => __('Email Notifications', WPPM_TEXTDOMAIN),
            'callback' => array($this, 'renderEmailSettings'),
            'order' => 2,
            'sub_items' => [
                ''
            ]
        ];

        array_push($tabs, $tab);

        return $tabs;
    }

    /**
     * Render General Settings
     *
     */
    public function renderEmailSettings()
    {


        $general_settings = get_option(WPPM_EMAIL_SETTINGS_KEY);

        $args = [
            'settings' => $general_settings,
            'events' => $this->events()
        ];

        $file = __DIR__ . '/tabs/email-settings.php';
        wppm_render_template($file, $args);
    }

    function emailEventMessage()
    {
        $general_settings = get_option(WPPM_EMAIL_SETTINGS_KEY);
        $args = [
            'settings' => $general_settings,
            'events' => $this->events()
        ];
        $file = __DIR__ . '/tabs/email-template-editor.php';
        wppm_render_template($file, $args);
    }


    /**
     * Save General Settings
     *
     */
    private function saveEmailSettings()
    {
        $general_settings = wpdm_query_var(WPPM_EMAIL_SETTINGS_KEY);
        //pd($general_settings);
        update_option(WPPM_EMAIL_SETTINGS_KEY, stripslashes_deep($general_settings));
        if (wpdm_is_ajax()) {
            wp_send_json(['success' => true,]);
        }
    }


    function saveSettings()
    {
        if (isset($_POST[WPPM_EMAIL_SETTINGS_NONCE]) && wp_verify_nonce($_POST[WPPM_EMAIL_SETTINGS_NONCE])) {
            $this->saveEmailSettings();
        }
    }



    /**
     *
     *
     */
    public function addEmailTemplates($templates)
    {

        $link = WPPM()->account_manager->getAccountPagePermalink();
        $templates['new-subscription'] =  [
            'label'   => __("New Subscription", WPPM_TEXTDOMAIN),
            'for'     => 'subscriber',
            'plugin'  => 'Pro Membership',
            'default' => array(
                'subject'    => __("Thanks for your subscription", WPPM_TEXTDOMAIN),
                'from_name'  => get_option('blogname'),
                'from_email' => get_option('admin_email'),
                'message'    => 'Hello [#display_name#],<br/>Thanks for your subscription.'.__MailUI::panel("Subscription Plan", ["<strong>[#plan#]</strong>"])."<a class='button' style='color: #ffffff;margin-top: 10px' href='$link'>View Details</a>"
            )

        ];

        $templates['subscriptions-changed'] =  [
            'label'   => __("Subscription(s) Changed", WPPM_TEXTDOMAIN),
            'for'     => 'subscriber',
            'plugin'    => 'Pro Membership',
            'default' => array(
                'subject'    => __("WPPM Subscription Changed [#username#]", WPPM_TEXTDOMAIN),
                'from_name'  => get_option('blogname'),
                'from_email' => get_option('admin_email'),
                'message'    => 'Hello [#display_name#], your subscription(s) has changed.<br/>New Subscriptions : [#new_subscriptions#],<br/>Canceled Subscriptions: [#canceled_subscriptions#],<br/>Updated Subscriptions: [#updated_subscriptions#]'
            )

        ];

        $templates['subscription-cancelled'] =  [
            'label'   => __("Subscription Cancellation", WPPM_TEXTDOMAIN),
            'for'     => 'subscriber',
            'plugin'  => 'Pro Membership',
            'default' => array(
                'subject'    => __("Your [#plan#] subscription is cancelled", WPPM_TEXTDOMAIN),
                'from_name'  => get_option('blogname'),
                'from_email' => get_option('admin_email'),
                'message'    => 'Hello [#display_name#], your subscription(s) has changed.<br/>New Subscriptions : [#new_subscriptions#],<br/>Canceled Subscriptions: [#canceled_subscriptions#],<br/>Updated Subscriptions: [#updated_subscriptions#]'
            )

        ];

        return $templates;
    }


    /**
     * handles sending signup notification
     *
     */
    public function sendSignupNotification($data)
    {
        extract($data);
        //$admin_email = get_option('admin_email');

        //To User
        $args = array(
            'to_email' => $data['user_email'],
            'name' => $data['display_name'],
            'first_name' =>  $data['first_name'],
            'last_name' => $data['last_name'],
            'user_email' => $data['user_email'],
            'username' => $data['user_login'],
            'password' => $data['user_pass']
        );
        //pd($args);

        try {
            \WPDM\__\Email::send("user-signup", $args);
        } catch (\Exception $e) {
            wppm_write_log($e->getMessage());
        }
    }


    /**
     * Sends Subscription Will be Expired notification
     *
     */
    public function sendSubscriptionExpirationReminders()
    {
        $subscriptions = Subscription::getByExpiresAfterDays(7);
        $today = new DateTime();

        foreach ($subscriptions as $subscription) {
            $notified_at = $subscription->getExpirationNotifiedAt();
            $user = $subscription->getUser();

            if ($user && ($notified_at == null || $notified_at->format('Y-m-d') != $today->format('Y-m-d'))) {

                $args = [
                    'to_email' => $user->user_email,
                    'name' => $user->display_name
                ];
                //send email
                wppm_write_log($user->user_email);
                //save the renewal notified time
                $domain = parse_url(home_url('/'));
                $message = " Hello,<br/>Thanks for your continued support<br/>.We're sending this message to remind you that, as your subscription will be renewed automatically on " . $subscription->getFormattedExpiresDate();
                $params = array(
                    'subject' => sprintf(__("[%s] Subscription Reminder"), get_bloginfo('name'), WPPM_TEXTDOMAIN),
                    'to_email' => $user->user_email,
                    'from_name' => get_bloginfo('name'),
                    'from_email' => 'noreply@' . $domain['host'],
                    'message' => $message
                );

                try {

                    \WPDM\__\Email::send("default", $params);
                    $subscription->setExpirationNotifiedAt($today->getTimestamp())
                        ->save();
                } catch (Exception $e) {
                    wppm_write_log($e->getMessage());
                }
            }
        }
    }


    /**
     *
     *
     */
    public function sendUserSubscriptionsChangedNotification($user, $data)
    {
        $new_subs = [];
        $canceled_subs = [];
        $updated_subs = [];

        foreach ($data['canceled'] as $s) {
            if($s->getPlan())
                $canceled_subs[] = $s->getPlan()->getName();
        }
        $canceled_subs = count($canceled_subs) > 0 ? implode(", ", $canceled_subs) : 'None';

        foreach ($data['updated'] as $s) {
            if($s->getPlan())
                $updated_subs[] = $s->getPlan()->getName();
        }
        $updated_subs = count($updated_subs) > 0 ? implode(", ", $updated_subs) : 'None';

        foreach ($data['new'] as $s) {
            if($s->getPlan())
                $new_subs[] = $s->getPlan()->getName();
        }
        $new_subs = count($new_subs) > 0 ? implode(", ", $new_subs) : 'None';


        $params = [
            'to_email' => $user->user_email,
            'display_name' => $user->display_name,
            'new_subscriptions' => $new_subs,
            'canceled_subscriptions' => $canceled_subs,
            'updated_subscriptions' => $updated_subs
        ];

        try {
            \WPDM\__\Email::send("subscriptions-changed", $params);
        } catch (Exception $e) {
            wppm_write_log($e->getMessage());
        }
    }

    public function events()
    {
        $events = [
            'new-subscription-notification' => 'New Subscription Notification',
            'subscription-update-notification' => 'Subscription Update Notification',
            'subscription-cancellation-notification' => 'Subscription Cancellation Notification',
        ];
        $events = apply_filters("wppm_email_event", $events);
        return $events;
    }
}
