<?php

namespace WPDM\WPPM\Payment\Free;

use WPDM\WPPM\Payment\PaymentSystem;
use WPDM\WPPM\Plan\Plan;
use WPDM\WPPM\Subscription\Subscription;

if (!defined('ABSPATH')) exit;



/**
 * This payment system is used to pay the Free plan payment
 * 
 * 
 */
class FreePaymentSystem extends PaymentSystem
{
    /**
     * holds singleton instance of the class
     */
    private static $instance;

    /**
     * payment system id
     */
    public $payment_system_id = "free";

    /**
     * payment system name
     */
    public $payment_system_name = "Free Payment";

    /**
     * Get singleton instance of the class
     * 
     */
    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
        }
        return self::$instance;
    }


    /**
     * Constructor 
     * 
     */
    protected function __construct()
    {
        parent::__construct();
    }


    /**
     * 
     * @return true
     */
    public function isFree()
    {
        return true;
    }


    /**
     * Should the payment system show in settings
     * 
     * @return boolean
     */
    public function showInSettings()
    {
        return false;
    }


    /**
     * Render payment interface
     * 
     */
    function renderPaymentInterface(Plan $plan)
    {
        //if plan is not free then return
        if (!$plan->isFree()) {
            die('Not a free Plan');
        }

        $args = [
            'plan' => $plan,
            'payment_system_id' => $this->getPaymentSystemId()
        ];

        $file = __DIR__ . '/payment-interface.php';
        wppm_render_template($file, $args);
    }


    /**
     * Renders settings in global payment settings
     * 
     */
    public function renderSettings()
    {
        echo 'No Settings.';
    }


    public function processSubscription(Subscription $subscription)
    {
        $subscription->setPaymentSystemSubscriptionId("free_sub_" . generate_random_string(8));
        $subscription->setExpiresAt(0); // Eever expires
        $subscription->setSubscriptionStatusActive();

        return $subscription->save();
    }
}
