<?php

namespace WPDM\WPPM\Payment\PayPal;


use WPDM\WPPM\Payment\WebhookHandler;
use WPDM\WPPM\Subscription\Subscription;

class PayPalWebhookHandler extends WebhookHandler
{


    public function __construct(PayPalPaymentSystem &$paypal)
    {
        $this->payment_system = &$paypal;
    }


    /**
     * Handle the payload sent by the paypal
     * 
     */
    public function handle($payload)
    {
        if (key_exists($payload, "event_type")) {
            $event_type = $payload['event_type'];
            $event_version = $payload['event_version'];

            $resource = $payload['resource'];
            $resource_version = $payload['resource_version'];

            switch ($event_type) {
                case 'BILLING.SUBSCRIPTION.CANCELLED':
                    $this->handleSubscriptionCancelled($resource, $resource_version);
                    break;
            }
        }
    }


    /**
     * Handle subscription Cancelled event
     * 
     */
    private function handleSubscriptionCancelled($resource, $resource_version)
    {
        $subscription_id = $resource['id'];

        if ($resource_version && $resource_version == "2.0") {
            $status = $resource['status'];
        } else {
            $status = $resource['state'];
        }

        $wppm_subscription = Subscription::getByPaymentSystemSubscriptionId($subscription_id);
        if ($wppm_subscription) {
            $wppm_subscription->setSubscriptionStatusCanceled()
                ->setPaymentSystemSubscriptionData($resource)
                ->setExpiresAt(null);
            $wppm_subscription->save();

            wp_send_json(['status' => 'success', 'message' => 'Canceled']);
        } else {
            wp_send_json(['status' => 'failed', 'message' => 'no wppm subscription found.']);
        }
    }
}
