<?php

namespace WPDM\WPPM\Payment\PayPal;

use Exception;
use Ohanspace\PayPalPHPSdk\Models\EventType;
use Ohanspace\PayPalPHPSdk\Models\Patch;
use Ohanspace\PayPalPHPSdk\Models\Webhook;
use Ohanspace\PayPalPHPSdk\Webhooks\WebhooksCreateRequest;
use Ohanspace\PayPalPHPSdk\Webhooks\WebhooksDetailsRequest;
use Ohanspace\PayPalPHPSdk\Webhooks\WebhooksPatchRequest;
use WPDM\WPPM\Payment\WebhookManager;

class PayPalWebhookManager extends WebhookManager
{
    private $_events = [
        ['name' => 'PAYMENT.SALE.COMPLETED'],
        ['name' => 'BILLING.SUBSCRIPTION.CANCELLED'],
        ['name' => 'BILLING.SUBSCRIPTION.SUSPENDED'],
        ['name' => 'BILLING.SUBSCRIPTION.EXPIRED']
    ];


    /**
     * create webhook
     * 
     * @return Webhook
     */
    protected function createWebhook($url)
    {
        $webhook = new Webhook();
        $webhook->setUrl($url);
        foreach ($this->_events as $event) {
            $webhook->addEventType(new EventType($event));
        }

        $request = new WebhooksCreateRequest();
        $request->body = $webhook->toArray();

        $response = $this->payment_system->getClient()->execute($request);

        return $response->result;
    }


    /**
     * Update webhook
     * 
     * @return Webhook
     */
    protected function updateWebhook($webhook_id, $url)
    {
        $url_patch = new Patch();
        $url_patch->setOp("replace")
            ->setPath("/url")
            ->setValue($url);

        $event_types_patch = new Patch();
        $event_types_patch->setOp('replace')
            ->setPath('/event_types')
            ->setValue($this->_events);

        $request = new WebhooksPatchRequest($webhook_id);
        $request->body = [
            $url_patch->toArray(),
            $event_types_patch->toArray()
        ];

        $response = $this->payment_system->getClient()->execute($request);

        return $response->result;
    }


    /**
     * Check if a webhook is already exists in the payment system server
     * 
     * @return boolean
     */
    protected function webhookExists($webhook_id)
    {
        if (empty($webhook_id)) return false;

        try {
            $request = new WebhooksDetailsRequest($webhook_id);
            $this->payment_system->getClient()->execute($request);
            return true;
        } catch (Exception $e) {
            return false;
        }
    }
}
