<?php

namespace WPDM\WPPM\Payment;

use Exception;
use WPDM\WPPM\Plan\Plan;
use WPDM\WPPM\Plan\PlanComparator;

abstract class RemotePaymentSystem extends PaymentSystem
{

    /**
     *
     */
    protected $client;


    /**
     *
     *
     */
    abstract function initClient();

    /**
     *
     * @return boolean
     */
    abstract function apiConnected();

    /**
     *
     *
     */
    abstract protected function createPlan(Plan $wppm_plan);

    /**
     *
     *
     */
    //abstract protected function updatePlan(string $payment_system_plan_id, Plan $wppm_plan, PlanComparator $plan_comparator);

    /**
     *
     *
     */
    abstract function getWebhookManager();


    /**
     *
     *
     */
    abstract function getWebhookHandler();


    /**
     *
     *
     */
    abstract function getSubscriptionDetails($subscription_id);

    /**
     *
     *
     */
    public function getClient()
    {
        return $this->client;
    }


    /**
     *
     *
     */
    public function saveSettings($settings)
    {
        $mode = wpdm_valueof($settings, 'mode');
        $enabled = wpdm_valueof($settings, 'enabled');

        $webhook_settings = wpdm_valueof($settings, $mode . '/webhook');

        if ($enabled && $webhook_settings != null) {

            $webhook_url_old = $this->getSettingValueFromCurrentMode('webhook/url');

            if ($this->client == null) {
                $this->setSettings($settings);
                $this->initClient();
            }


            $home_url = wppm_is_localhost() ? "https://example2.com/" : get_home_url();

            $webhook_settings['url']  = $webhook_url = add_query_arg([
                'wppm_task' => 'PAYMENT_SYSTEM_WEBHOOK',
                'payment_system_id' => $this->getPaymentSystemId()
            ], $home_url);


            $webhook_id = wpdm_valueof($webhook_settings, 'id');
            $force_update =  wpdm_valueof($settings, 'force_update_webhook');

            if (empty($webhook_id) || ($webhook_url != $webhook_url_old) || $force_update) {
                try {
                    $webhook_settings = $this->getWebhookManager()->saveWebhook($webhook_settings, $force_update);
                    $settings[$mode]['webhook'] = $webhook_settings;
                } catch (Exception $e) {
                    wppm_write_log($e->getMessage());
                }
            }
        }

        parent::saveSettings($settings);
    }


    /**
     * Get or create Payment System Plan Id
     *
     * @return string
     */
    public function getOrCreatePlanId(Plan $plan)
    {
        if ($plan->isCouponApplied()) {
            return $this->createPlan($plan);
        }

        $payment_system_plan_id = $plan->getPlanIdOfPaymentSystem($this->getPaymentSystemId());
        if (empty($payment_system_plan_id)) {
            $payment_system_plan_id = $this->savePlan($plan);
        }

        return $payment_system_plan_id;
    }


    /**
     * Save plan
     *
     * @return string payment system plan id
     */
    public function savePlan(Plan $wppm_plan, PlanComparator $plan_comparator = null)
    {
        $payment_system_plan_id =  $wppm_plan->getPlanIdOfPaymentSystem($this->getPaymentSystemId());

        if (!empty($payment_system_plan_id) && $plan_comparator && $plan_comparator->pricingSchemesChanged()) {
            //update existing plan
            $payment_system_plan_id =  $this->updatePlan($payment_system_plan_id, $wppm_plan, $plan_comparator);
            return $payment_system_plan_id;
        } else {

            if ($wppm_plan->hasRecurringBill()) {

                //create new plan
                $payment_system_plan_id = $this->createPlan($wppm_plan);

                $wppm_plan->savePlanIdOfPaymentSystem($this->getPaymentSystemId(), $payment_system_plan_id);
                return $payment_system_plan_id;
            }
        }
    }
}
