<?php

namespace WPDM\WPPM\Payment\Stripe;

use WPDM\WPPM\Invoice\Invoice;
use WPDM\WPPM\Payment\WebhookHandler;
use WPDM\WPPM\Subscription\Subscription;

class StripeWebhookHandler extends WebhookHandler
{
    /**
     * Constructor
     * 
     */
    public function __construct(StripePaymentSystem &$payment_system)
    {
        $this->payment_system = &$payment_system;
    }


    /**
     * handle stripe event payload
     * 
     */
    public function handle($payload)
    {

        $event = \Stripe\Event::constructFrom($payload);

        // Handle the event
        switch ($event->type) {
            case 'invoice.paid':
                $invoice = $event->data->object;
                $this->handleInvoicePaidEvent($invoice);
                break;
            default:
                // Unexpected event type
                http_response_code(400);
                exit();
        }
    }


    /**
     * handle invoice paid event
     * 
     */
    private function handleInvoicePaidEvent($stripe_invoice)
    {
        $stripe_subscription_id = $stripe_invoice->subscription;

        $subscription = Subscription::getByPaymentSystemSubscriptionId($stripe_subscription_id);

        if ($subscription) {
            $subscription->fetchPaymentSystemSubscriptionData()
                ->setSubscriptionStatusActive()
                ->save();

            //add the invoice
            $invoice = new Invoice(); //wppm invoice
            $invoice->setSubscriptionId($subscription->getId())
                ->setPaymentSystemId($this->payment_system->getPaymentSystemId())
                ->setPaymentSystemInvoiceId($stripe_invoice->id)
                ->setPaymentSystemInvoiceData($stripe_invoice)
                ->setAmount($invoice->getParser()->getAmount()) //TODO move it to setPaymentSystemInvoiceData function
                ->setCurrencyCode($invoice->getParser()->getCurrencyCode()); //TODO move it to setPaymentSystemInvoiceData function

            $invoice->save();
        }
    }
}
