<?php

namespace WPDM\WPPM\Payment\Stripe;

use Exception;
use WPDM\WPPM\Payment\WebhookManager;

class StripeWebhookManager extends WebhookManager
{
    private $_events = [
        'invoice.paid',
        'customer.subscription.trial_will_end'
    ];


    /**
     * create webhook
     * 
     * @return Webhook
     */
    protected function createWebhook($url)
    {
        $response = $this->payment_system->getClient()->webhookEndpoints->create([
            'url' => $url,
            'enabled_events' => $this->_events,
        ]);

        return $response;
    }


    /**
     * Update webhook
     * 
     * @return Webhook
     */
    protected function updateWebhook($webhook_id, $url)
    {
        $response = $this->payment_system->getClient()->webhookEndpoints->update(
            $webhook_id,
            ['url' => $url, 'enabled_events' => $this->_events]
        );

        return $response;
    }


    /**
     * Check if a webhook is already exists in the payment system server
     * 
     * @return boolean
     */
    protected function webhookExists($webhook_id)
    {
        try {
            $webhook = $this->payment_system->getClient()->webhookEndpoints->retrieve($webhook_id, []);
            return true;
        } catch (Exception $e) {
            return false;
        }
        return false;
    }
}
