<?php

namespace WPDM\WPPM\Payment\TestPay;

if (!defined('ABSPATH')) exit;


use WPDM\WPPM\Payment\PaymentSystem;
use WPDM\WPPM\Plan\Plan;
use WPDM\WPPM\Subscription\Subscription;



class TestPayPaymentSystem extends PaymentSystem
{
    /**
     * payment system id
     */
    public $payment_system_id = "testpay";

    /**
     * payment system name
     */
    public $payment_system_name = "Test Pay";

    /**
     * holds singleton instance of the class
     */
    private static $instance;


    /**
     * Get singleton instance of the class
     * 
     */
    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
        }
        return self::$instance;
    }


    /**
     * Constructor 
     * 
     */
    protected function __construct()
    {
        parent::__construct();

        $this->addHooks();
    }


    /**
     * add hooks
     * 
     */
    public function addHooks()
    {

    }


    /**
     * Render settings in global payment settings page
     * 
     */
    public function renderSettings()
    {
        $args = [];
        $file = __DIR__ . '/settings.php';
        return wppm_render_template($file, $args);
    }


    /**
     * Renders the payment interface
     * 
     */
    public function renderPaymentInterface(Plan $plan)
    {

        $args = [
            'payment_system_id' => $this->getPaymentSystemId(),
            'plan' => $plan
        ];


        $file = __DIR__ . '/payment-interface.php';

        return wppm_render_template($file, $args);
    }



    public function processSubscription(Subscription $subscription)
    {
        $subscription->setPaymentSystemSubscriptionId("testpay_sub_" . generate_random_string(8));
        $subscription->setExpiresAt(strtotime('+1 month'));
        $subscription->setSubscriptionStatusActive();

        return $subscription->save();
    }

}
