<?php

namespace WPDM\WPPM\Payment;

use Exception;

if (!defined('ABSPATH')) exit;


/**
 * Payment Systems Webhook Listener
 *
 *
 */
class WebhookListener
{

    /**
     * holds singleton instance of the class
     */
    private static $instance;


    /**
     * Get singleton instance of the class
     *
     */
    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
        }
        return self::$instance;
    }


    /**
     * Constructor
     *
     */
    private function __construct()
    {
        $this->addHooks();
    }


    /**
     * add hooks
     *
     */
    private function addHooks()
    {
        add_action('init', array($this, 'listen'));
    }


    /**
     * Callback
     * 
     */
    public function listen()
    {
        $wppm_task = wpdm_query_var('wppm_task');
        if ($wppm_task && $wppm_task === 'PAYMENT_SYSTEM_WEBHOOK') {

            $payment_system_id = wpdm_query_var('payment_system_id');
            $payload = file_get_contents('php://input');
            $payload = json_decode($payload, true);

            try {
                $payment_system = WPPM()->payment_system_manager->getPaymentSystem($payment_system_id);
                $payment_system->getWebhookHandler()->handle($payload);
                http_response_code(200);
            } catch (Exception $e) {
                wp_send_json(['status' => 'failed', 'message' => $e->getMessage()], 400);
            }

            exit();
        }
    }
}
