<?php

namespace WPDM\WPPM\Stats;

use WPDM\WPPM\Invoice\InvoiceFilter;
use WPDM\WPPM\Invoice\InvoiceManager;
use WPDM\WPPM\Plan\PlanManager;
use WPDM\WPPM\Subscription\SubscriptionFilter;
use WPDM\WPPM\Subscription\SubscriptionManager;

if (!defined('ABSPATH')) exit;


class StatsManager
{

    /**
     * holds singleton instance of the class
     */
    private static $instance;


    /**
     * get the singleton instance of the class
     */
    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
        }

        return self::$instance;
    }


    /**
     * private constructor of the class
     * so this class cannot be created outside
     *
     */
    private function __construct()
    {
        $this->addHooks();
    }


    /**
     * Add necessary hooks
     *
     */
    public function addHooks()
    {
    }


    /**
     * 
     * 
     */
    public function renderStatsPage()
    {
        $filters = wpdm_query_var('filters', ['default' => []]);

        $default_filters = [
            'period' => 'MONTH',
            'stats_type' => 'SUBSCRIPTIONS',
            'month' => date('m'),
            'year' => date('Y'),
            'plan_id' => null
        ];

        $filters = wp_parse_args($filters, $default_filters);

        //p($filters);

        $sub_manager = SubscriptionManager::getInstance();
        $invoice_manager = InvoiceManager::getInstance();

        $months = wppm_get_all_months();
        $filter = new SubscriptionFilter();
        $filter->setPlanId($filters['plan_id']);

        $chart_columns = [];
        $chart_data = [];


        if ($filters['period'] == 'YEAR') {
            $chart_columns = [
                ['label' => 'Months', 'type' => 'string'],
                ['label' => 'Subscriptions', 'type' => 'number'],
                ['label' => 'Canceled', 'type' => 'number']
            ];

            $filter->setIntervalYear($filters['year']);
            $monthly_subscriptions = $sub_manager->countMonthlySubscriptions($filter);

            $filter->setSubscriptionStatus('CANCELED');
            $monthly_cancellations = $sub_manager->countMonthlySubscriptions($filter);

            foreach ($months as $i => $month) {
                array_push($chart_data, [
                    $month['name'],
                    $monthly_subscriptions[$i],
                    $monthly_cancellations[$i]
                ]);
            }
        }



        if ($filters['period'] == 'MONTH') {
            $chart_columns = [
                ['label' => 'Days', 'type' => 'number'],
                ['label' => 'subscriptions', 'type' => 'number'],
                ['label' => 'canceled', 'type' => 'number'],

            ];

            $filter->setIntervalMonth($filters['month'], $filters['year']);
            $daily_subs = $sub_manager->countDailySubscriptions($filter);

            $filter->setSubscriptionStatus('CANCELED');
            $daily_canceled = $sub_manager->countDailySubscriptions($filter);
            
            foreach ($daily_subs as $day => $sub_count) {
                array_push($chart_data, [
                    (int) $day,
                    $sub_count,
                    wpdm_valueof($daily_canceled, $day)
                ]);
            }
        }



        $args = [
            'count_all_subscriptions' => $sub_manager->countSubscriptions(),
            'count_active_subscriptions' => $sub_manager->countActiveSubscriptions(),
            'cancellation_rate' => $sub_manager->getCancellationRate(),
            'sum_revenue_this_month' => $invoice_manager->sumAmount((new InvoiceFilter())->setInterval('THIS_MONTH')),
            'sum_revenue_this_year' => $invoice_manager->sumAmount((new InvoiceFilter())->setInterval('THIS_YEAR')),
            'chart_columns' => $chart_columns,
            'chart_data' => $chart_data,
            'months' => $months,
            'plans' => PlanManager::getInstance()->getPlans(),
            'filters' => $filters
        ];

        $file = __DIR__ . '/stats.php';
        wppm_render_template($file, $args);
    }


    /**
     * 
     * 
     */
    public function renderSubscriptionsCancellationTable()
    {
        $args = [];

        $file = __DIR__ . '/subscriptions-cancellations-table.php';
        echo wppm_render_template($file, $args, false);
    }


    /**
     * 
     * 
     */
    public function renderSubscriptionsRevenueTable()
    {
        $args = [];

        $file = __DIR__ . '/subscriptions-revenue-table.php';
        echo wppm_render_template($file, $args, false);
    }
}
