<?php


namespace WPDM\WPPM\Subscription;

use WPDM\__\UI;
use WPDM\WPPM\Access\AccessManager;
use WPDM\WPPM\Plan\PlanManager;
use WPDMPP\WPDMPremiumPackage;

class AccessControl
{
    /**
     * holds singleton instance of the class
     */
    private static $instance;

    /**
     * get the singleton instance of the class
     */
    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
        }

        return self::$instance;
    }

    private function __construct()
    {
        $this->hooks();
    }

    function hooks()
    {
        add_filter("wdm_before_fetch_template", [$this, 'downloadLink'], 999999, 3);
    }

    function isSubscriptionRequired($ID)
    {

    }

    function downloadLink($package, $template, $type)
    {
        global $current_user;
        $plans = array_intersect( WPPM()->role_manager->getRoleIds(), $current_user->roles );
        $package_access = is_array(wpdm_valueof($package, 'access')) ? wpdm_valueof($package, 'access') : [];
        $plans = array_intersect($plans, $package_access);
        $allowed = count($plans);
        $premium = (function_exists('WPDMPP') && WPDMPremiumPackage::isPremium($package['ID']));
        $package['wppm_download_link'] = '';
        if(!$premium) {
            if (!WPDM()->package->userHasAccess(get_current_user_id(), $package['ID'])) {
                if($type === 'page') {
                    $message = is_user_logged_in() ? WPPM()->settings_manager->getGeneralSettingValue('nonmembertext') : WPPM()->settings_manager->getGeneralSettingValue('notloggedintext');
                    $footer = "";

                    if (!is_user_logged_in()) {
                        $login_link = WPDM()->user->login->modalLoginFormBtn();
                        $login_link = $login_link ?: "<a href='" . WPPM()->account_manager->getAccountPagePermalink($_SERVER['REQUEST_URI']) . "'>" . esc_attr__('Login', WPPM_TEXTDOMAIN) . "</a>";
                        $footer = "<strong>" . esc_attr__('Already Subscribed?', WPPM_TEXTDOMAIN) . " " . $login_link . "</strong>";
                    }
                    $message = str_replace("!!levels!!", AccessManager::getInstance()->getAccessiblePlanLinks($package['ID'], "btn btn-danger btn-sm pl-2 pr-2 pt-0 pb-0", " or "), $message);
                    $message = [$message];
                    $message = UI::card(esc_attr__('', WPPM_TEXTDOMAIN), $message, $footer, ['class' => 'text-center', 'style' => 'margin: 0 auto;line-height: 1.8;']);
                    $package['download_link'] = $package['download_link_extended'] = $message;
                } else {
                    $plan_page = PlanManager::getInstance()->getPlansPage();
                    $login_link = WPDM()->user->login->modalLoginFormBtn(['class' => 'btn btn-danger', 'label' => esc_attr__( 'Login To Download', WPPM_TEXTDOMAIN )]);
                    $login_link = $login_link ?: "<a class='btn btn-danger' href='" . WPPM()->account_manager->getAccountPagePermalink($_SERVER['REQUEST_URI']) . "'>" . esc_attr__('Login', WPPM_TEXTDOMAIN) . "</a>";
                    $full_message = is_user_logged_in() ? WPPM()->settings_manager->getGeneralSettingValue('nonmembertext') : WPPM()->settings_manager->getGeneralSettingValue('notloggedintext');
                    $full_message = str_replace("!!levels!!", AccessManager::getInstance()->getAccessiblePlanLinks($package['ID'], "", " or "), $full_message);
                    $full_message = strip_tags($full_message);
                    $message = is_user_logged_in() ? "<a title='{$full_message}' href='{$plan_page}' class='btn btn-danger ttip'>".esc_attr__( 'Subscribe To Download', WPPM_TEXTDOMAIN )."</a>" : $login_link;
                    $package['download_link'] = $package['download_link_extended'] = $message;
                }
            }
        }
        if ($premium && $allowed)
            $package['wppm_download_link'] = "<a class='btn btn-success' href='".home_url("/?wppmdl=" . $package['ID'])."'>".esc_attr__( 'Download', 'download-manager' )."</a>";
        return $package;
    }

}
