<?php

namespace WPDM\WPPM\User;

use WP_User;
use WPDM\WPPM\Subscription\Subscription;

if (!defined('ABSPATH')) exit;



class UserManager
{

    /**
     * holds singleton instance of the class
     */
    private static $instance;


    /**
     * private constructor of the class
     * so this class cannot be created outside
     * 
     */
    private function __construct()
    {
        $this->loadDependencies();
        $this->addHooks();
    }


    /**
     * Load dependency files
     * 
     */
    private function loadDependencies()
    {
    }


    /**
     * add hooks
     */
    public function addHooks()
    {
        add_filter('manage_users_columns', array($this, 'addUserColumns'));
        add_filter('manage_users_custom_column', array($this, 'addUserColumnData'), 9999, 3);
    }


    /**
     * get the singleton instance of the class
     */
    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self;
        }

        return self::$instance;
    }


    /**
     * 
     * 
     */
    public function addUserColumns($column)
    {
        $column['wppm_account_url'] = 'Membership Account';
        return $column;
    }


    /**
     * 
     * 
     */
    public function addUserColumnData($output, $column_name, $user_id)
    {
        switch ($column_name) {
            case 'wppm_account_url':
                $account_url = add_query_arg([
                    'post_type' => 'wppm_plan',
                    'page' => 'wppm_account',
                    'user_id' => $user_id
                ],  admin_url('/edit.php'));
                return "<a href='{$account_url}'>Manage Subscription</a>";
            default:
        }
        
        return $output;
    }

    /**
     * Get user's download limit
     * @return int
     */
    public function downloadLimit(){
        global $current_user;
        if(!function_exists('wpdm_dd_check_user_download')) return 0;
        $download_limits = get_option('_wpdm_global_role_limit',array());
        $download_limit = 0;
        foreach ($current_user->roles as $role){
            $download_limit += (int)$download_limits[$role];
        }
        return $download_limit;
    }

    /**
     * Get user's downloads count
     * @param null $ID
     * @return int
     */
    public function downloadCount($ID = null){
        $ID = $ID?$ID:get_current_user_id();
        $user_download_count = (int)get_user_meta($ID, 'wpdm_dd_user_dlc', true);
        return $user_download_count;
    }

    /**
     * Reset user's download limit
     * @param null $ID
     * @param null $plan
     */
    public function resetDownloadLimit($ID = null, $plan = null){
        $ID = $ID?$ID:get_current_user_id();
        if(!$plan)
            update_user_meta($ID, 'wpdm_dd_user_dlc', 0);
        if($plan){
            $download_limits = get_option('_wpdm_global_role_limit',array());
            $count = $this->downloadCount();
            $plan_limit = $download_limits[$plan];
            if($count <= $plan_limit)
                update_user_meta($ID, 'wpdm_dd_user_dlc', 0);
            else {
                $count = $count - $plan_limit;
                update_user_meta($ID, 'wpdm_dd_user_dlc', $count);
            }

        }
    }
}
