<?php

/**
 * Prints a given file template with extracting args
 *
 */
if (!function_exists('wppm_render_template')) {

    function wppm_render_template($file, $args = [], $echo = true)
    {
        if (!file_exists($file)) {
            return $file . ' Does not exists';
        }
        // Make values in the associative array easier to access by extracting them
        if (is_array($args)) {
            extract($args);
        }
        // buffer the output (including the file is "output")
        ob_start();
        include $file;
        $data =  ob_get_clean();
        if (!$echo) return $data;
        echo $data;
    }
}


/**
 * Pretty print
 */
if (!function_exists('p')) {
    function p()
    {

        $numargs = func_num_args();
        $arg_list = func_get_args();
        echo '<pre>';

        for ($i = 0; $i < $numargs; $i++) {
            print_r($arg_list[$i]);
        }
        echo '</pre>';
    }
}


/**
 * Pretty print and die
 */
if (!function_exists('pd')) {
    function pd()
    {
        $numargs = func_num_args();
        $arg_list = func_get_args();
        echo '<pre>';

        for ($i = 0; $i < $numargs; $i++) {
            print_r($arg_list[$i]);
        }
        echo '</pre>';
        die();
    }
}


/**
 * pretty var dump
 */
if (!function_exists('vd')) {
    function vd()
    {

        $numargs = func_num_args();
        $arg_list = func_get_args();
        echo '<pre>';

        for ($i = 0; $i < $numargs; $i++) {
            var_dump($arg_list[$i]);
        }
        echo '</pre>';
    }
}


/**
 * pretty var dump and die
 */
if (!function_exists('vdd')) {
    function vdd()
    {
        $numargs = func_num_args();
        $arg_list = func_get_args();
        echo '<pre>';

        for ($i = 0; $i < $numargs; $i++) {
            var_dump($arg_list[$i]);
        }
        echo '</pre>';
        die();
    }
}

/**
 * Generate random strings of given length
 *
 */
if (!function_exists('generate_random_string')) {
    function generate_random_string($length = 10)
    {
        $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }
        return $randomString;
    }
}


/**
 *
 *
 */
if (!function_exists('maybe_json_encode')) {
    function maybe_json_encode($var)
    {
        if ($var !== null && gettype($var) != 'string') {
            return json_encode($var);
        }
        return $var;
    }
}


/**
 *
 *
 */
if (!function_exists('maybe_json_decode')) {
    function maybe_json_decode($var, $as_array = false)
    {
        if (gettype($var) == 'string') {
            return json_decode($var, $as_array);
        }
        return $var;
    }
}


if (!function_exists('wppm_write_log')) {

    function wppm_write_log($log)
    {
        if (true === WP_DEBUG) {
            if (is_array($log) || is_object($log)) {
                error_log(print_r($log, true));
            } else {
                error_log($log);
            }
        }
    }
}


/**
 * 
 * @return boolean
 */
if (!function_exists('wppm_is_localhost')) {
    function wppm_is_localhost()
    {
        $local = array('127.0.0.1', '::1');

        if (in_array($_SERVER['REMOTE_ADDR'], $local)) {
            return true;
        }
        return false;
    }
}


/**
 * 
 * @return DateTime|NULL
 */
if (!function_exists('wppm_get_date_time')) {
    function wppm_get_date_time($dt)
    {
        $timestamp = null;

        if ($dt) {
            if (is_numeric($dt)) {
                $timestamp = $dt;
            } elseif (is_string($dt)) {
                $timestamp = strtotime($dt);
            }

            if ($timestamp) {
                return (new DateTime())->setTimestamp($timestamp);
            }
        }

        return NULL;
    }
}


/**
 * 
 * @return string
 */
if (!function_exists('wppm_get_formatted_datetime')) {
    function wppm_get_formatted_datetime($datetime)
    {
        if ($datetime instanceof DateTime) {
            return wp_date(get_option('date_format'), $datetime->getTimestamp());
        }
    }
}


/**
 * 
 * @return array ['January', 'February', ...];
 */
if (!function_exists('wppm_get_all_month_names')) {
    function wppm_get_all_month_names()
    {
        $months = [];
        for ($m = 1; $m <= 12; $m++) {
            $month = date('F', mktime(0, 0, 0, $m, 1, date('Y')));
            $months[] = $month;
        }

        return $months;
    }
}


/**
 * 
 * @return array ['January', 'February', ...];
 */
if (!function_exists('wppm_get_all_months')) {
    function wppm_get_all_months()
    {
        $months = [];
        for ($m = 1; $m <= 12; $m++) {
            array_push($months, [
                'value' => sprintf("%02d", $m),
                'name' => date('F', mktime(0, 0, 0, $m, 1, date('Y')))
            ]);
        }

        return $months;
    }
}

if (!function_exists('wppm_currency_code')) {
    function wppm_currency_code()
    {
        return function_exists('wpdmpp_currency_code') ? wpdmpp_currency_code() : 'USD';
    }
}


/**
 * @usage template file path
 * 
 * @return string
 */
function wppm_tpl_path($file, $fallback = '')
{
    $path = get_stylesheet_directory() . '/wppromembership/' . $file;

    if (file_exists($path)) return $path;

    $path = get_template_directory() . '/wppromembership/' . $file;

    if (file_exists($path)) return $path;

    return  $path = $fallback . "/" . $file;
}
